import { Suspense } from "react"
import { Skeleton } from "@/components/ui/skeleton"

async function getBasicPage() {
  const url = `${process.env.NEXT_PUBLIC_DRUPAL_BASE_URL}/jsonapi/node/page/8b53db13-613e-45c4-80d7-dc81eba75f11`
  console.log('Fetching from URL:', url)
  
  try {
    const res = await fetch(url, {
      next: { revalidate: 60 },
      headers: {
        'Accept': 'application/vnd.api+json',
      }
    })
    
    if (!res.ok) {
      const errorText = await res.text()
      console.error('Response not OK:', {
        status: res.status,
        statusText: res.statusText,
        body: errorText
      })
      throw new Error(`Failed to fetch basic page: ${res.status} ${res.statusText}`)
    }
    
    return res.json()
  } catch (error) {
    console.error('Fetch error:', error)
    throw error
  }
}

export default async function HomePage() {
  try {
    const basicPage = await getBasicPage()
    const { title, body } = basicPage.data.attributes

    return (
      <main className="container mx-auto py-8 px-4">
        <h1 className="text-3xl font-bold mb-8">{title}</h1>
        <div className="prose max-w-none" dangerouslySetInnerHTML={{ __html: body.value }} />
      </main>
    )
  } catch (error) {
    console.error('HomePage error:', error)
    return (
      <main className="container mx-auto py-8 px-4">
        <h1 className="text-3xl font-bold mb-8 text-red-600">Error Loading Page</h1>
        <p className="text-gray-600">Sorry, there was an error loading this page. Please try again later.</p>
      </main>
    )
  }
}



