"use client"

import { useEffect, useState } from 'react'
import Link from 'next/link'
import { fetchMenuItems } from "@/lib/api"

interface MenuItem {
  id: string
  attributes: {
    title: string
    url: string
  }
}

export function Header() {
  const [menuItems, setMenuItems] = useState<MenuItem[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)

  useEffect(() => {
    const loadMenuItems = async () => {
      try {
        setLoading(true)
        const data = await fetchMenuItems()
        setMenuItems(data)
        setError(null)
      } catch (err) {
        console.error("Failed to fetch menu items:", err)
        setError("Failed to load menu items")
        setMenuItems([])
      } finally {
        setLoading(false)
      }
    }

    loadMenuItems()
  }, [])

  return (
    <header className="bg-white shadow-sm">
      <nav className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between h-16">
          <div className="flex">
            <div className="flex-shrink-0 flex items-center">
              <Link href="/" className="text-xl font-bold">
                <img src="/drop-small.webp" width="45"></img>
              </Link>
            </div>
            <div className="hidden sm:ml-6 sm:flex sm:space-x-8">
              {error ? (
                <span className="text-red-500">Failed to load menu</span>
              ) : loading ? (
                <span className="text-gray-400">Loading...</span>
              ) : (
                menuItems.map((item) => (
                  <Link
                    key={item.id}
                    href={item.attributes.url}
                    className="inline-flex items-center px-1 pt-1 text-sm font-medium text-gray-900 hover:text-gray-600"
                  >
                    {item.attributes.title}
                  </Link>
                ))
              )}
            </div>
          </div>
        </div>
      </nav>
    </header>
  )
}
