SET NAMES utf8;
SET time_zone = '+00:00';
SET foreign_key_checks = 0;
SET sql_mode = 'NO_AUTO_VALUE_ON_ZERO';

SET NAMES utf8mb4;

--
-- Table structure for table `batch`
--

DROP TABLE IF EXISTS `batch`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `batch` (
  `bid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique batch ID.',
  `token` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A string token generated against the current user''s session id and the batch id, used to ensure that only the user who submitted the batch can effectively access it.',
  `timestamp` int NOT NULL COMMENT 'A Unix timestamp indicating when this batch was submitted for processing. Stale batches are purged at cron time.',
  `batch` longblob COMMENT 'A serialized array containing the processing data for the batch.',
  PRIMARY KEY (`bid`),
  KEY `token` (`token`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores details about batches (processes that run in…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `batch`
--

LOCK TABLES `batch` WRITE;
/*!40000 ALTER TABLE `batch` DISABLE KEYS */;
/*!40000 ALTER TABLE `batch` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content`
--

DROP TABLE IF EXISTS `block_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `block_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content`
--

LOCK TABLES `block_content` WRITE;
/*!40000 ALTER TABLE `block_content` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content__body`
--

DROP TABLE IF EXISTS `block_content__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content__body`
--

LOCK TABLES `block_content__body` WRITE;
/*!40000 ALTER TABLE `block_content__body` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_field_data`
--

DROP TABLE IF EXISTS `block_content_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `reusable` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`),
  KEY `block_content_field__reusable` (`reusable`),
  KEY `block_content__status_type` (`status`,`type`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_field_data`
--

LOCK TABLES `block_content_field_data` WRITE;
/*!40000 ALTER TABLE `block_content_field_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_field_revision`
--

DROP TABLE IF EXISTS `block_content_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_field_revision`
--

LOCK TABLES `block_content_field_revision` WRITE;
/*!40000 ALTER TABLE `block_content_field_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_revision`
--

DROP TABLE IF EXISTS `block_content_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `block_content__id` (`id`),
  KEY `block_content_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_revision`
--

LOCK TABLES `block_content_revision` WRITE;
/*!40000 ALTER TABLE `block_content_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_revision__body`
--

DROP TABLE IF EXISTS `block_content_revision__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_revision__body`
--

LOCK TABLES `block_content_revision__body` WRITE;
/*!40000 ALTER TABLE `block_content_revision__body` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_revision__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_access_policy`
--

DROP TABLE IF EXISTS `cache_access_policy`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_access_policy` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_access_policy`
--

LOCK TABLES `cache_access_policy` WRITE;
/*!40000 ALTER TABLE `cache_access_policy` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_access_policy` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_bootstrap`
--

DROP TABLE IF EXISTS `cache_bootstrap`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_bootstrap` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_bootstrap`
--

LOCK TABLES `cache_bootstrap` WRITE;
/*!40000 ALTER TABLE `cache_bootstrap` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_bootstrap` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_config`
--

DROP TABLE IF EXISTS `cache_config`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_config` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_config`
--

LOCK TABLES `cache_config` WRITE;
/*!40000 ALTER TABLE `cache_config` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_config` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_container`
--

DROP TABLE IF EXISTS `cache_container`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_container` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_container`
--

LOCK TABLES `cache_container` WRITE;
/*!40000 ALTER TABLE `cache_container` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_container` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_data`
--

DROP TABLE IF EXISTS `cache_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_data` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_data`
--

LOCK TABLES `cache_data` WRITE;
/*!40000 ALTER TABLE `cache_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_default`
--

DROP TABLE IF EXISTS `cache_default`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_default` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_default`
--

LOCK TABLES `cache_default` WRITE;
/*!40000 ALTER TABLE `cache_default` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_default` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_discovery`
--

DROP TABLE IF EXISTS `cache_discovery`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_discovery` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_discovery`
--

LOCK TABLES `cache_discovery` WRITE;
/*!40000 ALTER TABLE `cache_discovery` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_discovery` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_dynamic_page_cache`
--

DROP TABLE IF EXISTS `cache_dynamic_page_cache`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_dynamic_page_cache` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_dynamic_page_cache`
--

LOCK TABLES `cache_dynamic_page_cache` WRITE;
/*!40000 ALTER TABLE `cache_dynamic_page_cache` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_dynamic_page_cache` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_entity`
--

DROP TABLE IF EXISTS `cache_entity`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_entity` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_entity`
--

LOCK TABLES `cache_entity` WRITE;
/*!40000 ALTER TABLE `cache_entity` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_entity` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_jsonapi_normalizations`
--

DROP TABLE IF EXISTS `cache_jsonapi_normalizations`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_jsonapi_normalizations` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_jsonapi_normalizations`
--

LOCK TABLES `cache_jsonapi_normalizations` WRITE;
/*!40000 ALTER TABLE `cache_jsonapi_normalizations` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_jsonapi_normalizations` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_menu`
--

DROP TABLE IF EXISTS `cache_menu`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_menu` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_menu`
--

LOCK TABLES `cache_menu` WRITE;
/*!40000 ALTER TABLE `cache_menu` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_menu` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_page`
--

DROP TABLE IF EXISTS `cache_page`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_page` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_page`
--

LOCK TABLES `cache_page` WRITE;
/*!40000 ALTER TABLE `cache_page` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_page` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_render`
--

DROP TABLE IF EXISTS `cache_render`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_render` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_render`
--

LOCK TABLES `cache_render` WRITE;
/*!40000 ALTER TABLE `cache_render` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_render` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_rest`
--

DROP TABLE IF EXISTS `cache_rest`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_rest` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_rest`
--

LOCK TABLES `cache_rest` WRITE;
/*!40000 ALTER TABLE `cache_rest` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_rest` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_toolbar`
--

DROP TABLE IF EXISTS `cache_toolbar`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_toolbar` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_toolbar`
--

LOCK TABLES `cache_toolbar` WRITE;
/*!40000 ALTER TABLE `cache_toolbar` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_toolbar` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cachetags`
--

DROP TABLE IF EXISTS `cachetags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cachetags` (
  `tag` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Namespace-prefixed tag string.',
  `invalidations` int NOT NULL DEFAULT '0' COMMENT 'Number incremented when the tag is invalidated.',
  PRIMARY KEY (`tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Cache table for tracking cache tag invalidations.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cachetags`
--

LOCK TABLES `cachetags` WRITE;
/*!40000 ALTER TABLE `cachetags` DISABLE KEYS */;
INSERT INTO `cachetags` VALUES ('4xx-response',95),('block_content_view',1),('breakpoints',98),('comment_view',1),('config:action_list',7),('config:behavior_settings_list',1),('config:block.block.claro_help_search',1),('config:block.block.gin_breadcrumbs',1),('config:block.block.gin_content',1),('config:block.block.gin_help',1),('config:block.block.gin_local_actions',1),('config:block.block.gin_messages',1),('config:block.block.gin_page_title',1),('config:block.block.gin_primary_local_tasks',1),('config:block.block.gin_secondary_local_tasks',1),('config:block.block.olivero_powered',1),('config:block.block.olivero_search_form_narrow',1),('config:block.block.olivero_search_form_wide',1),('config:block.block.olivero_syndicate',1),('config:block_list',4),('config:configurable_language_list',1),('config:core.entity_form_display.block_content.basic.default',1),('config:core.entity_form_display.comment.comment.default',1),('config:core.entity_form_display.node.article.default',1),('config:core.entity_form_display.node.page.default',1),('config:core.entity_form_display.user.user.default',1),('config:core.entity_view_display.block_content.basic.default',1),('config:core.entity_view_display.comment.comment.default',1),('config:core.entity_view_display.node.article.default',1),('config:core.entity_view_display.node.article.rss',1),('config:core.entity_view_display.node.article.teaser',1),('config:core.entity_view_display.node.page.default',1),('config:core.entity_view_display.node.page.teaser',1),('config:core.entity_view_display.user.user.compact',1),('config:core.entity_view_display.user.user.default',1),('config:core.extension',76),('config:core.menu.static_menu_link_overrides',1),('config:diff.settings',1),('config:editor.editor.basic_html',1),('config:editor.editor.full_html',4),('config:editor.editor.webform_default',3),('config:editor_list',8),('config:entity_form_display_list',2),('config:entity_view_display_list',2),('config:entity_view_mode_list',2),('config:file.settings',1),('config:filter.format.basic_html',2),('config:filter.format.full_html',5),('config:filter.format.plain_text',1),('config:filter.format.restricted_html',1),('config:filter.format.webform_default',1),('config:filter_format_list',9),('config:image_style_list',1),('config:jsonapi_extras.settings',1),('config:language.negotiation',1),('config:language.types',33),('config:linkit_profile_list',1),('config:locale.settings',2),('config:menu_list',1),('config:metatag_defaults_list',1),('config:node.settings',1),('config:node_type_list',1),('config:pathauto.settings',1),('config:pathauto_pattern_list',2),('config:rest_resource_config_list',4),('config:search.page.help_search',1),('config:search.page.node_search',1),('config:search.page.user_search',1),('config:search.settings',1),('config:search_page_list',1),('config:simple_sitemap.bundle_settings.default.pathauto_pattern.pathauto_pattern',1),('config:simple_sitemap.bundle_settings.default.search_page.search_page',1),('config:simple_sitemap_list',1),('config:simple_sitemap_type_list',1),('config:system.action.pathauto_update_alias_node',1),('config:system.action.pathauto_update_alias_user',1),('config:system.action.webform_archive_action',1),('config:system.action.webform_close_action',1),('config:system.action.webform_delete_action',1),('config:system.action.webform_open_action',1),('config:system.action.webform_submission_delete_action',1),('config:system.action.webform_submission_make_lock_action',1),('config:system.action.webform_submission_make_sticky_action',1),('config:system.action.webform_submission_make_unlock_action',1),('config:system.action.webform_submission_make_unsticky_action',1),('config:system.action.webform_unarchive_action',1),('config:system.file',1),('config:system.image',1),('config:system.image.gd',1),('config:system.mail',3),('config:system.menu.account',68),('config:system.menu.admin',68),('config:system.menu.footer',68),('config:system.menu.main',71),('config:system.menu.tools',68),('config:system.site',1),('config:system.theme',1),('config:user.role.administrator',12),('config:user.role.anonymous',12),('config:user.role.authenticated',13),('config:user.role.content_editor',11),('config:user_role_list',14),('config:views.settings',1),('config:views.view.redirect',1),('config:views.view.webform_submissions',3),('config:view_list',4),('config:webform.settings',1),('config:webform.webform.contact',1),('config:webform.webform_options.country_codes',1),('config:webform.webform_options.country_names',1),('config:webform.webform_options.days',1),('config:webform.webform_options.education',1),('config:webform.webform_options.employment_status',1),('config:webform.webform_options.ethnicity',1),('config:webform.webform_options.gender',1),('config:webform.webform_options.industry',1),('config:webform.webform_options.languages',1),('config:webform.webform_options.likert_agreement',1),('config:webform.webform_options.likert_comparison',1),('config:webform.webform_options.likert_importance',1),('config:webform.webform_options.likert_quality',1),('config:webform.webform_options.likert_satisfaction',1),('config:webform.webform_options.likert_ten_scale',1),('config:webform.webform_options.likert_would_you',1),('config:webform.webform_options.marital_status',1),('config:webform.webform_options.months',1),('config:webform.webform_options.phone_types',1),('config:webform.webform_options.province_codes',1),('config:webform.webform_options.province_names',1),('config:webform.webform_options.relationship',1),('config:webform.webform_options.sex',1),('config:webform.webform_options.sex_icao',1),('config:webform.webform_options.size',1),('config:webform.webform_options.state_codes',1),('config:webform.webform_options.state_names',1),('config:webform.webform_options.state_province_codes',1),('config:webform.webform_options.state_province_names',1),('config:webform.webform_options.time_zones',1),('config:webform.webform_options.titles',1),('config:webform.webform_options.translations',1),('config:webform.webform_options.yes_no',1),('config:webform_list',5),('config:webform_options_list',2),('entity_bundles',5),('entity_field_info',38),('entity_types',154),('file:1',1),('file:2',1),('file:3',1),('file:4',1),('file:5',1),('file:6',1),('file_list',12),('http_response',68),('icon_pack_collector',98),('icon_pack_plugin',98),('jsonapi_resource_types',2),('library_info',66),('link_attributes',78),('local_task',105),('menu_link_content:1',1),('menu_link_content:2',1),('menu_link_content_list',3),('menu_link_content_list:main',3),('node:1',2),('node:2',2),('node:3',2),('node:4',4),('node_list',14),('node_list:article',9),('node_list:page',5),('node_view',2),('redirect_list',1),('redirect_list:redirect',1),('rendered',5),('routes',69),('route_match',74),('search_index:help_search',11),('search_index:node_search',6),('simple_sitemap:default',18),('simple_sitemap:index',18),('taxonomy_term:1',1),('taxonomy_term_list',4),('taxonomy_term_list:tags',4),('token_info',1),('user_view',1),('views_data',1),('webform_submission_list',13),('webform_submission_list:contact',3);
/*!40000 ALTER TABLE `cachetags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment`
--

DROP TABLE IF EXISTS `comment`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment` (
  `cid` int unsigned NOT NULL AUTO_INCREMENT,
  `comment_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`cid`),
  UNIQUE KEY `comment_field__uuid__value` (`uuid`),
  KEY `comment_field__comment_type__target_id` (`comment_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for comment entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment`
--

LOCK TABLES `comment` WRITE;
/*!40000 ALTER TABLE `comment` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment__comment_body`
--

DROP TABLE IF EXISTS `comment__comment_body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment__comment_body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_body_value` longtext NOT NULL,
  `comment_body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `comment_body_format` (`comment_body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for comment field comment_body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment__comment_body`
--

LOCK TABLES `comment__comment_body` WRITE;
/*!40000 ALTER TABLE `comment__comment_body` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment__comment_body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment_entity_statistics`
--

DROP TABLE IF EXISTS `comment_entity_statistics`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment_entity_statistics` (
  `entity_id` int unsigned NOT NULL DEFAULT '0' COMMENT 'The entity_id of the entity for which the statistics are compiled.',
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'node' COMMENT 'The entity_type of the entity to which this comment is a reply.',
  `field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field_name of the field that was used to add this comment.',
  `cid` int NOT NULL DEFAULT '0' COMMENT 'The "comment".cid of the last comment.',
  `last_comment_timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp of the last comment that was posted within this node, from "comment".changed.',
  `last_comment_name` varchar(60) DEFAULT NULL COMMENT 'The name of the latest author to post a comment on this node, from "comment".name.',
  `last_comment_uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The user ID of the latest author to post a comment on this node, from "comment".uid.',
  `comment_count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The total number of comments on this entity.',
  PRIMARY KEY (`entity_id`,`entity_type`,`field_name`),
  KEY `last_comment_timestamp` (`last_comment_timestamp`),
  KEY `comment_count` (`comment_count`),
  KEY `last_comment_uid` (`last_comment_uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maintains statistics of entity and comments posts to show …';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment_entity_statistics`
--

LOCK TABLES `comment_entity_statistics` WRITE;
/*!40000 ALTER TABLE `comment_entity_statistics` DISABLE KEYS */;
INSERT INTO `comment_entity_statistics` VALUES (1,'node','comment',0,1742136377,NULL,1,0),(2,'node','comment',0,1742136512,NULL,1,0),(3,'node','comment',0,1742153978,NULL,1,0);
/*!40000 ALTER TABLE `comment_entity_statistics` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment_field_data`
--

DROP TABLE IF EXISTS `comment_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment_field_data` (
  `cid` int unsigned NOT NULL,
  `comment_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `pid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `entity_id` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `subject` varchar(64) DEFAULT NULL,
  `name` varchar(60) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `homepage` varchar(255) DEFAULT NULL,
  `hostname` varchar(128) DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `thread` varchar(255) NOT NULL,
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`cid`,`langcode`),
  KEY `comment__id__default_langcode__langcode` (`cid`,`default_langcode`,`langcode`),
  KEY `comment_field__comment_type__target_id` (`comment_type`),
  KEY `comment_field__uid__target_id` (`uid`),
  KEY `comment_field__created` (`created`),
  KEY `comment__status_comment_type` (`status`,`comment_type`,`cid`),
  KEY `comment__status_pid` (`pid`,`status`),
  KEY `comment__num_new` (`entity_id`,`entity_type`,`comment_type`,`status`,`created`,`cid`,`thread`(191)),
  KEY `comment__entity_langcode` (`entity_id`,`entity_type`,`comment_type`,`default_langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for comment entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment_field_data`
--

LOCK TABLES `comment_field_data` WRITE;
/*!40000 ALTER TABLE `comment_field_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `config`
--

DROP TABLE IF EXISTS `config`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `config` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `config`
--

LOCK TABLES `config` WRITE;
/*!40000 ALTER TABLE `config` DISABLE KEYS */;
INSERT INTO `config` VALUES ('','announcements_feed.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),('','automated_cron.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),('','block.block.claro_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"2ee473b3-a425-411a-ab54-a68f6158b424\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"76004679-c667-48f4-8315-0938ae25c677\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"32e45861-c4ef-4890-9456-d4d3178e6dff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"49e09740-a7ab-405b-9ab5-bfd13b5e620f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"7d8fc1d9-1953-4095-be0e-84db7c675688\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"51ff8126-5055-4bce-9ccb-18c944436bfa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"a8503923-9b73-4303-b900-8d31d288f15a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"eecd31b5-688c-478a-9a64-3f7a71835f70\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"b6522fa8-f871-47e7-b9ce-f5ae8e81bc1c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"y9X3xgCsO59pQyzNLzY1D3SDJJxCHILLWkpPnmuTJ2E\";}s:2:\"id\";s:15:\"gin_breadcrumbs\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"2fcd6937-f7e2-4164-9961-4645225145e5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBHXB7hC05XU7pDYzETt-GUcpFlogK1gkjyAsg0Ym58\";}s:2:\"id\";s:11:\"gin_content\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"8b83c953-f174-46e0-a364-09d2175e38ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8nOAry2oKqJOr0zbrlJ3sZHDFJLIO6j-0vT0K_TYca4\";}s:2:\"id\";s:8:\"gin_help\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"e15a620f-69da-49e6-b189-04443f574743\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OQ9aJ-4qVwK1x00o9EOYK4eFDjQr_HLpbPiJaPSVZiQ\";}s:2:\"id\";s:17:\"gin_local_actions\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"c6c79d5e-aa2f-4b8d-b495-90d172f5a37f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WvPhI8OwllG0gE69-F8qL3ai3nd5SbYD6JpmEuZcyok\";}s:2:\"id\";s:12:\"gin_messages\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"ebea0892-f451-48c1-9e1d-88b202d03b18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HLQY2xgby8K3vN_98hiOSasOhm9pdCsH234-s0duJ8Q\";}s:2:\"id\";s:14:\"gin_page_title\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"16251d67-ff59-46ea-992c-c18706ab2d54\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hh01DLj9k7UnNdPpOQXHZHW7GHf2OPNDQyCJF7_R9ac\";}s:2:\"id\";s:23:\"gin_primary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"07f111f7-352c-4382-846e-5dc96ba3e79c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCWhood0xXFQYqxFgL1spXdb9KeIuXH1YvTdjIEedDg\";}s:2:\"id\";s:25:\"gin_secondary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"870c3a2a-0f9d-4654-a000-d2679516fe2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"07be5c27-7c5f-41b8-964c-98c06048a345\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"cde6aefd-f0a4-4b0b-beec-de088e3ba750\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"ebb3e07a-d14f-423b-a996-02cd370cd1fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"f31a287c-6331-4954-8774-a5c1a562ded4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"f22a6909-6281-401a-81e1-e7b2b08f2d29\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"c705cc7a-6121-476d-bbe4-261ea3e5d449\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"c936529a-a175-4104-a0be-d34480b5c15a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"41b6f077-7605-4a7d-9b49-e8bf57957354\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"b67d55b6-584f-4ea8-a5ad-1ff5a0ce5f58\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"f9fbe17e-b414-4baa-8e48-f52b2907dd61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block_content.type.basic',_binary 'a:9:{s:4:\"uuid\";s:36:\"d64644ad-b094-4c5b-a15a-19a3b8bdc1c9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),('','ckeditor5_plugin_pack.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uAMHMIBA-fCvlzeeOYZ4vKwSBXvThlEytdEKK_Ur8nI\";}s:12:\"dll_location\";s:0:\"\";}'),('','claro.settings',_binary 'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),('','comment.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNUW2Ij5uE7a4oaXp3i_2lvaFdYM1zNKPPfnEjB0jEc\";}s:16:\"log_ip_addresses\";b:0;}'),('','comment.type.comment',_binary 'a:9:{s:4:\"uuid\";s:36:\"a33bd86b-5bbd-4f5c-807b-eba5e4396f23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bqZsN31T2n0UjcbyCpOPi9D2iO0sAOHR7FnEs9qMvaA\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:16:\"Default comments\";s:21:\"target_entity_type_id\";s:4:\"node\";s:11:\"description\";s:28:\"Allows commenting on content\";}'),('','config_ignore.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IgOVnECx6lbVt6JVFnadoEEugneDf3UblPZnOzov43Q\";}s:4:\"mode\";s:6:\"simple\";s:23:\"ignored_config_entities\";a:0:{}}'),('','contact.form.feedback',_binary 'a:12:{s:4:\"uuid\";s:36:\"b09080d0-d32f-48de-a42f-70fdecbd5e2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.form.personal',_binary 'a:12:{s:4:\"uuid\";s:36:\"f3831747-359e-4997-a6d5-abd5e6e9f842\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),('','core.base_field_override.node.page.promote',_binary 'a:17:{s:4:\"uuid\";s:36:\"c23528a5-02ac-44f4-a644-5500abef763e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','core.base_field_override.node.webform.promote',_binary 'a:17:{s:4:\"uuid\";s:36:\"a3af19ad-36e8-452e-873e-127297423512\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:17:\"node.type.webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FvXJkxryo6J_0TQRlb5Z77Ge-sim5GHzCI1Ft3kZu-4\";}s:2:\"id\";s:20:\"node.webform.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','core.date_format.fallback',_binary 'a:9:{s:4:\"uuid\";s:36:\"d367ac3c-4ca1-4026-a47e-4817dc8c2511\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iIBLu1j9n6Oo5PW-wpu5gdyNs9Kvv4LMRqtQUdJjRz8\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, j M Y - H:i\";}'),('','core.date_format.html_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"0af4b8bf-1ba3-4ecc-a123-f2abfa8a7e34\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),('','core.date_format.html_datetime',_binary 'a:9:{s:4:\"uuid\";s:36:\"78cb7097-519a-4d33-a9cf-890f946cd1b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),('','core.date_format.html_month',_binary 'a:9:{s:4:\"uuid\";s:36:\"bc061bc9-c166-47f3-be0f-abbba94af1dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),('','core.date_format.html_time',_binary 'a:9:{s:4:\"uuid\";s:36:\"cc1685f0-a1bc-49c4-b22f-ecaeb8a7a384\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),('','core.date_format.html_week',_binary 'a:9:{s:4:\"uuid\";s:36:\"d3f418c7-8741-4033-8fcb-48c7f8608816\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),('','core.date_format.html_year',_binary 'a:9:{s:4:\"uuid\";s:36:\"0f2d4f08-392f-4b29-bf5c-4d4c8aa13945\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),('','core.date_format.html_yearless_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"1eeb9283-48cf-42b5-9ec2-e3277335126d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),('','core.date_format.long',_binary 'a:9:{s:4:\"uuid\";s:36:\"57191129-5da9-459f-b5cb-e31c471cbf54\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5B4_r5Vd0_9UaJwtAC5yFCm9-k8NNvp1xiQNhFFkknU\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"l, j F Y - H:i\";}'),('','core.date_format.medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"0629967e-77af-4eb2-8a78-d6b4f1a8a540\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"q7pDV2d9qFh1IVqvymOxUUYGSziZDeg961wURC0cSLs\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, j M Y - H:i\";}'),('','core.date_format.olivero_medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"010477b9-d765-490f-9425-dd432bfb786e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z7ynTCss9wwEi8ojENJ08qx44RN6leI-tqoN2o5QzdE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:5:\"j F Y\";}'),('','core.date_format.short',_binary 'a:9:{s:4:\"uuid\";s:36:\"205997a0-85e2-480b-afbf-364040dbe3a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SAeixlV7Djy_Ggv_1P95TiqD4KUihA5icvU521tA84Y\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"j M Y - H:i\";}'),('','core.entity_form_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"885ef637-ecc7-404d-98d6-f886bae2a7dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"915f5663-37e7-48c1-877a-dd2574a2366c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0Pa0aQvT_jawlPo9oz4FE3h_ickc55dYKTPl6gILes\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:6:\"author\";a:2:{s:6:\"weight\";i:-2;s:6:\"region\";s:7:\"content\";}s:12:\"comment_body\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:7:\"subject\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"39076dd4-f606-4559-8e09-9c4076a6a9a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:29:\"field.field.node.article.body\";i:1;s:32:\"field.field.node.article.comment\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:21:\"image.style.thumbnail\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:7:\"comment\";i:1;s:5:\"image\";i:2;s:4:\"path\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:12:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"comment\";a:5:{s:4:\"type\";s:15:\"comment_default\";s:6:\"weight\";i:20;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8052ad9d-9ad8-4d4f-a2cc-01b3312dbac3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"field.field.node.page.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"path\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:9:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.webform.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ffb66cab-c432-432a-9abe-556ec76c9de4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:29:\"field.field.node.webform.body\";i:1;s:32:\"field.field.node.webform.webform\";i:2;s:17:\"node.type.webform\";}s:6:\"module\";a:3:{i:0;s:4:\"path\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A3evv2pt6d-bKCPcgjXA5VGTemXWOxG3lSXvWiRWcck\";}s:2:\"id\";s:20:\"node.webform.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:12:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:0;s:8:\"settings\";a:3:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:15;s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:14:\"simple_sitemap\";a:4:{s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:16;s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:3:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:13:\"url_redirects\";a:4:{s:6:\"weight\";i:50;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:7:\"webform\";a:5:{s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8b44064a-21df-44c2-bc70-8583a0b6d00f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_form_mode.user.register',_binary 'a:10:{s:4:\"uuid\";s:36:\"5d33687a-c0b1-4d5d-96a5-9b558b4d62ae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"01eed67b-49a4-45a7-81f3-7be9338dca46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"5932e0d4-d732-487d-a85d-b8314a5b32ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aBQUGsQ46M4048fIlFuTXwl2zV0j2cJX89CTUobh9hA\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:12:\"comment_body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d5d627a7-d4a0-4cf7-9ee0-b7946878aa35\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:48:\"core.entity_view_display.comment.comment.default\";i:1;s:29:\"field.field.node.article.body\";i:2;s:32:\"field.field.node.article.comment\";i:3;s:36:\"field.field.node.article.field_image\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:16:\"image.style.wide\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:7:\"comment\";i:1;s:5:\"image\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:7:\"comment\";a:6:{s:4:\"type\";s:15:\"comment_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:8:\"pager_id\";i:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:110;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.article.rss',_binary 'a:11:{s:4:\"uuid\";s:36:\"a31296e3-ecfb-448f-8fcc-077d53a3e7f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:32:\"field.field.node.article.comment\";i:3;s:36:\"field.field.node.article.field_image\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:5:{s:4:\"body\";b:1;s:7:\"comment\";b:1;s:11:\"field_image\";b:1;s:10:\"field_tags\";b:1;s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.article.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"0c236e6a-27ce-4c19-8e5a-126cde1d65fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:32:\"field.field.node.article.comment\";i:3;s:36:\"field.field.node.article.field_image\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:18:\"image.style.medium\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"comment\";b:1;s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f5cc614c-3972-4b19-aa5e-f5ffad215f88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"field.field.node.page.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.page.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"4690aa2b-761f-4e63-b494-b09f2bffff83\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.webform.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"5f4e9c64-9f98-4d2c-a273-044234fb3a37\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:29:\"field.field.node.webform.body\";i:1;s:32:\"field.field.node.webform.webform\";i:2;s:17:\"node.type.webform\";}s:6:\"module\";a:3:{i:0;s:4:\"text\";i:1;s:4:\"user\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3r1i0UMUbeNHhvmiqHDYznoS4G9XR1jq6lQ49r80lDE\";}s:2:\"id\";s:20:\"node.webform.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:101;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:6:\"weight\";i:100;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:7:\"webform\";a:6:{s:6:\"weight\";i:102;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.webform.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"58b778bb-172e-472d-b9f5-17c920bb4232\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.webform.body\";i:2;s:32:\"field.field.node.webform.webform\";i:3;s:17:\"node.type.webform\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ls5l3Xs7-YstJnurxFLKj38Exqr2JMZs1j9YeX1Kh2o\";}s:2:\"id\";s:19:\"node.webform.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:6:\"weight\";i:101;s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:6:\"weight\";i:100;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:8:\"langcode\";b:1;s:7:\"webform\";b:1;}}'),('','core.entity_view_display.user.user.compact',_binary 'a:11:{s:4:\"uuid\";s:36:\"a22a500a-58f5-443b-895c-dd210187a86d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:8:\"langcode\";b:1;s:10:\"member_for\";b:1;}}'),('','core.entity_view_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"227a1b86-49df-47ac-8efe-562bcf176cd2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_mode.block.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"b250be27-e5ae-4b0b-845e-171e9a9517cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"block\";}}s:2:\"id\";s:11:\"block.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:5:\"block\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.block_content.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"72737862-d3bd-415c-8ab6-4c512f6678f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.block_content.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"e7c3d152-d1b1-47fa-949d-6aac95fd9f43\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:2:\"id\";s:19:\"block_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.comment.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"8617e7ab-2c6e-478b-ab0a-552ff354eeab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N4mUjXpPckUkVRY1PbKw4GGoL1i2ECU7PL3EreiKStk\";}s:2:\"id\";s:12:\"comment.full\";s:5:\"label\";s:12:\"Full comment\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"comment\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.comment.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"4f6c41a4-657c-42fd-8268-276a87df9731\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:2:\"id\";s:13:\"comment.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:7:\"comment\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.contact_message.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"5d4499b8-9506-49e9-85b4-3d93fe61d4f8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"contact\";}}s:2:\"id\";s:21:\"contact_message.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:15:\"contact_message\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.file.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"cd3c6575-783d-4a1a-ac9c-8adaf1c76f8a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:2:\"id\";s:10:\"file.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:4:\"file\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.menu_link_content.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"e1026fe1-359d-41cf-8422-735c2c858db2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:17:\"menu_link_content\";}}s:2:\"id\";s:23:\"menu_link_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:17:\"menu_link_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.diff',_binary 'a:10:{s:4:\"uuid\";s:36:\"86727042-5ea2-41bc-927d-32de67fe734d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"diff\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pqZNtad5J9THcdbYjwPD4qINqvrTxnOd8KCWn6tUBRs\";}s:2:\"id\";s:9:\"node.diff\";s:5:\"label\";s:19:\"Revision comparison\";s:11:\"description\";N;s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"84e1094d-b40c-4dd6-82a6-a75eb1250270\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.rss',_binary 'a:10:{s:4:\"uuid\";s:36:\"8f4a1fcd-6a35-47e7-bb3e-0ba29c104629\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_index',_binary 'a:10:{s:4:\"uuid\";s:36:\"1e54deca-38ff-416c-86d0-eed69eedefd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_result',_binary 'a:10:{s:4:\"uuid\";s:36:\"fc474d30-f444-421a-ab7a-40651906ebc2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.teaser',_binary 'a:10:{s:4:\"uuid\";s:36:\"d3afe08d-7024-4fa1-bf4a-2bdc2b459c34\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"8fe537b9-59a2-4e02-9c75-17d825a2e09c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:10:\"node.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.path_alias.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"cd3bc5d6-a185-496e-bd75-7b418012951a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"path_alias\";}}s:2:\"id\";s:16:\"path_alias.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:10:\"path_alias\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.shortcut.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"1c9bd81e-6e7c-4441-a47e-1c1a8944e0c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"shortcut\";}}s:2:\"id\";s:14:\"shortcut.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:8:\"shortcut\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.taxonomy_term.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"cddf0fac-c858-4a6c-8a52-8e5be3324d15\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.taxonomy_term.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"66378eb1-2d94-4ea0-9430-7d3725ba07de\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:2:\"id\";s:19:\"taxonomy_term.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.compact',_binary 'a:10:{s:4:\"uuid\";s:36:\"4f67af00-60de-4117-81cf-5679ade2ddcc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"6107c823-b21d-4d0f-b5d3-e1c2151d15fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"abbbcbe6-fbc2-4032-b329-faa7fe4fab0f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:10:\"user.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.extension',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:100:{s:11:\"anchor_link\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:30:\"ckeditor5_plugin_pack_bookmark\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:7:\"comment\";i:0;s:6:\"config\";i:0;s:13:\"config_ignore\";i:0;s:12:\"config_split\";i:0;s:18:\"config_translation\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:4:\"diff\";i:0;s:18:\"dynamic_page_cache\";i:0;s:6:\"editor\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:6:\"filter\";i:0;s:11:\"gin_toolbar\";i:0;s:9:\"glightbox\";i:0;s:16:\"glightbox_inline\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:16:\"hotkeys_for_save\";i:0;s:5:\"image\";i:0;s:7:\"jsonapi\";i:0;s:16:\"jsonapi_defaults\";i:0;s:14:\"jsonapi_extras\";i:0;s:18:\"jsonapi_menu_items\";i:0;s:17:\"jsonapi_resources\";i:0;s:22:\"jsonapi_response_alter\";i:0;s:13:\"jsonapi_views\";i:0;s:8:\"language\";i:0;s:4:\"link\";i:0;s:15:\"link_attributes\";i:0;s:33:\"link_attributes_menu_link_content\";i:0;s:6:\"linkit\";i:0;s:17:\"linkit_attributes\";i:0;s:6:\"locale\";i:0;s:18:\"media_library_edit\";i:0;s:16:\"menu_item_extras\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:7:\"metatag\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:11:\"rabbit_hole\";i:0;s:8:\"redirect\";i:0;s:10:\"rel_to_abs\";i:0;s:4:\"rest\";i:0;s:18:\"rest_absolute_urls\";i:0;s:6:\"restui\";i:0;s:7:\"rh_node\";i:0;s:11:\"rh_taxonomy\";i:0;s:13:\"serialization\";i:0;s:8:\"shortcut\";i:0;s:14:\"simple_sitemap\";i:0;s:9:\"svg_image\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:4:\"text\";i:0;s:5:\"token\";i:0;s:7:\"toolbar\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:7:\"webform\";i:0;s:14:\"webform_access\";i:0;s:18:\"webform_attachment\";i:0;s:12:\"webform_node\";i:0;s:21:\"webform_options_limit\";i:0;s:12:\"webform_rest\";i:0;s:14:\"webform_schema\";i:0;s:32:\"webform_submission_export_import\";i:0;s:10:\"webform_ui\";i:0;s:8:\"pathauto\";i:1;s:5:\"views\";i:10;s:4:\"fast\";i:1000;}s:5:\"theme\";a:3:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;s:3:\"gin\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),('','core.menu.static_menu_link_overrides',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:2:{s:18:\"contact__site_page\";a:5:{s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:7:\"enabled\";b:1;}s:20:\"standard__front_page\";a:5:{s:6:\"weight\";i:-50;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:7:\"enabled\";b:1;}}}'),('','dblog.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),('','diff.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYD4Zz6IzdUZR-N_MxkJnacUlP94l-qPt--QRY-OdZc\";}s:16:\"general_settings\";a:7:{s:14:\"radio_behavior\";s:6:\"simple\";s:21:\"context_lines_leading\";i:1;s:22:\"context_lines_trailing\";i:1;s:20:\"revision_pager_limit\";i:50;s:14:\"layout_plugins\";a:3:{s:13:\"visual_inline\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:0;}s:12:\"split_fields\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:1;}s:14:\"unified_fields\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:2;}}s:24:\"visual_default_view_mode\";s:4:\"full\";s:19:\"visual_inline_theme\";s:7:\"default\";}}'),('','editor.editor.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"714302b5-b69b-48c9-822c-6906b789be66\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:7:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:44:\"ckeditor5_plugin_pack_auto_image__auto_image\";a:1:{s:7:\"enabled\";b:0;}s:62:\"ckeditor5_plugin_pack_text_transformation__text_transformation\";a:4:{s:7:\"enabled\";b:0;s:21:\"extra_transformations\";s:0:\"\";s:27:\"extra_regex_transformations\";a:0:{}s:6:\"groups\";a:5:{s:10:\"typography\";a:2:{s:15:\"transformations\";a:3:{s:8:\"ellipsis\";a:1:{s:7:\"enabled\";i:1;}s:6:\"enDash\";a:1:{s:7:\"enabled\";i:1;}s:6:\"emDash\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:6:\"quotes\";a:2:{s:15:\"transformations\";a:2:{s:13:\"quotesPrimary\";a:1:{s:7:\"enabled\";i:1;}s:15:\"quotesSecondary\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:7:\"symbols\";a:2:{s:15:\"transformations\";a:3:{s:9:\"trademark\";a:1:{s:7:\"enabled\";i:1;}s:19:\"registeredTrademark\";a:1:{s:7:\"enabled\";i:1;}s:9:\"copyright\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:12:\"mathematical\";a:2:{s:15:\"transformations\";a:10:{s:7:\"oneHalf\";a:1:{s:7:\"enabled\";i:1;}s:8:\"oneThird\";a:1:{s:7:\"enabled\";i:1;}s:9:\"twoThirds\";a:1:{s:7:\"enabled\";i:1;}s:9:\"oneFourth\";a:1:{s:7:\"enabled\";i:1;}s:13:\"threeQuarters\";a:1:{s:7:\"enabled\";i:1;}s:15:\"lessThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:18:\"greaterThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:8:\"notEqual\";a:1:{s:7:\"enabled\";i:1;}s:9:\"arrowLeft\";a:1:{s:7:\"enabled\";i:1;}s:10:\"arrowRight\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:4:\"misc\";a:2:{s:15:\"transformations\";a:4:{s:17:\"quotesPrimaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:19:\"quotesSecondaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:15:\"quotesPrimaryPl\";a:1:{s:7:\"enabled\";i:0;}s:17:\"quotesSecondaryPl\";a:1:{s:7:\"enabled\";i:0;}}s:7:\"enabled\";i:0;}}}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:12:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:17:\"<blockquote cite>\";i:5;s:9:\"<ul type>\";i:6;s:9:\"<ol type>\";i:7;s:7:\"<h2 id>\";i:8;s:7:\"<h3 id>\";i:9;s:7:\"<h4 id>\";i:10;s:7:\"<h5 id>\";i:11;s:7:\"<h6 id>\";}}s:16:\"linkit_extension\";a:2:{s:14:\"linkit_enabled\";b:1;s:14:\"linkit_profile\";s:7:\"default\";}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"7a68f2fe-d2c4-467b-94db-f1b3c98a4c4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:44:{i:0;s:4:\"undo\";i:1;s:4:\"redo\";i:2;s:5:\"style\";i:3;s:6:\"indent\";i:4;s:7:\"outdent\";i:5;s:8:\"fontSize\";i:6;s:4:\"bold\";i:7;s:6:\"italic\";i:8;s:13:\"strikethrough\";i:9;s:9:\"underline\";i:10;s:10:\"fontFamily\";i:11;s:9:\"highlight\";i:12;s:9:\"fontColor\";i:13;s:19:\"fontBackgroundColor\";i:14;s:11:\"superscript\";i:15;s:9:\"subscript\";i:16;s:9:\"alignment\";i:17;s:12:\"removeFormat\";i:18;s:1:\"|\";i:19;s:4:\"link\";i:20;s:6:\"anchor\";i:21;s:1:\"|\";i:22;s:14:\"findAndReplace\";i:23;s:12:\"bulletedList\";i:24;s:12:\"numberedList\";i:25;s:1:\"|\";i:26;s:10:\"fullScreen\";i:27;s:10:\"blockQuote\";i:28;s:17:\"drupalInsertImage\";i:29;s:11:\"insertTable\";i:30;s:14:\"horizontalLine\";i:31;s:1:\"|\";i:32;s:7:\"heading\";i:33;s:9:\"codeBlock\";i:34;s:9:\"selectAll\";i:35;s:1:\"|\";i:36;s:13:\"sourceEditing\";i:37;s:4:\"code\";i:38;s:17:\"specialCharacters\";i:39;s:9:\"pageBreak\";i:40;s:14:\"insertTemplate\";i:41;s:10:\"showBlocks\";i:42;s:8:\"bookmark\";i:43;s:16:\"textPartLanguage\";}}s:7:\"plugins\";a:17:{s:19:\"ckeditor5_alignment\";a:1:{s:18:\"enabled_alignments\";a:4:{i:0;s:6:\"center\";i:1;s:7:\"justify\";i:2;s:4:\"left\";i:3;s:5:\"right\";}}s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:6:{i:0;s:8:\"heading1\";i:1;s:8:\"heading2\";i:2;s:8:\"heading3\";i:3;s:8:\"heading4\";i:4;s:8:\"heading5\";i:5;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:18:\"ckeditor5_language\";a:1:{s:13:\"language_list\";s:2:\"un\";}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:44:\"ckeditor5_plugin_pack_auto_image__auto_image\";a:1:{s:7:\"enabled\";b:0;}s:56:\"ckeditor5_plugin_pack_find_and_replace__find_and_replace\";a:1:{s:7:\"ui_type\";s:6:\"dialog\";}s:38:\"ckeditor5_plugin_pack_font__font_color\";a:7:{s:6:\"colors\";a:0:{}s:18:\"use_default_colors\";b:1;s:15:\"use_colorpicker\";b:1;s:18:\"font_color_columns\";i:5;s:26:\"font_color_document_colors\";i:10;s:16:\"bg_color_columns\";i:5;s:24:\"bg_color_document_colors\";i:10;}s:39:\"ckeditor5_plugin_pack_font__font_family\";a:1:{s:7:\"options\";s:0:\"\";}s:37:\"ckeditor5_plugin_pack_font__font_size\";a:1:{s:7:\"options\";s:0:\"\";}s:42:\"ckeditor5_plugin_pack_highlight__highlight\";a:3:{s:7:\"options\";a:0:{}s:19:\"use_default_markers\";b:1;s:13:\"attach_styles\";b:0;}s:48:\"ckeditor5_plugin_pack_indent_block__indent_block\";a:1:{s:7:\"enabled\";b:1;}s:62:\"ckeditor5_plugin_pack_text_transformation__text_transformation\";a:4:{s:7:\"enabled\";b:0;s:21:\"extra_transformations\";s:0:\"\";s:27:\"extra_regex_transformations\";a:0:{}s:6:\"groups\";a:5:{s:10:\"typography\";a:2:{s:15:\"transformations\";a:3:{s:8:\"ellipsis\";a:1:{s:7:\"enabled\";i:1;}s:6:\"enDash\";a:1:{s:7:\"enabled\";i:1;}s:6:\"emDash\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:6:\"quotes\";a:2:{s:15:\"transformations\";a:2:{s:13:\"quotesPrimary\";a:1:{s:7:\"enabled\";i:1;}s:15:\"quotesSecondary\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:7:\"symbols\";a:2:{s:15:\"transformations\";a:3:{s:9:\"trademark\";a:1:{s:7:\"enabled\";i:1;}s:19:\"registeredTrademark\";a:1:{s:7:\"enabled\";i:1;}s:9:\"copyright\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:12:\"mathematical\";a:2:{s:15:\"transformations\";a:10:{s:7:\"oneHalf\";a:1:{s:7:\"enabled\";i:1;}s:8:\"oneThird\";a:1:{s:7:\"enabled\";i:1;}s:9:\"twoThirds\";a:1:{s:7:\"enabled\";i:1;}s:9:\"oneFourth\";a:1:{s:7:\"enabled\";i:1;}s:13:\"threeQuarters\";a:1:{s:7:\"enabled\";i:1;}s:15:\"lessThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:18:\"greaterThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:8:\"notEqual\";a:1:{s:7:\"enabled\";i:1;}s:9:\"arrowLeft\";a:1:{s:7:\"enabled\";i:1;}s:10:\"arrowRight\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:4:\"misc\";a:2:{s:15:\"transformations\";a:4:{s:17:\"quotesPrimaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:19:\"quotesSecondaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:15:\"quotesPrimaryPl\";a:1:{s:7:\"enabled\";i:0;}s:17:\"quotesSecondaryPl\";a:1:{s:7:\"enabled\";i:0;}}s:7:\"enabled\";i:0;}}}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}s:15:\"ckeditor5_style\";a:1:{s:6:\"styles\";a:1:{i:0;a:2:{s:5:\"label\";s:7:\"Caption\";s:7:\"element\";s:22:\"<span class=\"caption\">\";}}}s:16:\"linkit_extension\";a:2:{s:14:\"linkit_enabled\";b:1;s:14:\"linkit_profile\";s:7:\"default\";}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.webform_default',_binary 'a:8:{s:4:\"uuid\";s:36:\"b83f2eef-227c-4316-9376-0182174cb48a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:6:\"format\";s:15:\"webform_default\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:20:{i:0;s:7:\"heading\";i:1;s:1:\"|\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:9:\"subscript\";i:5;s:11:\"superscript\";i:6;s:1:\"|\";i:7;s:17:\"specialCharacters\";i:8;s:1:\"|\";i:9;s:12:\"numberedList\";i:10;s:12:\"bulletedList\";i:11;s:1:\"|\";i:12;s:4:\"link\";i:13;s:1:\"|\";i:14;s:6:\"indent\";i:15;s:7:\"outdent\";i:16;s:1:\"|\";i:17;s:10:\"blockQuote\";i:18;s:1:\"|\";i:19;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:3:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:1:{s:6:\"status\";b:0;}}'),('','field.field.block_content.basic.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"66f77a78-8dbc-42dd-865d-64c9d97497e5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.comment.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"85d0b6cd-cb9e-43f0-b97a-097bc7bfb2ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:34:\"field.storage.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"62rlTOx3sPVrYhBnSBHZStXwiO02v1UpHSMrhWDsuG8\";}s:2:\"id\";s:28:\"comment.comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:5:\"label\";s:7:\"Comment\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.node.article.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"e8e918f3-0065-4fba-bab0-bbf3f9012680\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.article.comment',_binary 'a:17:{s:4:\"uuid\";s:36:\"fbcc6ac8-045f-46f3-9c69-215e5aee20fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"field.storage.node.comment\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UqXlkKC4v2-bDfWx4zcXQrD5YIi3d5byENEmWv-G_Uc\";}s:2:\"id\";s:20:\"node.article.comment\";s:10:\"field_name\";s:7:\"comment\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:8:\"Comments\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:6:{s:6:\"status\";i:2;s:3:\"cid\";i:0;s:22:\"last_comment_timestamp\";i:0;s:17:\"last_comment_name\";N;s:16:\"last_comment_uid\";i:0;s:13:\"comment_count\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:12:\"default_mode\";i:1;s:8:\"per_page\";i:50;s:9:\"anonymous\";i:0;s:13:\"form_location\";b:1;s:7:\"preview\";i:1;}s:10:\"field_type\";s:7:\"comment\";}'),('','field.field.node.article.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"a821c784-0c14-4d95-afe8-b3870cea2d6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.node.article.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"8301f478-2242-4c70-95e1-e38295e4c668\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.node.page.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"14afe9f8-2fd1-40c6-b8d8-e5d9dcb2b2aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.webform.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"22aaedcb-09db-4794-9acb-2becd13a2e0d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.webform\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Qu0UyzQ0jD4TDYq8fOasS-D-vGd3gSwzi15PzRJUD4\";}s:2:\"id\";s:17:\"node.webform.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.webform.webform',_binary 'a:17:{s:4:\"uuid\";s:36:\"cc7f6f2e-82c2-41b5-9e91-ef9ffdf8558b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"field.storage.node.webform\";i:1;s:17:\"node.type.webform\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w6hvTj8CaO8YVQDnlsD-jRBzMA_vNmx2cXLEKX13yT4\";}s:2:\"id\";s:20:\"node.webform.webform\";s:10:\"field_name\";s:7:\"webform\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:5:\"label\";s:7:\"Webform\";s:11:\"description\";s:62:\"Select the webform that you would like to attach to this node.\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:5:{s:12:\"default_data\";s:0:\"\";s:6:\"status\";s:4:\"open\";s:4:\"open\";s:0:\"\";s:5:\"close\";s:0:\"\";s:11:\"target_uuid\";s:0:\"\";}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:0:{}}s:10:\"field_type\";s:7:\"webform\";}'),('','field.field.user.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"2765f954-a749-4676-a2b3-63be8c7d3800\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),('','field.storage.block_content.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac53f9a6-7651-4e31-83f3-63793c128360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"e5ee7b1b-bd81-4fd0-af67-f92e6bae8313\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:2:\"id\";s:20:\"comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"8a930e87-45e4-410a-af3d-198c8f27a1a8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.comment',_binary 'a:17:{s:4:\"uuid\";s:36:\"d8ddfd2c-c777-440f-a0e1-ce7cea17d4dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ktCna9xmWvYZIUfOCUyDQvedn5RtnS4CRmEIwNmvYjc\";}s:2:\"id\";s:12:\"node.comment\";s:10:\"field_name\";s:7:\"comment\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:7:\"comment\";s:8:\"settings\";a:1:{s:12:\"comment_type\";s:7:\"comment\";}s:6:\"module\";s:7:\"comment\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"2e760d93-d8f1-4cc0-a846-8a1be50ab6b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"81b92d69-01d7-4755-b08e-038fae9ed965\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.webform',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad237af2-b5d3-4fac-8674-82493f95d005\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:12:\"webform_node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SJRNyZvo1lWcPLKxH_u6giTk1y51ymXvpKX65YUNd7w\";}s:2:\"id\";s:12:\"node.webform\";s:10:\"field_name\";s:7:\"webform\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"dfa0301c-438e-4abc-a17f-d0d555a64089\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),('','file.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:1;s:18:\"replace_whitespace\";b:1;s:24:\"replace_non_alphanumeric\";b:0;s:22:\"deduplicate_separators\";b:1;s:9:\"lowercase\";b:1;s:21:\"replacement_character\";s:1:\"-\";}}'),('','filter.format.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"568418de-cc1f-4161-bfd4-806e6cda5041\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:6:\"editor\";i:1;s:6:\"linkit\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:-9;s:7:\"filters\";a:7:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:293:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <blockquote cite> <ul type> <ol type start> <strong> <em> <code> <a href data-entity-type data-entity-uuid data-entity-substitution> <li> <img src alt height width data-entity-uuid data-entity-type data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}s:6:\"linkit\";a:5:{s:2:\"id\";s:6:\"linkit\";s:8:\"provider\";s:6:\"linkit\";s:6:\"status\";b:0;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:5:\"title\";b:0;}}}}'),('','filter.format.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"4116e91f-e5fa-4a37-942f-11ab8d868828\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:6:\"editor\";i:1;s:10:\"rel_to_abs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:-10;s:7:\"filters\";a:7:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:0;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:22:\"<span class=\"caption\">\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}s:10:\"rel_to_abs\";a:5:{s:2:\"id\";s:10:\"rel_to_abs\";s:8:\"provider\";s:10:\"rel_to_abs\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}}}'),('','filter.format.plain_text',_binary 'a:9:{s:4:\"uuid\";s:36:\"d6c89fdd-daf5-43dd-8fd3-2de981a4e2c3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:-7;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.restricted_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"150b0210-ca67-4d68-8a96-47161c6734ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:-8;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.webform_default',_binary 'a:9:{s:4:\"uuid\";s:36:\"7e21f965-39b3-4af0-bca5-32809fcc5e3b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EeKp_M4Oid3erARiAam9rsgBKR91uEnFkEP3aZS2ol8\";}s:4:\"name\";s:31:\"Webform (Default) - DO NOT EDIT\";s:6:\"format\";s:15:\"webform_default\";s:6:\"weight\";i:100;s:7:\"filters\";a:0:{}}'),('','filter.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),('','gin.settings',_binary 'a:13:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"c8aZhkIY8zHUo0_UOll4vVs_l48dHL_gBqbvfuAM0Rs\";}s:19:\"preset_accent_color\";s:4:\"blue\";s:18:\"preset_focus_color\";s:3:\"gin\";s:15:\"enable_darkmode\";s:1:\"0\";s:15:\"classic_toolbar\";s:3:\"new\";s:26:\"secondary_toolbar_frontend\";b:1;s:4:\"logo\";a:1:{s:11:\"use_default\";b:1;}s:18:\"high_contrast_mode\";b:0;s:14:\"layout_density\";s:7:\"default\";s:23:\"show_description_toggle\";b:0;s:24:\"show_user_theme_settings\";b:0;s:21:\"sticky_action_buttons\";b:0;s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),('','glightbox.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e4lHOh2jMu4BTmZv8Pds85ZvpYvEYgH1AsR9crZHJPg\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}s:4:\"plyr\";a:22:{s:7:\"enabled\";b:1;s:5:\"debug\";b:0;s:8:\"controls\";s:124:\"[\'play-large\', \'play\', \'progress\', \'current-time\', \'mute\', \'volume\', \'captions\', \'settings\', \'pip\', \'airplay\', \'fullscreen\']\";s:8:\"settings\";s:40:\"[\'captions\', \'quality\', \'speed\', \'loop\']\";s:11:\"load_sprite\";b:1;s:8:\"icon_url\";s:0:\"\";s:11:\"icon_prefix\";s:4:\"plyr\";s:11:\"blank_video\";s:36:\"https://cdn.plyr.io/static/blank.mp4\";s:8:\"autoplay\";b:0;s:9:\"autopause\";b:1;s:11:\"playsinline\";b:1;s:9:\"seek_time\";i:10;s:6:\"volume\";i:1;s:5:\"muted\";b:0;s:13:\"click_to_play\";b:1;s:20:\"disable_context_menu\";b:1;s:13:\"hide_controls\";b:1;s:12:\"reset_on_end\";b:0;s:16:\"display_duration\";b:1;s:11:\"invert_time\";b:1;s:13:\"toggle_invert\";b:1;s:5:\"ratio\";s:0:\"\";}}'),('','image.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),('','image.style.large',_binary 'a:8:{s:4:\"uuid\";s:36:\"29940d30-64d8-4da8-9c82-a253f2d27667\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.linkit_result_thumbnail',_binary 'a:8:{s:4:\"uuid\";s:36:\"6eea7178-ad4d-464d-90a5-16d53236deb2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PY0kMp7KIxvU4kBi5mcnD_DHTKUc1OkYCfaPliXjpa8\";}s:4:\"name\";s:23:\"linkit_result_thumbnail\";s:5:\"label\";s:23:\"Linkit result thumbnail\";s:7:\"effects\";a:1:{s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";a:4:{s:4:\"uuid\";s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:50;s:6:\"height\";i:50;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.medium',_binary 'a:8:{s:4:\"uuid\";s:36:\"1bf69c20-6eff-4470-93d3-bae2dc31f207\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.thumbnail',_binary 'a:8:{s:4:\"uuid\";s:36:\"3375957d-2d6c-475c-bc6b-124e63c6164a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.wide',_binary 'a:8:{s:4:\"uuid\";s:36:\"b652d976-a322-4aa9-9474-2415078a63e8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','jsonapi.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bbhVQEgCMWzCNQ9nBMR-PZeax3Tkujtue1HA7CE5574\";}s:9:\"read_only\";b:1;s:32:\"maintenance_header_retry_seconds\";a:2:{s:3:\"min\";i:5;s:3:\"max\";i:10;}}'),('','jsonapi_extras.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4_ifqxmFEAYSrGFkA63fLBYAWO-Fz9ACp9qVjkxPghg\";}s:11:\"path_prefix\";s:7:\"jsonapi\";s:13:\"include_count\";b:1;s:16:\"default_disabled\";b:0;s:32:\"validate_configuration_integrity\";b:1;}'),('','language.content_settings.path_alias.path_alias',_binary 'a:10:{s:4:\"uuid\";s:36:\"255480ac-2d85-450d-ba7f-1f49e3d9b8b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"path_alias\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dhjFABRzm52DkRXnYja5ZoHwjY0R3gEGic3KpDUXgRo\";}s:2:\"id\";s:21:\"path_alias.path_alias\";s:21:\"target_entity_type_id\";s:10:\"path_alias\";s:13:\"target_bundle\";s:10:\"path_alias\";s:16:\"default_langcode\";s:3:\"und\";s:18:\"language_alterable\";b:1;}'),('','language.content_settings.redirect.redirect',_binary 'a:10:{s:4:\"uuid\";s:36:\"8cc7a8b1-2dde-4238-aad8-64e49400f338\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"y734AXEpjry1Ppff_hQQBFQGJvYjF0fk1JoWtp5q2JY\";}s:2:\"id\";s:17:\"redirect.redirect\";s:21:\"target_entity_type_id\";s:8:\"redirect\";s:13:\"target_bundle\";s:8:\"redirect\";s:16:\"default_langcode\";s:3:\"und\";s:18:\"language_alterable\";b:1;}'),('','language.entity.en',_binary 'a:10:{s:4:\"uuid\";s:36:\"541e3fe7-505e-4e41-a296-2b93fab83b55\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lBXDpdDPXQtrfTJQhr6MjRJJEEyYSoRJ0acdvHLsWeA\";}s:2:\"id\";s:2:\"en\";s:5:\"label\";s:7:\"English\";s:9:\"direction\";s:3:\"ltr\";s:6:\"weight\";i:0;s:6:\"locked\";b:0;}'),('','language.entity.und',_binary 'a:10:{s:4:\"uuid\";s:36:\"f479fc2f-303e-4d96-b8dc-cf40b3c917a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNX6lLCKDaY83nCMh20My---y03KbiFlv802DKCCpvg\";}s:2:\"id\";s:3:\"und\";s:5:\"label\";s:13:\"Not specified\";s:9:\"direction\";s:3:\"ltr\";s:6:\"weight\";i:2;s:6:\"locked\";b:1;}'),('','language.entity.zxx',_binary 'a:10:{s:4:\"uuid\";s:36:\"577d2e0c-b2fc-4b0f-a051-dcb71bf1c920\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"35CefWbnzaiytcg3acexxz_GTvuwIjYd_ZTcmmR-tXA\";}s:2:\"id\";s:3:\"zxx\";s:5:\"label\";s:14:\"Not applicable\";s:9:\"direction\";s:3:\"ltr\";s:6:\"weight\";i:3;s:6:\"locked\";b:1;}'),('','language.mappings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EMWe7Yu4Q5eD-NUfNuQAWGBvYUNZPIinztEtONSmsDc\";}s:3:\"map\";a:10:{s:2:\"no\";s:2:\"nb\";s:2:\"pt\";s:5:\"pt-pt\";s:2:\"zh\";s:7:\"zh-hans\";s:5:\"zh-tw\";s:7:\"zh-hant\";s:5:\"zh-hk\";s:7:\"zh-hant\";s:5:\"zh-mo\";s:7:\"zh-hant\";s:6:\"zh-cht\";s:7:\"zh-hant\";s:5:\"zh-cn\";s:7:\"zh-hans\";s:5:\"zh-sg\";s:7:\"zh-hans\";s:6:\"zh-chs\";s:7:\"zh-hans\";}}'),('','language.negotiation',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uEePITI9tV6WqzmsTb7MfPCi5yPWXSxAN1xeLcYFQbM\";}s:7:\"session\";a:1:{s:9:\"parameter\";s:8:\"language\";}s:3:\"url\";a:3:{s:6:\"source\";s:11:\"path_prefix\";s:8:\"prefixes\";a:1:{s:2:\"en\";s:0:\"\";}s:7:\"domains\";a:1:{s:2:\"en\";s:0:\"\";}}s:17:\"selected_langcode\";s:12:\"site_default\";}'),('','language.types',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dqouFqVseNJNvEjsoYKxbinFOITuCxYhi4y2OTNQP_8\";}s:3:\"all\";a:3:{i:0;s:18:\"language_interface\";i:1;s:16:\"language_content\";i:2;s:12:\"language_url\";}s:12:\"configurable\";a:1:{i:0;s:18:\"language_interface\";}s:11:\"negotiation\";a:3:{s:16:\"language_content\";a:1:{s:7:\"enabled\";a:1:{s:18:\"language-interface\";i:0;}}s:12:\"language_url\";a:1:{s:7:\"enabled\";a:2:{s:12:\"language-url\";i:0;s:21:\"language-url-fallback\";i:1;}}s:18:\"language_interface\";a:1:{s:7:\"enabled\";a:1:{s:12:\"language-url\";i:0;}}}}'),('','linkit.linkit_profile.default',_binary 'a:9:{s:4:\"uuid\";s:36:\"24222d7c-50f5-45f4-8a23-489ca365134d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0Jw_BFJCCtWk187tIYvME58VFpYwPaAdrc4eRtAyHH0\";}s:5:\"label\";s:7:\"Default\";s:2:\"id\";s:7:\"default\";s:11:\"description\";s:24:\"A default Linkit profile\";s:8:\"matchers\";a:1:{s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";a:4:{s:2:\"id\";s:11:\"entity:node\";s:4:\"uuid\";s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";s:8:\"settings\";a:6:{s:8:\"metadata\";s:77:\"[node:content-type:name] #[node:nid] | [node:created:medium] by [node:author]\";s:7:\"bundles\";a:0:{}s:15:\"group_by_bundle\";b:0;s:19:\"include_unpublished\";b:0;s:17:\"substitution_type\";s:9:\"canonical\";s:5:\"limit\";i:100;}s:6:\"weight\";i:0;}}}'),('','locale.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cSdYeE-_AQETCNZnl8BMFS9-sVn5--VzAYILkpPBUbM\";}s:13:\"cache_strings\";b:1;s:17:\"translate_english\";b:0;s:10:\"javascript\";a:1:{s:9:\"directory\";s:9:\"languages\";}s:11:\"translation\";a:8:{s:10:\"use_source\";s:16:\"remote_and_local\";s:16:\"default_filename\";s:30:\"%project-%version.%language.po\";s:22:\"default_server_pattern\";s:87:\"https://ftp.drupal.org/files/translations/%core/%project/%project-%version.%language.po\";s:20:\"overwrite_customized\";b:0;s:24:\"overwrite_not_customized\";b:1;s:20:\"update_interval_days\";i:0;s:4:\"path\";s:32:\"sites/default/files/translations\";s:14:\"import_enabled\";b:1;}}'),('','menu_item_extras.utility',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJyVsRDycEefcdJUBrw82evYJtCphyLU4BV5MMQ5rPQ\";}s:24:\"entity_type_build_status\";b:1;}'),('','menu_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),('','metatag.metatag_defaults.403',_binary 'a:8:{s:4:\"uuid\";s:36:\"aa7a542d-baa7-40ad-afc6-49bb56062750\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RDCkFL0NDt75Gwioooxo1iuA1S50xTVsBOgX__c6wTw\";}s:2:\"id\";s:3:\"403\";s:5:\"label\";s:17:\"403 access denied\";s:4:\"tags\";a:3:{s:6:\"robots\";s:7:\"noindex\";s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),('','metatag.metatag_defaults.404',_binary 'a:8:{s:4:\"uuid\";s:36:\"cf9933a3-28ef-476d-9838-4a92e3eeb1fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"puBstSLDz8mbaWU357zaqQDBGMGsJzG0j-TQNQkjg20\";}s:2:\"id\";s:3:\"404\";s:5:\"label\";s:18:\"404 page not found\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),('','metatag.metatag_defaults.front',_binary 'a:8:{s:4:\"uuid\";s:36:\"c52f9ced-fccb-43cb-9fe2-a8040eb13542\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1noCXlegCr5HFehQRF1ViXy1jhU1jZ_sNN99a8Sj5jo\";}s:2:\"id\";s:5:\"front\";s:5:\"label\";s:10:\"Front page\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),('','metatag.metatag_defaults.global',_binary 'a:8:{s:4:\"uuid\";s:36:\"fa0b3dbf-4333-431d-8522-9036aea72657\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sL588ui1E_8-2c_UupwyYxcqX2OVyMFp3HTLbbFqvPc\";}s:2:\"id\";s:6:\"global\";s:5:\"label\";s:6:\"Global\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:18:\"[current-page:url]\";s:5:\"title\";s:34:\"[current-page:title] | [site:name]\";}}'),('','metatag.metatag_defaults.node',_binary 'a:8:{s:4:\"uuid\";s:36:\"d7d2466e-ab6f-4c1b-a923-ca531f2fa600\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rpwvgyEURXLz_JjgMCrkS1rUv-0k3L79BpO-ReN7fDI\";}s:2:\"id\";s:4:\"node\";s:5:\"label\";s:7:\"Content\";s:4:\"tags\";a:3:{s:5:\"title\";s:26:\"[node:title] | [site:name]\";s:11:\"description\";s:14:\"[node:summary]\";s:13:\"canonical_url\";s:10:\"[node:url]\";}}'),('','metatag.metatag_defaults.taxonomy_term',_binary 'a:8:{s:4:\"uuid\";s:36:\"d237fb3f-9063-48b4-82ba-1dfe13df5594\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"92bXZdyYJ5xqukdfmGRr_CYcwm1vfuS8b8aJ7X_G7E0\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[term:url]\";s:11:\"description\";s:18:\"[term:description]\";s:5:\"title\";s:25:\"[term:name] | [site:name]\";}}'),('','metatag.metatag_defaults.user',_binary 'a:8:{s:4:\"uuid\";s:36:\"b8863b10-cb33-4649-8d52-ceac3c926829\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MvQPTbQx0Vxwy0ordSHyixdZmLCMpvMdLD69dlwkrKc\";}s:2:\"id\";s:4:\"user\";s:5:\"label\";s:4:\"User\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[user:url]\";s:11:\"description\";s:11:\"[site:name]\";s:5:\"title\";s:33:\"[user:display-name] | [site:name]\";}}'),('','metatag.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DrYt8PcXA0xB3C3L1SvtefnkO5SwUonhY3n4Ld8yun4\";}s:18:\"entity_type_groups\";a:0:{}s:9:\"separator\";s:0:\"\";s:15:\"tag_trim_method\";s:11:\"beforeValue\";s:18:\"tag_trim_maxlength\";a:0:{}s:21:\"tag_scroll_max_height\";s:0:\"\";s:13:\"use_maxlength\";b:1;s:12:\"tag_trim_end\";s:14:\"|.,-:;/+&([{\"\'\";}'),('','node.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),('','node.type.article',_binary 'a:12:{s:4:\"uuid\";s:36:\"59988f5b-edd5-420c-9c7c-ec760037efc2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:1;}'),('','node.type.page',_binary 'a:12:{s:4:\"uuid\";s:36:\"f4c4b6bf-cd51-4c75-a261-fd038e87f35d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','node.type.webform',_binary 'a:12:{s:4:\"uuid\";s:36:\"f6f57731-a98c-4930-9cb9-50e4bbe5c135\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:12:\"webform_node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BuY_3PjmYtRTSuvyFORJZUe0-TQiNXEE6yYQ_dkjxW8\";}s:4:\"name\";s:7:\"Webform\";s:4:\"type\";s:7:\"webform\";s:11:\"description\";s:37:\"A basic page with a webform attached.\";s:4:\"help\";s:0:\"\";s:12:\"new_revision\";b:0;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:1;}'),('','olivero.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),('','pathauto.pattern.article',_binary 'a:12:{s:4:\"uuid\";s:36:\"8b4b8af3-f1de-4297-b432-2332d9ae25f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:7:\"article\";s:5:\"label\";s:7:\"Article\";s:4:\"type\";s:23:\"canonical_entities:node\";s:7:\"pattern\";s:20:\"article/[node:title]\";s:18:\"selection_criteria\";a:1:{s:36:\"f09b7e0b-17d8-4b74-80a8-271b585f6ff7\";a:5:{s:2:\"id\";s:18:\"entity_bundle:node\";s:6:\"negate\";b:0;s:4:\"uuid\";s:36:\"f09b7e0b-17d8-4b74-80a8-271b585f6ff7\";s:15:\"context_mapping\";a:1:{s:4:\"node\";s:4:\"node\";}s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}}s:15:\"selection_logic\";s:3:\"and\";s:6:\"weight\";i:-5;s:13:\"relationships\";a:0:{}}'),('','pathauto.pattern.basic_page',_binary 'a:12:{s:4:\"uuid\";s:36:\"831fa73e-f731-4650-a164-eec6143af109\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:10:\"basic_page\";s:5:\"label\";s:10:\"Basic Page\";s:4:\"type\";s:23:\"canonical_entities:node\";s:7:\"pattern\";s:17:\"page/[node:title]\";s:18:\"selection_criteria\";a:1:{s:36:\"67338c08-4969-434a-8357-4a8abb2ede22\";a:5:{s:2:\"id\";s:18:\"entity_bundle:node\";s:6:\"negate\";b:0;s:4:\"uuid\";s:36:\"67338c08-4969-434a-8357-4a8abb2ede22\";s:15:\"context_mapping\";a:1:{s:4:\"node\";s:4:\"node\";}s:7:\"bundles\";a:1:{s:4:\"page\";s:4:\"page\";}}}s:15:\"selection_logic\";s:3:\"and\";s:6:\"weight\";i:-5;s:13:\"relationships\";a:0:{}}'),('','pathauto.settings',_binary 'a:13:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SwvLp8snyPEExF41CaJJYdPUVomofLqtXvwciHc4cPg\";}s:20:\"enabled_entity_types\";a:1:{i:0;s:4:\"user\";}s:11:\"punctuation\";a:1:{s:6:\"hyphen\";i:1;}s:7:\"verbose\";b:0;s:9:\"separator\";s:1:\"-\";s:10:\"max_length\";i:100;s:20:\"max_component_length\";i:100;s:13:\"transliterate\";b:1;s:12:\"reduce_ascii\";b:0;s:4:\"case\";b:1;s:12:\"ignore_words\";s:134:\"a, an, as, at, before, but, by, for, from, is, in, into, like, of, off, on, onto, per, since, than, the, this, that, to, up, via, with\";s:13:\"update_action\";i:2;s:11:\"safe_tokens\";a:6:{i:0;s:5:\"alias\";i:1;s:4:\"path\";i:2;s:9:\"join-path\";i:3;s:9:\"login-url\";i:4;s:3:\"url\";i:5;s:9:\"url-brief\";}}'),('','rabbit_hole.behavior_settings.default',_binary 'a:13:{s:4:\"uuid\";s:36:\"76010145-adf2-4485-8e92-6a2464384ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzh9CgsYCGxPEcbR3ieT1la6e43lMv-ivoN7oZJKkQQ\";}s:2:\"id\";s:7:\"default\";s:14:\"entity_type_id\";N;s:9:\"entity_id\";N;s:6:\"action\";s:12:\"display_page\";s:14:\"allow_override\";i:1;s:8:\"redirect\";s:0:\"\";s:13:\"redirect_code\";i:0;s:24:\"redirect_fallback_action\";s:13:\"access_denied\";}'),('','rabbit_hole.behavior_settings.default_bundle',_binary 'a:13:{s:4:\"uuid\";s:36:\"ca871477-04f2-44a1-858c-731fed4e2a7d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qUkgsWZRCa_sLIn5JsMzB3xnx5ekIsVeGGZr7T0s9MY\";}s:2:\"id\";s:14:\"default_bundle\";s:14:\"entity_type_id\";N;s:9:\"entity_id\";N;s:6:\"action\";s:12:\"display_page\";s:14:\"allow_override\";i:1;s:8:\"redirect\";s:0:\"\";s:13:\"redirect_code\";i:0;s:24:\"redirect_fallback_action\";s:13:\"access_denied\";}'),('','redirect.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FEwQLW1wXW7fiJdG1B2bxW1c_-k6w-r-3V3bSsW6PqM\";}s:13:\"auto_redirect\";b:1;s:19:\"default_status_code\";i:301;s:23:\"passthrough_querystring\";b:1;s:7:\"warning\";b:0;s:17:\"ignore_admin_path\";b:0;s:12:\"access_check\";b:0;s:24:\"route_normalizer_enabled\";b:1;}'),('','rest.resource.entity.webform',_binary 'a:8:{s:4:\"uuid\";s:36:\"bef3799e-1ae8-4704-8d0f-a73fe64c4f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"serialization\";i:1;s:4:\"user\";i:2;s:7:\"webform\";}}s:2:\"id\";s:14:\"entity.webform\";s:9:\"plugin_id\";s:14:\"entity:webform\";s:11:\"granularity\";s:8:\"resource\";s:13:\"configuration\";a:3:{s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:7:\"formats\";a:1:{i:0;s:4:\"json\";}s:14:\"authentication\";a:1:{i:0;s:6:\"cookie\";}}}'),('','rest.resource.entity.webform_options',_binary 'a:8:{s:4:\"uuid\";s:36:\"938e4e98-191f-4790-bc0b-9a8a5d6cc7c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"serialization\";i:1;s:4:\"user\";i:2;s:7:\"webform\";}}s:2:\"id\";s:22:\"entity.webform_options\";s:9:\"plugin_id\";s:22:\"entity:webform_options\";s:11:\"granularity\";s:8:\"resource\";s:13:\"configuration\";a:3:{s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:7:\"formats\";a:1:{i:0;s:4:\"json\";}s:14:\"authentication\";a:1:{i:0;s:6:\"cookie\";}}}'),('','rest.resource.webform_rest_elements',_binary 'a:8:{s:4:\"uuid\";s:36:\"d320e37f-6fd5-4580-9cfe-3dcd1ff080cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"serialization\";i:1;s:4:\"user\";i:2;s:12:\"webform_rest\";}}s:2:\"id\";s:21:\"webform_rest_elements\";s:9:\"plugin_id\";s:21:\"webform_rest_elements\";s:11:\"granularity\";s:8:\"resource\";s:13:\"configuration\";a:3:{s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:7:\"formats\";a:1:{i:0;s:4:\"json\";}s:14:\"authentication\";a:1:{i:0;s:6:\"cookie\";}}}'),('','rest.resource.webform_rest_submit',_binary 'a:8:{s:4:\"uuid\";s:36:\"2f7011ea-42d4-4e84-9783-ecb872c2e2e1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"serialization\";i:1;s:4:\"user\";i:2;s:12:\"webform_rest\";}}s:2:\"id\";s:19:\"webform_rest_submit\";s:9:\"plugin_id\";s:19:\"webform_rest_submit\";s:11:\"granularity\";s:8:\"resource\";s:13:\"configuration\";a:3:{s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:7:\"formats\";a:1:{i:0;s:4:\"json\";}s:14:\"authentication\";a:1:{i:0;s:6:\"cookie\";}}}'),('','shortcut.set.default',_binary 'a:7:{s:4:\"uuid\";s:36:\"903954a5-8548-48e0-9cb6-eec525501eed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),('','simple_sitemap.custom_links.default',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"25hWeYa4sasuJtHqKKcEN_nYiuEC1lMPYHsn5dawJEw\";}s:5:\"links\";a:1:{i:0;a:3:{s:4:\"path\";s:1:\"/\";s:8:\"priority\";s:3:\"1.0\";s:10:\"changefreq\";s:5:\"daily\";}}}'),('','simple_sitemap.settings',_binary 'a:16:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MUpaAk1hn-0Ph4OFw3DD_6gUF9KbGwxja9Y0qmampzo\";}s:9:\"max_links\";i:2000;s:13:\"cron_generate\";b:1;s:22:\"cron_generate_interval\";i:0;s:17:\"generate_duration\";i:10000;s:23:\"entities_per_queue_item\";i:50;s:17:\"remove_duplicates\";b:1;s:17:\"skip_untranslated\";b:1;s:3:\"xsl\";b:1;s:8:\"base_url\";s:0:\"\";s:15:\"default_variant\";s:7:\"default\";s:27:\"custom_links_include_images\";b:0;s:25:\"disable_language_hreflang\";b:0;s:13:\"hide_branding\";b:0;s:18:\"excluded_languages\";a:0:{}s:20:\"enabled_entity_types\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"taxonomy_term\";i:2;s:17:\"menu_link_content\";}}'),('','simple_sitemap.sitemap.default',_binary 'a:10:{s:4:\"uuid\";s:36:\"38c791a5-1548-4677-810e-c994dd439795\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:36:\"simple_sitemap.type.default_hreflang\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rzLPapRSW-bgTs4MObzlqsqwj5IxPGO9EQZolw2ZzFc\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";s:11:\"description\";s:81:\"The default hreflang sitemap - lists URLs to be indexed by modern search engines.\";s:4:\"type\";s:16:\"default_hreflang\";s:6:\"weight\";i:0;}'),('','simple_sitemap.sitemap.index',_binary 'a:10:{s:4:\"uuid\";s:36:\"d0b3a005-f27b-40db-a375-17c6125c3e08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:25:\"simple_sitemap.type.index\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WffB95XdMvoUEvymTyLFLB-Q_JnCbbjy9Kj7TvlzN9s\";}s:2:\"id\";s:5:\"index\";s:5:\"label\";s:13:\"Sitemap Index\";s:11:\"description\";s:193:\"The sitemap index listing all other sitemaps - useful if there are at least two other sitemaps. In most cases this sitemap should be last in the generation queue and set as the default sitemap.\";s:4:\"type\";s:5:\"index\";s:6:\"weight\";i:1000;}'),('','simple_sitemap.type.default_hreflang',_binary 'a:10:{s:4:\"uuid\";s:36:\"87a31fbb-d316-4031-9da8-27a78f161b1e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yaHZPVGZtW3BUvzzdMgc4ed5l4GCiFjcgYlLZmupcqA\";}s:2:\"id\";s:16:\"default_hreflang\";s:5:\"label\";s:16:\"Default hreflang\";s:11:\"description\";s:102:\"The default hreflang sitemap type. A sitemap of this type is understood by most modern search engines.\";s:17:\"sitemap_generator\";s:7:\"default\";s:14:\"url_generators\";a:4:{i:0;s:6:\"custom\";i:1;s:6:\"entity\";i:2;s:24:\"entity_menu_link_content\";i:3;s:9:\"arbitrary\";}}'),('','simple_sitemap.type.index',_binary 'a:10:{s:4:\"uuid\";s:36:\"39c7fcad-3c78-4c1d-9e97-a160469913a4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yS_TZXc9X2zr2RfAwk7momW3LG9wra--H2ApqA5Vgak\";}s:2:\"id\";s:5:\"index\";s:5:\"label\";s:13:\"Sitemap Index\";s:11:\"description\";s:89:\"The sitemap index sitemap type. A sitemap of this type lists sitemaps of all other types.\";s:17:\"sitemap_generator\";s:5:\"index\";s:14:\"url_generators\";a:1:{i:0;s:5:\"index\";}}'),('','system.action.comment_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c7d14f6a-6e6a-45ea-8fa6-b13072dfe4b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpBH8OmL4sdesCdeZLsW8KOutB5gkbreWJbfjhfFKaQ\";}s:2:\"id\";s:21:\"comment_delete_action\";s:5:\"label\";s:14:\"Delete comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:28:\"entity:delete_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"592b4324-cb2f-4348-a5e7-e7465b63312f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C00dyL_W_5M0nFlgUB3lWUTUs96jn51Jw1MLHVEHZD0\";}s:2:\"id\";s:22:\"comment_publish_action\";s:5:\"label\";s:15:\"Publish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:29:\"entity:publish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"825fd299-837b-45d7-99f0-05d512a7b4e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lfyE_snmvfg_EQ3VDyhUtGAXgmqtEiqa46I3bTMg8DU\";}s:2:\"id\";s:19:\"comment_save_action\";s:5:\"label\";s:12:\"Save comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:26:\"entity:save_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"60d38e09-2fb3-41b8-b097-8cfd3153ea58\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tWOIjSMobEWOFZddMkNqb9JySbOVwE1diC6NRqcfLTk\";}s:2:\"id\";s:24:\"comment_unpublish_action\";s:5:\"label\";s:17:\"Unpublish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:31:\"entity:unpublish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"9d8c9ee3-e66d-4a91-96e7-930a4d37b701\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"0d5b6f2e-6a01-4548-80d0-2b2f921f5ce1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f1a2a8bf-e58b-4436-8b2d-858b28738221\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_promote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ad08f939-8821-4b11-949f-8731eb3b08ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"b0e3c96b-6c2c-461b-8ffc-a06d3863e7f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"bb994d72-a95d-4051-8c29-3d7b939b7aeb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpromote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"914162ea-d84f-4516-bd2b-4f0706afdc16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"25777620-04cb-41ec-8e16-8c4348c4f694\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.pathauto_update_alias_node',_binary 'a:10:{s:4:\"uuid\";s:36:\"eee484c2-7858-45fd-b4dd-731b43fbff3a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Cr0CsPUSuio4ClP7bOTqHBefJOLtN5KPyKyYj9E4qvQ\";}s:2:\"id\";s:26:\"pathauto_update_alias_node\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),('','system.action.pathauto_update_alias_user',_binary 'a:10:{s:4:\"uuid\";s:36:\"3f3a79f9-8861-47f0-9a48-7763b20662c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6eiNWATGTd3lUEKuxNPNyDRDVMsUlM0HS90_R6JJLUI\";}s:2:\"id\";s:26:\"pathauto_update_alias_user\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),('','system.action.redirect_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"3bcda49f-6cd5-4dd0-9351-32a81d30f2a1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vcnRZRvBqTbK3nZ2M4_lKPlEGc8GjPzgaqapYUfyX8M\";}s:2:\"id\";s:22:\"redirect_delete_action\";s:5:\"label\";s:15:\"Delete redirect\";s:4:\"type\";s:8:\"redirect\";s:6:\"plugin\";s:22:\"redirect_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c81c6465-71f1-49ec-87c0-665cb21bddc1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"419ab97d-38b5-44bf-8bc7-4363dd8cd152\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_add_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"fc5862d9-e21c-4c86-9dbf-f476320fc76b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_add_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"80b46801-8606-45a5-ac48-556164d453f8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:35:\"user_add_role_action.content_editor\";s:5:\"label\";s:51:\"Add the Content editor role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_block_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6fddfca8-1c8f-41ce-8413-06d675230a6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_cancel_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7d87b2ec-5200-4708-ab2e-b9270cd87667\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_remove_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"4efe6291-b04e-4adc-96a1-342f84a493c7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_remove_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"b838c238-785f-4fa9-bda4-f6d575f823a2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:38:\"user_remove_role_action.content_editor\";s:5:\"label\";s:56:\"Remove the Content editor role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_unblock_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"8e84e417-0929-4c2e-9659-9e54cc04b4fd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_archive_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"342b3323-7057-4ffe-ade0-4338b9bba972\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OmnschvBLb9ZJn0iVyBd2odf8U8Nt0INjRbRMixZw9U\";}s:2:\"id\";s:22:\"webform_archive_action\";s:5:\"label\";s:15:\"Archive webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:22:\"webform_archive_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_close_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ddc1f1da-5251-49ef-9ea8-eaff39c9a1a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dl-1T9PDkraB7MyMUjTJAioPEx6UNvIB9gqmnB1CRkk\";}s:2:\"id\";s:20:\"webform_close_action\";s:5:\"label\";s:13:\"Close webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:20:\"webform_close_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f2218b96-cb4e-4226-bdca-6170e30bc34f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e1bCTp0ryXZZtnS9nlVAbtoWz3-8fmbNlqKY3GHzbsM\";}s:2:\"id\";s:21:\"webform_delete_action\";s:5:\"label\";s:14:\"Delete webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:21:\"webform_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_open_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"4cf610b1-6607-4437-8e3c-20c2d77f21ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AK83C-dOZEPruvi6GbkuhihWLnO4VtrbesqSC6izf4o\";}s:2:\"id\";s:19:\"webform_open_action\";s:5:\"label\";s:12:\"Open webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:19:\"webform_open_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f84c0b0d-7607-4ce0-8236-398e642bdbc7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBnl4vapW7sy5bRi7TcF-ueJnvz7aZNLif95ifvhfTQ\";}s:2:\"id\";s:32:\"webform_submission_delete_action\";s:5:\"label\";s:17:\"Delete submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:32:\"webform_submission_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_lock_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c14576ba-6a4d-4bbd-b73b-8c0eef62c795\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MKmZlPRk3OJKNcYdYxSeZGQUh7LMah6MRShfkzch4bk\";}s:2:\"id\";s:35:\"webform_submission_make_lock_action\";s:5:\"label\";s:15:\"Lock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:35:\"webform_submission_make_lock_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7794e8ff-9168-4532-9036-0e67d7591d62\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mPWBT52fKHyINRl9S3cCWFxY3rKbwkIRxaK6sIA26oo\";}s:2:\"id\";s:37:\"webform_submission_make_sticky_action\";s:5:\"label\";s:20:\"Star/flag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_unlock_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"471e29d2-dca7-49e2-9e95-9bd8584625b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"begZ0-RmTzO_zDAwEKA2lKvtGYw1vbFOzbQOJzUbZX0\";}s:2:\"id\";s:37:\"webform_submission_make_unlock_action\";s:5:\"label\";s:17:\"Unlock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_unlock_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"83915ff9-c752-4733-8ea4-73564fa9dd24\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4gTFiUsdp7gw6yWUlDbKFEasZLCgXWWCmm7eJejay0\";}s:2:\"id\";s:39:\"webform_submission_make_unsticky_action\";s:5:\"label\";s:24:\"Unstar/unflag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:39:\"webform_submission_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_unarchive_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ffe260a0-779e-4401-b0b8-40ddaffc73dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aqi5Ftlnhe9KyOowpK7CanEvJMBBo8xAR1dA99bKOuc\";}s:2:\"id\";s:24:\"webform_unarchive_action\";s:5:\"label\";s:15:\"Restore webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:24:\"webform_unarchive_action\";s:13:\"configuration\";a:0:{}}'),('','system.advisories',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),('','system.cron',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),('','system.date',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),('','system.diff',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),('','system.feature_flags',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),('','system.file',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),('','system.image',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),('','system.image.gd',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:80;}'),('','system.logging',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),('','system.mail',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:2:{s:7:\"default\";s:8:\"php_mail\";s:7:\"webform\";s:16:\"webform_php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),('','system.maintenance',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),('','system.menu.account',_binary 'a:9:{s:4:\"uuid\";s:36:\"b8440982-72a9-44aa-afc8-0c3d14b807bd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),('','system.menu.admin',_binary 'a:9:{s:4:\"uuid\";s:36:\"820b8378-aa9a-4e15-bbdf-809cea9e6a97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),('','system.menu.footer',_binary 'a:9:{s:4:\"uuid\";s:36:\"7cb08dc9-4331-47ba-a3ad-aac0e10c8e7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),('','system.menu.main',_binary 'a:9:{s:4:\"uuid\";s:36:\"3762582d-2630-48d8-ab96-b29392c1a26a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),('','system.menu.tools',_binary 'a:9:{s:4:\"uuid\";s:36:\"b61fcb8a-ca27-4780-86d8-575615409f31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),('','system.performance',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}}'),('','system.rss',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),('','system.site',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"62840b97-650e-41be-abc8-edb78d15585b\";s:4:\"name\";s:8:\"JSON:API\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:7:\"/node/4\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),('','system.theme',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:3:\"gin\";s:7:\"default\";s:7:\"olivero\";}'),('','system.theme.global',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),('','taxonomy.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),('','taxonomy.vocabulary.tags',_binary 'a:10:{s:4:\"uuid\";s:36:\"6d3544ef-5124-4a14-88e1-ce69ad1016dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),('','text.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),('','update.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:0:{}s:9:\"threshold\";s:3:\"all\";}}'),('','user.flood',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),('','user.mail',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),('','user.role.administrator',_binary 'a:10:{s:4:\"uuid\";s:36:\"6eb8a031-0e43-4c9d-af8a-e9962b82903a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),('','user.role.anonymous',_binary 'a:10:{s:4:\"uuid\";s:36:\"d281cf36-4128-465b-8870-56e1ab0fac55\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:29:\"filter.format.restricted_html\";i:1;s:35:\"rest.resource.webform_rest_elements\";i:2;s:33:\"rest.resource.webform_rest_submit\";}s:6:\"module\";a:5:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:6:\"filter\";i:3;s:4:\"rest\";i:4;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:6:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:29:\"access site-wide contact form\";i:3;s:33:\"restful get webform_rest_elements\";i:4;s:32:\"restful post webform_rest_submit\";i:5;s:31:\"use text format restricted_html\";}}'),('','user.role.authenticated',_binary 'a:10:{s:4:\"uuid\";s:36:\"02e47401-b1fc-4d8a-9928-a86f0f8611ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:24:\"filter.format.basic_html\";i:1;s:29:\"filter.format.webform_default\";i:2;s:35:\"rest.resource.webform_rest_elements\";i:3;s:33:\"rest.resource.webform_rest_submit\";}s:6:\"module\";a:7:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:4:\"file\";i:3;s:6:\"filter\";i:4;s:4:\"rest\";i:5;s:8:\"shortcut\";i:6;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:11:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:16:\"access shortcuts\";i:3;s:29:\"access site-wide contact form\";i:4;s:16:\"delete own files\";i:5;s:13:\"post comments\";i:6;s:33:\"restful get webform_rest_elements\";i:7;s:32:\"restful post webform_rest_submit\";i:8;s:21:\"skip comment approval\";i:9;s:26:\"use text format basic_html\";i:10;s:31:\"use text format webform_default\";}}'),('','user.role.content_editor',_binary 'a:10:{s:4:\"uuid\";s:36:\"d3ede7c1-114f-4c1a-bda4-af6f0b80e54e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:24:\"filter.format.basic_html\";i:1;s:23:\"filter.format.full_html\";i:2;s:17:\"node.type.article\";i:3;s:14:\"node.type.page\";i:4;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:12:{i:0;s:7:\"comment\";i:1;s:10:\"contextual\";i:2;s:4:\"file\";i:3;s:6:\"filter\";i:4;s:4:\"node\";i:5;s:4:\"path\";i:6;s:8:\"pathauto\";i:7;s:11:\"rabbit_hole\";i:8;s:8:\"redirect\";i:9;s:6:\"system\";i:10;s:8:\"taxonomy\";i:11;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:33:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:19:\"administer pathauto\";i:6;s:28:\"administer redirect settings\";i:7;s:20:\"administer redirects\";i:8;s:22:\"administer url aliases\";i:9;s:19:\"bulk delete aliases\";i:10;s:19:\"bulk update aliases\";i:11;s:22:\"create article content\";i:12;s:19:\"create page content\";i:13;s:20:\"create terms in tags\";i:14;s:18:\"create url aliases\";i:15;s:24:\"delete article revisions\";i:16;s:26:\"delete own article content\";i:17;s:16:\"delete own files\";i:18;s:23:\"delete own page content\";i:19;s:21:\"delete page revisions\";i:20;s:24:\"edit own article content\";i:21;s:17:\"edit own comments\";i:22;s:21:\"edit own page content\";i:23;s:18:\"edit terms in tags\";i:24;s:22:\"notify of path changes\";i:25;s:23:\"rabbit hole bypass node\";i:26;s:32:\"rabbit hole bypass taxonomy_term\";i:27;s:20:\"revert all revisions\";i:28;s:26:\"use text format basic_html\";i:29;s:25:\"use text format full_html\";i:30;s:18:\"view all revisions\";i:31;s:28:\"view own unpublished content\";i:32;s:29:\"view the administration theme\";}}'),('','user.settings',_binary 'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Y-Xpk050V3opj3WiFb4oUbVT9S7fDA1XLpigO-qVMVQ\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:10:\"admin_only\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),('','views.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:1:{i:0;s:13:\"jsonapi_views\";}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),('','views.view.archive',_binary 'a:13:{s:4:\"uuid\";s:36:\"64aae2b3-26a1-4bfc-ac1f-04aeec606c61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.block_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"b4c93afb-55bd-4d60-9f83-9f1d440c911a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.comment',_binary 'a:13:{s:4:\"uuid\";s:36:\"af87d0b4-0ac9-4106-a4aa-935bef82b793\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"H6JHGXl97yOKmVaV62SoY1ki1tWVdyD44fgOkdmVyRM\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:8:\"Comments\";s:6:\"module\";s:7:\"comment\";s:11:\"description\";s:25:\"Find and manage comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:26:{s:5:\"title\";s:8:\"Comments\";s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:24:\"comment_unpublish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"next ›\";s:8:\"previous\";s:12:\"‹ previous\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"administer comments\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:17:\"comment_bulk_form\";s:17:\"comment_bulk_form\";s:7:\"subject\";s:7:\"subject\";s:3:\"uid\";s:3:\"uid\";s:9:\"entity_id\";s:9:\"entity_id\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:17:\"comment_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"subject\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"entity_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:1;s:13:\"use_more_text\";s:4:\"more\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:14:\"page_published\";a:6:{s:2:\"id\";s:14:\"page_published\";s:13:\"display_title\";s:18:\"Published comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:19:\"display_description\";s:30:\"The approved comments listing.\";s:15:\"display_comment\";s:0:\"\";s:13:\"exposed_block\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:21:\"admin/content/comment\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:8:\"Comments\";s:11:\"description\";s:18:\"Comments published\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:15:\"page_unapproved\";a:6:{s:2:\"id\";s:15:\"page_unapproved\";s:13:\"display_title\";s:19:\"Unapproved comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:8:{s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:22:\"comment_publish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:3:{s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:19:\"display_description\";s:32:\"The unapproved comments listing.\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:30:\"admin/content/comment/approval\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:19:\"Unapproved comments\";s:11:\"description\";s:19:\"Comments unapproved\";s:6:\"weight\";i:1;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}}}'),('','views.view.comments_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"6346d08f-a177-4e83-a747-6b308aa63315\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:7:\"comment\";i:1;s:4:\"node\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFOucxH8PAXDQ2kViCcAHgK-JMCcxVkpIMzD56EfpZo\";}s:2:\"id\";s:15:\"comments_recent\";s:5:\"label\";s:15:\"Recent comments\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:16:\"Recent comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:14:{s:5:\"title\";s:15:\"Recent comments\";s:6:\"fields\";a:2:{s:7:\"subject\";a:26:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:1:{s:4:\"type\";s:5:\"basic\";}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:15:\"access comments\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:2:{s:7:\"created\";a:12:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;}s:3:\"cid\";a:12:{s:2:\"id\";s:3:\"cid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"cid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"cid\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"cid\";}s:7:\"exposed\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:11:\"status_node\";a:10:{s:2:\"id\";s:11:\"status_node\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"node\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:2:{s:22:\"default_field_elements\";b:1;s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:4:\"node\";a:5:{s:2:\"id\";s:4:\"node\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"node\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:15:\"Recent comments\";s:14:\"block_category\";s:13:\"Lists (Views)\";s:5:\"allow\";a:1:{s:14:\"items_per_page\";b:1;}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content',_binary 'a:13:{s:4:\"uuid\";s:36:\"411c53b7-69dc-4ed5-b1d4-84bafe5b08c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d7p-wwJZ_Wmz1gnvla9jDtRsjOaWAhPoIoW9w3vo4R4\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:14:\"field_language\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"94d1a705-2830-41cf-9d68-7f6f7cf4bf6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.files',_binary 'a:13:{s:4:\"uuid\";s:36:\"ca1f0b7a-286d-4a9a-9741-13d1f2ff8c31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NYJWABHsIFg-cU-Qya8fiMuQSM4rirBEfPFqkgRtsKA\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:26:\"@count place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.frontpage',_binary 'a:13:{s:4:\"uuid\";s:36:\"ba1d2200-30f3-40f8-a597-b4f370e813e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.glossary',_binary 'a:13:{s:4:\"uuid\";s:36:\"6660456c-c025-42e0-94a2-7e6daffa6992\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.redirect',_binary 'a:13:{s:4:\"uuid\";s:36:\"64bc6974-4eb3-4942-b516-db108a373cea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:8:\"redirect\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I9VqfbwK5ZyKzL7810d0fswaadU6riFT3kPL0yxcpLs\";}s:2:\"id\";s:8:\"redirect\";s:5:\"label\";s:8:\"Redirect\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:17:\"List of redirects\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"redirect\";s:10:\"base_field\";s:3:\"rid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"administer redirects\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:7:{s:14:\"items_per_page\";i:50;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:12:\"‹ previous\";s:4:\"next\";s:8:\"next ›\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:6:{s:21:\"redirect_source__path\";s:21:\"redirect_source__path\";s:22:\"redirect_redirect__uri\";s:22:\"redirect_redirect__uri\";s:11:\"status_code\";s:11:\"status_code\";s:8:\"language\";s:8:\"language\";s:7:\"created\";s:7:\"created\";s:10:\"operations\";s:10:\"operations\";}s:4:\"info\";a:6:{s:21:\"redirect_source__path\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:22:\"redirect_redirect__uri\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"status_code\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"language\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:6:\"fields\";a:7:{s:18:\"redirect_bulk_form\";a:26:{s:2:\"id\";s:18:\"redirect_bulk_form\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:18:\"redirect_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:14:\"With selection\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:18:\"redirect_bulk_form\";}s:21:\"redirect_source__path\";a:37:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:4:\"From\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:4:\"path\";s:4:\"type\";s:15:\"redirect_source\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:5:\"field\";}s:22:\"redirect_redirect__uri\";a:6:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"status_code\";a:6:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"language\";a:6:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:27:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:8:\"fallback\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";}s:10:\"operations\";a:5:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:10:\"operations\";s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:4:{s:21:\"redirect_source__path\";a:16:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:24:\"redirect_source__path_op\";s:5:\"label\";s:4:\"From\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:24:\"redirect_source__path_op\";s:10:\"identifier\";s:21:\"redirect_source__path\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:6:\"string\";}s:22:\"redirect_redirect__uri\";a:16:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:25:\"redirect_redirect__uri_op\";s:5:\"label\";s:2:\"To\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:25:\"redirect_redirect__uri_op\";s:10:\"identifier\";s:22:\"redirect_redirect__uri\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"status_code\";a:16:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:14:\"status_code_op\";s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:14:\"status_code_op\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:7:{i:1;a:3:{s:5:\"title\";s:20:\"300 Multiple Choices\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"300\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:2;a:3:{s:5:\"title\";s:21:\"301 Moved Permanently\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"301\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:3;a:3:{s:5:\"title\";s:9:\"302 Found\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"302\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:4;a:3:{s:5:\"title\";s:13:\"303 See Other\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"303\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:5;a:3:{s:5:\"title\";s:16:\"304 Not Modified\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"304\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:6;a:3:{s:5:\"title\";s:13:\"305 Use Proxy\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"305\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:7;a:3:{s:5:\"title\";s:22:\"307 Temporary Redirect\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"307\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:7:\"numeric\";}s:8:\"language\";a:16:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"language_op\";s:5:\"label\";s:17:\"Original language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"language_op\";s:10:\"identifier\";s:8:\"language\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:8:\"language\";}}s:5:\"sorts\";a:0:{}s:5:\"title\";s:8:\"Redirect\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"There is no redirect yet.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:0:{}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:14:\"display_plugin\";s:4:\"page\";s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:28:\"admin/config/search/redirect\";}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}}}'),('','views.view.taxonomy_term',_binary 'a:13:{s:4:\"uuid\";s:36:\"612a6feb-f41d-4b4d-8eda-dc2fb8df706f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.user_admin_people',_binary 'a:13:{s:4:\"uuid\";s:36:\"6abb021b-7e65-4890-9172-d2d762cc0396\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.watchdog',_binary 'a:13:{s:4:\"uuid\";s:36:\"76b82b04-b93f-4522-a84c-7c06e72ca046\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.webform_submissions',_binary 'a:13:{s:4:\"uuid\";s:36:\"d30db33d-ecb9-4776-91cd-2d54f2f7a15c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"user\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uIuCYXi8Y6GTe4pKUxK2t9OjQEcrwvFJZFeitfnQ8Ys\";}s:2:\"id\";s:19:\"webform_submissions\";s:5:\"label\";s:19:\"Webform submissions\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:34:\"Default webform submissions views.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:18:\"webform_submission\";s:10:\"base_field\";s:3:\"sid\";s:7:\"display\";a:5:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:7:{s:14:\"items_per_page\";i:25;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:6:\"‹‹\";s:4:\"next\";s:6:\"››\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:23:\"5, 10, 25, 50, 100, 200\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"fields\";a:5:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:7:\"filters\";a:0:{}s:5:\"sorts\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:0;s:7:\"content\";s:34:\"Displaying @start - @end of @total\";s:9:\"plugin_id\";s:6:\"result\";}}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"No submissions available.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:5:{s:10:\"webform_id\";a:6:{s:2:\"id\";s:10:\"webform_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:10:\"webform_id\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"entity_type\";a:6:{s:2:\"id\";s:11:\"entity_type\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"entity_type\";s:9:\"plugin_id\";s:6:\"string\";}s:9:\"entity_id\";a:6:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:6:\"string\";}s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:16:\"entity_target_id\";}s:8:\"in_draft\";a:22:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:14:\"items_per_page\";i:25;s:8:\"override\";b:0;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"numeric\";}}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"title\";s:19:\"Webform submissions\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:16:\"embed_administer\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:16:\"embed_administer\";s:13:\"display_title\";s:17:\"Embed: Administer\";s:8:\"position\";i:2;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:23:\"Administer submissions.\";s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:8:\"defaults\";a:6:{s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:29:\"administer webform submission\";}}s:6:\"fields\";a:9:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:10:\"operations\";a:25:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;s:11:\"entity_type\";N;s:12:\"entity_field\";N;s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:13:\"embed_default\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:13:\"embed_default\";s:13:\"display_title\";s:14:\"Embed: Default\";s:8:\"position\";i:1;s:15:\"display_options\";a:5:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:20:\"Display submissions.\";s:8:\"defaults\";a:5:{s:6:\"fields\";b:1;s:5:\"style\";b:0;s:3:\"row\";b:0;s:7:\"filters\";b:1;s:13:\"filter_groups\";b:1;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:5:{s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:7:\"created\";s:7:\"created\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:5:{s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_manage\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_manage\";s:13:\"display_title\";s:13:\"Embed: Manage\";s:8:\"position\";i:3;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Manage submissions.\";s:6:\"fields\";a:10:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:4:{i:0;s:35:\"webform_submission_make_lock_action\";i:1;s:37:\"webform_submission_make_sticky_action\";i:2;s:37:\"webform_submission_make_unlock_action\";i:3;s:39:\"webform_submission_make_unsticky_action\";}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}s:23:\"edit_webform_submission\";a:26:{s:2:\"id\";s:23:\"edit_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"edit_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"edit any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_review\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_review\";s:13:\"display_title\";s:13:\"Embed: Review\";s:8:\"position\";i:4;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Review submissions.\";s:6:\"fields\";a:8:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"view any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.who_s_new',_binary 'a:13:{s:4:\"uuid\";s:36:\"2d64aef5-17f8-4af2-993d-4766096aeca3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.who_s_online',_binary 'a:13:{s:4:\"uuid\";s:36:\"46b6645e-44b7-437f-a3b8-23ad0c31cce9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','webform.settings',_binary 'a:20:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jx9JXVmXsMI7nasmBHSGH0gt9MY8BE3XD2nJzjwz0ZU\";}s:8:\"settings\";a:73:{s:14:\"default_status\";s:4:\"open\";s:18:\"default_categories\";a:0:{}s:12:\"default_page\";b:1;s:22:\"default_page_base_path\";s:5:\"/form\";s:12:\"default_ajax\";b:0;s:19:\"default_ajax_effect\";s:4:\"fade\";s:18:\"default_ajax_speed\";i:500;s:26:\"default_ajax_progress_type\";s:8:\"throbber\";s:25:\"default_form_open_message\";s:49:\"This form has not yet been opened to submissions.\";s:26:\"default_form_close_message\";s:48:\"Sorry… This form is closed to new submissions.\";s:30:\"default_form_exception_message\";s:70:\"Unable to display this webform. Please contact the site administrator.\";s:27:\"default_submit_button_label\";s:6:\"Submit\";s:26:\"default_reset_button_label\";s:5:\"Reset\";s:27:\"default_delete_button_label\";s:6:\"Delete\";s:24:\"default_form_submit_once\";b:0;s:33:\"default_form_confidential_message\";s:135:\"This form is confidential. You must <a href=\"[site:login-url]/logout?destination=[current-page:url:relative]\">Log out</a> to submit it.\";s:34:\"default_form_access_denied_message\";s:34:\"Please log in to access this form.\";s:25:\"default_form_disable_back\";b:0;s:24:\"default_form_submit_back\";b:0;s:20:\"default_form_unsaved\";b:0;s:32:\"default_form_disable_remote_addr\";b:0;s:23:\"default_form_novalidate\";b:0;s:34:\"default_form_disable_inline_errors\";b:0;s:21:\"default_form_required\";b:0;s:27:\"default_form_required_label\";s:24:\"Indicates required field\";s:27:\"default_form_details_toggle\";b:1;s:23:\"default_form_file_limit\";s:0:\"\";s:12:\"form_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:14:\"button_classes\";s:0:\"\";s:32:\"default_wizard_prev_button_label\";s:10:\"< Previous\";s:32:\"default_wizard_next_button_label\";s:6:\"Next >\";s:26:\"default_wizard_start_label\";s:5:\"Start\";s:33:\"default_wizard_confirmation_label\";s:8:\"Complete\";s:32:\"default_wizard_toggle_show_label\";s:8:\"Show all\";s:32:\"default_wizard_toggle_hide_label\";s:8:\"Hide all\";s:33:\"default_preview_next_button_label\";s:7:\"Preview\";s:33:\"default_preview_prev_button_label\";s:10:\"< Previous\";s:21:\"default_preview_label\";s:7:\"Preview\";s:21:\"default_preview_title\";s:24:\"[webform:title]: Preview\";s:23:\"default_preview_message\";s:99:\"Please review your submission. Your submission is not complete until you press the \"Submit\" button!\";s:26:\"default_draft_button_label\";s:10:\"Save Draft\";s:27:\"default_draft_saved_message\";s:91:\"Submission saved. You may return to this form later and it will restore the current values.\";s:28:\"default_draft_loaded_message\";s:77:\"A partially-completed form was found. Please complete the remaining portions.\";s:36:\"default_draft_pending_single_message\";s:83:\"You have a pending draft for this webform. <a href=\"#\">Load your pending draft</a>.\";s:38:\"default_draft_pending_multiple_message\";s:83:\"You have pending drafts for this webform. <a href=\"#\">View your pending drafts</a>.\";s:28:\"default_confirmation_message\";s:40:\"New submission added to [webform:title].\";s:31:\"default_confirmation_back_label\";s:12:\"Back to form\";s:28:\"default_confirmation_noindex\";b:1;s:24:\"default_submission_label\";s:74:\"[webform_submission:submitted-to]: Submission #[webform_submission:serial]\";s:40:\"default_submission_access_denied_message\";s:40:\"Please log in to access this submission.\";s:36:\"default_submission_exception_message\";s:73:\"Unable to process this submission. Please contact the site administrator.\";s:33:\"default_submission_locked_message\";s:32:\"This submission has been locked.\";s:22:\"default_submission_log\";b:0;s:24:\"default_submission_views\";a:0:{}s:32:\"default_submission_views_replace\";a:3:{s:13:\"global_routes\";a:2:{i:0;s:36:\"entity.webform_submission.collection\";i:1;s:30:\"entity.webform_submission.user\";}s:14:\"webform_routes\";a:3:{i:0;s:34:\"entity.webform.results_submissions\";i:1;s:26:\"entity.webform.user.drafts\";i:2;s:31:\"entity.webform.user.submissions\";}s:11:\"node_routes\";a:3:{i:0;s:39:\"entity.node.webform.results_submissions\";i:1;s:31:\"entity.node.webform.user.drafts\";i:2;s:36:\"entity.node.webform.user.submissions\";}}s:25:\"default_results_customize\";b:0;s:35:\"default_previous_submission_message\";s:87:\"You have already submitted this webform. <a href=\"#\">View your previous submission</a>.\";s:36:\"default_previous_submissions_message\";s:88:\"You have already submitted this webform. <a href=\"#\">View your previous submissions</a>.\";s:24:\"default_autofill_message\";s:66:\"This submission has been autofilled with your previous submission.\";s:15:\"preview_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:20:\"confirmation_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:25:\"confirmation_back_classes\";s:7:\"button\n\";s:27:\"default_limit_total_message\";s:34:\"No more submissions are permitted.\";s:26:\"default_limit_user_message\";s:34:\"No more submissions are permitted.\";s:13:\"default_share\";b:0;s:18:\"default_share_node\";b:0;s:24:\"default_share_theme_name\";s:0:\"\";s:6:\"dialog\";b:0;s:14:\"dialog_options\";a:3:{s:6:\"narrow\";a:2:{s:5:\"title\";s:6:\"Narrow\";s:5:\"width\";i:600;}s:6:\"normal\";a:2:{s:5:\"title\";s:6:\"Normal\";s:5:\"width\";i:800;}s:4:\"wide\";a:2:{s:5:\"title\";s:4:\"Wide\";s:5:\"width\";i:1000;}}s:17:\"webform_bulk_form\";b:1;s:25:\"webform_bulk_form_actions\";a:5:{i:0;s:19:\"webform_open_action\";i:1;s:20:\"webform_close_action\";i:2;s:22:\"webform_archive_action\";i:3;s:24:\"webform_unarchive_action\";i:4;s:21:\"webform_delete_action\";}s:28:\"webform_submission_bulk_form\";b:1;s:36:\"webform_submission_bulk_form_actions\";a:5:{i:0;s:37:\"webform_submission_make_sticky_action\";i:1;s:39:\"webform_submission_make_unsticky_action\";i:2;s:35:\"webform_submission_make_lock_action\";i:3;s:37:\"webform_submission_make_unlock_action\";i:4;s:32:\"webform_submission_delete_action\";}}s:6:\"assets\";a:2:{s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";}s:7:\"handler\";a:1:{s:17:\"excluded_handlers\";a:0:{}}s:7:\"variant\";a:1:{s:17:\"excluded_variants\";a:0:{}}s:6:\"export\";a:18:{s:14:\"temp_directory\";s:0:\"\";s:8:\"exporter\";s:9:\"delimited\";s:18:\"multiple_delimiter\";s:1:\";\";s:13:\"header_format\";s:5:\"label\";s:13:\"header_prefix\";b:1;s:29:\"header_prefix_label_delimiter\";s:2:\": \";s:27:\"header_prefix_key_delimiter\";s:2:\"__\";s:29:\"composite_element_item_format\";s:5:\"label\";s:21:\"options_single_format\";s:7:\"compact\";s:23:\"options_multiple_format\";s:7:\"compact\";s:19:\"options_item_format\";s:5:\"label\";s:22:\"entity_reference_items\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"title\";i:2;s:3:\"url\";}s:21:\"likert_answers_format\";s:5:\"label\";s:16:\"signature_format\";s:6:\"status\";s:9:\"delimiter\";s:1:\",\";s:5:\"excel\";b:0;s:12:\"archive_type\";s:3:\"tar\";s:18:\"excluded_exporters\";a:0:{}}s:5:\"batch\";a:5:{s:25:\"default_batch_export_size\";i:500;s:25:\"default_batch_import_size\";i:100;s:25:\"default_batch_update_size\";i:500;s:25:\"default_batch_delete_size\";i:500;s:24:\"default_batch_email_size\";i:500;}s:5:\"purge\";a:1:{s:9:\"cron_size\";i:100;}s:4:\"form\";a:3:{s:5:\"limit\";i:50;s:15:\"filter_category\";s:0:\"\";s:12:\"filter_state\";s:0:\"\";}s:7:\"element\";a:13:{s:20:\"machine_name_pattern\";s:7:\"a-z0-9_\";s:13:\"empty_message\";s:7:\"{Empty}\";s:12:\"allowed_tags\";s:5:\"admin\";s:15:\"wrapper_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:7:\"classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:23:\"horizontal_rule_classes\";s:286:\"webform-horizontal-rule--solid\nwebform-horizontal-rule--dashed\nwebform-horizontal-rule--dotted\nwebform-horizontal-rule--gradient\nwebform-horizontal-rule--thin\nwebform-horizontal-rule--medium\nwebform-horizontal-rule--thick\nwebform-horizontal-rule--flaired\nwebform-horizontal-rule--glyph\n\";s:27:\"default_description_display\";s:0:\"\";s:18:\"default_more_title\";s:4:\"More\";s:25:\"default_section_title_tag\";s:2:\"h2\";s:20:\"default_empty_option\";b:1;s:29:\"default_empty_option_required\";s:0:\"\";s:29:\"default_empty_option_optional\";s:0:\"\";s:17:\"excluded_elements\";a:2:{s:8:\"password\";s:8:\"password\";s:16:\"password_confirm\";s:16:\"password_confirm\";}}s:11:\"html_editor\";a:5:{s:8:\"disabled\";b:0;s:14:\"element_format\";s:15:\"webform_default\";s:11:\"mail_format\";s:15:\"webform_default\";s:4:\"tidy\";b:1;s:35:\"make_unused_managed_files_temporary\";b:1;}s:4:\"file\";a:11:{s:11:\"file_public\";b:0;s:21:\"file_private_redirect\";b:1;s:29:\"file_private_redirect_message\";s:42:\"Please log in to access the uploaded file.\";s:20:\"default_max_filesize\";s:0:\"\";s:31:\"default_managed_file_extensions\";s:148:\"gif jpg jpeg png bmp eps tif pict psd txt rtf html odf pdf doc docx ppt pptx xls xlsx xml avi mov mp3 mp4 ogg wav bz2 dmg gz jar rar sit svg tar zip\";s:29:\"default_audio_file_extensions\";s:11:\"mp3 ogg wav\";s:32:\"default_document_file_extensions\";s:50:\"txt rtf pdf doc docx odt ppt pptx odp xls xlsx ods\";s:29:\"default_image_file_extensions\";s:16:\"gif jpg jpeg png\";s:29:\"default_video_file_extensions\";s:24:\"avi mov mp4 ogg wav webm\";s:35:\"make_unused_managed_files_temporary\";b:1;s:30:\"delete_temporary_managed_files\";b:1;}s:6:\"format\";a:0:{}s:4:\"mail\";a:11:{s:15:\"default_to_mail\";s:11:\"[site:mail]\";s:17:\"default_from_mail\";s:11:\"[site:mail]\";s:17:\"default_from_name\";s:11:\"[site:name]\";s:16:\"default_reply_to\";s:0:\"\";s:19:\"default_return_path\";s:0:\"\";s:19:\"default_sender_mail\";s:0:\"\";s:19:\"default_sender_name\";s:0:\"\";s:15:\"default_subject\";s:58:\"Webform submission from: [webform_submission:source-title]\";s:17:\"default_body_text\";s:133:\"Submitted on [webform_submission:created]\nSubmitted by: [webform_submission:user]\n\nSubmitted values are:\n[webform_submission:values]\n\";s:17:\"default_body_html\";s:153:\"<p>Submitted on [webform_submission:created]</p>\n<p>Submitted by: [webform_submission:user]</p>\n<p>Submitted values are:</p>\n[webform_submission:values]\n\";s:5:\"roles\";a:0:{}}s:4:\"test\";a:2:{s:5:\"types\";s:3347:\"checkbox:\n  - true\ncolor:\n  - \'#ffffcc\'\n  - \'#ffffcc\'\n  - \'#ccffff\'\nemail:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nlanguage_select:\n  - en\nmachine_name:\n  - \'loremipsum\'\n  - \'oratione\'\n  - \'dixisset\'\ntel:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ntextarea:\n  - \'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.\'\n  - \'Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;\'\n  - \'Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.\'\ntext_format:\n  - value: \'<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.</p>\'\n  - value: \'<p>Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;</p>\'\n  - value: \'<p>Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.</p>\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\nwebform_email_confirm:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nwebform_email_multiple:\n  - \'example@example.com, test@test.com, random@random.com\'\nwebform_time:\n  - \'09:00\'\n  - \'17:00\'\n\";s:5:\"names\";s:547:\"first_name:\n  - \'John\'\n  - \'Paul\'\n  - \'Ringo\'\n  - \'George\'\nlast_name:\n  - \'Lennon\'\n  - \'McCartney\'\n  - \'Starr\'\n  - \'Harrison\'\naddress:\n  - \'10 Main Street\'\n  - \'11 Brook Alley Road. APT 1\'\nzip:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\npostal_code:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\nphone:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\nfax:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ncity:\n  - \'Springfield\'\n  - \'Pleasantville\'\n  - \'Hill Valley\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\ndefault:\n  - \'Loremipsum\'\n  - \'Oratione\'\n  - \'Dixisset\'\n\";}s:2:\"ui\";a:9:{s:13:\"video_display\";s:6:\"dialog\";s:12:\"details_save\";b:1;s:13:\"help_disabled\";b:0;s:15:\"dialog_disabled\";b:0;s:18:\"offcanvas_disabled\";b:0;s:19:\"promotions_disabled\";b:0;s:16:\"support_disabled\";b:0;s:16:\"description_help\";b:1;s:12:\"toolbar_item\";b:0;}s:9:\"libraries\";a:1:{s:18:\"excluded_libraries\";a:2:{i:0;s:7:\"choices\";i:1;s:13:\"jquery.chosen\";}}s:12:\"requirements\";a:3:{s:3:\"cdn\";b:1;s:21:\"clientside_validation\";b:1;s:4:\"spam\";b:1;}s:8:\"langcode\";s:2:\"en\";s:20:\"third_party_settings\";a:1:{s:7:\"captcha\";a:1:{s:27:\"replace_administration_mode\";b:1;}}}'),('','webform.webform.contact',_binary 'a:22:{s:4:\"uuid\";s:36:\"f815005f-42fe-4d84-a6aa-7c6f08223a9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";s:4:\"open\";s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_je-MWeeJB6gfm6iECiqjcyNetfMFbn-YIInYwZ1gIk\";}s:4:\"open\";N;s:5:\"close\";N;s:6:\"weight\";i:0;s:3:\"uid\";N;s:8:\"template\";b:0;s:7:\"archive\";b:0;s:2:\"id\";s:7:\"contact\";s:5:\"title\";s:7:\"Contact\";s:11:\"description\";s:28:\"Basic email contact webform.\";s:10:\"categories\";a:0:{}s:8:\"elements\";s:566:\"name:\n  \'#title\': \'Your Name\'\n  \'#type\': textfield\n  \'#required\': true\n  \'#default_value\': \'[current-user:display-name]\'\nemail:\n  \'#title\': \'Your Email\'\n  \'#type\': email\n  \'#required\': true\n  \'#default_value\': \'[current-user:mail]\'\nsubject:\n  \'#title\': Subject\n  \'#type\': textfield\n  \'#required\': true\n  \'#test\': \'Testing contact webform from [site:name]\'\nmessage:\n  \'#title\': Message\n  \'#type\': textarea\n  \'#required\': true\n  \'#test\': \'Please ignore this email.\'\nactions:\n  \'#type\': webform_actions\n  \'#title\': \'Submit button(s)\'\n  \'#submit__label\': \'Send message\'\n\";s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";s:8:\"settings\";a:133:{s:4:\"ajax\";b:0;s:15:\"ajax_scroll_top\";s:4:\"form\";s:18:\"ajax_progress_type\";s:0:\"\";s:11:\"ajax_effect\";s:0:\"\";s:10:\"ajax_speed\";N;s:4:\"page\";b:1;s:16:\"page_submit_path\";s:0:\"\";s:17:\"page_confirm_path\";s:0:\"\";s:15:\"page_theme_name\";s:0:\"\";s:10:\"form_title\";s:21:\"source_entity_webform\";s:16:\"form_submit_once\";b:0;s:22:\"form_exception_message\";s:0:\"\";s:17:\"form_open_message\";s:0:\"\";s:18:\"form_close_message\";s:0:\"\";s:25:\"form_previous_submissions\";b:1;s:17:\"form_confidential\";b:0;s:25:\"form_confidential_message\";s:0:\"\";s:24:\"form_disable_remote_addr\";b:0;s:22:\"form_convert_anonymous\";b:0;s:16:\"form_prepopulate\";b:0;s:30:\"form_prepopulate_source_entity\";b:0;s:39:\"form_prepopulate_source_entity_required\";b:0;s:35:\"form_prepopulate_source_entity_type\";s:0:\"\";s:10:\"form_reset\";b:0;s:25:\"form_disable_autocomplete\";b:0;s:15:\"form_novalidate\";b:0;s:26:\"form_disable_inline_errors\";b:0;s:13:\"form_required\";b:0;s:12:\"form_unsaved\";b:0;s:17:\"form_disable_back\";b:0;s:16:\"form_submit_back\";b:0;s:14:\"form_autofocus\";b:0;s:19:\"form_details_toggle\";b:0;s:18:\"form_access_denied\";s:7:\"default\";s:24:\"form_access_denied_title\";s:0:\"\";s:26:\"form_access_denied_message\";s:0:\"\";s:29:\"form_access_denied_attributes\";a:0:{}s:15:\"form_file_limit\";s:0:\"\";s:11:\"form_method\";s:0:\"\";s:11:\"form_action\";s:0:\"\";s:15:\"form_attributes\";a:0:{}s:5:\"share\";b:0;s:10:\"share_node\";b:0;s:16:\"share_theme_name\";s:0:\"\";s:11:\"share_title\";b:1;s:26:\"share_page_body_attributes\";a:0:{}s:16:\"submission_label\";s:0:\"\";s:14:\"submission_log\";b:0;s:16:\"submission_views\";a:0:{}s:24:\"submission_views_replace\";a:0:{}s:23:\"submission_user_columns\";a:0:{}s:25:\"submission_user_duplicate\";b:0;s:24:\"submission_access_denied\";s:7:\"default\";s:30:\"submission_access_denied_title\";s:0:\"\";s:32:\"submission_access_denied_message\";s:0:\"\";s:35:\"submission_access_denied_attributes\";a:0:{}s:28:\"submission_exception_message\";s:0:\"\";s:25:\"submission_locked_message\";s:0:\"\";s:28:\"submission_excluded_elements\";a:0:{}s:24:\"submission_exclude_empty\";b:0;s:33:\"submission_exclude_empty_checkbox\";b:0;s:27:\"previous_submission_message\";s:0:\"\";s:28:\"previous_submissions_message\";s:0:\"\";s:8:\"autofill\";b:0;s:16:\"autofill_message\";s:0:\"\";s:26:\"autofill_excluded_elements\";a:0:{}s:19:\"wizard_progress_bar\";b:1;s:21:\"wizard_progress_pages\";b:0;s:26:\"wizard_progress_percentage\";b:0;s:20:\"wizard_progress_link\";b:0;s:22:\"wizard_progress_states\";b:0;s:19:\"wizard_auto_forward\";b:1;s:36:\"wizard_auto_forward_hide_next_button\";b:0;s:15:\"wizard_keyboard\";b:1;s:18:\"wizard_start_label\";s:0:\"\";s:19:\"wizard_preview_link\";b:0;s:19:\"wizard_confirmation\";b:1;s:25:\"wizard_confirmation_label\";s:0:\"\";s:12:\"wizard_track\";s:0:\"\";s:24:\"wizard_prev_button_label\";s:0:\"\";s:24:\"wizard_next_button_label\";s:0:\"\";s:13:\"wizard_toggle\";b:0;s:24:\"wizard_toggle_show_label\";s:0:\"\";s:24:\"wizard_toggle_hide_label\";s:0:\"\";s:16:\"wizard_page_type\";s:9:\"container\";s:21:\"wizard_page_title_tag\";s:2:\"h2\";s:7:\"preview\";i:0;s:13:\"preview_label\";s:0:\"\";s:13:\"preview_title\";s:0:\"\";s:15:\"preview_message\";s:0:\"\";s:18:\"preview_attributes\";a:0:{}s:25:\"preview_excluded_elements\";a:0:{}s:21:\"preview_exclude_empty\";b:1;s:30:\"preview_exclude_empty_checkbox\";b:0;s:5:\"draft\";s:4:\"none\";s:14:\"draft_multiple\";b:0;s:15:\"draft_auto_save\";b:0;s:19:\"draft_saved_message\";s:0:\"\";s:20:\"draft_loaded_message\";s:0:\"\";s:28:\"draft_pending_single_message\";s:0:\"\";s:30:\"draft_pending_multiple_message\";s:0:\"\";s:17:\"confirmation_type\";s:11:\"url_message\";s:18:\"confirmation_title\";s:0:\"\";s:20:\"confirmation_message\";s:27:\"Your message has been sent.\";s:16:\"confirmation_url\";s:7:\"<front>\";s:23:\"confirmation_attributes\";a:0:{}s:17:\"confirmation_back\";b:1;s:23:\"confirmation_back_label\";s:0:\"\";s:28:\"confirmation_back_attributes\";a:0:{}s:26:\"confirmation_exclude_query\";b:0;s:26:\"confirmation_exclude_token\";b:0;s:19:\"confirmation_update\";b:0;s:11:\"limit_total\";N;s:20:\"limit_total_interval\";N;s:19:\"limit_total_message\";s:0:\"\";s:18:\"limit_total_unique\";b:0;s:10:\"limit_user\";N;s:19:\"limit_user_interval\";N;s:18:\"limit_user_message\";s:0:\"\";s:17:\"limit_user_unique\";b:0;s:18:\"entity_limit_total\";N;s:27:\"entity_limit_total_interval\";N;s:17:\"entity_limit_user\";N;s:26:\"entity_limit_user_interval\";N;s:5:\"purge\";s:4:\"none\";s:10:\"purge_days\";N;s:16:\"results_disabled\";b:0;s:23:\"results_disabled_ignore\";b:0;s:17:\"results_customize\";b:0;s:10:\"token_view\";b:0;s:12:\"token_update\";b:0;s:12:\"token_delete\";b:0;s:15:\"serial_disabled\";b:0;}s:6:\"access\";a:11:{s:6:\"create\";a:3:{s:5:\"roles\";a:2:{i:0;s:9:\"anonymous\";i:1;s:13:\"authenticated\";}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:9:\"purge_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"administer\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:4:\"test\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:13:\"configuration\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}}s:8:\"handlers\";a:2:{s:18:\"email_confirmation\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email confirmation\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_confirmation\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:1;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:19:\"[current-user:mail]\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:8:\"_default\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:8:\"_default\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}s:18:\"email_notification\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email notification\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_notification\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:2;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:8:\"_default\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:37:\"[webform_submission:values:email:raw]\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:36:\"[webform_submission:values:name:raw]\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}}s:8:\"variants\";a:0:{}}'),('','webform.webform_options.country_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"291c60c8-5109-4209-b98d-ab6dc2425dc0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"adQ16YGDPk7QfUKrfrC35o2sKdHEozdNtdpiH7CftQQ\";}s:2:\"id\";s:13:\"country_codes\";s:5:\"label\";s:13:\"Country codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.country_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"430ba6dc-e989-4104-81a2-731e98ece9e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zsfFP124dAM-sJkuEfnwaA7DN6o3-IsaXLgdNmObbYg\";}s:2:\"id\";s:13:\"country_names\";s:5:\"label\";s:13:\"Country names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.days',_binary 'a:10:{s:4:\"uuid\";s:36:\"837c888f-46bd-4a04-8f99-cf5698404d99\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNrKbYrWWjeubUUM8AsQ19KnX7cU1elACR14CZJHmdg\";}s:2:\"id\";s:4:\"days\";s:5:\"label\";s:4:\"Days\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:121:\"Sunday: Sunday\nMonday: Monday\nTuesday: Tuesday\nWednesday: Wednesday\nThursday: Thursday\nFriday: Friday\nSaturday: Saturday\n\";}'),('','webform.webform_options.education',_binary 'a:10:{s:4:\"uuid\";s:36:\"93ade06e-58d8-4139-8417-d050228586a1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mII4acOv33s-j8PINywrCag4OITbeJGxdPO373dnHHw\";}s:2:\"id\";s:9:\"education\";s:5:\"label\";s:9:\"Education\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:152:\"High School: High School\nAssociate Degree: Associate Degree\nGraduate or Professional Degree: Graduate or Professional Degree\nSome College: Some College\n\";}'),('','webform.webform_options.employment_status',_binary 'a:10:{s:4:\"uuid\";s:36:\"fb4b79d1-46ed-431a-a9f9-93a58abf2ca8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8MCmsz_csdJkVItxI8g_s4zp2PM285YqCy_gWTzOLPw\";}s:2:\"id\";s:17:\"employment_status\";s:5:\"label\";s:17:\"Employment status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:113:\"\'Full Time\': \'Full Time\'\n\'Part Time\': \'Part Time\'\n\'Military\': \'Military\'\nUnemployed: Unemployed\nRetired: Retired\n\";}'),('','webform.webform_options.ethnicity',_binary 'a:10:{s:4:\"uuid\";s:36:\"cff7754e-905c-4ee7-916d-51863211ea47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIPgrAC82wE2GAk1mOv2UvMYv71YQe4VT8667QIYdvI\";}s:2:\"id\";s:9:\"ethnicity\";s:5:\"label\";s:9:\"Ethnicity\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:200:\"Caucasian: Caucasian\n\'Latino/Hispanic\': \'Latino/Hispanic\'\n\'Middle Eastern\': \'Middle Eastern\'\nAfrican: African\nCaribbean: Caribbean\n\'South Asian\': \'South Asian\'\n\'East Asian\': \'East Asian\'\nMixed: Mixed\n\";}'),('','webform.webform_options.gender',_binary 'a:10:{s:4:\"uuid\";s:36:\"accbbb74-6855-4d35-89ef-aaf806d9fddf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yxhG0JmQs2HT-Ro6ZeDQboDc9ZWR4GglflTtyoqxK4A\";}s:2:\"id\";s:6:\"gender\";s:5:\"label\";s:6:\"Gender\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:756:\"Man: Man\nWoman: Woman\nNon-binary: Non-binary\nAgender/Genderless: Agender/Genderless\nAndrogyne/Androgynous: Androgyne/Androgynous\nAporagender: Aporagender\nBigender: Bigender\nDemi-agender: Demi-agender\nDemi-boy: Demi-boy\nDemi-fluid: Demi-fluid\nDemi-girl: Demi-girl\nDemi-gender: Demi-gender\nDemi-non-binary: Demi-non-binary\nGenderqueer: Genderqueer\nGenderflux: Genderflux\nGenderfluid: Genderfluid\nGender-indifferent: Gender-indifferent\nGender-neutral: Gender-neutral\nGraygender: Graygender\nIntergender: Intergender\nMaverique: Maverique\nMaxigender: Maxigender\nMultigender/Polygender: Multigender/Polygender\nNeutrois: Neutrois\nPangender/Omnigender: Pangender/Omnigender\nTrigender: Trigender\nTwo-spirit: Two-spirit\n\'Prefer Not to Answer\': \'Prefer Not to Answer\'\n\";}'),('','webform.webform_options.industry',_binary 'a:10:{s:4:\"uuid\";s:36:\"fde6fb59-d642-483a-89e6-a8bf864192e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"s_SXZn2HbRGvTex-TLOCxz2oOnMYqtEZh8HD4_318QI\";}s:2:\"id\";s:8:\"industry\";s:5:\"label\";s:8:\"Industry\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1425:\"Accounting/Finance: Accounting/Finance\nAdvertising/Public Relations: Advertising/Public Relations\nAerospace/Aviation: Aerospace/Aviation\nArts/Entertainment/Publishing: Arts/Entertainment/Publishing\nAutomotive: Automotive\nBanking/Mortgage: Banking/Mortgage\nBusiness Development: Business Development\nBusiness Opportunity: Business Opportunity\nClerical/Administrative: Clerical/Administrative\nConstruction/Facilities: Construction/Facilities\nConsumer Goods: Consumer Goods\nCustomer Service: Customer Service\nEducation/Training: Education/Training\nEnergy/Utilities: Energy/Utilities\nEngineering: Engineering\nGovernment/Military: Government/Military\nHealthcare: Healthcare\nHospitality/Travel: Hospitality/Travel\nHuman Resources: Human Resources\nInstallation/Maintenance: Installation/Maintenance\nInsurance: Insurance\nInternet: Internet\nLaw Enforcement/Security: Law Enforcement/Security\nLegal: Legal\nManagement/Executive: Management/Executive\nManufacturing/Operations: Manufacturing/Operations\nMarketing: Marketing\nNon-Profit/Volunteer: Non-Profit/Volunteer\nPharmaceutical/Biotech: Pharmaceutical/Biotech\nProfessional Services: Professional Services\nReal Estate: Real Estate\nRestaurant/Food Service: Restaurant/Food Service\nRetail: Retail\nSales: Sales\nScience/Research: Science/Research\nSkilled Labor: Skilled Labor\nTechnology: Technology\nTelecommunications: Telecommunications\nTransportation/Logistics: Transportation/Logistics\n\";}'),('','webform.webform_options.languages',_binary 'a:10:{s:4:\"uuid\";s:36:\"05fc358f-135e-4f8d-8e30-9bde5b4e34d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYH14Vi65Ixj10c_GFa7CipxU3D0Bt9wgo8zE8zjOfE\";}s:2:\"id\";s:9:\"languages\";s:5:\"label\";s:9:\"Languages\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.likert_agreement',_binary 'a:10:{s:4:\"uuid\";s:36:\"e7d35339-5044-42d3-9c89-6bcf4c7b3f86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nPp-CfMKrP0yDMtyO0wQRwawEqaJVAPzQapinXmDgyU\";}s:2:\"id\";s:16:\"likert_agreement\";s:5:\"label\";s:17:\"Likert: Agreement\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:71:\"1: Strongly Disagree\n2: Disagree\n3: Neutral\n4: Agree\n5: Strongly Agree\n\";}'),('','webform.webform_options.likert_comparison',_binary 'a:10:{s:4:\"uuid\";s:36:\"c05e7ce1-8d8c-4fe2-ad87-51fb46a4fa7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DMG4TKTHEXtHN8ho_sG_GiZHgweZ6nrRm6BAjk0LZ_Y\";}s:2:\"id\";s:17:\"likert_comparison\";s:5:\"label\";s:18:\"Likert: Comparison\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:84:\"1: Much Worse\n2: Somewhat Worse\n3: About the Same\n4: Somewhat Better\n5: Much Better\n\";}'),('','webform.webform_options.likert_importance',_binary 'a:10:{s:4:\"uuid\";s:36:\"b3f9da96-6241-4951-994d-2a00fc66b8e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hbc8n5HtVZVs5fSBSpSbuY07CVvqkKP76csvRHN9pK8\";}s:2:\"id\";s:17:\"likert_importance\";s:5:\"label\";s:18:\"Likert: Importance\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:88:\"1: Not at all Important\n2: Somewhat Important\n3: Neutral\n4: Important\n5: Very Important\n\";}'),('','webform.webform_options.likert_quality',_binary 'a:10:{s:4:\"uuid\";s:36:\"6e7a0384-f89e-4ad5-87b9-0a6f41301026\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swmYtBVUbwq7aHJWWDN7ODByuvur9vMkexDC9h64NZ8\";}s:2:\"id\";s:14:\"likert_quality\";s:5:\"label\";s:15:\"Likert: Quality\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:50:\"1: Poor\n2: Fair\n3: Good\n4: Very good\n5: Excellent\n\";}'),('','webform.webform_options.likert_satisfaction',_binary 'a:10:{s:4:\"uuid\";s:36:\"e52c5b0d-4f4e-4ea8-b30c-9f53646066c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKE2SNwCpl6Mu_cmbq9ZM2_cXxCikCVj1vcPE9oHWTs\";}s:2:\"id\";s:19:\"likert_satisfaction\";s:5:\"label\";s:20:\"Likert: Satisfaction\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:77:\"1: Very Unsatisfied\n2: Unsatisfied\n3: Neutral\n4: Satisfied\n5: Very Satisfied\n\";}'),('','webform.webform_options.likert_ten_scale',_binary 'a:10:{s:4:\"uuid\";s:36:\"f9cdebb7-5b4d-4f5b-873e-1d4e461985d9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zEZX8JSVqznnFtqFfpuC593h3t1JDAZhF0Q3pvA229o\";}s:2:\"id\";s:16:\"likert_ten_scale\";s:5:\"label\";s:17:\"Likert: Ten Scale\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:52:\"1: 1\n2: 2\n3: 3\n4: 4\n5: 5\n6: 6\n7: 7\n8: 8\n9: 9\n10: 10\n\";}'),('','webform.webform_options.likert_would_you',_binary 'a:10:{s:4:\"uuid\";s:36:\"3e23d906-eeea-4c78-a29f-a37b82dbf616\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qBS2TmfAJB37Qn3TnrNM8x4AWimmDapcizzRllgo0fo\";}s:2:\"id\";s:16:\"likert_would_you\";s:5:\"label\";s:17:\"Likert: Would You\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:72:\"1: Definitely Not\n2: Probably Not\n3: Not Sure\n4: Probably\n5: Definitely\n\";}'),('','webform.webform_options.marital_status',_binary 'a:10:{s:4:\"uuid\";s:36:\"67011573-341a-4e22-893d-6fbff6623594\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cjVDbAE5BlopGrY-tfxsxMoyEibwBBNgdQwDdxOSkow\";}s:2:\"id\";s:14:\"marital_status\";s:5:\"label\";s:14:\"Marital status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:68:\"Single: Single\nMarried: Married\nDivorced: Divorced\nWidowed: Widowed\n\";}'),('','webform.webform_options.months',_binary 'a:10:{s:4:\"uuid\";s:36:\"2160769c-f93c-45f7-b28e-52d800ec51c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pZJnuQkh9afNML5IcMuKTUC__vmHMFn66Qr5IWtedZ4\";}s:2:\"id\";s:6:\"months\";s:5:\"label\";s:6:\"Months\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:184:\"January: January\nFebruary: February\nMarch: March\nApril: April\nMay: May\nJune: June\nJuly: July\nAugust: August\nSeptember: September\nOctober: October\nNovember: November\nDecember: December\n\";}'),('','webform.webform_options.phone_types',_binary 'a:10:{s:4:\"uuid\";s:36:\"ede08b1a-9f0a-4e51-bb56-baa6f6edc279\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LkO63Zl2cP_l9YdjzWI8dWoD9uD0pytkPiUiUM2bo9A\";}s:2:\"id\";s:11:\"phone_types\";s:5:\"label\";s:10:\"Phone type\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:37:\"Home: Home\nOffice: Office\nCell: Cell\n\";}'),('','webform.webform_options.province_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"595af078-ff40-4b8f-a59c-c9b5622dbc65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cR3A6XXinVGC9g5vLS-vVvTC2ppZXRNXLPWA8xBUMew\";}s:2:\"id\";s:14:\"province_codes\";s:5:\"label\";s:14:\"Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:237:\"AB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),('','webform.webform_options.province_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"26a80f5e-c29e-4eee-9918-eefc2b54b8ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aaEeYBWoWETLKX2ivmZBpUAd3uPe2iPNydaxBuLPXKc\";}s:2:\"id\";s:14:\"province_names\";s:5:\"label\";s:14:\"Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:379:\"Alberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),('','webform.webform_options.relationship',_binary 'a:10:{s:4:\"uuid\";s:36:\"5e9987f1-71cd-4573-88c0-ff0fc33fe873\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4J2RPG4JmsD4Fm1NlIQY0JHkrJ08UUl0qTF0_EjUxvw\";}s:2:\"id\";s:12:\"relationship\";s:5:\"label\";s:12:\"Relationship\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:101:\"Parent: Parent\n\'Significant Other\': \'Significant Other\'\nSibling: Sibling\nChild: Child\nFriend: Friend\n\";}'),('','webform.webform_options.sex',_binary 'a:10:{s:4:\"uuid\";s:36:\"052b2071-a7ca-48a1-b511-cf26c5c28801\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WRpxpwYpfcO_i0so7BV4QXxXlbPiSVppYmAV6DAz4c0\";}s:2:\"id\";s:3:\"sex\";s:5:\"label\";s:3:\"Sex\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:26:\"Male: Male\nFemale: Female\n\";}'),('','webform.webform_options.sex_icao',_binary 'a:10:{s:4:\"uuid\";s:36:\"0b914fae-9fd3-4903-8774-8c355aa91632\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9mxo86dMII5OxkHl4mbe2l4AgQloOXuErOte57BU9IY\";}s:2:\"id\";s:8:\"sex_icao\";s:5:\"label\";s:54:\"Sex - International Civil Aviation Organization (ICAO)\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:33:\"M: Male\nF: Female\nX: Unspecified\n\";}'),('','webform.webform_options.size',_binary 'a:10:{s:4:\"uuid\";s:36:\"c671c93b-871e-49ba-964c-d0fe4ad73550\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RKkc6tf1VudvYiOtwPCf3Tp_EoA6fov6BFC34D7gMoQ\";}s:2:\"id\";s:4:\"size\";s:5:\"label\";s:4:\"Size\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:91:\"Extra Small: Extra Small\nSmall: Small\nMedium: Medium\nLarge: Large\nExtra Large: Extra Large\n\";}'),('','webform.webform_options.state_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"82d7e2f4-fb87-4c81-a5f3-0dd704eee27f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8mYO8ewsZX3LVfNga69jXa0RNO0LNN8-EGkXLhSAMBU\";}s:2:\"id\";s:11:\"state_codes\";s:5:\"label\";s:11:\"State codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:728:\"AL: Alabama\nAK: Alaska\nAZ: Arizona\nAR: Arkansas\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPA: Pennsylvania\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\n\";}'),('','webform.webform_options.state_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"2141569b-1460-424e-9f43-303b2a435e45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KfYqMSrFJ5iGtDzvy_rGUeRUJ4KyM7Xt-tWtYx9WjiM\";}s:2:\"id\";s:11:\"state_names\";s:5:\"label\";s:11:\"State names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1081:\"Alabama: Alabama\nAlaska: Alaska\nArizona: Arizona\nArkansas: Arkansas\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\nFlorida: Florida\nGeorgia: Georgia\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPennsylvania: Pennsylvania\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\n\";}'),('','webform.webform_options.state_province_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"ea84bfcf-e9b1-47e7-ac33-c7743aa2ccae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ziWv9xVss1UBnP_R38EqduZOprwOAifpxjXhyOPzmys\";}s:2:\"id\";s:20:\"state_province_codes\";s:5:\"label\";s:20:\"State/Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1241:\"AL: Alabama\nAK: Alaska\nAS: \'American Samoa\'\nAZ: Arizona\nAR: Arkansas\nAE: \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\nAA: \'Armed Forces Americas\'\nAP: \'Armed Forces Pacific\'\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFM: \'Federated States of Micronesia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMH: \'Marshall Islands\'\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nMP: \'Northern Mariana Islands\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPW: Palau\nPA: Pennsylvania\nPR: \'Puerto Rico\'\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVI: \'Virgin Islands\'\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\nAB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),('','webform.webform_options.state_province_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"f757b555-27c8-4894-a589-58863a4bfb38\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d4mxS_CxdzHZK4WaGQf1H3m-Uubm5HPbu9U4ydzscuo\";}s:2:\"id\";s:20:\"state_province_names\";s:5:\"label\";s:20:\"State/Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1953:\"Alabama: Alabama\nAlaska: Alaska\n\'American Samoa\': \'American Samoa\'\nArizona: Arizona\nArkansas: Arkansas\n\'Armed Forces (Canada, Europe, Africa, or Middle East)\': \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\n\'Armed Forces Americas\': \'Armed Forces Americas\'\n\'Armed Forces Pacific\': \'Armed Forces Pacific\'\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\n\'Federated States of Micronesia\': \'Federated States of Micronesia\'\nFlorida: Florida\nGeorgia: Georgia\nGuam: Guam\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\n\'Marshall Islands\': \'Marshall Islands\'\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\n\'Northern Mariana Islands\': \'Northern Mariana Islands\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPalau: Palau\nPennsylvania: Pennsylvania\n\'Puerto Rico\': \'Puerto Rico\'\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\n\'Virgin Islands\': \'Virgin Islands\'\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\nAlberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),('','webform.webform_options.time_zones',_binary 'a:10:{s:4:\"uuid\";s:36:\"95a86930-8c84-4d30-8c47-9b5513752ab6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8rVcRXLnTAEoWs7zl8du-7RIUnayqUcGYnvb3JT21-o\";}s:2:\"id\";s:10:\"time_zones\";s:5:\"label\";s:10:\"Time zones\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.titles',_binary 'a:10:{s:4:\"uuid\";s:36:\"bf77360d-2ee5-4057-94df-b64936a0e9c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PEUoedWrfYEX7oZ8CcOukfBTVxar1cPSROX8534esuU\";}s:2:\"id\";s:6:\"titles\";s:5:\"label\";s:6:\"Titles\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:41:\"Miss: Miss\nMs: Ms\nMr: Mr\nMrs: Mrs\nDr: Dr\n\";}'),('','webform.webform_options.translations',_binary 'a:10:{s:4:\"uuid\";s:36:\"c5a0c3d0-00d1-4e7a-82bd-38a69656f42a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mb_L3vE-0IBZH5s2rjpk2LNn0QHClQP9AARQdCmVLt4\";}s:2:\"id\";s:12:\"translations\";s:5:\"label\";s:12:\"Translations\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.yes_no',_binary 'a:10:{s:4:\"uuid\";s:36:\"6b9fbab8-7082-4f33-903d-44c1c725d64f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W88NYg31DbaVNQx1Uir_dwwXHVtF09QOq4VBGsH1Snk\";}s:2:\"id\";s:6:\"yes_no\";s:5:\"label\";s:6:\"Yes/No\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:16:\"Yes: Yes\nNo: No\n\";}'),('','webform_rest.settings',_binary 'a:1:{s:21:\"confirmation_settings\";i:1;}');
/*!40000 ALTER TABLE `config` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `config_export`
--

DROP TABLE IF EXISTS `config_export`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `config_export` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `config_export`
--

LOCK TABLES `config_export` WRITE;
/*!40000 ALTER TABLE `config_export` DISABLE KEYS */;
INSERT INTO `config_export` VALUES ('','announcements_feed.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),('','automated_cron.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),('','block.block.claro_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"2ee473b3-a425-411a-ab54-a68f6158b424\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"76004679-c667-48f4-8315-0938ae25c677\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"32e45861-c4ef-4890-9456-d4d3178e6dff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help_search',_binary 'a:13:{s:4:\"uuid\";s:36:\"9b1697a0-5897-45e8-a80f-5af8cca317c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"module\";a:2:{i:0;s:6:\"search\";i:1;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}s:8:\"enforced\";a:1:{s:6:\"config\";a:1:{i:0;s:23:\"search.page.help_search\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2ToeZLvlHKTeFY74gpgu1PejLoFyCECLO_gw6rAZwqw\";}s:2:\"id\";s:17:\"claro_help_search\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:11:\"Search help\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:11:\"help_search\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:4:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:0:{}s:5:\"pages\";s:11:\"/admin/help\";}}}'),('','block.block.claro_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"49e09740-a7ab-405b-9ab5-bfd13b5e620f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"7d8fc1d9-1953-4095-be0e-84db7c675688\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"51ff8126-5055-4bce-9ccb-18c944436bfa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"a8503923-9b73-4303-b900-8d31d288f15a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"eecd31b5-688c-478a-9a64-3f7a71835f70\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"b6522fa8-f871-47e7-b9ce-f5ae8e81bc1c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"y9X3xgCsO59pQyzNLzY1D3SDJJxCHILLWkpPnmuTJ2E\";}s:2:\"id\";s:15:\"gin_breadcrumbs\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"2fcd6937-f7e2-4164-9961-4645225145e5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBHXB7hC05XU7pDYzETt-GUcpFlogK1gkjyAsg0Ym58\";}s:2:\"id\";s:11:\"gin_content\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"8b83c953-f174-46e0-a364-09d2175e38ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8nOAry2oKqJOr0zbrlJ3sZHDFJLIO6j-0vT0K_TYca4\";}s:2:\"id\";s:8:\"gin_help\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"e15a620f-69da-49e6-b189-04443f574743\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OQ9aJ-4qVwK1x00o9EOYK4eFDjQr_HLpbPiJaPSVZiQ\";}s:2:\"id\";s:17:\"gin_local_actions\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"c6c79d5e-aa2f-4b8d-b495-90d172f5a37f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WvPhI8OwllG0gE69-F8qL3ai3nd5SbYD6JpmEuZcyok\";}s:2:\"id\";s:12:\"gin_messages\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"ebea0892-f451-48c1-9e1d-88b202d03b18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HLQY2xgby8K3vN_98hiOSasOhm9pdCsH234-s0duJ8Q\";}s:2:\"id\";s:14:\"gin_page_title\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"16251d67-ff59-46ea-992c-c18706ab2d54\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hh01DLj9k7UnNdPpOQXHZHW7GHf2OPNDQyCJF7_R9ac\";}s:2:\"id\";s:23:\"gin_primary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"07f111f7-352c-4382-846e-5dc96ba3e79c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCWhood0xXFQYqxFgL1spXdb9KeIuXH1YvTdjIEedDg\";}s:2:\"id\";s:25:\"gin_secondary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"870c3a2a-0f9d-4654-a000-d2679516fe2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"07be5c27-7c5f-41b8-964c-98c06048a345\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"cde6aefd-f0a4-4b0b-beec-de088e3ba750\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"ebb3e07a-d14f-423b-a996-02cd370cd1fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"f31a287c-6331-4954-8774-a5c1a562ded4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"f22a6909-6281-401a-81e1-e7b2b08f2d29\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"c705cc7a-6121-476d-bbe4-261ea3e5d449\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"c936529a-a175-4104-a0be-d34480b5c15a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"41b6f077-7605-4a7d-9b49-e8bf57957354\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_search_form_narrow',_binary 'a:13:{s:4:\"uuid\";s:36:\"98b2c86d-d24c-4de7-8c49-37e7b561633c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_nZjxxdypO6xrOAJkCYD81v0L7wh2zbCAVO7_C-UKIc\";}s:2:\"id\";s:26:\"olivero_search_form_narrow\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";N;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_search_form_wide',_binary 'a:13:{s:4:\"uuid\";s:36:\"2d18073a-a84e-4d8b-87e7-0f10885c993d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pbbed0hdqGDF-_QWVVTWRAwgDIotFuAvWH5mWUZu0fA\";}s:2:\"id\";s:24:\"olivero_search_form_wide\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";N;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"b67d55b6-584f-4ea8-a5ad-1ff5a0ce5f58\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"f9fbe17e-b414-4baa-8e48-f52b2907dd61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block_content.type.basic',_binary 'a:9:{s:4:\"uuid\";s:36:\"d64644ad-b094-4c5b-a15a-19a3b8bdc1c9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),('','ckeditor5_plugin_pack.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uAMHMIBA-fCvlzeeOYZ4vKwSBXvThlEytdEKK_Ur8nI\";}s:12:\"dll_location\";s:0:\"\";}'),('','claro.settings',_binary 'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),('','comment.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNUW2Ij5uE7a4oaXp3i_2lvaFdYM1zNKPPfnEjB0jEc\";}s:16:\"log_ip_addresses\";b:0;}'),('','comment.type.comment',_binary 'a:9:{s:4:\"uuid\";s:36:\"a33bd86b-5bbd-4f5c-807b-eba5e4396f23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bqZsN31T2n0UjcbyCpOPi9D2iO0sAOHR7FnEs9qMvaA\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:16:\"Default comments\";s:21:\"target_entity_type_id\";s:4:\"node\";s:11:\"description\";s:28:\"Allows commenting on content\";}'),('','config_ignore.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IgOVnECx6lbVt6JVFnadoEEugneDf3UblPZnOzov43Q\";}s:4:\"mode\";s:6:\"simple\";s:23:\"ignored_config_entities\";a:0:{}}'),('','contact.form.feedback',_binary 'a:12:{s:4:\"uuid\";s:36:\"b09080d0-d32f-48de-a42f-70fdecbd5e2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.form.personal',_binary 'a:12:{s:4:\"uuid\";s:36:\"f3831747-359e-4997-a6d5-abd5e6e9f842\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),('','core.base_field_override.node.page.promote',_binary 'a:17:{s:4:\"uuid\";s:36:\"c23528a5-02ac-44f4-a644-5500abef763e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','core.base_field_override.node.webform.promote',_binary 'a:17:{s:4:\"uuid\";s:36:\"a3af19ad-36e8-452e-873e-127297423512\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:17:\"node.type.webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FvXJkxryo6J_0TQRlb5Z77Ge-sim5GHzCI1Ft3kZu-4\";}s:2:\"id\";s:20:\"node.webform.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','core.date_format.fallback',_binary 'a:9:{s:4:\"uuid\";s:36:\"d367ac3c-4ca1-4026-a47e-4817dc8c2511\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iIBLu1j9n6Oo5PW-wpu5gdyNs9Kvv4LMRqtQUdJjRz8\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, j M Y - H:i\";}'),('','core.date_format.html_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"0af4b8bf-1ba3-4ecc-a123-f2abfa8a7e34\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),('','core.date_format.html_datetime',_binary 'a:9:{s:4:\"uuid\";s:36:\"78cb7097-519a-4d33-a9cf-890f946cd1b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),('','core.date_format.html_month',_binary 'a:9:{s:4:\"uuid\";s:36:\"bc061bc9-c166-47f3-be0f-abbba94af1dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),('','core.date_format.html_time',_binary 'a:9:{s:4:\"uuid\";s:36:\"cc1685f0-a1bc-49c4-b22f-ecaeb8a7a384\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),('','core.date_format.html_week',_binary 'a:9:{s:4:\"uuid\";s:36:\"d3f418c7-8741-4033-8fcb-48c7f8608816\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),('','core.date_format.html_year',_binary 'a:9:{s:4:\"uuid\";s:36:\"0f2d4f08-392f-4b29-bf5c-4d4c8aa13945\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),('','core.date_format.html_yearless_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"1eeb9283-48cf-42b5-9ec2-e3277335126d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),('','core.date_format.long',_binary 'a:9:{s:4:\"uuid\";s:36:\"57191129-5da9-459f-b5cb-e31c471cbf54\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5B4_r5Vd0_9UaJwtAC5yFCm9-k8NNvp1xiQNhFFkknU\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"l, j F Y - H:i\";}'),('','core.date_format.medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"0629967e-77af-4eb2-8a78-d6b4f1a8a540\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"q7pDV2d9qFh1IVqvymOxUUYGSziZDeg961wURC0cSLs\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, j M Y - H:i\";}'),('','core.date_format.olivero_medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"010477b9-d765-490f-9425-dd432bfb786e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z7ynTCss9wwEi8ojENJ08qx44RN6leI-tqoN2o5QzdE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:5:\"j F Y\";}'),('','core.date_format.short',_binary 'a:9:{s:4:\"uuid\";s:36:\"205997a0-85e2-480b-afbf-364040dbe3a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SAeixlV7Djy_Ggv_1P95TiqD4KUihA5icvU521tA84Y\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"j M Y - H:i\";}'),('','core.entity_form_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"885ef637-ecc7-404d-98d6-f886bae2a7dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"915f5663-37e7-48c1-877a-dd2574a2366c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0Pa0aQvT_jawlPo9oz4FE3h_ickc55dYKTPl6gILes\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:6:\"author\";a:2:{s:6:\"weight\";i:-2;s:6:\"region\";s:7:\"content\";}s:12:\"comment_body\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:7:\"subject\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"39076dd4-f606-4559-8e09-9c4076a6a9a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:29:\"field.field.node.article.body\";i:1;s:32:\"field.field.node.article.comment\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:21:\"image.style.thumbnail\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:7:\"comment\";i:1;s:5:\"image\";i:2;s:4:\"path\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:12:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"comment\";a:5:{s:4:\"type\";s:15:\"comment_default\";s:6:\"weight\";i:20;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8052ad9d-9ad8-4d4f-a2cc-01b3312dbac3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"field.field.node.page.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"path\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:9:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.webform.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ffb66cab-c432-432a-9abe-556ec76c9de4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:29:\"field.field.node.webform.body\";i:1;s:32:\"field.field.node.webform.webform\";i:2;s:17:\"node.type.webform\";}s:6:\"module\";a:3:{i:0;s:4:\"path\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A3evv2pt6d-bKCPcgjXA5VGTemXWOxG3lSXvWiRWcck\";}s:2:\"id\";s:20:\"node.webform.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:12:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:0;s:8:\"settings\";a:3:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:14:\"include_locked\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:15;s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:14:\"simple_sitemap\";a:4:{s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:16;s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:3:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:13:\"url_redirects\";a:4:{s:6:\"weight\";i:50;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:7:\"webform\";a:5:{s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8b44064a-21df-44c2-bc70-8583a0b6d00f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_form_mode.user.register',_binary 'a:10:{s:4:\"uuid\";s:36:\"5d33687a-c0b1-4d5d-96a5-9b558b4d62ae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"01eed67b-49a4-45a7-81f3-7be9338dca46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"5932e0d4-d732-487d-a85d-b8314a5b32ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aBQUGsQ46M4048fIlFuTXwl2zV0j2cJX89CTUobh9hA\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:12:\"comment_body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d5d627a7-d4a0-4cf7-9ee0-b7946878aa35\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:48:\"core.entity_view_display.comment.comment.default\";i:1;s:29:\"field.field.node.article.body\";i:2;s:32:\"field.field.node.article.comment\";i:3;s:36:\"field.field.node.article.field_image\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:16:\"image.style.wide\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:7:\"comment\";i:1;s:5:\"image\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:7:\"comment\";a:6:{s:4:\"type\";s:15:\"comment_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:8:\"pager_id\";i:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:110;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.article.rss',_binary 'a:11:{s:4:\"uuid\";s:36:\"a31296e3-ecfb-448f-8fcc-077d53a3e7f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:32:\"field.field.node.article.comment\";i:3;s:36:\"field.field.node.article.field_image\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:5:{s:4:\"body\";b:1;s:7:\"comment\";b:1;s:11:\"field_image\";b:1;s:10:\"field_tags\";b:1;s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.article.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"0c236e6a-27ce-4c19-8e5a-126cde1d65fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:32:\"field.field.node.article.comment\";i:3;s:36:\"field.field.node.article.field_image\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:18:\"image.style.medium\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"comment\";b:1;s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f5cc614c-3972-4b19-aa5e-f5ffad215f88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"field.field.node.page.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.page.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"4690aa2b-761f-4e63-b494-b09f2bffff83\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.webform.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"5f4e9c64-9f98-4d2c-a273-044234fb3a37\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:29:\"field.field.node.webform.body\";i:1;s:32:\"field.field.node.webform.webform\";i:2;s:17:\"node.type.webform\";}s:6:\"module\";a:3:{i:0;s:4:\"text\";i:1;s:4:\"user\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3r1i0UMUbeNHhvmiqHDYznoS4G9XR1jq6lQ49r80lDE\";}s:2:\"id\";s:20:\"node.webform.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:101;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:6:\"weight\";i:100;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:7:\"webform\";a:6:{s:6:\"weight\";i:102;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_display.node.webform.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"58b778bb-172e-472d-b9f5-17c920bb4232\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.webform.body\";i:2;s:32:\"field.field.node.webform.webform\";i:3;s:17:\"node.type.webform\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ls5l3Xs7-YstJnurxFLKj38Exqr2JMZs1j9YeX1Kh2o\";}s:2:\"id\";s:19:\"node.webform.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:6:\"weight\";i:101;s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:6:\"weight\";i:100;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:8:\"langcode\";b:1;s:7:\"webform\";b:1;}}'),('','core.entity_view_display.user.user.compact',_binary 'a:11:{s:4:\"uuid\";s:36:\"a22a500a-58f5-443b-895c-dd210187a86d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:8:\"langcode\";b:1;s:10:\"member_for\";b:1;}}'),('','core.entity_view_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"227a1b86-49df-47ac-8efe-562bcf176cd2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:8:\"langcode\";b:1;}}'),('','core.entity_view_mode.block.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"b250be27-e5ae-4b0b-845e-171e9a9517cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"block\";}}s:2:\"id\";s:11:\"block.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:5:\"block\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.block_content.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"72737862-d3bd-415c-8ab6-4c512f6678f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.block_content.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"e7c3d152-d1b1-47fa-949d-6aac95fd9f43\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:2:\"id\";s:19:\"block_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.comment.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"8617e7ab-2c6e-478b-ab0a-552ff354eeab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N4mUjXpPckUkVRY1PbKw4GGoL1i2ECU7PL3EreiKStk\";}s:2:\"id\";s:12:\"comment.full\";s:5:\"label\";s:12:\"Full comment\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"comment\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.comment.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"4f6c41a4-657c-42fd-8268-276a87df9731\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:2:\"id\";s:13:\"comment.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:7:\"comment\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.contact_message.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"5d4499b8-9506-49e9-85b4-3d93fe61d4f8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"contact\";}}s:2:\"id\";s:21:\"contact_message.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:15:\"contact_message\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.file.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"cd3c6575-783d-4a1a-ac9c-8adaf1c76f8a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:2:\"id\";s:10:\"file.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:4:\"file\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.menu_link_content.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"e1026fe1-359d-41cf-8422-735c2c858db2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:17:\"menu_link_content\";}}s:2:\"id\";s:23:\"menu_link_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:17:\"menu_link_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.diff',_binary 'a:10:{s:4:\"uuid\";s:36:\"86727042-5ea2-41bc-927d-32de67fe734d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"diff\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pqZNtad5J9THcdbYjwPD4qINqvrTxnOd8KCWn6tUBRs\";}s:2:\"id\";s:9:\"node.diff\";s:5:\"label\";s:19:\"Revision comparison\";s:11:\"description\";N;s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"84e1094d-b40c-4dd6-82a6-a75eb1250270\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.rss',_binary 'a:10:{s:4:\"uuid\";s:36:\"8f4a1fcd-6a35-47e7-bb3e-0ba29c104629\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_index',_binary 'a:10:{s:4:\"uuid\";s:36:\"1e54deca-38ff-416c-86d0-eed69eedefd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_result',_binary 'a:10:{s:4:\"uuid\";s:36:\"fc474d30-f444-421a-ab7a-40651906ebc2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.teaser',_binary 'a:10:{s:4:\"uuid\";s:36:\"d3afe08d-7024-4fa1-bf4a-2bdc2b459c34\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"8fe537b9-59a2-4e02-9c75-17d825a2e09c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:10:\"node.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.path_alias.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"cd3bc5d6-a185-496e-bd75-7b418012951a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"path_alias\";}}s:2:\"id\";s:16:\"path_alias.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:10:\"path_alias\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.shortcut.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"1c9bd81e-6e7c-4441-a47e-1c1a8944e0c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"shortcut\";}}s:2:\"id\";s:14:\"shortcut.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:8:\"shortcut\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.taxonomy_term.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"cddf0fac-c858-4a6c-8a52-8e5be3324d15\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.taxonomy_term.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"66378eb1-2d94-4ea0-9430-7d3725ba07de\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:2:\"id\";s:19:\"taxonomy_term.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.compact',_binary 'a:10:{s:4:\"uuid\";s:36:\"4f67af00-60de-4117-81cf-5679ade2ddcc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"6107c823-b21d-4d0f-b5d3-e1c2151d15fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.token',_binary 'a:9:{s:4:\"uuid\";s:36:\"abbbcbe6-fbc2-4032-b329-faa7fe4fab0f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:10:\"user.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";N;s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.extension',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:101:{s:11:\"anchor_link\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:30:\"ckeditor5_plugin_pack_bookmark\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:7:\"comment\";i:0;s:6:\"config\";i:0;s:13:\"config_ignore\";i:0;s:12:\"config_split\";i:0;s:18:\"config_translation\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:4:\"diff\";i:0;s:18:\"dynamic_page_cache\";i:0;s:6:\"editor\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:6:\"filter\";i:0;s:11:\"gin_toolbar\";i:0;s:9:\"glightbox\";i:0;s:16:\"glightbox_inline\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:16:\"hotkeys_for_save\";i:0;s:5:\"image\";i:0;s:7:\"jsonapi\";i:0;s:16:\"jsonapi_defaults\";i:0;s:14:\"jsonapi_extras\";i:0;s:18:\"jsonapi_menu_items\";i:0;s:17:\"jsonapi_resources\";i:0;s:22:\"jsonapi_response_alter\";i:0;s:13:\"jsonapi_views\";i:0;s:8:\"language\";i:0;s:4:\"link\";i:0;s:15:\"link_attributes\";i:0;s:33:\"link_attributes_menu_link_content\";i:0;s:6:\"linkit\";i:0;s:17:\"linkit_attributes\";i:0;s:6:\"locale\";i:0;s:18:\"media_library_edit\";i:0;s:16:\"menu_item_extras\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:7:\"metatag\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:11:\"rabbit_hole\";i:0;s:8:\"redirect\";i:0;s:10:\"rel_to_abs\";i:0;s:4:\"rest\";i:0;s:18:\"rest_absolute_urls\";i:0;s:6:\"restui\";i:0;s:7:\"rh_node\";i:0;s:11:\"rh_taxonomy\";i:0;s:6:\"search\";i:0;s:13:\"serialization\";i:0;s:8:\"shortcut\";i:0;s:14:\"simple_sitemap\";i:0;s:9:\"svg_image\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:4:\"text\";i:0;s:5:\"token\";i:0;s:7:\"toolbar\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:7:\"webform\";i:0;s:14:\"webform_access\";i:0;s:18:\"webform_attachment\";i:0;s:12:\"webform_node\";i:0;s:21:\"webform_options_limit\";i:0;s:12:\"webform_rest\";i:0;s:14:\"webform_schema\";i:0;s:32:\"webform_submission_export_import\";i:0;s:10:\"webform_ui\";i:0;s:8:\"pathauto\";i:1;s:5:\"views\";i:10;s:4:\"fast\";i:1000;}s:5:\"theme\";a:3:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;s:3:\"gin\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),('','core.menu.static_menu_link_overrides',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:2:{s:18:\"contact__site_page\";a:5:{s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:7:\"enabled\";b:1;}s:20:\"standard__front_page\";a:5:{s:6:\"weight\";i:-50;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:7:\"enabled\";b:1;}}}'),('','dblog.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),('','diff.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYD4Zz6IzdUZR-N_MxkJnacUlP94l-qPt--QRY-OdZc\";}s:16:\"general_settings\";a:7:{s:14:\"radio_behavior\";s:6:\"simple\";s:21:\"context_lines_leading\";i:1;s:22:\"context_lines_trailing\";i:1;s:20:\"revision_pager_limit\";i:50;s:14:\"layout_plugins\";a:3:{s:13:\"visual_inline\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:0;}s:12:\"split_fields\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:1;}s:14:\"unified_fields\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:2;}}s:24:\"visual_default_view_mode\";s:4:\"full\";s:19:\"visual_inline_theme\";s:7:\"default\";}}'),('','editor.editor.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"714302b5-b69b-48c9-822c-6906b789be66\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:7:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:44:\"ckeditor5_plugin_pack_auto_image__auto_image\";a:1:{s:7:\"enabled\";b:0;}s:62:\"ckeditor5_plugin_pack_text_transformation__text_transformation\";a:4:{s:7:\"enabled\";b:0;s:21:\"extra_transformations\";s:0:\"\";s:27:\"extra_regex_transformations\";a:0:{}s:6:\"groups\";a:5:{s:10:\"typography\";a:2:{s:15:\"transformations\";a:3:{s:8:\"ellipsis\";a:1:{s:7:\"enabled\";i:1;}s:6:\"enDash\";a:1:{s:7:\"enabled\";i:1;}s:6:\"emDash\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:6:\"quotes\";a:2:{s:15:\"transformations\";a:2:{s:13:\"quotesPrimary\";a:1:{s:7:\"enabled\";i:1;}s:15:\"quotesSecondary\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:7:\"symbols\";a:2:{s:15:\"transformations\";a:3:{s:9:\"trademark\";a:1:{s:7:\"enabled\";i:1;}s:19:\"registeredTrademark\";a:1:{s:7:\"enabled\";i:1;}s:9:\"copyright\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:12:\"mathematical\";a:2:{s:15:\"transformations\";a:10:{s:7:\"oneHalf\";a:1:{s:7:\"enabled\";i:1;}s:8:\"oneThird\";a:1:{s:7:\"enabled\";i:1;}s:9:\"twoThirds\";a:1:{s:7:\"enabled\";i:1;}s:9:\"oneFourth\";a:1:{s:7:\"enabled\";i:1;}s:13:\"threeQuarters\";a:1:{s:7:\"enabled\";i:1;}s:15:\"lessThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:18:\"greaterThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:8:\"notEqual\";a:1:{s:7:\"enabled\";i:1;}s:9:\"arrowLeft\";a:1:{s:7:\"enabled\";i:1;}s:10:\"arrowRight\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:4:\"misc\";a:2:{s:15:\"transformations\";a:4:{s:17:\"quotesPrimaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:19:\"quotesSecondaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:15:\"quotesPrimaryPl\";a:1:{s:7:\"enabled\";i:0;}s:17:\"quotesSecondaryPl\";a:1:{s:7:\"enabled\";i:0;}}s:7:\"enabled\";i:0;}}}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:12:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:17:\"<blockquote cite>\";i:5;s:9:\"<ul type>\";i:6;s:9:\"<ol type>\";i:7;s:7:\"<h2 id>\";i:8;s:7:\"<h3 id>\";i:9;s:7:\"<h4 id>\";i:10;s:7:\"<h5 id>\";i:11;s:7:\"<h6 id>\";}}s:16:\"linkit_extension\";a:2:{s:14:\"linkit_enabled\";b:1;s:14:\"linkit_profile\";s:7:\"default\";}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"7a68f2fe-d2c4-467b-94db-f1b3c98a4c4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:44:{i:0;s:4:\"undo\";i:1;s:4:\"redo\";i:2;s:5:\"style\";i:3;s:6:\"indent\";i:4;s:7:\"outdent\";i:5;s:8:\"fontSize\";i:6;s:4:\"bold\";i:7;s:6:\"italic\";i:8;s:13:\"strikethrough\";i:9;s:9:\"underline\";i:10;s:10:\"fontFamily\";i:11;s:9:\"highlight\";i:12;s:9:\"fontColor\";i:13;s:19:\"fontBackgroundColor\";i:14;s:11:\"superscript\";i:15;s:9:\"subscript\";i:16;s:9:\"alignment\";i:17;s:12:\"removeFormat\";i:18;s:1:\"|\";i:19;s:4:\"link\";i:20;s:6:\"anchor\";i:21;s:1:\"|\";i:22;s:14:\"findAndReplace\";i:23;s:12:\"bulletedList\";i:24;s:12:\"numberedList\";i:25;s:1:\"|\";i:26;s:10:\"fullScreen\";i:27;s:10:\"blockQuote\";i:28;s:17:\"drupalInsertImage\";i:29;s:11:\"insertTable\";i:30;s:14:\"horizontalLine\";i:31;s:1:\"|\";i:32;s:7:\"heading\";i:33;s:9:\"codeBlock\";i:34;s:9:\"selectAll\";i:35;s:1:\"|\";i:36;s:13:\"sourceEditing\";i:37;s:4:\"code\";i:38;s:17:\"specialCharacters\";i:39;s:9:\"pageBreak\";i:40;s:14:\"insertTemplate\";i:41;s:10:\"showBlocks\";i:42;s:8:\"bookmark\";i:43;s:16:\"textPartLanguage\";}}s:7:\"plugins\";a:17:{s:19:\"ckeditor5_alignment\";a:1:{s:18:\"enabled_alignments\";a:4:{i:0;s:6:\"center\";i:1;s:7:\"justify\";i:2;s:4:\"left\";i:3;s:5:\"right\";}}s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:6:{i:0;s:8:\"heading1\";i:1;s:8:\"heading2\";i:2;s:8:\"heading3\";i:3;s:8:\"heading4\";i:4;s:8:\"heading5\";i:5;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:18:\"ckeditor5_language\";a:1:{s:13:\"language_list\";s:2:\"un\";}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:44:\"ckeditor5_plugin_pack_auto_image__auto_image\";a:1:{s:7:\"enabled\";b:0;}s:56:\"ckeditor5_plugin_pack_find_and_replace__find_and_replace\";a:1:{s:7:\"ui_type\";s:6:\"dialog\";}s:38:\"ckeditor5_plugin_pack_font__font_color\";a:7:{s:6:\"colors\";a:0:{}s:18:\"use_default_colors\";b:1;s:15:\"use_colorpicker\";b:1;s:18:\"font_color_columns\";i:5;s:26:\"font_color_document_colors\";i:10;s:16:\"bg_color_columns\";i:5;s:24:\"bg_color_document_colors\";i:10;}s:39:\"ckeditor5_plugin_pack_font__font_family\";a:1:{s:7:\"options\";s:0:\"\";}s:37:\"ckeditor5_plugin_pack_font__font_size\";a:1:{s:7:\"options\";s:0:\"\";}s:42:\"ckeditor5_plugin_pack_highlight__highlight\";a:3:{s:7:\"options\";a:0:{}s:19:\"use_default_markers\";b:1;s:13:\"attach_styles\";b:0;}s:48:\"ckeditor5_plugin_pack_indent_block__indent_block\";a:1:{s:7:\"enabled\";b:1;}s:62:\"ckeditor5_plugin_pack_text_transformation__text_transformation\";a:4:{s:7:\"enabled\";b:0;s:21:\"extra_transformations\";s:0:\"\";s:27:\"extra_regex_transformations\";a:0:{}s:6:\"groups\";a:5:{s:10:\"typography\";a:2:{s:15:\"transformations\";a:3:{s:8:\"ellipsis\";a:1:{s:7:\"enabled\";i:1;}s:6:\"enDash\";a:1:{s:7:\"enabled\";i:1;}s:6:\"emDash\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:6:\"quotes\";a:2:{s:15:\"transformations\";a:2:{s:13:\"quotesPrimary\";a:1:{s:7:\"enabled\";i:1;}s:15:\"quotesSecondary\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:7:\"symbols\";a:2:{s:15:\"transformations\";a:3:{s:9:\"trademark\";a:1:{s:7:\"enabled\";i:1;}s:19:\"registeredTrademark\";a:1:{s:7:\"enabled\";i:1;}s:9:\"copyright\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:12:\"mathematical\";a:2:{s:15:\"transformations\";a:10:{s:7:\"oneHalf\";a:1:{s:7:\"enabled\";i:1;}s:8:\"oneThird\";a:1:{s:7:\"enabled\";i:1;}s:9:\"twoThirds\";a:1:{s:7:\"enabled\";i:1;}s:9:\"oneFourth\";a:1:{s:7:\"enabled\";i:1;}s:13:\"threeQuarters\";a:1:{s:7:\"enabled\";i:1;}s:15:\"lessThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:18:\"greaterThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:8:\"notEqual\";a:1:{s:7:\"enabled\";i:1;}s:9:\"arrowLeft\";a:1:{s:7:\"enabled\";i:1;}s:10:\"arrowRight\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:4:\"misc\";a:2:{s:15:\"transformations\";a:4:{s:17:\"quotesPrimaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:19:\"quotesSecondaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:15:\"quotesPrimaryPl\";a:1:{s:7:\"enabled\";i:0;}s:17:\"quotesSecondaryPl\";a:1:{s:7:\"enabled\";i:0;}}s:7:\"enabled\";i:0;}}}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}s:15:\"ckeditor5_style\";a:1:{s:6:\"styles\";a:1:{i:0;a:2:{s:5:\"label\";s:7:\"Caption\";s:7:\"element\";s:22:\"<span class=\"caption\">\";}}}s:16:\"linkit_extension\";a:2:{s:14:\"linkit_enabled\";b:1;s:14:\"linkit_profile\";s:7:\"default\";}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.webform_default',_binary 'a:8:{s:4:\"uuid\";s:36:\"b83f2eef-227c-4316-9376-0182174cb48a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:6:\"format\";s:15:\"webform_default\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:20:{i:0;s:7:\"heading\";i:1;s:1:\"|\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:9:\"subscript\";i:5;s:11:\"superscript\";i:6;s:1:\"|\";i:7;s:17:\"specialCharacters\";i:8;s:1:\"|\";i:9;s:12:\"numberedList\";i:10;s:12:\"bulletedList\";i:11;s:1:\"|\";i:12;s:4:\"link\";i:13;s:1:\"|\";i:14;s:6:\"indent\";i:15;s:7:\"outdent\";i:16;s:1:\"|\";i:17;s:10:\"blockQuote\";i:18;s:1:\"|\";i:19;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:3:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:1:{s:6:\"status\";b:0;}}'),('','field.field.block_content.basic.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"66f77a78-8dbc-42dd-865d-64c9d97497e5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.comment.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"85d0b6cd-cb9e-43f0-b97a-097bc7bfb2ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:34:\"field.storage.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"62rlTOx3sPVrYhBnSBHZStXwiO02v1UpHSMrhWDsuG8\";}s:2:\"id\";s:28:\"comment.comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:5:\"label\";s:7:\"Comment\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.node.article.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"e8e918f3-0065-4fba-bab0-bbf3f9012680\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.article.comment',_binary 'a:17:{s:4:\"uuid\";s:36:\"fbcc6ac8-045f-46f3-9c69-215e5aee20fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"field.storage.node.comment\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UqXlkKC4v2-bDfWx4zcXQrD5YIi3d5byENEmWv-G_Uc\";}s:2:\"id\";s:20:\"node.article.comment\";s:10:\"field_name\";s:7:\"comment\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:8:\"Comments\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:6:{s:6:\"status\";i:2;s:3:\"cid\";i:0;s:22:\"last_comment_timestamp\";i:0;s:17:\"last_comment_name\";N;s:16:\"last_comment_uid\";i:0;s:13:\"comment_count\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:12:\"default_mode\";i:1;s:8:\"per_page\";i:50;s:9:\"anonymous\";i:0;s:13:\"form_location\";b:1;s:7:\"preview\";i:1;}s:10:\"field_type\";s:7:\"comment\";}'),('','field.field.node.article.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"a821c784-0c14-4d95-afe8-b3870cea2d6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.node.article.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"8301f478-2242-4c70-95e1-e38295e4c668\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.node.page.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"14afe9f8-2fd1-40c6-b8d8-e5d9dcb2b2aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.webform.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"22aaedcb-09db-4794-9acb-2becd13a2e0d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.webform\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Qu0UyzQ0jD4TDYq8fOasS-D-vGd3gSwzi15PzRJUD4\";}s:2:\"id\";s:17:\"node.webform.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.webform.webform',_binary 'a:17:{s:4:\"uuid\";s:36:\"cc7f6f2e-82c2-41b5-9e91-ef9ffdf8558b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"field.storage.node.webform\";i:1;s:17:\"node.type.webform\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w6hvTj8CaO8YVQDnlsD-jRBzMA_vNmx2cXLEKX13yT4\";}s:2:\"id\";s:20:\"node.webform.webform\";s:10:\"field_name\";s:7:\"webform\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"webform\";s:5:\"label\";s:7:\"Webform\";s:11:\"description\";s:62:\"Select the webform that you would like to attach to this node.\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:5:{s:12:\"default_data\";s:0:\"\";s:6:\"status\";s:4:\"open\";s:4:\"open\";s:0:\"\";s:5:\"close\";s:0:\"\";s:11:\"target_uuid\";s:0:\"\";}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:0:{}}s:10:\"field_type\";s:7:\"webform\";}'),('','field.field.user.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"2765f954-a749-4676-a2b3-63be8c7d3800\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),('','field.storage.block_content.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac53f9a6-7651-4e31-83f3-63793c128360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"e5ee7b1b-bd81-4fd0-af67-f92e6bae8313\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:2:\"id\";s:20:\"comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"8a930e87-45e4-410a-af3d-198c8f27a1a8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.comment',_binary 'a:17:{s:4:\"uuid\";s:36:\"d8ddfd2c-c777-440f-a0e1-ce7cea17d4dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ktCna9xmWvYZIUfOCUyDQvedn5RtnS4CRmEIwNmvYjc\";}s:2:\"id\";s:12:\"node.comment\";s:10:\"field_name\";s:7:\"comment\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:7:\"comment\";s:8:\"settings\";a:1:{s:12:\"comment_type\";s:7:\"comment\";}s:6:\"module\";s:7:\"comment\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"2e760d93-d8f1-4cc0-a846-8a1be50ab6b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"81b92d69-01d7-4755-b08e-038fae9ed965\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.webform',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad237af2-b5d3-4fac-8674-82493f95d005\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:12:\"webform_node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SJRNyZvo1lWcPLKxH_u6giTk1y51ymXvpKX65YUNd7w\";}s:2:\"id\";s:12:\"node.webform\";s:10:\"field_name\";s:7:\"webform\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"dfa0301c-438e-4abc-a17f-d0d555a64089\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),('','file.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:0;s:18:\"replace_whitespace\";b:0;s:24:\"replace_non_alphanumeric\";b:0;s:22:\"deduplicate_separators\";b:0;s:9:\"lowercase\";b:0;s:21:\"replacement_character\";s:1:\"-\";}}'),('','filter.format.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"568418de-cc1f-4161-bfd4-806e6cda5041\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:6:\"editor\";i:1;s:6:\"linkit\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:-9;s:7:\"filters\";a:7:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:293:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <blockquote cite> <ul type> <ol type start> <strong> <em> <code> <a href data-entity-type data-entity-uuid data-entity-substitution> <li> <img src alt height width data-entity-uuid data-entity-type data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}s:6:\"linkit\";a:5:{s:2:\"id\";s:6:\"linkit\";s:8:\"provider\";s:6:\"linkit\";s:6:\"status\";b:0;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:5:\"title\";b:0;}}}}'),('','filter.format.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"4116e91f-e5fa-4a37-942f-11ab8d868828\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:6:\"editor\";i:1;s:10:\"rel_to_abs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:-10;s:7:\"filters\";a:7:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:0;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:22:\"<span class=\"caption\">\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}s:10:\"rel_to_abs\";a:5:{s:2:\"id\";s:10:\"rel_to_abs\";s:8:\"provider\";s:10:\"rel_to_abs\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}}}'),('','filter.format.plain_text',_binary 'a:9:{s:4:\"uuid\";s:36:\"d6c89fdd-daf5-43dd-8fd3-2de981a4e2c3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:-7;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.restricted_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"150b0210-ca67-4d68-8a96-47161c6734ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:-8;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.webform_default',_binary 'a:9:{s:4:\"uuid\";s:36:\"7e21f965-39b3-4af0-bca5-32809fcc5e3b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EeKp_M4Oid3erARiAam9rsgBKR91uEnFkEP3aZS2ol8\";}s:4:\"name\";s:31:\"Webform (Default) - DO NOT EDIT\";s:6:\"format\";s:15:\"webform_default\";s:6:\"weight\";i:100;s:7:\"filters\";a:0:{}}'),('','filter.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),('','gin.settings',_binary 'a:13:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"c8aZhkIY8zHUo0_UOll4vVs_l48dHL_gBqbvfuAM0Rs\";}s:19:\"preset_accent_color\";s:4:\"blue\";s:18:\"preset_focus_color\";s:3:\"gin\";s:15:\"enable_darkmode\";s:1:\"0\";s:15:\"classic_toolbar\";s:3:\"new\";s:26:\"secondary_toolbar_frontend\";b:1;s:4:\"logo\";a:1:{s:11:\"use_default\";b:1;}s:18:\"high_contrast_mode\";b:0;s:14:\"layout_density\";s:7:\"default\";s:23:\"show_description_toggle\";b:0;s:24:\"show_user_theme_settings\";b:0;s:21:\"sticky_action_buttons\";b:0;s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),('','glightbox.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e4lHOh2jMu4BTmZv8Pds85ZvpYvEYgH1AsR9crZHJPg\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}s:4:\"plyr\";a:22:{s:7:\"enabled\";b:1;s:5:\"debug\";b:0;s:8:\"controls\";s:124:\"[\'play-large\', \'play\', \'progress\', \'current-time\', \'mute\', \'volume\', \'captions\', \'settings\', \'pip\', \'airplay\', \'fullscreen\']\";s:8:\"settings\";s:40:\"[\'captions\', \'quality\', \'speed\', \'loop\']\";s:11:\"load_sprite\";b:1;s:8:\"icon_url\";s:0:\"\";s:11:\"icon_prefix\";s:4:\"plyr\";s:11:\"blank_video\";s:36:\"https://cdn.plyr.io/static/blank.mp4\";s:8:\"autoplay\";b:0;s:9:\"autopause\";b:1;s:11:\"playsinline\";b:1;s:9:\"seek_time\";i:10;s:6:\"volume\";i:1;s:5:\"muted\";b:0;s:13:\"click_to_play\";b:1;s:20:\"disable_context_menu\";b:1;s:13:\"hide_controls\";b:1;s:12:\"reset_on_end\";b:0;s:16:\"display_duration\";b:1;s:11:\"invert_time\";b:1;s:13:\"toggle_invert\";b:1;s:5:\"ratio\";s:0:\"\";}}'),('','image.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),('','image.style.large',_binary 'a:8:{s:4:\"uuid\";s:36:\"29940d30-64d8-4da8-9c82-a253f2d27667\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.linkit_result_thumbnail',_binary 'a:8:{s:4:\"uuid\";s:36:\"6eea7178-ad4d-464d-90a5-16d53236deb2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PY0kMp7KIxvU4kBi5mcnD_DHTKUc1OkYCfaPliXjpa8\";}s:4:\"name\";s:23:\"linkit_result_thumbnail\";s:5:\"label\";s:23:\"Linkit result thumbnail\";s:7:\"effects\";a:1:{s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";a:4:{s:4:\"uuid\";s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:50;s:6:\"height\";i:50;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.medium',_binary 'a:8:{s:4:\"uuid\";s:36:\"1bf69c20-6eff-4470-93d3-bae2dc31f207\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.thumbnail',_binary 'a:8:{s:4:\"uuid\";s:36:\"3375957d-2d6c-475c-bc6b-124e63c6164a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.wide',_binary 'a:8:{s:4:\"uuid\";s:36:\"b652d976-a322-4aa9-9474-2415078a63e8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','jsonapi.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bbhVQEgCMWzCNQ9nBMR-PZeax3Tkujtue1HA7CE5574\";}s:9:\"read_only\";b:1;s:32:\"maintenance_header_retry_seconds\";a:2:{s:3:\"min\";i:5;s:3:\"max\";i:10;}}'),('','jsonapi_extras.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4_ifqxmFEAYSrGFkA63fLBYAWO-Fz9ACp9qVjkxPghg\";}s:11:\"path_prefix\";s:7:\"jsonapi\";s:13:\"include_count\";b:1;s:16:\"default_disabled\";b:0;s:32:\"validate_configuration_integrity\";b:1;}'),('','language.content_settings.path_alias.path_alias',_binary 'a:10:{s:4:\"uuid\";s:36:\"255480ac-2d85-450d-ba7f-1f49e3d9b8b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"path_alias\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dhjFABRzm52DkRXnYja5ZoHwjY0R3gEGic3KpDUXgRo\";}s:2:\"id\";s:21:\"path_alias.path_alias\";s:21:\"target_entity_type_id\";s:10:\"path_alias\";s:13:\"target_bundle\";s:10:\"path_alias\";s:16:\"default_langcode\";s:3:\"und\";s:18:\"language_alterable\";b:1;}'),('','language.content_settings.redirect.redirect',_binary 'a:10:{s:4:\"uuid\";s:36:\"8cc7a8b1-2dde-4238-aad8-64e49400f338\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"y734AXEpjry1Ppff_hQQBFQGJvYjF0fk1JoWtp5q2JY\";}s:2:\"id\";s:17:\"redirect.redirect\";s:21:\"target_entity_type_id\";s:8:\"redirect\";s:13:\"target_bundle\";s:8:\"redirect\";s:16:\"default_langcode\";s:3:\"und\";s:18:\"language_alterable\";b:1;}'),('','language.entity.en',_binary 'a:10:{s:4:\"uuid\";s:36:\"541e3fe7-505e-4e41-a296-2b93fab83b55\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lBXDpdDPXQtrfTJQhr6MjRJJEEyYSoRJ0acdvHLsWeA\";}s:2:\"id\";s:2:\"en\";s:5:\"label\";s:7:\"English\";s:9:\"direction\";s:3:\"ltr\";s:6:\"weight\";i:0;s:6:\"locked\";b:0;}'),('','language.entity.und',_binary 'a:10:{s:4:\"uuid\";s:36:\"f479fc2f-303e-4d96-b8dc-cf40b3c917a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNX6lLCKDaY83nCMh20My---y03KbiFlv802DKCCpvg\";}s:2:\"id\";s:3:\"und\";s:5:\"label\";s:13:\"Not specified\";s:9:\"direction\";s:3:\"ltr\";s:6:\"weight\";i:2;s:6:\"locked\";b:1;}'),('','language.entity.zxx',_binary 'a:10:{s:4:\"uuid\";s:36:\"577d2e0c-b2fc-4b0f-a051-dcb71bf1c920\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"35CefWbnzaiytcg3acexxz_GTvuwIjYd_ZTcmmR-tXA\";}s:2:\"id\";s:3:\"zxx\";s:5:\"label\";s:14:\"Not applicable\";s:9:\"direction\";s:3:\"ltr\";s:6:\"weight\";i:3;s:6:\"locked\";b:1;}'),('','language.mappings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EMWe7Yu4Q5eD-NUfNuQAWGBvYUNZPIinztEtONSmsDc\";}s:3:\"map\";a:10:{s:2:\"no\";s:2:\"nb\";s:2:\"pt\";s:5:\"pt-pt\";s:2:\"zh\";s:7:\"zh-hans\";s:5:\"zh-tw\";s:7:\"zh-hant\";s:5:\"zh-hk\";s:7:\"zh-hant\";s:5:\"zh-mo\";s:7:\"zh-hant\";s:6:\"zh-cht\";s:7:\"zh-hant\";s:5:\"zh-cn\";s:7:\"zh-hans\";s:5:\"zh-sg\";s:7:\"zh-hans\";s:6:\"zh-chs\";s:7:\"zh-hans\";}}'),('','language.negotiation',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uEePITI9tV6WqzmsTb7MfPCi5yPWXSxAN1xeLcYFQbM\";}s:7:\"session\";a:1:{s:9:\"parameter\";s:8:\"language\";}s:3:\"url\";a:3:{s:6:\"source\";s:11:\"path_prefix\";s:8:\"prefixes\";a:1:{s:2:\"en\";s:0:\"\";}s:7:\"domains\";a:1:{s:2:\"en\";s:0:\"\";}}s:17:\"selected_langcode\";s:12:\"site_default\";}'),('','language.types',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dqouFqVseNJNvEjsoYKxbinFOITuCxYhi4y2OTNQP_8\";}s:3:\"all\";a:3:{i:0;s:18:\"language_interface\";i:1;s:16:\"language_content\";i:2;s:12:\"language_url\";}s:12:\"configurable\";a:1:{i:0;s:18:\"language_interface\";}s:11:\"negotiation\";a:3:{s:16:\"language_content\";a:1:{s:7:\"enabled\";a:1:{s:18:\"language-interface\";i:0;}}s:12:\"language_url\";a:1:{s:7:\"enabled\";a:2:{s:12:\"language-url\";i:0;s:21:\"language-url-fallback\";i:1;}}s:18:\"language_interface\";a:1:{s:7:\"enabled\";a:1:{s:12:\"language-url\";i:0;}}}}'),('','linkit.linkit_profile.default',_binary 'a:9:{s:4:\"uuid\";s:36:\"24222d7c-50f5-45f4-8a23-489ca365134d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0Jw_BFJCCtWk187tIYvME58VFpYwPaAdrc4eRtAyHH0\";}s:5:\"label\";s:7:\"Default\";s:2:\"id\";s:7:\"default\";s:11:\"description\";s:24:\"A default Linkit profile\";s:8:\"matchers\";a:1:{s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";a:4:{s:2:\"id\";s:11:\"entity:node\";s:4:\"uuid\";s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";s:8:\"settings\";a:6:{s:8:\"metadata\";s:77:\"[node:content-type:name] #[node:nid] | [node:created:medium] by [node:author]\";s:7:\"bundles\";a:0:{}s:15:\"group_by_bundle\";b:0;s:19:\"include_unpublished\";b:0;s:17:\"substitution_type\";s:9:\"canonical\";s:5:\"limit\";i:100;}s:6:\"weight\";i:0;}}}'),('','locale.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cSdYeE-_AQETCNZnl8BMFS9-sVn5--VzAYILkpPBUbM\";}s:13:\"cache_strings\";b:1;s:17:\"translate_english\";b:0;s:10:\"javascript\";a:1:{s:9:\"directory\";s:9:\"languages\";}s:11:\"translation\";a:8:{s:10:\"use_source\";s:16:\"remote_and_local\";s:16:\"default_filename\";s:30:\"%project-%version.%language.po\";s:22:\"default_server_pattern\";s:87:\"https://ftp.drupal.org/files/translations/%core/%project/%project-%version.%language.po\";s:20:\"overwrite_customized\";b:0;s:24:\"overwrite_not_customized\";b:1;s:20:\"update_interval_days\";i:0;s:4:\"path\";s:32:\"sites/default/files/translations\";s:14:\"import_enabled\";b:1;}}'),('','menu_item_extras.utility',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJyVsRDycEefcdJUBrw82evYJtCphyLU4BV5MMQ5rPQ\";}s:24:\"entity_type_build_status\";b:1;}'),('','menu_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),('','metatag.metatag_defaults.403',_binary 'a:8:{s:4:\"uuid\";s:36:\"aa7a542d-baa7-40ad-afc6-49bb56062750\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RDCkFL0NDt75Gwioooxo1iuA1S50xTVsBOgX__c6wTw\";}s:2:\"id\";s:3:\"403\";s:5:\"label\";s:17:\"403 access denied\";s:4:\"tags\";a:3:{s:6:\"robots\";s:7:\"noindex\";s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),('','metatag.metatag_defaults.404',_binary 'a:8:{s:4:\"uuid\";s:36:\"cf9933a3-28ef-476d-9838-4a92e3eeb1fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"puBstSLDz8mbaWU357zaqQDBGMGsJzG0j-TQNQkjg20\";}s:2:\"id\";s:3:\"404\";s:5:\"label\";s:18:\"404 page not found\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),('','metatag.metatag_defaults.front',_binary 'a:8:{s:4:\"uuid\";s:36:\"c52f9ced-fccb-43cb-9fe2-a8040eb13542\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1noCXlegCr5HFehQRF1ViXy1jhU1jZ_sNN99a8Sj5jo\";}s:2:\"id\";s:5:\"front\";s:5:\"label\";s:10:\"Front page\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),('','metatag.metatag_defaults.global',_binary 'a:8:{s:4:\"uuid\";s:36:\"fa0b3dbf-4333-431d-8522-9036aea72657\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sL588ui1E_8-2c_UupwyYxcqX2OVyMFp3HTLbbFqvPc\";}s:2:\"id\";s:6:\"global\";s:5:\"label\";s:6:\"Global\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:18:\"[current-page:url]\";s:5:\"title\";s:34:\"[current-page:title] | [site:name]\";}}'),('','metatag.metatag_defaults.node',_binary 'a:8:{s:4:\"uuid\";s:36:\"d7d2466e-ab6f-4c1b-a923-ca531f2fa600\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rpwvgyEURXLz_JjgMCrkS1rUv-0k3L79BpO-ReN7fDI\";}s:2:\"id\";s:4:\"node\";s:5:\"label\";s:7:\"Content\";s:4:\"tags\";a:3:{s:5:\"title\";s:26:\"[node:title] | [site:name]\";s:11:\"description\";s:14:\"[node:summary]\";s:13:\"canonical_url\";s:10:\"[node:url]\";}}'),('','metatag.metatag_defaults.taxonomy_term',_binary 'a:8:{s:4:\"uuid\";s:36:\"d237fb3f-9063-48b4-82ba-1dfe13df5594\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"92bXZdyYJ5xqukdfmGRr_CYcwm1vfuS8b8aJ7X_G7E0\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[term:url]\";s:11:\"description\";s:18:\"[term:description]\";s:5:\"title\";s:25:\"[term:name] | [site:name]\";}}'),('','metatag.metatag_defaults.user',_binary 'a:8:{s:4:\"uuid\";s:36:\"b8863b10-cb33-4649-8d52-ceac3c926829\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MvQPTbQx0Vxwy0ordSHyixdZmLCMpvMdLD69dlwkrKc\";}s:2:\"id\";s:4:\"user\";s:5:\"label\";s:4:\"User\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[user:url]\";s:11:\"description\";s:11:\"[site:name]\";s:5:\"title\";s:33:\"[user:display-name] | [site:name]\";}}'),('','metatag.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DrYt8PcXA0xB3C3L1SvtefnkO5SwUonhY3n4Ld8yun4\";}s:18:\"entity_type_groups\";a:0:{}s:9:\"separator\";s:0:\"\";s:15:\"tag_trim_method\";s:11:\"beforeValue\";s:18:\"tag_trim_maxlength\";a:0:{}s:21:\"tag_scroll_max_height\";s:0:\"\";s:13:\"use_maxlength\";b:1;s:12:\"tag_trim_end\";s:14:\"|.,-:;/+&([{\"\'\";}'),('','node.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),('','node.type.article',_binary 'a:12:{s:4:\"uuid\";s:36:\"59988f5b-edd5-420c-9c7c-ec760037efc2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:1;}'),('','node.type.page',_binary 'a:12:{s:4:\"uuid\";s:36:\"f4c4b6bf-cd51-4c75-a261-fd038e87f35d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','node.type.webform',_binary 'a:12:{s:4:\"uuid\";s:36:\"f6f57731-a98c-4930-9cb9-50e4bbe5c135\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:12:\"webform_node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BuY_3PjmYtRTSuvyFORJZUe0-TQiNXEE6yYQ_dkjxW8\";}s:4:\"name\";s:7:\"Webform\";s:4:\"type\";s:7:\"webform\";s:11:\"description\";s:37:\"A basic page with a webform attached.\";s:4:\"help\";s:0:\"\";s:12:\"new_revision\";b:0;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:1;}'),('','olivero.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),('','pathauto.pattern.article',_binary 'a:12:{s:4:\"uuid\";s:36:\"8b4b8af3-f1de-4297-b432-2332d9ae25f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:7:\"article\";s:5:\"label\";s:7:\"Article\";s:4:\"type\";s:23:\"canonical_entities:node\";s:7:\"pattern\";s:20:\"article/[node:title]\";s:18:\"selection_criteria\";a:1:{s:36:\"f09b7e0b-17d8-4b74-80a8-271b585f6ff7\";a:5:{s:2:\"id\";s:18:\"entity_bundle:node\";s:6:\"negate\";b:0;s:4:\"uuid\";s:36:\"f09b7e0b-17d8-4b74-80a8-271b585f6ff7\";s:15:\"context_mapping\";a:1:{s:4:\"node\";s:4:\"node\";}s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}}s:15:\"selection_logic\";s:3:\"and\";s:6:\"weight\";i:-5;s:13:\"relationships\";a:0:{}}'),('','pathauto.pattern.basic_page',_binary 'a:12:{s:4:\"uuid\";s:36:\"831fa73e-f731-4650-a164-eec6143af109\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:10:\"basic_page\";s:5:\"label\";s:10:\"Basic Page\";s:4:\"type\";s:23:\"canonical_entities:node\";s:7:\"pattern\";s:17:\"page/[node:title]\";s:18:\"selection_criteria\";a:1:{s:36:\"67338c08-4969-434a-8357-4a8abb2ede22\";a:5:{s:2:\"id\";s:18:\"entity_bundle:node\";s:6:\"negate\";b:0;s:4:\"uuid\";s:36:\"67338c08-4969-434a-8357-4a8abb2ede22\";s:15:\"context_mapping\";a:1:{s:4:\"node\";s:4:\"node\";}s:7:\"bundles\";a:1:{s:4:\"page\";s:4:\"page\";}}}s:15:\"selection_logic\";s:3:\"and\";s:6:\"weight\";i:-5;s:13:\"relationships\";a:0:{}}'),('','pathauto.settings',_binary 'a:13:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SwvLp8snyPEExF41CaJJYdPUVomofLqtXvwciHc4cPg\";}s:20:\"enabled_entity_types\";a:1:{i:0;s:4:\"user\";}s:11:\"punctuation\";a:1:{s:6:\"hyphen\";i:1;}s:7:\"verbose\";b:0;s:9:\"separator\";s:1:\"-\";s:10:\"max_length\";i:100;s:20:\"max_component_length\";i:100;s:13:\"transliterate\";b:1;s:12:\"reduce_ascii\";b:0;s:4:\"case\";b:1;s:12:\"ignore_words\";s:134:\"a, an, as, at, before, but, by, for, from, is, in, into, like, of, off, on, onto, per, since, than, the, this, that, to, up, via, with\";s:13:\"update_action\";i:2;s:11:\"safe_tokens\";a:6:{i:0;s:5:\"alias\";i:1;s:4:\"path\";i:2;s:9:\"join-path\";i:3;s:9:\"login-url\";i:4;s:3:\"url\";i:5;s:9:\"url-brief\";}}'),('','rabbit_hole.behavior_settings.default',_binary 'a:13:{s:4:\"uuid\";s:36:\"76010145-adf2-4485-8e92-6a2464384ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzh9CgsYCGxPEcbR3ieT1la6e43lMv-ivoN7oZJKkQQ\";}s:2:\"id\";s:7:\"default\";s:14:\"entity_type_id\";N;s:9:\"entity_id\";N;s:6:\"action\";s:12:\"display_page\";s:14:\"allow_override\";i:1;s:8:\"redirect\";s:0:\"\";s:13:\"redirect_code\";i:0;s:24:\"redirect_fallback_action\";s:13:\"access_denied\";}'),('','rabbit_hole.behavior_settings.default_bundle',_binary 'a:13:{s:4:\"uuid\";s:36:\"ca871477-04f2-44a1-858c-731fed4e2a7d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qUkgsWZRCa_sLIn5JsMzB3xnx5ekIsVeGGZr7T0s9MY\";}s:2:\"id\";s:14:\"default_bundle\";s:14:\"entity_type_id\";N;s:9:\"entity_id\";N;s:6:\"action\";s:12:\"display_page\";s:14:\"allow_override\";i:1;s:8:\"redirect\";s:0:\"\";s:13:\"redirect_code\";i:0;s:24:\"redirect_fallback_action\";s:13:\"access_denied\";}'),('','redirect.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FEwQLW1wXW7fiJdG1B2bxW1c_-k6w-r-3V3bSsW6PqM\";}s:13:\"auto_redirect\";b:1;s:19:\"default_status_code\";i:301;s:23:\"passthrough_querystring\";b:1;s:7:\"warning\";b:0;s:17:\"ignore_admin_path\";b:0;s:12:\"access_check\";b:0;s:24:\"route_normalizer_enabled\";b:1;}'),('','rest.resource.entity.webform',_binary 'a:8:{s:4:\"uuid\";s:36:\"bef3799e-1ae8-4704-8d0f-a73fe64c4f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"serialization\";i:1;s:4:\"user\";i:2;s:7:\"webform\";}}s:2:\"id\";s:14:\"entity.webform\";s:9:\"plugin_id\";s:14:\"entity:webform\";s:11:\"granularity\";s:8:\"resource\";s:13:\"configuration\";a:3:{s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:7:\"formats\";a:1:{i:0;s:4:\"json\";}s:14:\"authentication\";a:1:{i:0;s:6:\"cookie\";}}}'),('','rest.resource.entity.webform_options',_binary 'a:8:{s:4:\"uuid\";s:36:\"938e4e98-191f-4790-bc0b-9a8a5d6cc7c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"serialization\";i:1;s:4:\"user\";i:2;s:7:\"webform\";}}s:2:\"id\";s:22:\"entity.webform_options\";s:9:\"plugin_id\";s:22:\"entity:webform_options\";s:11:\"granularity\";s:8:\"resource\";s:13:\"configuration\";a:3:{s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:7:\"formats\";a:1:{i:0;s:4:\"json\";}s:14:\"authentication\";a:1:{i:0;s:6:\"cookie\";}}}'),('','rest.resource.webform_rest_elements',_binary 'a:8:{s:4:\"uuid\";s:36:\"d320e37f-6fd5-4580-9cfe-3dcd1ff080cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"serialization\";i:1;s:4:\"user\";i:2;s:12:\"webform_rest\";}}s:2:\"id\";s:21:\"webform_rest_elements\";s:9:\"plugin_id\";s:21:\"webform_rest_elements\";s:11:\"granularity\";s:8:\"resource\";s:13:\"configuration\";a:3:{s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:7:\"formats\";a:1:{i:0;s:4:\"json\";}s:14:\"authentication\";a:1:{i:0;s:6:\"cookie\";}}}'),('','rest.resource.webform_rest_submit',_binary 'a:8:{s:4:\"uuid\";s:36:\"2f7011ea-42d4-4e84-9783-ecb872c2e2e1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"serialization\";i:1;s:4:\"user\";i:2;s:12:\"webform_rest\";}}s:2:\"id\";s:19:\"webform_rest_submit\";s:9:\"plugin_id\";s:19:\"webform_rest_submit\";s:11:\"granularity\";s:8:\"resource\";s:13:\"configuration\";a:3:{s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:7:\"formats\";a:1:{i:0;s:4:\"json\";}s:14:\"authentication\";a:1:{i:0;s:6:\"cookie\";}}}'),('','search.page.help_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"11e3441d-1706-4363-8843-4b977ed44ec2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RZ-bcSekNSsAbIPLW7Gmyd3uUjIOSrPvnb8RCCZYJm8\";}s:2:\"id\";s:11:\"help_search\";s:5:\"label\";s:4:\"Help\";s:4:\"path\";s:4:\"help\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"help_search\";s:13:\"configuration\";a:0:{}}'),('','search.page.node_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"c5382b4c-f6cb-4eca-80d6-5ff8750641fa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97tvtzGOa8_flb22CzSjgtm_YkiGMHvEBO-6q2K9V_U\";}s:2:\"id\";s:11:\"node_search\";s:5:\"label\";s:7:\"Content\";s:4:\"path\";s:4:\"node\";s:6:\"weight\";i:-10;s:6:\"plugin\";s:11:\"node_search\";s:13:\"configuration\";a:1:{s:8:\"rankings\";a:0:{}}}'),('','search.page.user_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"26c98a8d-21af-482c-ae3c-a9570e7dabbe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k3aUaZXGDuhkek2TZIee0PApOPTvYZLadziekdyHA5A\";}s:2:\"id\";s:11:\"user_search\";s:5:\"label\";s:5:\"Users\";s:4:\"path\";s:4:\"user\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"user_search\";s:13:\"configuration\";a:0:{}}'),('','search.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hvVxL1G-ZCxaq32IZws0YsfuhvaDiQE_np-0g35KjUk\";}s:12:\"and_or_limit\";i:7;s:12:\"default_page\";s:11:\"node_search\";s:5:\"index\";a:4:{s:10:\"cron_limit\";i:100;s:11:\"overlap_cjk\";b:1;s:17:\"minimum_word_size\";i:3;s:11:\"tag_weights\";a:12:{s:2:\"h1\";i:25;s:2:\"h2\";i:18;s:2:\"h3\";i:15;s:2:\"h4\";i:14;s:2:\"h5\";i:9;s:2:\"h6\";i:6;s:1:\"u\";i:3;s:1:\"b\";i:3;s:1:\"i\";i:3;s:6:\"strong\";i:3;s:2:\"em\";i:3;s:1:\"a\";i:10;}}s:7:\"logging\";b:0;}'),('','shortcut.set.default',_binary 'a:7:{s:4:\"uuid\";s:36:\"903954a5-8548-48e0-9cb6-eec525501eed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),('','simple_sitemap.custom_links.default',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"25hWeYa4sasuJtHqKKcEN_nYiuEC1lMPYHsn5dawJEw\";}s:5:\"links\";a:1:{i:0;a:3:{s:4:\"path\";s:1:\"/\";s:8:\"priority\";s:3:\"1.0\";s:10:\"changefreq\";s:5:\"daily\";}}}'),('','simple_sitemap.settings',_binary 'a:16:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MUpaAk1hn-0Ph4OFw3DD_6gUF9KbGwxja9Y0qmampzo\";}s:9:\"max_links\";i:2000;s:13:\"cron_generate\";b:1;s:22:\"cron_generate_interval\";i:0;s:17:\"generate_duration\";i:10000;s:23:\"entities_per_queue_item\";i:50;s:17:\"remove_duplicates\";b:1;s:17:\"skip_untranslated\";b:1;s:3:\"xsl\";b:1;s:8:\"base_url\";s:0:\"\";s:15:\"default_variant\";s:7:\"default\";s:27:\"custom_links_include_images\";b:0;s:25:\"disable_language_hreflang\";b:0;s:13:\"hide_branding\";b:0;s:18:\"excluded_languages\";a:0:{}s:20:\"enabled_entity_types\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"taxonomy_term\";i:2;s:17:\"menu_link_content\";}}'),('','simple_sitemap.sitemap.default',_binary 'a:10:{s:4:\"uuid\";s:36:\"38c791a5-1548-4677-810e-c994dd439795\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:36:\"simple_sitemap.type.default_hreflang\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rzLPapRSW-bgTs4MObzlqsqwj5IxPGO9EQZolw2ZzFc\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";s:11:\"description\";s:81:\"The default hreflang sitemap - lists URLs to be indexed by modern search engines.\";s:4:\"type\";s:16:\"default_hreflang\";s:6:\"weight\";i:0;}'),('','simple_sitemap.sitemap.index',_binary 'a:10:{s:4:\"uuid\";s:36:\"d0b3a005-f27b-40db-a375-17c6125c3e08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:25:\"simple_sitemap.type.index\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WffB95XdMvoUEvymTyLFLB-Q_JnCbbjy9Kj7TvlzN9s\";}s:2:\"id\";s:5:\"index\";s:5:\"label\";s:13:\"Sitemap Index\";s:11:\"description\";s:193:\"The sitemap index listing all other sitemaps - useful if there are at least two other sitemaps. In most cases this sitemap should be last in the generation queue and set as the default sitemap.\";s:4:\"type\";s:5:\"index\";s:6:\"weight\";i:1000;}'),('','simple_sitemap.type.default_hreflang',_binary 'a:10:{s:4:\"uuid\";s:36:\"87a31fbb-d316-4031-9da8-27a78f161b1e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yaHZPVGZtW3BUvzzdMgc4ed5l4GCiFjcgYlLZmupcqA\";}s:2:\"id\";s:16:\"default_hreflang\";s:5:\"label\";s:16:\"Default hreflang\";s:11:\"description\";s:102:\"The default hreflang sitemap type. A sitemap of this type is understood by most modern search engines.\";s:17:\"sitemap_generator\";s:7:\"default\";s:14:\"url_generators\";a:4:{i:0;s:6:\"custom\";i:1;s:6:\"entity\";i:2;s:24:\"entity_menu_link_content\";i:3;s:9:\"arbitrary\";}}'),('','simple_sitemap.type.index',_binary 'a:10:{s:4:\"uuid\";s:36:\"39c7fcad-3c78-4c1d-9e97-a160469913a4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yS_TZXc9X2zr2RfAwk7momW3LG9wra--H2ApqA5Vgak\";}s:2:\"id\";s:5:\"index\";s:5:\"label\";s:13:\"Sitemap Index\";s:11:\"description\";s:89:\"The sitemap index sitemap type. A sitemap of this type lists sitemaps of all other types.\";s:17:\"sitemap_generator\";s:5:\"index\";s:14:\"url_generators\";a:1:{i:0;s:5:\"index\";}}'),('','system.action.comment_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c7d14f6a-6e6a-45ea-8fa6-b13072dfe4b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpBH8OmL4sdesCdeZLsW8KOutB5gkbreWJbfjhfFKaQ\";}s:2:\"id\";s:21:\"comment_delete_action\";s:5:\"label\";s:14:\"Delete comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:28:\"entity:delete_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"592b4324-cb2f-4348-a5e7-e7465b63312f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C00dyL_W_5M0nFlgUB3lWUTUs96jn51Jw1MLHVEHZD0\";}s:2:\"id\";s:22:\"comment_publish_action\";s:5:\"label\";s:15:\"Publish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:29:\"entity:publish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"825fd299-837b-45d7-99f0-05d512a7b4e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lfyE_snmvfg_EQ3VDyhUtGAXgmqtEiqa46I3bTMg8DU\";}s:2:\"id\";s:19:\"comment_save_action\";s:5:\"label\";s:12:\"Save comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:26:\"entity:save_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"60d38e09-2fb3-41b8-b097-8cfd3153ea58\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tWOIjSMobEWOFZddMkNqb9JySbOVwE1diC6NRqcfLTk\";}s:2:\"id\";s:24:\"comment_unpublish_action\";s:5:\"label\";s:17:\"Unpublish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:31:\"entity:unpublish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"9d8c9ee3-e66d-4a91-96e7-930a4d37b701\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"0d5b6f2e-6a01-4548-80d0-2b2f921f5ce1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f1a2a8bf-e58b-4436-8b2d-858b28738221\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_promote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ad08f939-8821-4b11-949f-8731eb3b08ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"b0e3c96b-6c2c-461b-8ffc-a06d3863e7f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"bb994d72-a95d-4051-8c29-3d7b939b7aeb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpromote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"914162ea-d84f-4516-bd2b-4f0706afdc16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"25777620-04cb-41ec-8e16-8c4348c4f694\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.pathauto_update_alias_node',_binary 'a:10:{s:4:\"uuid\";s:36:\"eee484c2-7858-45fd-b4dd-731b43fbff3a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Cr0CsPUSuio4ClP7bOTqHBefJOLtN5KPyKyYj9E4qvQ\";}s:2:\"id\";s:26:\"pathauto_update_alias_node\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),('','system.action.pathauto_update_alias_user',_binary 'a:10:{s:4:\"uuid\";s:36:\"3f3a79f9-8861-47f0-9a48-7763b20662c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6eiNWATGTd3lUEKuxNPNyDRDVMsUlM0HS90_R6JJLUI\";}s:2:\"id\";s:26:\"pathauto_update_alias_user\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),('','system.action.redirect_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"3bcda49f-6cd5-4dd0-9351-32a81d30f2a1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vcnRZRvBqTbK3nZ2M4_lKPlEGc8GjPzgaqapYUfyX8M\";}s:2:\"id\";s:22:\"redirect_delete_action\";s:5:\"label\";s:15:\"Delete redirect\";s:4:\"type\";s:8:\"redirect\";s:6:\"plugin\";s:22:\"redirect_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c81c6465-71f1-49ec-87c0-665cb21bddc1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"419ab97d-38b5-44bf-8bc7-4363dd8cd152\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_add_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"fc5862d9-e21c-4c86-9dbf-f476320fc76b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_add_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"80b46801-8606-45a5-ac48-556164d453f8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:35:\"user_add_role_action.content_editor\";s:5:\"label\";s:51:\"Add the Content editor role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_block_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6fddfca8-1c8f-41ce-8413-06d675230a6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_cancel_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7d87b2ec-5200-4708-ab2e-b9270cd87667\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_remove_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"4efe6291-b04e-4adc-96a1-342f84a493c7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_remove_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"b838c238-785f-4fa9-bda4-f6d575f823a2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:38:\"user_remove_role_action.content_editor\";s:5:\"label\";s:56:\"Remove the Content editor role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_unblock_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"8e84e417-0929-4c2e-9659-9e54cc04b4fd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_archive_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"342b3323-7057-4ffe-ade0-4338b9bba972\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OmnschvBLb9ZJn0iVyBd2odf8U8Nt0INjRbRMixZw9U\";}s:2:\"id\";s:22:\"webform_archive_action\";s:5:\"label\";s:15:\"Archive webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:22:\"webform_archive_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_close_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ddc1f1da-5251-49ef-9ea8-eaff39c9a1a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dl-1T9PDkraB7MyMUjTJAioPEx6UNvIB9gqmnB1CRkk\";}s:2:\"id\";s:20:\"webform_close_action\";s:5:\"label\";s:13:\"Close webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:20:\"webform_close_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f2218b96-cb4e-4226-bdca-6170e30bc34f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e1bCTp0ryXZZtnS9nlVAbtoWz3-8fmbNlqKY3GHzbsM\";}s:2:\"id\";s:21:\"webform_delete_action\";s:5:\"label\";s:14:\"Delete webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:21:\"webform_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_open_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"4cf610b1-6607-4437-8e3c-20c2d77f21ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AK83C-dOZEPruvi6GbkuhihWLnO4VtrbesqSC6izf4o\";}s:2:\"id\";s:19:\"webform_open_action\";s:5:\"label\";s:12:\"Open webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:19:\"webform_open_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f84c0b0d-7607-4ce0-8236-398e642bdbc7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBnl4vapW7sy5bRi7TcF-ueJnvz7aZNLif95ifvhfTQ\";}s:2:\"id\";s:32:\"webform_submission_delete_action\";s:5:\"label\";s:17:\"Delete submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:32:\"webform_submission_delete_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_lock_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c14576ba-6a4d-4bbd-b73b-8c0eef62c795\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MKmZlPRk3OJKNcYdYxSeZGQUh7LMah6MRShfkzch4bk\";}s:2:\"id\";s:35:\"webform_submission_make_lock_action\";s:5:\"label\";s:15:\"Lock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:35:\"webform_submission_make_lock_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7794e8ff-9168-4532-9036-0e67d7591d62\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mPWBT52fKHyINRl9S3cCWFxY3rKbwkIRxaK6sIA26oo\";}s:2:\"id\";s:37:\"webform_submission_make_sticky_action\";s:5:\"label\";s:20:\"Star/flag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_unlock_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"471e29d2-dca7-49e2-9e95-9bd8584625b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"begZ0-RmTzO_zDAwEKA2lKvtGYw1vbFOzbQOJzUbZX0\";}s:2:\"id\";s:37:\"webform_submission_make_unlock_action\";s:5:\"label\";s:17:\"Unlock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_unlock_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_submission_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"83915ff9-c752-4733-8ea4-73564fa9dd24\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4gTFiUsdp7gw6yWUlDbKFEasZLCgXWWCmm7eJejay0\";}s:2:\"id\";s:39:\"webform_submission_make_unsticky_action\";s:5:\"label\";s:24:\"Unstar/unflag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:39:\"webform_submission_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.webform_unarchive_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ffe260a0-779e-4401-b0b8-40ddaffc73dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aqi5Ftlnhe9KyOowpK7CanEvJMBBo8xAR1dA99bKOuc\";}s:2:\"id\";s:24:\"webform_unarchive_action\";s:5:\"label\";s:15:\"Restore webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:24:\"webform_unarchive_action\";s:13:\"configuration\";a:0:{}}'),('','system.advisories',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),('','system.cron',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),('','system.date',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),('','system.diff',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),('','system.feature_flags',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),('','system.file',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),('','system.image',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),('','system.image.gd',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:75;}'),('','system.logging',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),('','system.mail',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:2:{s:7:\"default\";s:8:\"php_mail\";s:7:\"webform\";s:16:\"webform_php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),('','system.maintenance',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),('','system.menu.account',_binary 'a:9:{s:4:\"uuid\";s:36:\"b8440982-72a9-44aa-afc8-0c3d14b807bd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),('','system.menu.admin',_binary 'a:9:{s:4:\"uuid\";s:36:\"820b8378-aa9a-4e15-bbdf-809cea9e6a97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),('','system.menu.footer',_binary 'a:9:{s:4:\"uuid\";s:36:\"7cb08dc9-4331-47ba-a3ad-aac0e10c8e7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),('','system.menu.main',_binary 'a:9:{s:4:\"uuid\";s:36:\"3762582d-2630-48d8-ab96-b29392c1a26a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),('','system.menu.tools',_binary 'a:9:{s:4:\"uuid\";s:36:\"b61fcb8a-ca27-4780-86d8-575615409f31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),('','system.performance',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}}'),('','system.rss',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),('','system.site',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"62840b97-650e-41be-abc8-edb78d15585b\";s:4:\"name\";s:8:\"JSON:API\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:7:\"/node/4\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),('','system.theme',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:3:\"gin\";s:7:\"default\";s:7:\"olivero\";}'),('','system.theme.global',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),('','taxonomy.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),('','taxonomy.vocabulary.tags',_binary 'a:10:{s:4:\"uuid\";s:36:\"6d3544ef-5124-4a14-88e1-ce69ad1016dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),('','text.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),('','update.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:0:{}s:9:\"threshold\";s:3:\"all\";}}'),('','user.flood',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),('','user.mail',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),('','user.role.administrator',_binary 'a:10:{s:4:\"uuid\";s:36:\"6eb8a031-0e43-4c9d-af8a-e9962b82903a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),('','user.role.anonymous',_binary 'a:10:{s:4:\"uuid\";s:36:\"d281cf36-4128-465b-8870-56e1ab0fac55\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:29:\"filter.format.restricted_html\";i:1;s:35:\"rest.resource.webform_rest_elements\";i:2;s:33:\"rest.resource.webform_rest_submit\";}s:6:\"module\";a:6:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:6:\"filter\";i:3;s:4:\"rest\";i:4;s:6:\"search\";i:5;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:7:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:29:\"access site-wide contact form\";i:3;s:33:\"restful get webform_rest_elements\";i:4;s:32:\"restful post webform_rest_submit\";i:5;s:14:\"search content\";i:6;s:31:\"use text format restricted_html\";}}'),('','user.role.authenticated',_binary 'a:10:{s:4:\"uuid\";s:36:\"02e47401-b1fc-4d8a-9928-a86f0f8611ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:24:\"filter.format.basic_html\";i:1;s:29:\"filter.format.webform_default\";i:2;s:35:\"rest.resource.webform_rest_elements\";i:3;s:33:\"rest.resource.webform_rest_submit\";}s:6:\"module\";a:8:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:4:\"file\";i:3;s:6:\"filter\";i:4;s:4:\"rest\";i:5;s:6:\"search\";i:6;s:8:\"shortcut\";i:7;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:12:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:16:\"access shortcuts\";i:3;s:29:\"access site-wide contact form\";i:4;s:16:\"delete own files\";i:5;s:13:\"post comments\";i:6;s:33:\"restful get webform_rest_elements\";i:7;s:32:\"restful post webform_rest_submit\";i:8;s:14:\"search content\";i:9;s:21:\"skip comment approval\";i:10;s:26:\"use text format basic_html\";i:11;s:31:\"use text format webform_default\";}}'),('','user.role.content_editor',_binary 'a:10:{s:4:\"uuid\";s:36:\"d3ede7c1-114f-4c1a-bda4-af6f0b80e54e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:24:\"filter.format.basic_html\";i:1;s:23:\"filter.format.full_html\";i:2;s:17:\"node.type.article\";i:3;s:14:\"node.type.page\";i:4;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:12:{i:0;s:7:\"comment\";i:1;s:10:\"contextual\";i:2;s:4:\"file\";i:3;s:6:\"filter\";i:4;s:4:\"node\";i:5;s:4:\"path\";i:6;s:8:\"pathauto\";i:7;s:11:\"rabbit_hole\";i:8;s:8:\"redirect\";i:9;s:6:\"system\";i:10;s:8:\"taxonomy\";i:11;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:33:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:19:\"administer pathauto\";i:6;s:28:\"administer redirect settings\";i:7;s:20:\"administer redirects\";i:8;s:22:\"administer url aliases\";i:9;s:19:\"bulk delete aliases\";i:10;s:19:\"bulk update aliases\";i:11;s:22:\"create article content\";i:12;s:19:\"create page content\";i:13;s:20:\"create terms in tags\";i:14;s:18:\"create url aliases\";i:15;s:24:\"delete article revisions\";i:16;s:26:\"delete own article content\";i:17;s:16:\"delete own files\";i:18;s:23:\"delete own page content\";i:19;s:21:\"delete page revisions\";i:20;s:24:\"edit own article content\";i:21;s:17:\"edit own comments\";i:22;s:21:\"edit own page content\";i:23;s:18:\"edit terms in tags\";i:24;s:22:\"notify of path changes\";i:25;s:23:\"rabbit hole bypass node\";i:26;s:32:\"rabbit hole bypass taxonomy_term\";i:27;s:20:\"revert all revisions\";i:28;s:26:\"use text format basic_html\";i:29;s:25:\"use text format full_html\";i:30;s:18:\"view all revisions\";i:31;s:28:\"view own unpublished content\";i:32;s:29:\"view the administration theme\";}}'),('','user.settings',_binary 'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Y-Xpk050V3opj3WiFb4oUbVT9S7fDA1XLpigO-qVMVQ\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:10:\"admin_only\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),('','views.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:1:{i:0;s:13:\"jsonapi_views\";}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),('','views.view.archive',_binary 'a:13:{s:4:\"uuid\";s:36:\"64aae2b3-26a1-4bfc-ac1f-04aeec606c61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.block_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"b4c93afb-55bd-4d60-9f83-9f1d440c911a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.comment',_binary 'a:13:{s:4:\"uuid\";s:36:\"af87d0b4-0ac9-4106-a4aa-935bef82b793\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"H6JHGXl97yOKmVaV62SoY1ki1tWVdyD44fgOkdmVyRM\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:8:\"Comments\";s:6:\"module\";s:7:\"comment\";s:11:\"description\";s:25:\"Find and manage comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:26:{s:5:\"title\";s:8:\"Comments\";s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:24:\"comment_unpublish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"next ›\";s:8:\"previous\";s:12:\"‹ previous\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"administer comments\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:17:\"comment_bulk_form\";s:17:\"comment_bulk_form\";s:7:\"subject\";s:7:\"subject\";s:3:\"uid\";s:3:\"uid\";s:9:\"entity_id\";s:9:\"entity_id\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:17:\"comment_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"subject\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"entity_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:1;s:13:\"use_more_text\";s:4:\"more\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:14:\"page_published\";a:6:{s:2:\"id\";s:14:\"page_published\";s:13:\"display_title\";s:18:\"Published comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:19:\"display_description\";s:30:\"The approved comments listing.\";s:15:\"display_comment\";s:0:\"\";s:13:\"exposed_block\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:21:\"admin/content/comment\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:8:\"Comments\";s:11:\"description\";s:18:\"Comments published\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:15:\"page_unapproved\";a:6:{s:2:\"id\";s:15:\"page_unapproved\";s:13:\"display_title\";s:19:\"Unapproved comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:8:{s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:22:\"comment_publish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:3:{s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:19:\"display_description\";s:32:\"The unapproved comments listing.\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:30:\"admin/content/comment/approval\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:19:\"Unapproved comments\";s:11:\"description\";s:19:\"Comments unapproved\";s:6:\"weight\";i:1;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}}}'),('','views.view.comments_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"6346d08f-a177-4e83-a747-6b308aa63315\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:7:\"comment\";i:1;s:4:\"node\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFOucxH8PAXDQ2kViCcAHgK-JMCcxVkpIMzD56EfpZo\";}s:2:\"id\";s:15:\"comments_recent\";s:5:\"label\";s:15:\"Recent comments\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:16:\"Recent comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:14:{s:5:\"title\";s:15:\"Recent comments\";s:6:\"fields\";a:2:{s:7:\"subject\";a:26:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:1:{s:4:\"type\";s:5:\"basic\";}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:15:\"access comments\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:2:{s:7:\"created\";a:12:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;}s:3:\"cid\";a:12:{s:2:\"id\";s:3:\"cid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"cid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"cid\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"cid\";}s:7:\"exposed\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:11:\"status_node\";a:10:{s:2:\"id\";s:11:\"status_node\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"node\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:2:{s:22:\"default_field_elements\";b:1;s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:4:\"node\";a:5:{s:2:\"id\";s:4:\"node\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"node\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:15:\"Recent comments\";s:14:\"block_category\";s:13:\"Lists (Views)\";s:5:\"allow\";a:1:{s:14:\"items_per_page\";b:1;}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content',_binary 'a:13:{s:4:\"uuid\";s:36:\"411c53b7-69dc-4ed5-b1d4-84bafe5b08c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d7p-wwJZ_Wmz1gnvla9jDtRsjOaWAhPoIoW9w3vo4R4\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:14:\"field_language\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"94d1a705-2830-41cf-9d68-7f6f7cf4bf6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.files',_binary 'a:13:{s:4:\"uuid\";s:36:\"ca1f0b7a-286d-4a9a-9741-13d1f2ff8c31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NYJWABHsIFg-cU-Qya8fiMuQSM4rirBEfPFqkgRtsKA\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:26:\"@count place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.frontpage',_binary 'a:13:{s:4:\"uuid\";s:36:\"ba1d2200-30f3-40f8-a597-b4f370e813e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.glossary',_binary 'a:13:{s:4:\"uuid\";s:36:\"6660456c-c025-42e0-94a2-7e6daffa6992\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.redirect',_binary 'a:13:{s:4:\"uuid\";s:36:\"64bc6974-4eb3-4942-b516-db108a373cea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:8:\"redirect\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I9VqfbwK5ZyKzL7810d0fswaadU6riFT3kPL0yxcpLs\";}s:2:\"id\";s:8:\"redirect\";s:5:\"label\";s:8:\"Redirect\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:17:\"List of redirects\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"redirect\";s:10:\"base_field\";s:3:\"rid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"administer redirects\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:7:{s:14:\"items_per_page\";i:50;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:12:\"‹ previous\";s:4:\"next\";s:8:\"next ›\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:6:{s:21:\"redirect_source__path\";s:21:\"redirect_source__path\";s:22:\"redirect_redirect__uri\";s:22:\"redirect_redirect__uri\";s:11:\"status_code\";s:11:\"status_code\";s:8:\"language\";s:8:\"language\";s:7:\"created\";s:7:\"created\";s:10:\"operations\";s:10:\"operations\";}s:4:\"info\";a:6:{s:21:\"redirect_source__path\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:22:\"redirect_redirect__uri\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"status_code\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"language\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:6:\"fields\";a:7:{s:18:\"redirect_bulk_form\";a:26:{s:2:\"id\";s:18:\"redirect_bulk_form\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:18:\"redirect_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:14:\"With selection\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:18:\"redirect_bulk_form\";}s:21:\"redirect_source__path\";a:37:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:4:\"From\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:4:\"path\";s:4:\"type\";s:15:\"redirect_source\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:5:\"field\";}s:22:\"redirect_redirect__uri\";a:6:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"status_code\";a:6:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"language\";a:6:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:27:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:8:\"fallback\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";}s:10:\"operations\";a:5:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:10:\"operations\";s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:4:{s:21:\"redirect_source__path\";a:16:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:24:\"redirect_source__path_op\";s:5:\"label\";s:4:\"From\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:24:\"redirect_source__path_op\";s:10:\"identifier\";s:21:\"redirect_source__path\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:6:\"string\";}s:22:\"redirect_redirect__uri\";a:16:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:25:\"redirect_redirect__uri_op\";s:5:\"label\";s:2:\"To\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:25:\"redirect_redirect__uri_op\";s:10:\"identifier\";s:22:\"redirect_redirect__uri\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"status_code\";a:16:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:14:\"status_code_op\";s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:14:\"status_code_op\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:7:{i:1;a:3:{s:5:\"title\";s:20:\"300 Multiple Choices\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"300\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:2;a:3:{s:5:\"title\";s:21:\"301 Moved Permanently\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"301\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:3;a:3:{s:5:\"title\";s:9:\"302 Found\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"302\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:4;a:3:{s:5:\"title\";s:13:\"303 See Other\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"303\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:5;a:3:{s:5:\"title\";s:16:\"304 Not Modified\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"304\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:6;a:3:{s:5:\"title\";s:13:\"305 Use Proxy\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"305\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:7;a:3:{s:5:\"title\";s:22:\"307 Temporary Redirect\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"307\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:7:\"numeric\";}s:8:\"language\";a:16:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"language_op\";s:5:\"label\";s:17:\"Original language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"language_op\";s:10:\"identifier\";s:8:\"language\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:8:\"language\";}}s:5:\"sorts\";a:0:{}s:5:\"title\";s:8:\"Redirect\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"There is no redirect yet.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:0:{}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:14:\"display_plugin\";s:4:\"page\";s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:28:\"admin/config/search/redirect\";}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}}}'),('','views.view.taxonomy_term',_binary 'a:13:{s:4:\"uuid\";s:36:\"612a6feb-f41d-4b4d-8eda-dc2fb8df706f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.user_admin_people',_binary 'a:13:{s:4:\"uuid\";s:36:\"6abb021b-7e65-4890-9172-d2d762cc0396\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.watchdog',_binary 'a:13:{s:4:\"uuid\";s:36:\"76b82b04-b93f-4522-a84c-7c06e72ca046\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.webform_submissions',_binary 'a:13:{s:4:\"uuid\";s:36:\"d30db33d-ecb9-4776-91cd-2d54f2f7a15c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"user\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uIuCYXi8Y6GTe4pKUxK2t9OjQEcrwvFJZFeitfnQ8Ys\";}s:2:\"id\";s:19:\"webform_submissions\";s:5:\"label\";s:19:\"Webform submissions\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:34:\"Default webform submissions views.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:18:\"webform_submission\";s:10:\"base_field\";s:3:\"sid\";s:7:\"display\";a:5:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:7:{s:14:\"items_per_page\";i:25;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:6:\"‹‹\";s:4:\"next\";s:6:\"››\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:23:\"5, 10, 25, 50, 100, 200\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"fields\";a:5:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:7:\"filters\";a:0:{}s:5:\"sorts\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:0;s:7:\"content\";s:34:\"Displaying @start - @end of @total\";s:9:\"plugin_id\";s:6:\"result\";}}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"No submissions available.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:5:{s:10:\"webform_id\";a:6:{s:2:\"id\";s:10:\"webform_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:10:\"webform_id\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"entity_type\";a:6:{s:2:\"id\";s:11:\"entity_type\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"entity_type\";s:9:\"plugin_id\";s:6:\"string\";}s:9:\"entity_id\";a:6:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:6:\"string\";}s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:16:\"entity_target_id\";}s:8:\"in_draft\";a:22:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:14:\"items_per_page\";i:25;s:8:\"override\";b:0;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"numeric\";}}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"title\";s:19:\"Webform submissions\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:16:\"embed_administer\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:16:\"embed_administer\";s:13:\"display_title\";s:17:\"Embed: Administer\";s:8:\"position\";i:2;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:23:\"Administer submissions.\";s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:8:\"defaults\";a:6:{s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:29:\"administer webform submission\";}}s:6:\"fields\";a:9:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:10:\"operations\";a:25:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;s:11:\"entity_type\";N;s:12:\"entity_field\";N;s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:13:\"embed_default\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:13:\"embed_default\";s:13:\"display_title\";s:14:\"Embed: Default\";s:8:\"position\";i:1;s:15:\"display_options\";a:5:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:20:\"Display submissions.\";s:8:\"defaults\";a:5:{s:6:\"fields\";b:1;s:5:\"style\";b:0;s:3:\"row\";b:0;s:7:\"filters\";b:1;s:13:\"filter_groups\";b:1;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:5:{s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:7:\"created\";s:7:\"created\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:5:{s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_manage\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_manage\";s:13:\"display_title\";s:13:\"Embed: Manage\";s:8:\"position\";i:3;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Manage submissions.\";s:6:\"fields\";a:10:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:4:{i:0;s:35:\"webform_submission_make_lock_action\";i:1;s:37:\"webform_submission_make_sticky_action\";i:2;s:37:\"webform_submission_make_unlock_action\";i:3;s:39:\"webform_submission_make_unsticky_action\";}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}s:23:\"edit_webform_submission\";a:26:{s:2:\"id\";s:23:\"edit_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"edit_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"edit any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_review\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_review\";s:13:\"display_title\";s:13:\"Embed: Review\";s:8:\"position\";i:4;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Review submissions.\";s:6:\"fields\";a:8:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:3:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"view any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.who_s_new',_binary 'a:13:{s:4:\"uuid\";s:36:\"2d64aef5-17f8-4af2-993d-4766096aeca3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.who_s_online',_binary 'a:13:{s:4:\"uuid\";s:36:\"46b6645e-44b7-437f-a3b8-23ad0c31cce9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','webform.settings',_binary 'a:20:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jx9JXVmXsMI7nasmBHSGH0gt9MY8BE3XD2nJzjwz0ZU\";}s:8:\"settings\";a:73:{s:14:\"default_status\";s:4:\"open\";s:18:\"default_categories\";a:0:{}s:12:\"default_page\";b:1;s:22:\"default_page_base_path\";s:5:\"/form\";s:12:\"default_ajax\";b:0;s:19:\"default_ajax_effect\";s:4:\"fade\";s:18:\"default_ajax_speed\";i:500;s:26:\"default_ajax_progress_type\";s:8:\"throbber\";s:25:\"default_form_open_message\";s:49:\"This form has not yet been opened to submissions.\";s:26:\"default_form_close_message\";s:48:\"Sorry… This form is closed to new submissions.\";s:30:\"default_form_exception_message\";s:70:\"Unable to display this webform. Please contact the site administrator.\";s:27:\"default_submit_button_label\";s:6:\"Submit\";s:26:\"default_reset_button_label\";s:5:\"Reset\";s:27:\"default_delete_button_label\";s:6:\"Delete\";s:24:\"default_form_submit_once\";b:0;s:33:\"default_form_confidential_message\";s:135:\"This form is confidential. You must <a href=\"[site:login-url]/logout?destination=[current-page:url:relative]\">Log out</a> to submit it.\";s:34:\"default_form_access_denied_message\";s:34:\"Please log in to access this form.\";s:25:\"default_form_disable_back\";b:0;s:24:\"default_form_submit_back\";b:0;s:20:\"default_form_unsaved\";b:0;s:32:\"default_form_disable_remote_addr\";b:0;s:23:\"default_form_novalidate\";b:0;s:34:\"default_form_disable_inline_errors\";b:0;s:21:\"default_form_required\";b:0;s:27:\"default_form_required_label\";s:24:\"Indicates required field\";s:27:\"default_form_details_toggle\";b:1;s:23:\"default_form_file_limit\";s:0:\"\";s:12:\"form_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:14:\"button_classes\";s:0:\"\";s:32:\"default_wizard_prev_button_label\";s:10:\"< Previous\";s:32:\"default_wizard_next_button_label\";s:6:\"Next >\";s:26:\"default_wizard_start_label\";s:5:\"Start\";s:33:\"default_wizard_confirmation_label\";s:8:\"Complete\";s:32:\"default_wizard_toggle_show_label\";s:8:\"Show all\";s:32:\"default_wizard_toggle_hide_label\";s:8:\"Hide all\";s:33:\"default_preview_next_button_label\";s:7:\"Preview\";s:33:\"default_preview_prev_button_label\";s:10:\"< Previous\";s:21:\"default_preview_label\";s:7:\"Preview\";s:21:\"default_preview_title\";s:24:\"[webform:title]: Preview\";s:23:\"default_preview_message\";s:99:\"Please review your submission. Your submission is not complete until you press the \"Submit\" button!\";s:26:\"default_draft_button_label\";s:10:\"Save Draft\";s:27:\"default_draft_saved_message\";s:91:\"Submission saved. You may return to this form later and it will restore the current values.\";s:28:\"default_draft_loaded_message\";s:77:\"A partially-completed form was found. Please complete the remaining portions.\";s:36:\"default_draft_pending_single_message\";s:83:\"You have a pending draft for this webform. <a href=\"#\">Load your pending draft</a>.\";s:38:\"default_draft_pending_multiple_message\";s:83:\"You have pending drafts for this webform. <a href=\"#\">View your pending drafts</a>.\";s:28:\"default_confirmation_message\";s:40:\"New submission added to [webform:title].\";s:31:\"default_confirmation_back_label\";s:12:\"Back to form\";s:28:\"default_confirmation_noindex\";b:1;s:24:\"default_submission_label\";s:74:\"[webform_submission:submitted-to]: Submission #[webform_submission:serial]\";s:40:\"default_submission_access_denied_message\";s:40:\"Please log in to access this submission.\";s:36:\"default_submission_exception_message\";s:73:\"Unable to process this submission. Please contact the site administrator.\";s:33:\"default_submission_locked_message\";s:32:\"This submission has been locked.\";s:22:\"default_submission_log\";b:0;s:24:\"default_submission_views\";a:0:{}s:32:\"default_submission_views_replace\";a:3:{s:13:\"global_routes\";a:2:{i:0;s:36:\"entity.webform_submission.collection\";i:1;s:30:\"entity.webform_submission.user\";}s:14:\"webform_routes\";a:3:{i:0;s:34:\"entity.webform.results_submissions\";i:1;s:26:\"entity.webform.user.drafts\";i:2;s:31:\"entity.webform.user.submissions\";}s:11:\"node_routes\";a:3:{i:0;s:39:\"entity.node.webform.results_submissions\";i:1;s:31:\"entity.node.webform.user.drafts\";i:2;s:36:\"entity.node.webform.user.submissions\";}}s:25:\"default_results_customize\";b:0;s:35:\"default_previous_submission_message\";s:87:\"You have already submitted this webform. <a href=\"#\">View your previous submission</a>.\";s:36:\"default_previous_submissions_message\";s:88:\"You have already submitted this webform. <a href=\"#\">View your previous submissions</a>.\";s:24:\"default_autofill_message\";s:66:\"This submission has been autofilled with your previous submission.\";s:15:\"preview_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:20:\"confirmation_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:25:\"confirmation_back_classes\";s:7:\"button\n\";s:27:\"default_limit_total_message\";s:34:\"No more submissions are permitted.\";s:26:\"default_limit_user_message\";s:34:\"No more submissions are permitted.\";s:13:\"default_share\";b:0;s:18:\"default_share_node\";b:0;s:24:\"default_share_theme_name\";s:0:\"\";s:6:\"dialog\";b:0;s:14:\"dialog_options\";a:3:{s:6:\"narrow\";a:2:{s:5:\"title\";s:6:\"Narrow\";s:5:\"width\";i:600;}s:6:\"normal\";a:2:{s:5:\"title\";s:6:\"Normal\";s:5:\"width\";i:800;}s:4:\"wide\";a:2:{s:5:\"title\";s:4:\"Wide\";s:5:\"width\";i:1000;}}s:17:\"webform_bulk_form\";b:1;s:25:\"webform_bulk_form_actions\";a:5:{i:0;s:19:\"webform_open_action\";i:1;s:20:\"webform_close_action\";i:2;s:22:\"webform_archive_action\";i:3;s:24:\"webform_unarchive_action\";i:4;s:21:\"webform_delete_action\";}s:28:\"webform_submission_bulk_form\";b:1;s:36:\"webform_submission_bulk_form_actions\";a:5:{i:0;s:37:\"webform_submission_make_sticky_action\";i:1;s:39:\"webform_submission_make_unsticky_action\";i:2;s:35:\"webform_submission_make_lock_action\";i:3;s:37:\"webform_submission_make_unlock_action\";i:4;s:32:\"webform_submission_delete_action\";}}s:6:\"assets\";a:2:{s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";}s:7:\"handler\";a:1:{s:17:\"excluded_handlers\";a:0:{}}s:7:\"variant\";a:1:{s:17:\"excluded_variants\";a:0:{}}s:6:\"export\";a:18:{s:14:\"temp_directory\";s:0:\"\";s:8:\"exporter\";s:9:\"delimited\";s:18:\"multiple_delimiter\";s:1:\";\";s:13:\"header_format\";s:5:\"label\";s:13:\"header_prefix\";b:1;s:29:\"header_prefix_label_delimiter\";s:2:\": \";s:27:\"header_prefix_key_delimiter\";s:2:\"__\";s:29:\"composite_element_item_format\";s:5:\"label\";s:21:\"options_single_format\";s:7:\"compact\";s:23:\"options_multiple_format\";s:7:\"compact\";s:19:\"options_item_format\";s:5:\"label\";s:22:\"entity_reference_items\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"title\";i:2;s:3:\"url\";}s:21:\"likert_answers_format\";s:5:\"label\";s:16:\"signature_format\";s:6:\"status\";s:9:\"delimiter\";s:1:\",\";s:5:\"excel\";b:0;s:12:\"archive_type\";s:3:\"tar\";s:18:\"excluded_exporters\";a:0:{}}s:5:\"batch\";a:5:{s:25:\"default_batch_export_size\";i:500;s:25:\"default_batch_import_size\";i:100;s:25:\"default_batch_update_size\";i:500;s:25:\"default_batch_delete_size\";i:500;s:24:\"default_batch_email_size\";i:500;}s:5:\"purge\";a:1:{s:9:\"cron_size\";i:100;}s:4:\"form\";a:3:{s:5:\"limit\";i:50;s:15:\"filter_category\";s:0:\"\";s:12:\"filter_state\";s:0:\"\";}s:7:\"element\";a:13:{s:20:\"machine_name_pattern\";s:7:\"a-z0-9_\";s:13:\"empty_message\";s:7:\"{Empty}\";s:12:\"allowed_tags\";s:5:\"admin\";s:15:\"wrapper_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:7:\"classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:23:\"horizontal_rule_classes\";s:286:\"webform-horizontal-rule--solid\nwebform-horizontal-rule--dashed\nwebform-horizontal-rule--dotted\nwebform-horizontal-rule--gradient\nwebform-horizontal-rule--thin\nwebform-horizontal-rule--medium\nwebform-horizontal-rule--thick\nwebform-horizontal-rule--flaired\nwebform-horizontal-rule--glyph\n\";s:27:\"default_description_display\";s:0:\"\";s:18:\"default_more_title\";s:4:\"More\";s:25:\"default_section_title_tag\";s:2:\"h2\";s:20:\"default_empty_option\";b:1;s:29:\"default_empty_option_required\";s:0:\"\";s:29:\"default_empty_option_optional\";s:0:\"\";s:17:\"excluded_elements\";a:2:{s:8:\"password\";s:8:\"password\";s:16:\"password_confirm\";s:16:\"password_confirm\";}}s:11:\"html_editor\";a:5:{s:8:\"disabled\";b:0;s:14:\"element_format\";s:15:\"webform_default\";s:11:\"mail_format\";s:15:\"webform_default\";s:4:\"tidy\";b:1;s:35:\"make_unused_managed_files_temporary\";b:1;}s:4:\"file\";a:11:{s:11:\"file_public\";b:0;s:21:\"file_private_redirect\";b:1;s:29:\"file_private_redirect_message\";s:42:\"Please log in to access the uploaded file.\";s:20:\"default_max_filesize\";s:0:\"\";s:31:\"default_managed_file_extensions\";s:148:\"gif jpg jpeg png bmp eps tif pict psd txt rtf html odf pdf doc docx ppt pptx xls xlsx xml avi mov mp3 mp4 ogg wav bz2 dmg gz jar rar sit svg tar zip\";s:29:\"default_audio_file_extensions\";s:11:\"mp3 ogg wav\";s:32:\"default_document_file_extensions\";s:50:\"txt rtf pdf doc docx odt ppt pptx odp xls xlsx ods\";s:29:\"default_image_file_extensions\";s:16:\"gif jpg jpeg png\";s:29:\"default_video_file_extensions\";s:24:\"avi mov mp4 ogg wav webm\";s:35:\"make_unused_managed_files_temporary\";b:1;s:30:\"delete_temporary_managed_files\";b:1;}s:6:\"format\";a:0:{}s:4:\"mail\";a:11:{s:15:\"default_to_mail\";s:11:\"[site:mail]\";s:17:\"default_from_mail\";s:11:\"[site:mail]\";s:17:\"default_from_name\";s:11:\"[site:name]\";s:16:\"default_reply_to\";s:0:\"\";s:19:\"default_return_path\";s:0:\"\";s:19:\"default_sender_mail\";s:0:\"\";s:19:\"default_sender_name\";s:0:\"\";s:15:\"default_subject\";s:58:\"Webform submission from: [webform_submission:source-title]\";s:17:\"default_body_text\";s:133:\"Submitted on [webform_submission:created]\nSubmitted by: [webform_submission:user]\n\nSubmitted values are:\n[webform_submission:values]\n\";s:17:\"default_body_html\";s:153:\"<p>Submitted on [webform_submission:created]</p>\n<p>Submitted by: [webform_submission:user]</p>\n<p>Submitted values are:</p>\n[webform_submission:values]\n\";s:5:\"roles\";a:0:{}}s:4:\"test\";a:2:{s:5:\"types\";s:3347:\"checkbox:\n  - true\ncolor:\n  - \'#ffffcc\'\n  - \'#ffffcc\'\n  - \'#ccffff\'\nemail:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nlanguage_select:\n  - en\nmachine_name:\n  - \'loremipsum\'\n  - \'oratione\'\n  - \'dixisset\'\ntel:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ntextarea:\n  - \'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.\'\n  - \'Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;\'\n  - \'Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.\'\ntext_format:\n  - value: \'<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.</p>\'\n  - value: \'<p>Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;</p>\'\n  - value: \'<p>Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.</p>\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\nwebform_email_confirm:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nwebform_email_multiple:\n  - \'example@example.com, test@test.com, random@random.com\'\nwebform_time:\n  - \'09:00\'\n  - \'17:00\'\n\";s:5:\"names\";s:547:\"first_name:\n  - \'John\'\n  - \'Paul\'\n  - \'Ringo\'\n  - \'George\'\nlast_name:\n  - \'Lennon\'\n  - \'McCartney\'\n  - \'Starr\'\n  - \'Harrison\'\naddress:\n  - \'10 Main Street\'\n  - \'11 Brook Alley Road. APT 1\'\nzip:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\npostal_code:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\nphone:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\nfax:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ncity:\n  - \'Springfield\'\n  - \'Pleasantville\'\n  - \'Hill Valley\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\ndefault:\n  - \'Loremipsum\'\n  - \'Oratione\'\n  - \'Dixisset\'\n\";}s:2:\"ui\";a:9:{s:13:\"video_display\";s:6:\"dialog\";s:12:\"details_save\";b:1;s:13:\"help_disabled\";b:0;s:15:\"dialog_disabled\";b:0;s:18:\"offcanvas_disabled\";b:0;s:19:\"promotions_disabled\";b:0;s:16:\"support_disabled\";b:0;s:16:\"description_help\";b:1;s:12:\"toolbar_item\";b:0;}s:9:\"libraries\";a:1:{s:18:\"excluded_libraries\";a:2:{i:0;s:7:\"choices\";i:1;s:13:\"jquery.chosen\";}}s:12:\"requirements\";a:3:{s:3:\"cdn\";b:1;s:21:\"clientside_validation\";b:1;s:4:\"spam\";b:1;}s:8:\"langcode\";s:2:\"en\";s:20:\"third_party_settings\";a:1:{s:7:\"captcha\";a:1:{s:27:\"replace_administration_mode\";b:1;}}}'),('','webform.webform.contact',_binary 'a:22:{s:4:\"uuid\";s:36:\"f815005f-42fe-4d84-a6aa-7c6f08223a9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";s:4:\"open\";s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_je-MWeeJB6gfm6iECiqjcyNetfMFbn-YIInYwZ1gIk\";}s:4:\"open\";N;s:5:\"close\";N;s:6:\"weight\";i:0;s:3:\"uid\";N;s:8:\"template\";b:0;s:7:\"archive\";b:0;s:2:\"id\";s:7:\"contact\";s:5:\"title\";s:7:\"Contact\";s:11:\"description\";s:28:\"Basic email contact webform.\";s:10:\"categories\";a:0:{}s:8:\"elements\";s:566:\"name:\n  \'#title\': \'Your Name\'\n  \'#type\': textfield\n  \'#required\': true\n  \'#default_value\': \'[current-user:display-name]\'\nemail:\n  \'#title\': \'Your Email\'\n  \'#type\': email\n  \'#required\': true\n  \'#default_value\': \'[current-user:mail]\'\nsubject:\n  \'#title\': Subject\n  \'#type\': textfield\n  \'#required\': true\n  \'#test\': \'Testing contact webform from [site:name]\'\nmessage:\n  \'#title\': Message\n  \'#type\': textarea\n  \'#required\': true\n  \'#test\': \'Please ignore this email.\'\nactions:\n  \'#type\': webform_actions\n  \'#title\': \'Submit button(s)\'\n  \'#submit__label\': \'Send message\'\n\";s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";s:8:\"settings\";a:133:{s:4:\"ajax\";b:0;s:15:\"ajax_scroll_top\";s:4:\"form\";s:18:\"ajax_progress_type\";s:0:\"\";s:11:\"ajax_effect\";s:0:\"\";s:10:\"ajax_speed\";N;s:4:\"page\";b:1;s:16:\"page_submit_path\";s:0:\"\";s:17:\"page_confirm_path\";s:0:\"\";s:15:\"page_theme_name\";s:0:\"\";s:10:\"form_title\";s:21:\"source_entity_webform\";s:16:\"form_submit_once\";b:0;s:22:\"form_exception_message\";s:0:\"\";s:17:\"form_open_message\";s:0:\"\";s:18:\"form_close_message\";s:0:\"\";s:25:\"form_previous_submissions\";b:1;s:17:\"form_confidential\";b:0;s:25:\"form_confidential_message\";s:0:\"\";s:24:\"form_disable_remote_addr\";b:0;s:22:\"form_convert_anonymous\";b:0;s:16:\"form_prepopulate\";b:0;s:30:\"form_prepopulate_source_entity\";b:0;s:39:\"form_prepopulate_source_entity_required\";b:0;s:35:\"form_prepopulate_source_entity_type\";s:0:\"\";s:10:\"form_reset\";b:0;s:25:\"form_disable_autocomplete\";b:0;s:15:\"form_novalidate\";b:0;s:26:\"form_disable_inline_errors\";b:0;s:13:\"form_required\";b:0;s:12:\"form_unsaved\";b:0;s:17:\"form_disable_back\";b:0;s:16:\"form_submit_back\";b:0;s:14:\"form_autofocus\";b:0;s:19:\"form_details_toggle\";b:0;s:18:\"form_access_denied\";s:7:\"default\";s:24:\"form_access_denied_title\";s:0:\"\";s:26:\"form_access_denied_message\";s:0:\"\";s:29:\"form_access_denied_attributes\";a:0:{}s:15:\"form_file_limit\";s:0:\"\";s:11:\"form_method\";s:0:\"\";s:11:\"form_action\";s:0:\"\";s:15:\"form_attributes\";a:0:{}s:5:\"share\";b:0;s:10:\"share_node\";b:0;s:16:\"share_theme_name\";s:0:\"\";s:11:\"share_title\";b:1;s:26:\"share_page_body_attributes\";a:0:{}s:16:\"submission_label\";s:0:\"\";s:14:\"submission_log\";b:0;s:16:\"submission_views\";a:0:{}s:24:\"submission_views_replace\";a:0:{}s:23:\"submission_user_columns\";a:0:{}s:25:\"submission_user_duplicate\";b:0;s:24:\"submission_access_denied\";s:7:\"default\";s:30:\"submission_access_denied_title\";s:0:\"\";s:32:\"submission_access_denied_message\";s:0:\"\";s:35:\"submission_access_denied_attributes\";a:0:{}s:28:\"submission_exception_message\";s:0:\"\";s:25:\"submission_locked_message\";s:0:\"\";s:28:\"submission_excluded_elements\";a:0:{}s:24:\"submission_exclude_empty\";b:0;s:33:\"submission_exclude_empty_checkbox\";b:0;s:27:\"previous_submission_message\";s:0:\"\";s:28:\"previous_submissions_message\";s:0:\"\";s:8:\"autofill\";b:0;s:16:\"autofill_message\";s:0:\"\";s:26:\"autofill_excluded_elements\";a:0:{}s:19:\"wizard_progress_bar\";b:1;s:21:\"wizard_progress_pages\";b:0;s:26:\"wizard_progress_percentage\";b:0;s:20:\"wizard_progress_link\";b:0;s:22:\"wizard_progress_states\";b:0;s:19:\"wizard_auto_forward\";b:1;s:36:\"wizard_auto_forward_hide_next_button\";b:0;s:15:\"wizard_keyboard\";b:1;s:18:\"wizard_start_label\";s:0:\"\";s:19:\"wizard_preview_link\";b:0;s:19:\"wizard_confirmation\";b:1;s:25:\"wizard_confirmation_label\";s:0:\"\";s:12:\"wizard_track\";s:0:\"\";s:24:\"wizard_prev_button_label\";s:0:\"\";s:24:\"wizard_next_button_label\";s:0:\"\";s:13:\"wizard_toggle\";b:0;s:24:\"wizard_toggle_show_label\";s:0:\"\";s:24:\"wizard_toggle_hide_label\";s:0:\"\";s:16:\"wizard_page_type\";s:9:\"container\";s:21:\"wizard_page_title_tag\";s:2:\"h2\";s:7:\"preview\";i:0;s:13:\"preview_label\";s:0:\"\";s:13:\"preview_title\";s:0:\"\";s:15:\"preview_message\";s:0:\"\";s:18:\"preview_attributes\";a:0:{}s:25:\"preview_excluded_elements\";a:0:{}s:21:\"preview_exclude_empty\";b:1;s:30:\"preview_exclude_empty_checkbox\";b:0;s:5:\"draft\";s:4:\"none\";s:14:\"draft_multiple\";b:0;s:15:\"draft_auto_save\";b:0;s:19:\"draft_saved_message\";s:0:\"\";s:20:\"draft_loaded_message\";s:0:\"\";s:28:\"draft_pending_single_message\";s:0:\"\";s:30:\"draft_pending_multiple_message\";s:0:\"\";s:17:\"confirmation_type\";s:11:\"url_message\";s:18:\"confirmation_title\";s:0:\"\";s:20:\"confirmation_message\";s:27:\"Your message has been sent.\";s:16:\"confirmation_url\";s:7:\"<front>\";s:23:\"confirmation_attributes\";a:0:{}s:17:\"confirmation_back\";b:1;s:23:\"confirmation_back_label\";s:0:\"\";s:28:\"confirmation_back_attributes\";a:0:{}s:26:\"confirmation_exclude_query\";b:0;s:26:\"confirmation_exclude_token\";b:0;s:19:\"confirmation_update\";b:0;s:11:\"limit_total\";N;s:20:\"limit_total_interval\";N;s:19:\"limit_total_message\";s:0:\"\";s:18:\"limit_total_unique\";b:0;s:10:\"limit_user\";N;s:19:\"limit_user_interval\";N;s:18:\"limit_user_message\";s:0:\"\";s:17:\"limit_user_unique\";b:0;s:18:\"entity_limit_total\";N;s:27:\"entity_limit_total_interval\";N;s:17:\"entity_limit_user\";N;s:26:\"entity_limit_user_interval\";N;s:5:\"purge\";s:4:\"none\";s:10:\"purge_days\";N;s:16:\"results_disabled\";b:0;s:23:\"results_disabled_ignore\";b:0;s:17:\"results_customize\";b:0;s:10:\"token_view\";b:0;s:12:\"token_update\";b:0;s:12:\"token_delete\";b:0;s:15:\"serial_disabled\";b:0;}s:6:\"access\";a:11:{s:6:\"create\";a:3:{s:5:\"roles\";a:2:{i:0;s:9:\"anonymous\";i:1;s:13:\"authenticated\";}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:9:\"purge_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"administer\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:4:\"test\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:13:\"configuration\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}}s:8:\"handlers\";a:2:{s:18:\"email_confirmation\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email confirmation\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_confirmation\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:1;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:19:\"[current-user:mail]\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:8:\"_default\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:8:\"_default\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}s:18:\"email_notification\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email notification\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_notification\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:2;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:8:\"_default\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:37:\"[webform_submission:values:email:raw]\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:36:\"[webform_submission:values:name:raw]\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}}s:8:\"variants\";a:0:{}}'),('','webform.webform_options.country_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"291c60c8-5109-4209-b98d-ab6dc2425dc0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"adQ16YGDPk7QfUKrfrC35o2sKdHEozdNtdpiH7CftQQ\";}s:2:\"id\";s:13:\"country_codes\";s:5:\"label\";s:13:\"Country codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.country_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"430ba6dc-e989-4104-81a2-731e98ece9e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zsfFP124dAM-sJkuEfnwaA7DN6o3-IsaXLgdNmObbYg\";}s:2:\"id\";s:13:\"country_names\";s:5:\"label\";s:13:\"Country names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.days',_binary 'a:10:{s:4:\"uuid\";s:36:\"837c888f-46bd-4a04-8f99-cf5698404d99\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNrKbYrWWjeubUUM8AsQ19KnX7cU1elACR14CZJHmdg\";}s:2:\"id\";s:4:\"days\";s:5:\"label\";s:4:\"Days\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:121:\"Sunday: Sunday\nMonday: Monday\nTuesday: Tuesday\nWednesday: Wednesday\nThursday: Thursday\nFriday: Friday\nSaturday: Saturday\n\";}'),('','webform.webform_options.education',_binary 'a:10:{s:4:\"uuid\";s:36:\"93ade06e-58d8-4139-8417-d050228586a1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mII4acOv33s-j8PINywrCag4OITbeJGxdPO373dnHHw\";}s:2:\"id\";s:9:\"education\";s:5:\"label\";s:9:\"Education\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:152:\"High School: High School\nAssociate Degree: Associate Degree\nGraduate or Professional Degree: Graduate or Professional Degree\nSome College: Some College\n\";}'),('','webform.webform_options.employment_status',_binary 'a:10:{s:4:\"uuid\";s:36:\"fb4b79d1-46ed-431a-a9f9-93a58abf2ca8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8MCmsz_csdJkVItxI8g_s4zp2PM285YqCy_gWTzOLPw\";}s:2:\"id\";s:17:\"employment_status\";s:5:\"label\";s:17:\"Employment status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:113:\"\'Full Time\': \'Full Time\'\n\'Part Time\': \'Part Time\'\n\'Military\': \'Military\'\nUnemployed: Unemployed\nRetired: Retired\n\";}'),('','webform.webform_options.ethnicity',_binary 'a:10:{s:4:\"uuid\";s:36:\"cff7754e-905c-4ee7-916d-51863211ea47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIPgrAC82wE2GAk1mOv2UvMYv71YQe4VT8667QIYdvI\";}s:2:\"id\";s:9:\"ethnicity\";s:5:\"label\";s:9:\"Ethnicity\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:200:\"Caucasian: Caucasian\n\'Latino/Hispanic\': \'Latino/Hispanic\'\n\'Middle Eastern\': \'Middle Eastern\'\nAfrican: African\nCaribbean: Caribbean\n\'South Asian\': \'South Asian\'\n\'East Asian\': \'East Asian\'\nMixed: Mixed\n\";}'),('','webform.webform_options.gender',_binary 'a:10:{s:4:\"uuid\";s:36:\"accbbb74-6855-4d35-89ef-aaf806d9fddf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yxhG0JmQs2HT-Ro6ZeDQboDc9ZWR4GglflTtyoqxK4A\";}s:2:\"id\";s:6:\"gender\";s:5:\"label\";s:6:\"Gender\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:756:\"Man: Man\nWoman: Woman\nNon-binary: Non-binary\nAgender/Genderless: Agender/Genderless\nAndrogyne/Androgynous: Androgyne/Androgynous\nAporagender: Aporagender\nBigender: Bigender\nDemi-agender: Demi-agender\nDemi-boy: Demi-boy\nDemi-fluid: Demi-fluid\nDemi-girl: Demi-girl\nDemi-gender: Demi-gender\nDemi-non-binary: Demi-non-binary\nGenderqueer: Genderqueer\nGenderflux: Genderflux\nGenderfluid: Genderfluid\nGender-indifferent: Gender-indifferent\nGender-neutral: Gender-neutral\nGraygender: Graygender\nIntergender: Intergender\nMaverique: Maverique\nMaxigender: Maxigender\nMultigender/Polygender: Multigender/Polygender\nNeutrois: Neutrois\nPangender/Omnigender: Pangender/Omnigender\nTrigender: Trigender\nTwo-spirit: Two-spirit\n\'Prefer Not to Answer\': \'Prefer Not to Answer\'\n\";}'),('','webform.webform_options.industry',_binary 'a:10:{s:4:\"uuid\";s:36:\"fde6fb59-d642-483a-89e6-a8bf864192e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"s_SXZn2HbRGvTex-TLOCxz2oOnMYqtEZh8HD4_318QI\";}s:2:\"id\";s:8:\"industry\";s:5:\"label\";s:8:\"Industry\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1425:\"Accounting/Finance: Accounting/Finance\nAdvertising/Public Relations: Advertising/Public Relations\nAerospace/Aviation: Aerospace/Aviation\nArts/Entertainment/Publishing: Arts/Entertainment/Publishing\nAutomotive: Automotive\nBanking/Mortgage: Banking/Mortgage\nBusiness Development: Business Development\nBusiness Opportunity: Business Opportunity\nClerical/Administrative: Clerical/Administrative\nConstruction/Facilities: Construction/Facilities\nConsumer Goods: Consumer Goods\nCustomer Service: Customer Service\nEducation/Training: Education/Training\nEnergy/Utilities: Energy/Utilities\nEngineering: Engineering\nGovernment/Military: Government/Military\nHealthcare: Healthcare\nHospitality/Travel: Hospitality/Travel\nHuman Resources: Human Resources\nInstallation/Maintenance: Installation/Maintenance\nInsurance: Insurance\nInternet: Internet\nLaw Enforcement/Security: Law Enforcement/Security\nLegal: Legal\nManagement/Executive: Management/Executive\nManufacturing/Operations: Manufacturing/Operations\nMarketing: Marketing\nNon-Profit/Volunteer: Non-Profit/Volunteer\nPharmaceutical/Biotech: Pharmaceutical/Biotech\nProfessional Services: Professional Services\nReal Estate: Real Estate\nRestaurant/Food Service: Restaurant/Food Service\nRetail: Retail\nSales: Sales\nScience/Research: Science/Research\nSkilled Labor: Skilled Labor\nTechnology: Technology\nTelecommunications: Telecommunications\nTransportation/Logistics: Transportation/Logistics\n\";}'),('','webform.webform_options.languages',_binary 'a:10:{s:4:\"uuid\";s:36:\"05fc358f-135e-4f8d-8e30-9bde5b4e34d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYH14Vi65Ixj10c_GFa7CipxU3D0Bt9wgo8zE8zjOfE\";}s:2:\"id\";s:9:\"languages\";s:5:\"label\";s:9:\"Languages\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.likert_agreement',_binary 'a:10:{s:4:\"uuid\";s:36:\"e7d35339-5044-42d3-9c89-6bcf4c7b3f86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nPp-CfMKrP0yDMtyO0wQRwawEqaJVAPzQapinXmDgyU\";}s:2:\"id\";s:16:\"likert_agreement\";s:5:\"label\";s:17:\"Likert: Agreement\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:71:\"1: Strongly Disagree\n2: Disagree\n3: Neutral\n4: Agree\n5: Strongly Agree\n\";}'),('','webform.webform_options.likert_comparison',_binary 'a:10:{s:4:\"uuid\";s:36:\"c05e7ce1-8d8c-4fe2-ad87-51fb46a4fa7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DMG4TKTHEXtHN8ho_sG_GiZHgweZ6nrRm6BAjk0LZ_Y\";}s:2:\"id\";s:17:\"likert_comparison\";s:5:\"label\";s:18:\"Likert: Comparison\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:84:\"1: Much Worse\n2: Somewhat Worse\n3: About the Same\n4: Somewhat Better\n5: Much Better\n\";}'),('','webform.webform_options.likert_importance',_binary 'a:10:{s:4:\"uuid\";s:36:\"b3f9da96-6241-4951-994d-2a00fc66b8e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hbc8n5HtVZVs5fSBSpSbuY07CVvqkKP76csvRHN9pK8\";}s:2:\"id\";s:17:\"likert_importance\";s:5:\"label\";s:18:\"Likert: Importance\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:88:\"1: Not at all Important\n2: Somewhat Important\n3: Neutral\n4: Important\n5: Very Important\n\";}'),('','webform.webform_options.likert_quality',_binary 'a:10:{s:4:\"uuid\";s:36:\"6e7a0384-f89e-4ad5-87b9-0a6f41301026\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swmYtBVUbwq7aHJWWDN7ODByuvur9vMkexDC9h64NZ8\";}s:2:\"id\";s:14:\"likert_quality\";s:5:\"label\";s:15:\"Likert: Quality\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:50:\"1: Poor\n2: Fair\n3: Good\n4: Very good\n5: Excellent\n\";}'),('','webform.webform_options.likert_satisfaction',_binary 'a:10:{s:4:\"uuid\";s:36:\"e52c5b0d-4f4e-4ea8-b30c-9f53646066c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKE2SNwCpl6Mu_cmbq9ZM2_cXxCikCVj1vcPE9oHWTs\";}s:2:\"id\";s:19:\"likert_satisfaction\";s:5:\"label\";s:20:\"Likert: Satisfaction\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:77:\"1: Very Unsatisfied\n2: Unsatisfied\n3: Neutral\n4: Satisfied\n5: Very Satisfied\n\";}'),('','webform.webform_options.likert_ten_scale',_binary 'a:10:{s:4:\"uuid\";s:36:\"f9cdebb7-5b4d-4f5b-873e-1d4e461985d9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zEZX8JSVqznnFtqFfpuC593h3t1JDAZhF0Q3pvA229o\";}s:2:\"id\";s:16:\"likert_ten_scale\";s:5:\"label\";s:17:\"Likert: Ten Scale\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:52:\"1: 1\n2: 2\n3: 3\n4: 4\n5: 5\n6: 6\n7: 7\n8: 8\n9: 9\n10: 10\n\";}'),('','webform.webform_options.likert_would_you',_binary 'a:10:{s:4:\"uuid\";s:36:\"3e23d906-eeea-4c78-a29f-a37b82dbf616\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qBS2TmfAJB37Qn3TnrNM8x4AWimmDapcizzRllgo0fo\";}s:2:\"id\";s:16:\"likert_would_you\";s:5:\"label\";s:17:\"Likert: Would You\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:72:\"1: Definitely Not\n2: Probably Not\n3: Not Sure\n4: Probably\n5: Definitely\n\";}'),('','webform.webform_options.marital_status',_binary 'a:10:{s:4:\"uuid\";s:36:\"67011573-341a-4e22-893d-6fbff6623594\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cjVDbAE5BlopGrY-tfxsxMoyEibwBBNgdQwDdxOSkow\";}s:2:\"id\";s:14:\"marital_status\";s:5:\"label\";s:14:\"Marital status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:68:\"Single: Single\nMarried: Married\nDivorced: Divorced\nWidowed: Widowed\n\";}'),('','webform.webform_options.months',_binary 'a:10:{s:4:\"uuid\";s:36:\"2160769c-f93c-45f7-b28e-52d800ec51c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pZJnuQkh9afNML5IcMuKTUC__vmHMFn66Qr5IWtedZ4\";}s:2:\"id\";s:6:\"months\";s:5:\"label\";s:6:\"Months\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:184:\"January: January\nFebruary: February\nMarch: March\nApril: April\nMay: May\nJune: June\nJuly: July\nAugust: August\nSeptember: September\nOctober: October\nNovember: November\nDecember: December\n\";}'),('','webform.webform_options.phone_types',_binary 'a:10:{s:4:\"uuid\";s:36:\"ede08b1a-9f0a-4e51-bb56-baa6f6edc279\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LkO63Zl2cP_l9YdjzWI8dWoD9uD0pytkPiUiUM2bo9A\";}s:2:\"id\";s:11:\"phone_types\";s:5:\"label\";s:10:\"Phone type\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:37:\"Home: Home\nOffice: Office\nCell: Cell\n\";}'),('','webform.webform_options.province_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"595af078-ff40-4b8f-a59c-c9b5622dbc65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cR3A6XXinVGC9g5vLS-vVvTC2ppZXRNXLPWA8xBUMew\";}s:2:\"id\";s:14:\"province_codes\";s:5:\"label\";s:14:\"Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:237:\"AB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),('','webform.webform_options.province_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"26a80f5e-c29e-4eee-9918-eefc2b54b8ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aaEeYBWoWETLKX2ivmZBpUAd3uPe2iPNydaxBuLPXKc\";}s:2:\"id\";s:14:\"province_names\";s:5:\"label\";s:14:\"Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:379:\"Alberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),('','webform.webform_options.relationship',_binary 'a:10:{s:4:\"uuid\";s:36:\"5e9987f1-71cd-4573-88c0-ff0fc33fe873\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4J2RPG4JmsD4Fm1NlIQY0JHkrJ08UUl0qTF0_EjUxvw\";}s:2:\"id\";s:12:\"relationship\";s:5:\"label\";s:12:\"Relationship\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:101:\"Parent: Parent\n\'Significant Other\': \'Significant Other\'\nSibling: Sibling\nChild: Child\nFriend: Friend\n\";}'),('','webform.webform_options.sex',_binary 'a:10:{s:4:\"uuid\";s:36:\"052b2071-a7ca-48a1-b511-cf26c5c28801\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WRpxpwYpfcO_i0so7BV4QXxXlbPiSVppYmAV6DAz4c0\";}s:2:\"id\";s:3:\"sex\";s:5:\"label\";s:3:\"Sex\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:26:\"Male: Male\nFemale: Female\n\";}'),('','webform.webform_options.sex_icao',_binary 'a:10:{s:4:\"uuid\";s:36:\"0b914fae-9fd3-4903-8774-8c355aa91632\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9mxo86dMII5OxkHl4mbe2l4AgQloOXuErOte57BU9IY\";}s:2:\"id\";s:8:\"sex_icao\";s:5:\"label\";s:54:\"Sex - International Civil Aviation Organization (ICAO)\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:33:\"M: Male\nF: Female\nX: Unspecified\n\";}'),('','webform.webform_options.size',_binary 'a:10:{s:4:\"uuid\";s:36:\"c671c93b-871e-49ba-964c-d0fe4ad73550\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RKkc6tf1VudvYiOtwPCf3Tp_EoA6fov6BFC34D7gMoQ\";}s:2:\"id\";s:4:\"size\";s:5:\"label\";s:4:\"Size\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:91:\"Extra Small: Extra Small\nSmall: Small\nMedium: Medium\nLarge: Large\nExtra Large: Extra Large\n\";}'),('','webform.webform_options.state_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"82d7e2f4-fb87-4c81-a5f3-0dd704eee27f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8mYO8ewsZX3LVfNga69jXa0RNO0LNN8-EGkXLhSAMBU\";}s:2:\"id\";s:11:\"state_codes\";s:5:\"label\";s:11:\"State codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:728:\"AL: Alabama\nAK: Alaska\nAZ: Arizona\nAR: Arkansas\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPA: Pennsylvania\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\n\";}'),('','webform.webform_options.state_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"2141569b-1460-424e-9f43-303b2a435e45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KfYqMSrFJ5iGtDzvy_rGUeRUJ4KyM7Xt-tWtYx9WjiM\";}s:2:\"id\";s:11:\"state_names\";s:5:\"label\";s:11:\"State names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1081:\"Alabama: Alabama\nAlaska: Alaska\nArizona: Arizona\nArkansas: Arkansas\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\nFlorida: Florida\nGeorgia: Georgia\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPennsylvania: Pennsylvania\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\n\";}'),('','webform.webform_options.state_province_codes',_binary 'a:10:{s:4:\"uuid\";s:36:\"ea84bfcf-e9b1-47e7-ac33-c7743aa2ccae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ziWv9xVss1UBnP_R38EqduZOprwOAifpxjXhyOPzmys\";}s:2:\"id\";s:20:\"state_province_codes\";s:5:\"label\";s:20:\"State/Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1241:\"AL: Alabama\nAK: Alaska\nAS: \'American Samoa\'\nAZ: Arizona\nAR: Arkansas\nAE: \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\nAA: \'Armed Forces Americas\'\nAP: \'Armed Forces Pacific\'\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFM: \'Federated States of Micronesia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMH: \'Marshall Islands\'\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nMP: \'Northern Mariana Islands\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPW: Palau\nPA: Pennsylvania\nPR: \'Puerto Rico\'\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVI: \'Virgin Islands\'\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\nAB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),('','webform.webform_options.state_province_names',_binary 'a:10:{s:4:\"uuid\";s:36:\"f757b555-27c8-4894-a589-58863a4bfb38\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d4mxS_CxdzHZK4WaGQf1H3m-Uubm5HPbu9U4ydzscuo\";}s:2:\"id\";s:20:\"state_province_names\";s:5:\"label\";s:20:\"State/Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1953:\"Alabama: Alabama\nAlaska: Alaska\n\'American Samoa\': \'American Samoa\'\nArizona: Arizona\nArkansas: Arkansas\n\'Armed Forces (Canada, Europe, Africa, or Middle East)\': \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\n\'Armed Forces Americas\': \'Armed Forces Americas\'\n\'Armed Forces Pacific\': \'Armed Forces Pacific\'\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\n\'Federated States of Micronesia\': \'Federated States of Micronesia\'\nFlorida: Florida\nGeorgia: Georgia\nGuam: Guam\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\n\'Marshall Islands\': \'Marshall Islands\'\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\n\'Northern Mariana Islands\': \'Northern Mariana Islands\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPalau: Palau\nPennsylvania: Pennsylvania\n\'Puerto Rico\': \'Puerto Rico\'\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\n\'Virgin Islands\': \'Virgin Islands\'\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\nAlberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),('','webform.webform_options.time_zones',_binary 'a:10:{s:4:\"uuid\";s:36:\"95a86930-8c84-4d30-8c47-9b5513752ab6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8rVcRXLnTAEoWs7zl8du-7RIUnayqUcGYnvb3JT21-o\";}s:2:\"id\";s:10:\"time_zones\";s:5:\"label\";s:10:\"Time zones\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.titles',_binary 'a:10:{s:4:\"uuid\";s:36:\"bf77360d-2ee5-4057-94df-b64936a0e9c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PEUoedWrfYEX7oZ8CcOukfBTVxar1cPSROX8534esuU\";}s:2:\"id\";s:6:\"titles\";s:5:\"label\";s:6:\"Titles\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:41:\"Miss: Miss\nMs: Ms\nMr: Mr\nMrs: Mrs\nDr: Dr\n\";}'),('','webform.webform_options.translations',_binary 'a:10:{s:4:\"uuid\";s:36:\"c5a0c3d0-00d1-4e7a-82bd-38a69656f42a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mb_L3vE-0IBZH5s2rjpk2LNn0QHClQP9AARQdCmVLt4\";}s:2:\"id\";s:12:\"translations\";s:5:\"label\";s:12:\"Translations\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),('','webform.webform_options.yes_no',_binary 'a:10:{s:4:\"uuid\";s:36:\"6b9fbab8-7082-4f33-903d-44c1c725d64f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W88NYg31DbaVNQx1Uir_dwwXHVtF09QOq4VBGsH1Snk\";}s:2:\"id\";s:6:\"yes_no\";s:5:\"label\";s:6:\"Yes/No\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:16:\"Yes: Yes\nNo: No\n\";}'),('','webform_rest.settings',_binary 'a:1:{s:21:\"confirmation_settings\";i:1;}');
/*!40000 ALTER TABLE `config_export` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `file_managed`
--

DROP TABLE IF EXISTS `file_managed`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `file_managed` (
  `fid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `filename` varchar(255) DEFAULT NULL,
  `uri` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  `filemime` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `filesize` bigint unsigned DEFAULT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `changed` int NOT NULL,
  PRIMARY KEY (`fid`),
  UNIQUE KEY `file_field__uuid__value` (`uuid`),
  KEY `file_field__uid__target_id` (`uid`),
  KEY `file_field__uri` (`uri`(191)),
  KEY `file_field__status` (`status`),
  KEY `file_field__changed` (`changed`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for file entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `file_managed`
--

LOCK TABLES `file_managed` WRITE;
/*!40000 ALTER TABLE `file_managed` DISABLE KEYS */;
INSERT INTO `file_managed` VALUES (1,'27d7fec7-8bb0-4e7a-9d75-6c3cd2bd2e03','en',1,'Designer.jpeg','public://2025-03/Designer.jpeg','image/jpeg',159163,1,1742136318,1742136377),(2,'a16f4fec-8939-4c51-9e8f-0d17b0836c6a','en',1,'Designer (1).jpeg','public://2025-03/Designer (1).jpeg','image/jpeg',199886,1,1742136460,1742136512),(4,'876ab35f-1a96-444c-aeba-e96d038d21ea','en',1,'Designer3_0.jpeg','public://2025-03/Designer3_0.jpeg','image/jpeg',180837,1,1742153863,1742153978),(5,'6a4e240f-9716-4a36-98eb-f92133542bad','en',1,'json-api.png','public://inline-images/json-api.png','image/png',2910923,1,1743410544,1743410563),(6,'e5738396-f733-4814-b20c-5375ee9cfd39','en',1,'json-api.jpg','public://inline-images/json-api.jpg','image/jpeg',452844,1,1743937126,1743937139);
/*!40000 ALTER TABLE `file_managed` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `file_usage`
--

DROP TABLE IF EXISTS `file_usage`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `file_usage` (
  `fid` int unsigned NOT NULL COMMENT 'File ID.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module that is using the file.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the object type in which the file is used.',
  `id` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '0' COMMENT 'The primary key of the object using the file.',
  `count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The number of times this file is used by this object.',
  PRIMARY KEY (`fid`,`type`,`id`,`module`),
  KEY `type_id` (`type`,`id`),
  KEY `fid_count` (`fid`,`count`),
  KEY `fid_module` (`fid`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Track where a file is used.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `file_usage`
--

LOCK TABLES `file_usage` WRITE;
/*!40000 ALTER TABLE `file_usage` DISABLE KEYS */;
INSERT INTO `file_usage` VALUES (1,'file','node','1',3),(2,'file','node','2',3),(4,'file','node','3',3),(5,'editor','node','4',1),(6,'editor','node','4',1);
/*!40000 ALTER TABLE `file_usage` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `help_search_items`
--

DROP TABLE IF EXISTS `help_search_items`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `help_search_items` (
  `sid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Numeric index of this item in the search index',
  `section_plugin_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The help section the item comes from',
  `permission` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The permission needed to view this item',
  `topic_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The topic ID of the item',
  PRIMARY KEY (`sid`),
  KEY `section_plugin_id` (`section_plugin_id`),
  KEY `topic_id` (`topic_id`)
) ENGINE=InnoDB AUTO_INCREMENT=92 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores information about indexed help search items';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `help_search_items`
--

LOCK TABLES `help_search_items` WRITE;
/*!40000 ALTER TABLE `help_search_items` DISABLE KEYS */;
INSERT INTO `help_search_items` VALUES (1,'help_topics','','config.export_full'),(2,'help_topics','','config.export_single'),(3,'help_topics','','config.import_full'),(4,'help_topics','','config.import_single'),(5,'help_topics','','contact.adding_fields'),(6,'help_topics','','contact.configuring_personal'),(7,'help_topics','','contact.creating'),(8,'help_topics','','contact.overview'),(9,'help_topics','','contact.setting_default'),(10,'help_topics','','core.appearance'),(11,'help_topics','','core.config_overview'),(12,'help_topics','','core.content_structure'),(13,'help_topics','','core.cron'),(14,'help_topics','','core.extending'),(15,'help_topics','','core.maintenance'),(16,'help_topics','','core.media'),(17,'help_topics','','core.menus'),(18,'help_topics','','core.performance'),(19,'help_topics','','core.security'),(20,'help_topics','','core.settings_tray'),(21,'help_topics','','core.tracking_content'),(22,'help_topics','','core.translations'),(23,'help_topics','','core.ui_accessibility'),(24,'help_topics','','core.ui_components'),(25,'help_topics','','core.web_services'),(26,'help_topics','','help.help_topic_search'),(27,'help_topics','','help.overview'),(28,'help_topics','','search.configuring'),(29,'help_topics','','search.index'),(30,'help_topics','','search.overview'),(31,'help_topics','','system.cache'),(32,'help_topics','','system.config_basic'),(33,'help_topics','','system.config_error'),(34,'help_topics','','system.maintenance_mode'),(35,'help_topics','','system.module_install'),(36,'help_topics','','system.module_uninstall'),(37,'help_topics','','system.reports'),(38,'help_topics','','system.theme_install'),(39,'help_topics','','system.theme_uninstall'),(40,'help_topics','','user.create'),(41,'help_topics','','user.new_role'),(42,'help_topics','','user.overview'),(43,'help_topics','','user.permissions'),(44,'help_topics','','user.security_account_settings'),(45,'help_topics','','user.update'),(46,'help_topics','','announcements_feed.overview'),(47,'help_topics','','block.configure'),(48,'help_topics','','block.overview'),(49,'help_topics','','block.place'),(50,'help_topics','','filter.overview'),(51,'help_topics','','block_content.add'),(52,'help_topics','','block_content.type'),(53,'help_topics','','breakpoint.overview'),(54,'help_topics','','editor.overview'),(55,'help_topics','','comment.configuring'),(56,'help_topics','','comment.creating_type'),(57,'help_topics','','comment.disabling'),(58,'help_topics','','comment.moderating'),(59,'help_topics','','comment.overview'),(60,'help_topics','','contextual.overview'),(61,'help_topics','','field_ui.add_field'),(62,'help_topics','','field_ui.manage_display'),(63,'help_topics','','field_ui.manage_form'),(64,'help_topics','','field_ui.reference_field'),(65,'help_topics','','node.creating_content'),(66,'help_topics','','node.creating_type'),(67,'help_topics','','node.editing'),(68,'help_topics','','node.overview'),(69,'help_topics','','history.tracking_user_content'),(70,'help_topics','','image.style'),(71,'help_topics','','views.overview'),(72,'help_topics','','menu_ui.content_type_configuration'),(73,'help_topics','','menu_ui.menu_item_add'),(74,'help_topics','','menu_ui.menu_operations'),(75,'help_topics','','menu_ui.overriding'),(76,'help_topics','','path.creating_alias'),(77,'help_topics','','path.editing_alias'),(78,'help_topics','','path.overview'),(79,'help_topics','','shortcut.overview'),(80,'help_topics','','taxonomy.configuring'),(81,'help_topics','','taxonomy.overview'),(82,'help_topics','','views_ui.add_display'),(83,'help_topics','','views_ui.bulk_operations'),(84,'help_topics','','views_ui.create'),(85,'help_topics','','views_ui.edit'),(86,'help_topics','','language.add'),(87,'help_topics','','language.detect'),(88,'help_topics','','locale.import'),(89,'help_topics','','locale.translate_strings'),(90,'help_topics','','locale.translation_status'),(91,'help_topics','','config_translation.overview');
/*!40000 ALTER TABLE `help_search_items` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `history`
--

DROP TABLE IF EXISTS `history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `history` (
  `uid` int NOT NULL DEFAULT '0' COMMENT 'The "users".uid that read the "node" nid.',
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid that was read.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp at which the read occurred.',
  PRIMARY KEY (`uid`,`nid`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='A record of which "users" have read which "node"s.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `history`
--

LOCK TABLES `history` WRITE;
/*!40000 ALTER TABLE `history` DISABLE KEYS */;
INSERT INTO `history` VALUES (1,1,1742136397),(1,2,1742136518),(1,3,1742154715),(1,4,1743937148);
/*!40000 ALTER TABLE `history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `key_value`
--

DROP TABLE IF EXISTS `key_value`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `key_value` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key-value pair. As KEY is a SQL reserved keyword, name was chosen instead.',
  `value` longblob NOT NULL COMMENT 'The value.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Generic key-value storage table. See the state system for…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `key_value`
--

LOCK TABLES `key_value` WRITE;
/*!40000 ALTER TABLE `key_value` DISABLE KEYS */;
INSERT INTO `key_value` VALUES ('config.entity.key_store.action','uuid:0d5b6f2e-6a01-4548-80d0-2b2f921f5ce1',_binary 'a:1:{i:0;s:37:\"system.action.node_make_sticky_action\";}'),('config.entity.key_store.action','uuid:25777620-04cb-41ec-8e16-8c4348c4f694',_binary 'a:1:{i:0;s:35:\"system.action.node_unpublish_action\";}'),('config.entity.key_store.action','uuid:342b3323-7057-4ffe-ade0-4338b9bba972',_binary 'a:1:{i:0;s:36:\"system.action.webform_archive_action\";}'),('config.entity.key_store.action','uuid:3bcda49f-6cd5-4dd0-9351-32a81d30f2a1',_binary 'a:1:{i:0;s:36:\"system.action.redirect_delete_action\";}'),('config.entity.key_store.action','uuid:3f3a79f9-8861-47f0-9a48-7763b20662c5',_binary 'a:1:{i:0;s:40:\"system.action.pathauto_update_alias_user\";}'),('config.entity.key_store.action','uuid:419ab97d-38b5-44bf-8bc7-4363dd8cd152',_binary 'a:1:{i:0;s:44:\"system.action.taxonomy_term_unpublish_action\";}'),('config.entity.key_store.action','uuid:471e29d2-dca7-49e2-9e95-9bd8584625b9',_binary 'a:1:{i:0;s:51:\"system.action.webform_submission_make_unlock_action\";}'),('config.entity.key_store.action','uuid:4cf610b1-6607-4437-8e3c-20c2d77f21ce',_binary 'a:1:{i:0;s:33:\"system.action.webform_open_action\";}'),('config.entity.key_store.action','uuid:4efe6291-b04e-4adc-96a1-342f84a493c7',_binary 'a:1:{i:0;s:51:\"system.action.user_remove_role_action.administrator\";}'),('config.entity.key_store.action','uuid:592b4324-cb2f-4348-a5e7-e7465b63312f',_binary 'a:1:{i:0;s:36:\"system.action.comment_publish_action\";}'),('config.entity.key_store.action','uuid:60d38e09-2fb3-41b8-b097-8cfd3153ea58',_binary 'a:1:{i:0;s:38:\"system.action.comment_unpublish_action\";}'),('config.entity.key_store.action','uuid:6fddfca8-1c8f-41ce-8413-06d675230a6d',_binary 'a:1:{i:0;s:36:\"system.action.user_block_user_action\";}'),('config.entity.key_store.action','uuid:7794e8ff-9168-4532-9036-0e67d7591d62',_binary 'a:1:{i:0;s:51:\"system.action.webform_submission_make_sticky_action\";}'),('config.entity.key_store.action','uuid:7d87b2ec-5200-4708-ab2e-b9270cd87667',_binary 'a:1:{i:0;s:37:\"system.action.user_cancel_user_action\";}'),('config.entity.key_store.action','uuid:80b46801-8606-45a5-ac48-556164d453f8',_binary 'a:1:{i:0;s:49:\"system.action.user_add_role_action.content_editor\";}'),('config.entity.key_store.action','uuid:825fd299-837b-45d7-99f0-05d512a7b4e4',_binary 'a:1:{i:0;s:33:\"system.action.comment_save_action\";}'),('config.entity.key_store.action','uuid:83915ff9-c752-4733-8ea4-73564fa9dd24',_binary 'a:1:{i:0;s:53:\"system.action.webform_submission_make_unsticky_action\";}'),('config.entity.key_store.action','uuid:8e84e417-0929-4c2e-9659-9e54cc04b4fd',_binary 'a:1:{i:0;s:38:\"system.action.user_unblock_user_action\";}'),('config.entity.key_store.action','uuid:914162ea-d84f-4516-bd2b-4f0706afdc16',_binary 'a:1:{i:0;s:35:\"system.action.node_unpromote_action\";}'),('config.entity.key_store.action','uuid:9d8c9ee3-e66d-4a91-96e7-930a4d37b701',_binary 'a:1:{i:0;s:32:\"system.action.node_delete_action\";}'),('config.entity.key_store.action','uuid:ad08f939-8821-4b11-949f-8731eb3b08ac',_binary 'a:1:{i:0;s:33:\"system.action.node_promote_action\";}'),('config.entity.key_store.action','uuid:b0e3c96b-6c2c-461b-8ffc-a06d3863e7f0',_binary 'a:1:{i:0;s:33:\"system.action.node_publish_action\";}'),('config.entity.key_store.action','uuid:b838c238-785f-4fa9-bda4-f6d575f823a2',_binary 'a:1:{i:0;s:52:\"system.action.user_remove_role_action.content_editor\";}'),('config.entity.key_store.action','uuid:bb994d72-a95d-4051-8c29-3d7b939b7aeb',_binary 'a:1:{i:0;s:30:\"system.action.node_save_action\";}'),('config.entity.key_store.action','uuid:c14576ba-6a4d-4bbd-b73b-8c0eef62c795',_binary 'a:1:{i:0;s:49:\"system.action.webform_submission_make_lock_action\";}'),('config.entity.key_store.action','uuid:c7d14f6a-6e6a-45ea-8fa6-b13072dfe4b2',_binary 'a:1:{i:0;s:35:\"system.action.comment_delete_action\";}'),('config.entity.key_store.action','uuid:c81c6465-71f1-49ec-87c0-665cb21bddc1',_binary 'a:1:{i:0;s:42:\"system.action.taxonomy_term_publish_action\";}'),('config.entity.key_store.action','uuid:ddc1f1da-5251-49ef-9ea8-eaff39c9a1a3',_binary 'a:1:{i:0;s:34:\"system.action.webform_close_action\";}'),('config.entity.key_store.action','uuid:eee484c2-7858-45fd-b4dd-731b43fbff3a',_binary 'a:1:{i:0;s:40:\"system.action.pathauto_update_alias_node\";}'),('config.entity.key_store.action','uuid:f1a2a8bf-e58b-4436-8b2d-858b28738221',_binary 'a:1:{i:0;s:39:\"system.action.node_make_unsticky_action\";}'),('config.entity.key_store.action','uuid:f2218b96-cb4e-4226-bdca-6170e30bc34f',_binary 'a:1:{i:0;s:35:\"system.action.webform_delete_action\";}'),('config.entity.key_store.action','uuid:f84c0b0d-7607-4ce0-8236-398e642bdbc7',_binary 'a:1:{i:0;s:46:\"system.action.webform_submission_delete_action\";}'),('config.entity.key_store.action','uuid:fc5862d9-e21c-4c86-9dbf-f476320fc76b',_binary 'a:1:{i:0;s:48:\"system.action.user_add_role_action.administrator\";}'),('config.entity.key_store.action','uuid:ffe260a0-779e-4401-b0b8-40ddaffc73dc',_binary 'a:1:{i:0;s:38:\"system.action.webform_unarchive_action\";}'),('config.entity.key_store.base_field_override','uuid:a3af19ad-36e8-452e-873e-127297423512',_binary 'a:1:{i:0;s:45:\"core.base_field_override.node.webform.promote\";}'),('config.entity.key_store.base_field_override','uuid:c23528a5-02ac-44f4-a644-5500abef763e',_binary 'a:1:{i:0;s:42:\"core.base_field_override.node.page.promote\";}'),('config.entity.key_store.behavior_settings','uuid:76010145-adf2-4485-8e92-6a2464384ab5',_binary 'a:1:{i:0;s:37:\"rabbit_hole.behavior_settings.default\";}'),('config.entity.key_store.behavior_settings','uuid:ca871477-04f2-44a1-858c-731fed4e2a7d',_binary 'a:1:{i:0;s:44:\"rabbit_hole.behavior_settings.default_bundle\";}'),('config.entity.key_store.block','theme:claro',_binary 'a:8:{i:0;s:31:\"block.block.claro_local_actions\";i:1;s:28:\"block.block.claro_page_title\";i:2;s:37:\"block.block.claro_primary_local_tasks\";i:3;s:39:\"block.block.claro_secondary_local_tasks\";i:4;s:22:\"block.block.claro_help\";i:6;s:29:\"block.block.claro_breadcrumbs\";i:7;s:25:\"block.block.claro_content\";i:8;s:26:\"block.block.claro_messages\";}'),('config.entity.key_store.block','theme:gin',_binary 'a:8:{i:0;s:29:\"block.block.gin_local_actions\";i:1;s:26:\"block.block.gin_page_title\";i:2;s:35:\"block.block.gin_primary_local_tasks\";i:3;s:37:\"block.block.gin_secondary_local_tasks\";i:4;s:20:\"block.block.gin_help\";i:5;s:27:\"block.block.gin_breadcrumbs\";i:6;s:23:\"block.block.gin_content\";i:7;s:24:\"block.block.gin_messages\";}'),('config.entity.key_store.block','theme:olivero',_binary 'a:11:{i:0;s:24:\"block.block.olivero_help\";i:1;s:30:\"block.block.olivero_page_title\";i:2;s:41:\"block.block.olivero_primary_admin_actions\";i:3;s:39:\"block.block.olivero_primary_local_tasks\";i:4;s:41:\"block.block.olivero_secondary_local_tasks\";i:8;s:31:\"block.block.olivero_breadcrumbs\";i:9;s:27:\"block.block.olivero_content\";i:10;s:28:\"block.block.olivero_messages\";i:12;s:33:\"block.block.olivero_site_branding\";i:13;s:32:\"block.block.olivero_account_menu\";i:14;s:29:\"block.block.olivero_main_menu\";}'),('config.entity.key_store.block','uuid:07be5c27-7c5f-41b8-964c-98c06048a345',_binary 'a:1:{i:0;s:31:\"block.block.olivero_breadcrumbs\";}'),('config.entity.key_store.block','uuid:07f111f7-352c-4382-846e-5dc96ba3e79c',_binary 'a:1:{i:0;s:37:\"block.block.gin_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:16251d67-ff59-46ea-992c-c18706ab2d54',_binary 'a:1:{i:0;s:35:\"block.block.gin_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:2ee473b3-a425-411a-ab54-a68f6158b424',_binary 'a:1:{i:0;s:29:\"block.block.claro_breadcrumbs\";}'),('config.entity.key_store.block','uuid:2fcd6937-f7e2-4164-9961-4645225145e5',_binary 'a:1:{i:0;s:23:\"block.block.gin_content\";}'),('config.entity.key_store.block','uuid:32e45861-c4ef-4890-9456-d4d3178e6dff',_binary 'a:1:{i:0;s:22:\"block.block.claro_help\";}'),('config.entity.key_store.block','uuid:41b6f077-7605-4a7d-9b49-e8bf57957354',_binary 'a:1:{i:0;s:39:\"block.block.olivero_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:49e09740-a7ab-405b-9ab5-bfd13b5e620f',_binary 'a:1:{i:0;s:31:\"block.block.claro_local_actions\";}'),('config.entity.key_store.block','uuid:51ff8126-5055-4bce-9ccb-18c944436bfa',_binary 'a:1:{i:0;s:28:\"block.block.claro_page_title\";}'),('config.entity.key_store.block','uuid:76004679-c667-48f4-8315-0938ae25c677',_binary 'a:1:{i:0;s:25:\"block.block.claro_content\";}'),('config.entity.key_store.block','uuid:7d8fc1d9-1953-4095-be0e-84db7c675688',_binary 'a:1:{i:0;s:26:\"block.block.claro_messages\";}'),('config.entity.key_store.block','uuid:870c3a2a-0f9d-4654-a000-d2679516fe2d',_binary 'a:1:{i:0;s:32:\"block.block.olivero_account_menu\";}'),('config.entity.key_store.block','uuid:8b83c953-f174-46e0-a364-09d2175e38ac',_binary 'a:1:{i:0;s:20:\"block.block.gin_help\";}'),('config.entity.key_store.block','uuid:a8503923-9b73-4303-b900-8d31d288f15a',_binary 'a:1:{i:0;s:37:\"block.block.claro_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:b6522fa8-f871-47e7-b9ce-f5ae8e81bc1c',_binary 'a:1:{i:0;s:27:\"block.block.gin_breadcrumbs\";}'),('config.entity.key_store.block','uuid:b67d55b6-584f-4ea8-a5ad-1ff5a0ce5f58',_binary 'a:1:{i:0;s:41:\"block.block.olivero_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:c6c79d5e-aa2f-4b8d-b495-90d172f5a37f',_binary 'a:1:{i:0;s:24:\"block.block.gin_messages\";}'),('config.entity.key_store.block','uuid:c705cc7a-6121-476d-bbe4-261ea3e5d449',_binary 'a:1:{i:0;s:30:\"block.block.olivero_page_title\";}'),('config.entity.key_store.block','uuid:c936529a-a175-4104-a0be-d34480b5c15a',_binary 'a:1:{i:0;s:41:\"block.block.olivero_primary_admin_actions\";}'),('config.entity.key_store.block','uuid:cde6aefd-f0a4-4b0b-beec-de088e3ba750',_binary 'a:1:{i:0;s:27:\"block.block.olivero_content\";}'),('config.entity.key_store.block','uuid:e15a620f-69da-49e6-b189-04443f574743',_binary 'a:1:{i:0;s:29:\"block.block.gin_local_actions\";}'),('config.entity.key_store.block','uuid:ebb3e07a-d14f-423b-a996-02cd370cd1fb',_binary 'a:1:{i:0;s:24:\"block.block.olivero_help\";}'),('config.entity.key_store.block','uuid:ebea0892-f451-48c1-9e1d-88b202d03b18',_binary 'a:1:{i:0;s:26:\"block.block.gin_page_title\";}'),('config.entity.key_store.block','uuid:eecd31b5-688c-478a-9a64-3f7a71835f70',_binary 'a:1:{i:0;s:39:\"block.block.claro_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:f22a6909-6281-401a-81e1-e7b2b08f2d29',_binary 'a:1:{i:0;s:28:\"block.block.olivero_messages\";}'),('config.entity.key_store.block','uuid:f31a287c-6331-4954-8774-a5c1a562ded4',_binary 'a:1:{i:0;s:29:\"block.block.olivero_main_menu\";}'),('config.entity.key_store.block','uuid:f9fbe17e-b414-4baa-8e48-f52b2907dd61',_binary 'a:1:{i:0;s:33:\"block.block.olivero_site_branding\";}'),('config.entity.key_store.block_content_type','uuid:d64644ad-b094-4c5b-a15a-19a3b8bdc1c9',_binary 'a:1:{i:0;s:24:\"block_content.type.basic\";}'),('config.entity.key_store.comment_type','uuid:a33bd86b-5bbd-4f5c-807b-eba5e4396f23',_binary 'a:1:{i:0;s:20:\"comment.type.comment\";}'),('config.entity.key_store.configurable_language','uuid:541e3fe7-505e-4e41-a296-2b93fab83b55',_binary 'a:1:{i:0;s:18:\"language.entity.en\";}'),('config.entity.key_store.configurable_language','uuid:577d2e0c-b2fc-4b0f-a051-dcb71bf1c920',_binary 'a:1:{i:0;s:19:\"language.entity.zxx\";}'),('config.entity.key_store.configurable_language','uuid:f479fc2f-303e-4d96-b8dc-cf40b3c917a6',_binary 'a:1:{i:0;s:19:\"language.entity.und\";}'),('config.entity.key_store.contact_form','uuid:b09080d0-d32f-48de-a42f-70fdecbd5e2c',_binary 'a:1:{i:0;s:21:\"contact.form.feedback\";}'),('config.entity.key_store.contact_form','uuid:f3831747-359e-4997-a6d5-abd5e6e9f842',_binary 'a:1:{i:0;s:21:\"contact.form.personal\";}'),('config.entity.key_store.date_format','uuid:010477b9-d765-490f-9425-dd432bfb786e',_binary 'a:1:{i:0;s:31:\"core.date_format.olivero_medium\";}'),('config.entity.key_store.date_format','uuid:0629967e-77af-4eb2-8a78-d6b4f1a8a540',_binary 'a:1:{i:0;s:23:\"core.date_format.medium\";}'),('config.entity.key_store.date_format','uuid:0af4b8bf-1ba3-4ecc-a123-f2abfa8a7e34',_binary 'a:1:{i:0;s:26:\"core.date_format.html_date\";}'),('config.entity.key_store.date_format','uuid:0f2d4f08-392f-4b29-bf5c-4d4c8aa13945',_binary 'a:1:{i:0;s:26:\"core.date_format.html_year\";}'),('config.entity.key_store.date_format','uuid:1eeb9283-48cf-42b5-9ec2-e3277335126d',_binary 'a:1:{i:0;s:35:\"core.date_format.html_yearless_date\";}'),('config.entity.key_store.date_format','uuid:205997a0-85e2-480b-afbf-364040dbe3a0',_binary 'a:1:{i:0;s:22:\"core.date_format.short\";}'),('config.entity.key_store.date_format','uuid:57191129-5da9-459f-b5cb-e31c471cbf54',_binary 'a:1:{i:0;s:21:\"core.date_format.long\";}'),('config.entity.key_store.date_format','uuid:78cb7097-519a-4d33-a9cf-890f946cd1b7',_binary 'a:1:{i:0;s:30:\"core.date_format.html_datetime\";}'),('config.entity.key_store.date_format','uuid:bc061bc9-c166-47f3-be0f-abbba94af1dc',_binary 'a:1:{i:0;s:27:\"core.date_format.html_month\";}'),('config.entity.key_store.date_format','uuid:cc1685f0-a1bc-49c4-b22f-ecaeb8a7a384',_binary 'a:1:{i:0;s:26:\"core.date_format.html_time\";}'),('config.entity.key_store.date_format','uuid:d367ac3c-4ca1-4026-a47e-4817dc8c2511',_binary 'a:1:{i:0;s:25:\"core.date_format.fallback\";}'),('config.entity.key_store.date_format','uuid:d3f418c7-8741-4033-8fcb-48c7f8608816',_binary 'a:1:{i:0;s:26:\"core.date_format.html_week\";}'),('config.entity.key_store.editor','uuid:714302b5-b69b-48c9-822c-6906b789be66',_binary 'a:1:{i:0;s:24:\"editor.editor.basic_html\";}'),('config.entity.key_store.editor','uuid:7a68f2fe-d2c4-467b-94db-f1b3c98a4c4e',_binary 'a:1:{i:0;s:23:\"editor.editor.full_html\";}'),('config.entity.key_store.editor','uuid:b83f2eef-227c-4316-9376-0182174cb48a',_binary 'a:1:{i:0;s:29:\"editor.editor.webform_default\";}'),('config.entity.key_store.entity_form_display','uuid:39076dd4-f606-4559-8e09-9c4076a6a9a0',_binary 'a:1:{i:0;s:45:\"core.entity_form_display.node.article.default\";}'),('config.entity.key_store.entity_form_display','uuid:8052ad9d-9ad8-4d4f-a2cc-01b3312dbac3',_binary 'a:1:{i:0;s:42:\"core.entity_form_display.node.page.default\";}'),('config.entity.key_store.entity_form_display','uuid:885ef637-ecc7-404d-98d6-f886bae2a7dc',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.block_content.basic.default\";}'),('config.entity.key_store.entity_form_display','uuid:8b44064a-21df-44c2-bc70-8583a0b6d00f',_binary 'a:1:{i:0;s:42:\"core.entity_form_display.user.user.default\";}'),('config.entity.key_store.entity_form_display','uuid:915f5663-37e7-48c1-877a-dd2574a2366c',_binary 'a:1:{i:0;s:48:\"core.entity_form_display.comment.comment.default\";}'),('config.entity.key_store.entity_form_display','uuid:ffb66cab-c432-432a-9abe-556ec76c9de4',_binary 'a:1:{i:0;s:45:\"core.entity_form_display.node.webform.default\";}'),('config.entity.key_store.entity_form_mode','uuid:5d33687a-c0b1-4d5d-96a5-9b558b4d62ae',_binary 'a:1:{i:0;s:35:\"core.entity_form_mode.user.register\";}'),('config.entity.key_store.entity_view_display','uuid:01eed67b-49a4-45a7-81f3-7be9338dca46',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.block_content.basic.default\";}'),('config.entity.key_store.entity_view_display','uuid:0c236e6a-27ce-4c19-8e5a-126cde1d65fb',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.node.article.teaser\";}'),('config.entity.key_store.entity_view_display','uuid:227a1b86-49df-47ac-8efe-562bcf176cd2',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.user.user.default\";}'),('config.entity.key_store.entity_view_display','uuid:4690aa2b-761f-4e63-b494-b09f2bffff83',_binary 'a:1:{i:0;s:41:\"core.entity_view_display.node.page.teaser\";}'),('config.entity.key_store.entity_view_display','uuid:58b778bb-172e-472d-b9f5-17c920bb4232',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.node.webform.teaser\";}'),('config.entity.key_store.entity_view_display','uuid:5932e0d4-d732-487d-a85d-b8314a5b32ce',_binary 'a:1:{i:0;s:48:\"core.entity_view_display.comment.comment.default\";}'),('config.entity.key_store.entity_view_display','uuid:5f4e9c64-9f98-4d2c-a273-044234fb3a37',_binary 'a:1:{i:0;s:45:\"core.entity_view_display.node.webform.default\";}'),('config.entity.key_store.entity_view_display','uuid:a22a500a-58f5-443b-895c-dd210187a86d',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.user.user.compact\";}'),('config.entity.key_store.entity_view_display','uuid:a31296e3-ecfb-448f-8fcc-077d53a3e7f7',_binary 'a:1:{i:0;s:41:\"core.entity_view_display.node.article.rss\";}'),('config.entity.key_store.entity_view_display','uuid:d5d627a7-d4a0-4cf7-9ee0-b7946878aa35',_binary 'a:1:{i:0;s:45:\"core.entity_view_display.node.article.default\";}'),('config.entity.key_store.entity_view_display','uuid:f5cc614c-3972-4b19-aa5e-f5ffad215f88',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.node.page.default\";}'),('config.entity.key_store.entity_view_mode','uuid:1c9bd81e-6e7c-4441-a47e-1c1a8944e0c5',_binary 'a:1:{i:0;s:36:\"core.entity_view_mode.shortcut.token\";}'),('config.entity.key_store.entity_view_mode','uuid:1e54deca-38ff-416c-86d0-eed69eedefd0',_binary 'a:1:{i:0;s:39:\"core.entity_view_mode.node.search_index\";}'),('config.entity.key_store.entity_view_mode','uuid:4f67af00-60de-4117-81cf-5679ade2ddcc',_binary 'a:1:{i:0;s:34:\"core.entity_view_mode.user.compact\";}'),('config.entity.key_store.entity_view_mode','uuid:4f6c41a4-657c-42fd-8268-276a87df9731',_binary 'a:1:{i:0;s:35:\"core.entity_view_mode.comment.token\";}'),('config.entity.key_store.entity_view_mode','uuid:5d4499b8-9506-49e9-85b4-3d93fe61d4f8',_binary 'a:1:{i:0;s:43:\"core.entity_view_mode.contact_message.token\";}'),('config.entity.key_store.entity_view_mode','uuid:6107c823-b21d-4d0f-b5d3-e1c2151d15fb',_binary 'a:1:{i:0;s:31:\"core.entity_view_mode.user.full\";}'),('config.entity.key_store.entity_view_mode','uuid:66378eb1-2d94-4ea0-9430-7d3725ba07de',_binary 'a:1:{i:0;s:41:\"core.entity_view_mode.taxonomy_term.token\";}'),('config.entity.key_store.entity_view_mode','uuid:72737862-d3bd-415c-8ab6-4c512f6678f4',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.block_content.full\";}'),('config.entity.key_store.entity_view_mode','uuid:84e1094d-b40c-4dd6-82a6-a75eb1250270',_binary 'a:1:{i:0;s:31:\"core.entity_view_mode.node.full\";}'),('config.entity.key_store.entity_view_mode','uuid:8617e7ab-2c6e-478b-ab0a-552ff354eeab',_binary 'a:1:{i:0;s:34:\"core.entity_view_mode.comment.full\";}'),('config.entity.key_store.entity_view_mode','uuid:86727042-5ea2-41bc-927d-32de67fe734d',_binary 'a:1:{i:0;s:31:\"core.entity_view_mode.node.diff\";}'),('config.entity.key_store.entity_view_mode','uuid:8f4a1fcd-6a35-47e7-bb3e-0ba29c104629',_binary 'a:1:{i:0;s:30:\"core.entity_view_mode.node.rss\";}'),('config.entity.key_store.entity_view_mode','uuid:8fe537b9-59a2-4e02-9c75-17d825a2e09c',_binary 'a:1:{i:0;s:32:\"core.entity_view_mode.node.token\";}'),('config.entity.key_store.entity_view_mode','uuid:abbbcbe6-fbc2-4032-b329-faa7fe4fab0f',_binary 'a:1:{i:0;s:32:\"core.entity_view_mode.user.token\";}'),('config.entity.key_store.entity_view_mode','uuid:b250be27-e5ae-4b0b-845e-171e9a9517cd',_binary 'a:1:{i:0;s:33:\"core.entity_view_mode.block.token\";}'),('config.entity.key_store.entity_view_mode','uuid:cd3bc5d6-a185-496e-bd75-7b418012951a',_binary 'a:1:{i:0;s:38:\"core.entity_view_mode.path_alias.token\";}'),('config.entity.key_store.entity_view_mode','uuid:cd3c6575-783d-4a1a-ac9c-8adaf1c76f8a',_binary 'a:1:{i:0;s:32:\"core.entity_view_mode.file.token\";}'),('config.entity.key_store.entity_view_mode','uuid:cddf0fac-c858-4a6c-8a52-8e5be3324d15',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.taxonomy_term.full\";}'),('config.entity.key_store.entity_view_mode','uuid:d3afe08d-7024-4fa1-bf4a-2bdc2b459c34',_binary 'a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}'),('config.entity.key_store.entity_view_mode','uuid:e1026fe1-359d-41cf-8422-735c2c858db2',_binary 'a:1:{i:0;s:45:\"core.entity_view_mode.menu_link_content.token\";}'),('config.entity.key_store.entity_view_mode','uuid:e7c3d152-d1b1-47fa-949d-6aac95fd9f43',_binary 'a:1:{i:0;s:41:\"core.entity_view_mode.block_content.token\";}'),('config.entity.key_store.entity_view_mode','uuid:fc474d30-f444-421a-ab7a-40651906ebc2',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.node.search_result\";}'),('config.entity.key_store.field_config','uuid:14afe9f8-2fd1-40c6-b8d8-e5d9dcb2b2aa',_binary 'a:1:{i:0;s:26:\"field.field.node.page.body\";}'),('config.entity.key_store.field_config','uuid:22aaedcb-09db-4794-9acb-2becd13a2e0d',_binary 'a:1:{i:0;s:29:\"field.field.node.webform.body\";}'),('config.entity.key_store.field_config','uuid:2765f954-a749-4676-a2b3-63be8c7d3800',_binary 'a:1:{i:0;s:34:\"field.field.user.user.user_picture\";}'),('config.entity.key_store.field_config','uuid:66f77a78-8dbc-42dd-865d-64c9d97497e5',_binary 'a:1:{i:0;s:36:\"field.field.block_content.basic.body\";}'),('config.entity.key_store.field_config','uuid:8301f478-2242-4c70-95e1-e38295e4c668',_binary 'a:1:{i:0;s:35:\"field.field.node.article.field_tags\";}'),('config.entity.key_store.field_config','uuid:85d0b6cd-cb9e-43f0-b97a-097bc7bfb2ec',_binary 'a:1:{i:0;s:40:\"field.field.comment.comment.comment_body\";}'),('config.entity.key_store.field_config','uuid:a821c784-0c14-4d95-afe8-b3870cea2d6b',_binary 'a:1:{i:0;s:36:\"field.field.node.article.field_image\";}'),('config.entity.key_store.field_config','uuid:cc7f6f2e-82c2-41b5-9e91-ef9ffdf8558b',_binary 'a:1:{i:0;s:32:\"field.field.node.webform.webform\";}'),('config.entity.key_store.field_config','uuid:e8e918f3-0065-4fba-bab0-bbf3f9012680',_binary 'a:1:{i:0;s:29:\"field.field.node.article.body\";}'),('config.entity.key_store.field_config','uuid:fbcc6ac8-045f-46f3-9c69-215e5aee20fe',_binary 'a:1:{i:0;s:32:\"field.field.node.article.comment\";}'),('config.entity.key_store.field_storage_config','uuid:2e760d93-d8f1-4cc0-a846-8a1be50ab6b9',_binary 'a:1:{i:0;s:30:\"field.storage.node.field_image\";}'),('config.entity.key_store.field_storage_config','uuid:81b92d69-01d7-4755-b08e-038fae9ed965',_binary 'a:1:{i:0;s:29:\"field.storage.node.field_tags\";}'),('config.entity.key_store.field_storage_config','uuid:8a930e87-45e4-410a-af3d-198c8f27a1a8',_binary 'a:1:{i:0;s:23:\"field.storage.node.body\";}'),('config.entity.key_store.field_storage_config','uuid:ac53f9a6-7651-4e31-83f3-63793c128360',_binary 'a:1:{i:0;s:32:\"field.storage.block_content.body\";}'),('config.entity.key_store.field_storage_config','uuid:ad237af2-b5d3-4fac-8674-82493f95d005',_binary 'a:1:{i:0;s:26:\"field.storage.node.webform\";}'),('config.entity.key_store.field_storage_config','uuid:d8ddfd2c-c777-440f-a0e1-ce7cea17d4dd',_binary 'a:1:{i:0;s:26:\"field.storage.node.comment\";}'),('config.entity.key_store.field_storage_config','uuid:dfa0301c-438e-4abc-a17f-d0d555a64089',_binary 'a:1:{i:0;s:31:\"field.storage.user.user_picture\";}'),('config.entity.key_store.field_storage_config','uuid:e5ee7b1b-bd81-4fd0-af67-f92e6bae8313',_binary 'a:1:{i:0;s:34:\"field.storage.comment.comment_body\";}'),('config.entity.key_store.filter_format','uuid:150b0210-ca67-4d68-8a96-47161c6734ef',_binary 'a:1:{i:0;s:29:\"filter.format.restricted_html\";}'),('config.entity.key_store.filter_format','uuid:4116e91f-e5fa-4a37-942f-11ab8d868828',_binary 'a:1:{i:0;s:23:\"filter.format.full_html\";}'),('config.entity.key_store.filter_format','uuid:568418de-cc1f-4161-bfd4-806e6cda5041',_binary 'a:1:{i:0;s:24:\"filter.format.basic_html\";}'),('config.entity.key_store.filter_format','uuid:7e21f965-39b3-4af0-bca5-32809fcc5e3b',_binary 'a:1:{i:0;s:29:\"filter.format.webform_default\";}'),('config.entity.key_store.filter_format','uuid:d6c89fdd-daf5-43dd-8fd3-2de981a4e2c3',_binary 'a:1:{i:0;s:24:\"filter.format.plain_text\";}'),('config.entity.key_store.image_style','uuid:1bf69c20-6eff-4470-93d3-bae2dc31f207',_binary 'a:1:{i:0;s:18:\"image.style.medium\";}'),('config.entity.key_store.image_style','uuid:29940d30-64d8-4da8-9c82-a253f2d27667',_binary 'a:1:{i:0;s:17:\"image.style.large\";}'),('config.entity.key_store.image_style','uuid:3375957d-2d6c-475c-bc6b-124e63c6164a',_binary 'a:1:{i:0;s:21:\"image.style.thumbnail\";}'),('config.entity.key_store.image_style','uuid:6eea7178-ad4d-464d-90a5-16d53236deb2',_binary 'a:1:{i:0;s:35:\"image.style.linkit_result_thumbnail\";}'),('config.entity.key_store.image_style','uuid:b652d976-a322-4aa9-9474-2415078a63e8',_binary 'a:1:{i:0;s:16:\"image.style.wide\";}'),('config.entity.key_store.language_content_settings','uuid:255480ac-2d85-450d-ba7f-1f49e3d9b8b6',_binary 'a:1:{i:0;s:47:\"language.content_settings.path_alias.path_alias\";}'),('config.entity.key_store.language_content_settings','uuid:8cc7a8b1-2dde-4238-aad8-64e49400f338',_binary 'a:1:{i:0;s:43:\"language.content_settings.redirect.redirect\";}'),('config.entity.key_store.linkit_profile','uuid:24222d7c-50f5-45f4-8a23-489ca365134d',_binary 'a:1:{i:0;s:29:\"linkit.linkit_profile.default\";}'),('config.entity.key_store.menu','uuid:3762582d-2630-48d8-ab96-b29392c1a26a',_binary 'a:1:{i:0;s:16:\"system.menu.main\";}'),('config.entity.key_store.menu','uuid:7cb08dc9-4331-47ba-a3ad-aac0e10c8e7c',_binary 'a:1:{i:0;s:18:\"system.menu.footer\";}'),('config.entity.key_store.menu','uuid:820b8378-aa9a-4e15-bbdf-809cea9e6a97',_binary 'a:1:{i:0;s:17:\"system.menu.admin\";}'),('config.entity.key_store.menu','uuid:b61fcb8a-ca27-4780-86d8-575615409f31',_binary 'a:1:{i:0;s:17:\"system.menu.tools\";}'),('config.entity.key_store.menu','uuid:b8440982-72a9-44aa-afc8-0c3d14b807bd',_binary 'a:1:{i:0;s:19:\"system.menu.account\";}'),('config.entity.key_store.metatag_defaults','uuid:aa7a542d-baa7-40ad-afc6-49bb56062750',_binary 'a:1:{i:0;s:28:\"metatag.metatag_defaults.403\";}'),('config.entity.key_store.metatag_defaults','uuid:b8863b10-cb33-4649-8d52-ceac3c926829',_binary 'a:1:{i:0;s:29:\"metatag.metatag_defaults.user\";}'),('config.entity.key_store.metatag_defaults','uuid:c52f9ced-fccb-43cb-9fe2-a8040eb13542',_binary 'a:1:{i:0;s:30:\"metatag.metatag_defaults.front\";}'),('config.entity.key_store.metatag_defaults','uuid:cf9933a3-28ef-476d-9838-4a92e3eeb1fe',_binary 'a:1:{i:0;s:28:\"metatag.metatag_defaults.404\";}'),('config.entity.key_store.metatag_defaults','uuid:d237fb3f-9063-48b4-82ba-1dfe13df5594',_binary 'a:1:{i:0;s:38:\"metatag.metatag_defaults.taxonomy_term\";}'),('config.entity.key_store.metatag_defaults','uuid:d7d2466e-ab6f-4c1b-a923-ca531f2fa600',_binary 'a:1:{i:0;s:29:\"metatag.metatag_defaults.node\";}'),('config.entity.key_store.metatag_defaults','uuid:fa0b3dbf-4333-431d-8522-9036aea72657',_binary 'a:1:{i:0;s:31:\"metatag.metatag_defaults.global\";}'),('config.entity.key_store.node_type','uuid:59988f5b-edd5-420c-9c7c-ec760037efc2',_binary 'a:1:{i:0;s:17:\"node.type.article\";}'),('config.entity.key_store.node_type','uuid:f4c4b6bf-cd51-4c75-a261-fd038e87f35d',_binary 'a:1:{i:0;s:14:\"node.type.page\";}'),('config.entity.key_store.node_type','uuid:f6f57731-a98c-4930-9cb9-50e4bbe5c135',_binary 'a:1:{i:0;s:17:\"node.type.webform\";}'),('config.entity.key_store.pathauto_pattern','status:1',_binary 'a:2:{i:0;s:27:\"pathauto.pattern.basic_page\";i:1;s:24:\"pathauto.pattern.article\";}'),('config.entity.key_store.pathauto_pattern','type:canonical_entities:node',_binary 'a:2:{i:0;s:27:\"pathauto.pattern.basic_page\";i:1;s:24:\"pathauto.pattern.article\";}'),('config.entity.key_store.pathauto_pattern','uuid:831fa73e-f731-4650-a164-eec6143af109',_binary 'a:1:{i:0;s:27:\"pathauto.pattern.basic_page\";}'),('config.entity.key_store.pathauto_pattern','uuid:8b4b8af3-f1de-4297-b432-2332d9ae25f2',_binary 'a:1:{i:0;s:24:\"pathauto.pattern.article\";}'),('config.entity.key_store.rest_resource_config','uuid:2f7011ea-42d4-4e84-9783-ecb872c2e2e1',_binary 'a:1:{i:0;s:33:\"rest.resource.webform_rest_submit\";}'),('config.entity.key_store.rest_resource_config','uuid:938e4e98-191f-4790-bc0b-9a8a5d6cc7c0',_binary 'a:1:{i:0;s:36:\"rest.resource.entity.webform_options\";}'),('config.entity.key_store.rest_resource_config','uuid:bef3799e-1ae8-4704-8d0f-a73fe64c4f33',_binary 'a:1:{i:0;s:28:\"rest.resource.entity.webform\";}'),('config.entity.key_store.rest_resource_config','uuid:d320e37f-6fd5-4580-9cfe-3dcd1ff080cc',_binary 'a:1:{i:0;s:35:\"rest.resource.webform_rest_elements\";}'),('config.entity.key_store.shortcut_set','uuid:903954a5-8548-48e0-9cb6-eec525501eed',_binary 'a:1:{i:0;s:20:\"shortcut.set.default\";}'),('config.entity.key_store.simple_sitemap','uuid:38c791a5-1548-4677-810e-c994dd439795',_binary 'a:1:{i:0;s:30:\"simple_sitemap.sitemap.default\";}'),('config.entity.key_store.simple_sitemap','uuid:d0b3a005-f27b-40db-a375-17c6125c3e08',_binary 'a:1:{i:0;s:28:\"simple_sitemap.sitemap.index\";}'),('config.entity.key_store.simple_sitemap_type','uuid:39c7fcad-3c78-4c1d-9e97-a160469913a4',_binary 'a:1:{i:0;s:25:\"simple_sitemap.type.index\";}'),('config.entity.key_store.simple_sitemap_type','uuid:87a31fbb-d316-4031-9da8-27a78f161b1e',_binary 'a:1:{i:0;s:36:\"simple_sitemap.type.default_hreflang\";}'),('config.entity.key_store.taxonomy_vocabulary','uuid:6d3544ef-5124-4a14-88e1-ce69ad1016dc',_binary 'a:1:{i:0;s:24:\"taxonomy.vocabulary.tags\";}'),('config.entity.key_store.user_role','uuid:02e47401-b1fc-4d8a-9928-a86f0f8611ce',_binary 'a:1:{i:0;s:23:\"user.role.authenticated\";}'),('config.entity.key_store.user_role','uuid:6eb8a031-0e43-4c9d-af8a-e9962b82903a',_binary 'a:1:{i:0;s:23:\"user.role.administrator\";}'),('config.entity.key_store.user_role','uuid:d281cf36-4128-465b-8870-56e1ab0fac55',_binary 'a:1:{i:0;s:19:\"user.role.anonymous\";}'),('config.entity.key_store.user_role','uuid:d3ede7c1-114f-4c1a-bda4-af6f0b80e54e',_binary 'a:1:{i:0;s:24:\"user.role.content_editor\";}'),('config.entity.key_store.view','uuid:2d64aef5-17f8-4af2-993d-4766096aeca3',_binary 'a:1:{i:0;s:20:\"views.view.who_s_new\";}'),('config.entity.key_store.view','uuid:411c53b7-69dc-4ed5-b1d4-84bafe5b08c5',_binary 'a:1:{i:0;s:18:\"views.view.content\";}'),('config.entity.key_store.view','uuid:46b6645e-44b7-437f-a3b8-23ad0c31cce9',_binary 'a:1:{i:0;s:23:\"views.view.who_s_online\";}'),('config.entity.key_store.view','uuid:612a6feb-f41d-4b4d-8eda-dc2fb8df706f',_binary 'a:1:{i:0;s:24:\"views.view.taxonomy_term\";}'),('config.entity.key_store.view','uuid:6346d08f-a177-4e83-a747-6b308aa63315',_binary 'a:1:{i:0;s:26:\"views.view.comments_recent\";}'),('config.entity.key_store.view','uuid:64aae2b3-26a1-4bfc-ac1f-04aeec606c61',_binary 'a:1:{i:0;s:18:\"views.view.archive\";}'),('config.entity.key_store.view','uuid:64bc6974-4eb3-4942-b516-db108a373cea',_binary 'a:1:{i:0;s:19:\"views.view.redirect\";}'),('config.entity.key_store.view','uuid:6660456c-c025-42e0-94a2-7e6daffa6992',_binary 'a:1:{i:0;s:19:\"views.view.glossary\";}'),('config.entity.key_store.view','uuid:6abb021b-7e65-4890-9172-d2d762cc0396',_binary 'a:1:{i:0;s:28:\"views.view.user_admin_people\";}'),('config.entity.key_store.view','uuid:76b82b04-b93f-4522-a84c-7c06e72ca046',_binary 'a:1:{i:0;s:19:\"views.view.watchdog\";}'),('config.entity.key_store.view','uuid:94d1a705-2830-41cf-9d68-7f6f7cf4bf6c',_binary 'a:1:{i:0;s:25:\"views.view.content_recent\";}'),('config.entity.key_store.view','uuid:af87d0b4-0ac9-4106-a4aa-935bef82b793',_binary 'a:1:{i:0;s:18:\"views.view.comment\";}'),('config.entity.key_store.view','uuid:b4c93afb-55bd-4d60-9f83-9f1d440c911a',_binary 'a:1:{i:0;s:24:\"views.view.block_content\";}'),('config.entity.key_store.view','uuid:ba1d2200-30f3-40f8-a597-b4f370e813e2',_binary 'a:1:{i:0;s:20:\"views.view.frontpage\";}'),('config.entity.key_store.view','uuid:ca1f0b7a-286d-4a9a-9741-13d1f2ff8c31',_binary 'a:1:{i:0;s:16:\"views.view.files\";}'),('config.entity.key_store.view','uuid:d30db33d-ecb9-4776-91cd-2d54f2f7a15c',_binary 'a:1:{i:0;s:30:\"views.view.webform_submissions\";}'),('config.entity.key_store.webform','status:open',_binary 'a:1:{i:0;s:23:\"webform.webform.contact\";}'),('config.entity.key_store.webform','template:',_binary 'a:1:{i:0;s:23:\"webform.webform.contact\";}'),('config.entity.key_store.webform','uuid:4908a4d9-be76-4f30-a75c-c3ba00e0be48',_binary 'a:1:{i:0;s:23:\"webform.webform.contact\";}'),('config.entity.key_store.webform','uuid:f815005f-42fe-4d84-a6aa-7c6f08223a9c',_binary 'a:1:{i:0;s:23:\"webform.webform.contact\";}'),('config.entity.key_store.webform_options','uuid:052b2071-a7ca-48a1-b511-cf26c5c28801',_binary 'a:1:{i:0;s:27:\"webform.webform_options.sex\";}'),('config.entity.key_store.webform_options','uuid:05fc358f-135e-4f8d-8e30-9bde5b4e34d8',_binary 'a:1:{i:0;s:33:\"webform.webform_options.languages\";}'),('config.entity.key_store.webform_options','uuid:089cc8c2-e03c-4037-8c71-943e546c5e2b',_binary 'a:1:{i:0;s:30:\"webform.webform_options.titles\";}'),('config.entity.key_store.webform_options','uuid:0b914fae-9fd3-4903-8774-8c355aa91632',_binary 'a:1:{i:0;s:32:\"webform.webform_options.sex_icao\";}'),('config.entity.key_store.webform_options','uuid:194e3bca-f825-484d-9ef7-ef47413ae8f6',_binary 'a:1:{i:0;s:41:\"webform.webform_options.likert_comparison\";}'),('config.entity.key_store.webform_options','uuid:1fe70683-0043-4cbe-98c7-1a7110e4362d',_binary 'a:1:{i:0;s:33:\"webform.webform_options.ethnicity\";}'),('config.entity.key_store.webform_options','uuid:2141569b-1460-424e-9f43-303b2a435e45',_binary 'a:1:{i:0;s:35:\"webform.webform_options.state_names\";}'),('config.entity.key_store.webform_options','uuid:2160769c-f93c-45f7-b28e-52d800ec51c2',_binary 'a:1:{i:0;s:30:\"webform.webform_options.months\";}'),('config.entity.key_store.webform_options','uuid:25e89052-97e8-4c50-9e64-94e728ffc00f',_binary 'a:1:{i:0;s:35:\"webform.webform_options.state_names\";}'),('config.entity.key_store.webform_options','uuid:26a80f5e-c29e-4eee-9918-eefc2b54b8ee',_binary 'a:1:{i:0;s:38:\"webform.webform_options.province_names\";}'),('config.entity.key_store.webform_options','uuid:291c60c8-5109-4209-b98d-ab6dc2425dc0',_binary 'a:1:{i:0;s:37:\"webform.webform_options.country_codes\";}'),('config.entity.key_store.webform_options','uuid:305cd3e2-822b-4eaa-bd11-a40a393d4927',_binary 'a:1:{i:0;s:38:\"webform.webform_options.province_names\";}'),('config.entity.key_store.webform_options','uuid:376922ad-3508-4a61-a2f1-d152396229d2',_binary 'a:1:{i:0;s:32:\"webform.webform_options.sex_icao\";}'),('config.entity.key_store.webform_options','uuid:37f4e449-25ce-4087-b102-956d0b3bea7a',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_would_you\";}'),('config.entity.key_store.webform_options','uuid:3e23d906-eeea-4c78-a29f-a37b82dbf616',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_would_you\";}'),('config.entity.key_store.webform_options','uuid:40df7705-cac9-4dd3-9fdc-657289936b21',_binary 'a:1:{i:0;s:38:\"webform.webform_options.marital_status\";}'),('config.entity.key_store.webform_options','uuid:430ba6dc-e989-4104-81a2-731e98ece9e3',_binary 'a:1:{i:0;s:37:\"webform.webform_options.country_names\";}'),('config.entity.key_store.webform_options','uuid:4831f1f3-5fb7-468e-9c1e-f4ac2eba80cb',_binary 'a:1:{i:0;s:30:\"webform.webform_options.months\";}'),('config.entity.key_store.webform_options','uuid:4b00255b-b5a2-4059-b745-6116b291fab5',_binary 'a:1:{i:0;s:28:\"webform.webform_options.days\";}'),('config.entity.key_store.webform_options','uuid:4b54517f-8140-433c-a2da-ff5152cec079',_binary 'a:1:{i:0;s:38:\"webform.webform_options.likert_quality\";}'),('config.entity.key_store.webform_options','uuid:55b97337-72c4-4f25-bd44-ea059fa0c1f8',_binary 'a:1:{i:0;s:41:\"webform.webform_options.likert_importance\";}'),('config.entity.key_store.webform_options','uuid:57c15eda-3b17-4962-b473-9d4307b3d9a3',_binary 'a:1:{i:0;s:30:\"webform.webform_options.yes_no\";}'),('config.entity.key_store.webform_options','uuid:595af078-ff40-4b8f-a59c-c9b5622dbc65',_binary 'a:1:{i:0;s:38:\"webform.webform_options.province_codes\";}'),('config.entity.key_store.webform_options','uuid:5e37e7eb-ff08-45c7-9973-7f39a49fc6b9',_binary 'a:1:{i:0;s:34:\"webform.webform_options.time_zones\";}'),('config.entity.key_store.webform_options','uuid:5e9987f1-71cd-4573-88c0-ff0fc33fe873',_binary 'a:1:{i:0;s:36:\"webform.webform_options.relationship\";}'),('config.entity.key_store.webform_options','uuid:63442eac-e571-4c5b-a52d-8059e3f2a1dc',_binary 'a:1:{i:0;s:43:\"webform.webform_options.likert_satisfaction\";}'),('config.entity.key_store.webform_options','uuid:643bdc9b-5248-4eee-8aec-d9a4ea9ff993',_binary 'a:1:{i:0;s:35:\"webform.webform_options.phone_types\";}'),('config.entity.key_store.webform_options','uuid:67011573-341a-4e22-893d-6fbff6623594',_binary 'a:1:{i:0;s:38:\"webform.webform_options.marital_status\";}'),('config.entity.key_store.webform_options','uuid:6b9fbab8-7082-4f33-903d-44c1c725d64f',_binary 'a:1:{i:0;s:30:\"webform.webform_options.yes_no\";}'),('config.entity.key_store.webform_options','uuid:6e7a0384-f89e-4ad5-87b9-0a6f41301026',_binary 'a:1:{i:0;s:38:\"webform.webform_options.likert_quality\";}'),('config.entity.key_store.webform_options','uuid:746ced30-46e2-441f-bdf3-e9f7f17bff76',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_ten_scale\";}'),('config.entity.key_store.webform_options','uuid:7bfff7f2-a3a8-43cb-b43d-f5a21cca6ebb',_binary 'a:1:{i:0;s:30:\"webform.webform_options.gender\";}'),('config.entity.key_store.webform_options','uuid:7e10aa90-9257-4dcb-ab3c-279977df1f5f',_binary 'a:1:{i:0;s:37:\"webform.webform_options.country_codes\";}'),('config.entity.key_store.webform_options','uuid:82d7e2f4-fb87-4c81-a5f3-0dd704eee27f',_binary 'a:1:{i:0;s:35:\"webform.webform_options.state_codes\";}'),('config.entity.key_store.webform_options','uuid:837c888f-46bd-4a04-8f99-cf5698404d99',_binary 'a:1:{i:0;s:28:\"webform.webform_options.days\";}'),('config.entity.key_store.webform_options','uuid:873e0b5c-ef9b-44d2-96cd-bbc6df5b2292',_binary 'a:1:{i:0;s:32:\"webform.webform_options.industry\";}'),('config.entity.key_store.webform_options','uuid:89588176-7f35-448f-8509-765488c8a4d3',_binary 'a:1:{i:0;s:38:\"webform.webform_options.province_codes\";}'),('config.entity.key_store.webform_options','uuid:93ade06e-58d8-4139-8417-d050228586a1',_binary 'a:1:{i:0;s:33:\"webform.webform_options.education\";}'),('config.entity.key_store.webform_options','uuid:95a86930-8c84-4d30-8c47-9b5513752ab6',_binary 'a:1:{i:0;s:34:\"webform.webform_options.time_zones\";}'),('config.entity.key_store.webform_options','uuid:9a7684a9-4d86-4854-8946-95f898aa904a',_binary 'a:1:{i:0;s:44:\"webform.webform_options.state_province_names\";}'),('config.entity.key_store.webform_options','uuid:9acfc8f0-9331-433b-b105-36daa7c0f2db',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_agreement\";}'),('config.entity.key_store.webform_options','uuid:9cd4c79a-3b94-407b-9fa4-8297ddcf7f4b',_binary 'a:1:{i:0;s:33:\"webform.webform_options.languages\";}'),('config.entity.key_store.webform_options','uuid:9edeebb2-438e-4f2c-8c3f-3c1b8e236247',_binary 'a:1:{i:0;s:33:\"webform.webform_options.education\";}'),('config.entity.key_store.webform_options','uuid:a3be9802-18d3-4d31-8772-578d379e2c0b',_binary 'a:1:{i:0;s:37:\"webform.webform_options.country_names\";}'),('config.entity.key_store.webform_options','uuid:a5a2c63d-4d85-4d98-88c2-968098e209f8',_binary 'a:1:{i:0;s:36:\"webform.webform_options.translations\";}'),('config.entity.key_store.webform_options','uuid:a9a87b23-caa2-4b05-818b-613937d0d0fe',_binary 'a:1:{i:0;s:27:\"webform.webform_options.sex\";}'),('config.entity.key_store.webform_options','uuid:accbbb74-6855-4d35-89ef-aaf806d9fddf',_binary 'a:1:{i:0;s:30:\"webform.webform_options.gender\";}'),('config.entity.key_store.webform_options','uuid:b2213b8f-e823-4c5e-b499-d4038b994f1a',_binary 'a:1:{i:0;s:35:\"webform.webform_options.state_codes\";}'),('config.entity.key_store.webform_options','uuid:b3f9da96-6241-4951-994d-2a00fc66b8e3',_binary 'a:1:{i:0;s:41:\"webform.webform_options.likert_importance\";}'),('config.entity.key_store.webform_options','uuid:bf77360d-2ee5-4057-94df-b64936a0e9c0',_binary 'a:1:{i:0;s:30:\"webform.webform_options.titles\";}'),('config.entity.key_store.webform_options','uuid:c05e7ce1-8d8c-4fe2-ad87-51fb46a4fa7c',_binary 'a:1:{i:0;s:41:\"webform.webform_options.likert_comparison\";}'),('config.entity.key_store.webform_options','uuid:c40ca50d-cb7b-48fb-a60b-1f8bc689d053',_binary 'a:1:{i:0;s:44:\"webform.webform_options.state_province_codes\";}'),('config.entity.key_store.webform_options','uuid:c5a0c3d0-00d1-4e7a-82bd-38a69656f42a',_binary 'a:1:{i:0;s:36:\"webform.webform_options.translations\";}'),('config.entity.key_store.webform_options','uuid:c671c93b-871e-49ba-964c-d0fe4ad73550',_binary 'a:1:{i:0;s:28:\"webform.webform_options.size\";}'),('config.entity.key_store.webform_options','uuid:cff7754e-905c-4ee7-916d-51863211ea47',_binary 'a:1:{i:0;s:33:\"webform.webform_options.ethnicity\";}'),('config.entity.key_store.webform_options','uuid:d0340bdd-b820-4427-8e6e-a55eca2f56e4',_binary 'a:1:{i:0;s:28:\"webform.webform_options.size\";}'),('config.entity.key_store.webform_options','uuid:e52c5b0d-4f4e-4ea8-b30c-9f53646066c4',_binary 'a:1:{i:0;s:43:\"webform.webform_options.likert_satisfaction\";}'),('config.entity.key_store.webform_options','uuid:e7d35339-5044-42d3-9c89-6bcf4c7b3f86',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_agreement\";}'),('config.entity.key_store.webform_options','uuid:ea84bfcf-e9b1-47e7-ac33-c7743aa2ccae',_binary 'a:1:{i:0;s:44:\"webform.webform_options.state_province_codes\";}'),('config.entity.key_store.webform_options','uuid:ede08b1a-9f0a-4e51-bb56-baa6f6edc279',_binary 'a:1:{i:0;s:35:\"webform.webform_options.phone_types\";}'),('config.entity.key_store.webform_options','uuid:ef34588e-d73a-47c0-88dc-03457e055017',_binary 'a:1:{i:0;s:41:\"webform.webform_options.employment_status\";}'),('config.entity.key_store.webform_options','uuid:ef797d85-3f16-44c7-a25b-d7064cf27b20',_binary 'a:1:{i:0;s:36:\"webform.webform_options.relationship\";}'),('config.entity.key_store.webform_options','uuid:f757b555-27c8-4894-a589-58863a4bfb38',_binary 'a:1:{i:0;s:44:\"webform.webform_options.state_province_names\";}'),('config.entity.key_store.webform_options','uuid:f9cdebb7-5b4d-4f5b-873e-1d4e461985d9',_binary 'a:1:{i:0;s:40:\"webform.webform_options.likert_ten_scale\";}'),('config.entity.key_store.webform_options','uuid:fb4b79d1-46ed-431a-a9f9-93a58abf2ca8',_binary 'a:1:{i:0;s:41:\"webform.webform_options.employment_status\";}'),('config.entity.key_store.webform_options','uuid:fde6fb59-d642-483a-89e6-a8bf864192e7',_binary 'a:1:{i:0;s:32:\"webform.webform_options.industry\";}'),('entity.definitions.bundle_field_map','block_content',_binary 'a:1:{s:4:\"body\";a:2:{s:4:\"type\";s:17:\"text_with_summary\";s:7:\"bundles\";a:1:{s:5:\"basic\";s:5:\"basic\";}}}'),('entity.definitions.bundle_field_map','comment',_binary 'a:1:{s:12:\"comment_body\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:7:\"comment\";s:7:\"comment\";}}}'),('entity.definitions.bundle_field_map','node',_binary 'a:5:{s:11:\"field_image\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:7:\"comment\";a:2:{s:4:\"type\";s:7:\"comment\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:10:\"field_tags\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:4:\"body\";a:2:{s:4:\"type\";s:17:\"text_with_summary\";s:7:\"bundles\";a:3:{s:4:\"page\";s:4:\"page\";s:7:\"article\";s:7:\"article\";s:7:\"webform\";s:7:\"webform\";}}s:7:\"webform\";a:2:{s:4:\"type\";s:7:\"webform\";s:7:\"bundles\";a:1:{s:7:\"webform\";s:7:\"webform\";}}}'),('entity.definitions.bundle_field_map','user',_binary 'a:1:{s:12:\"user_picture\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:4:\"user\";s:4:\"user\";}}}'),('entity.definitions.installed','action.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:6:\"action\";s:8:\"\0*\0class\";s:27:\"Drupal\\system\\Entity\\Action\";s:11:\"\0*\0provider\";s:6:\"system\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\system\\Entity\\Action\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:18:\"administer actions\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:13:\"@count action\";s:6:\"plural\";s:14:\"@count actions\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"config:action_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"type\";i:3;s:6:\"plugin\";i:4;s:13:\"configuration\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','base_field_override.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"base_field_override\";s:8:\"\0*\0class\";s:42:\"Drupal\\Core\\Field\\Entity\\BaseFieldOverride\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:42:\"Drupal\\Core\\Field\\Entity\\BaseFieldOverride\";s:11:\"\0*\0handlers\";a:2:{s:7:\"storage\";s:42:\"Drupal\\Core\\Field\\BaseFieldOverrideStorage\";s:6:\"access\";s:55:\"Drupal\\Core\\Field\\BaseFieldOverrideAccessControlHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Base field override\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";N;s:17:\"\0*\0label_singular\";N;s:15:\"\0*\0label_plural\";N;s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:base_field_override_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:5:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:6:\"bundle\";i:3;s:10:\"field_name\";i:4;s:10:\"field_type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:19:\"base_field_override\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:6:\"bundle\";i:4;s:5:\"label\";i:5;s:11:\"description\";i:6;s:8:\"required\";i:7;s:12:\"translatable\";i:8;s:13:\"default_value\";i:9;s:22:\"default_value_callback\";i:10;s:8:\"settings\";i:11;s:10:\"field_type\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','behavior_settings.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:17:\"behavior_settings\";s:8:\"\0*\0class\";s:42:\"Drupal\\rabbit_hole\\Entity\\BehaviorSettings\";s:11:\"\0*\0provider\";s:11:\"rabbit_hole\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:12:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"action\";s:6:\"action\";s:14:\"allow_override\";s:14:\"allow_override\";s:8:\"redirect\";s:8:\"redirect\";s:13:\"redirect_code\";s:13:\"redirect_code\";s:24:\"redirect_fallback_action\";s:24:\"redirect_fallback_action\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:42:\"Drupal\\rabbit_hole\\Entity\\BehaviorSettings\";s:11:\"\0*\0handlers\";a:3:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:29:\"administer site configuration\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Rabbit hole settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:29:\"config:behavior_settings_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:17:\"behavior_settings\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:17:\"behavior_settings\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:9:{i:0;s:2:\"id\";i:1;s:14:\"entity_type_id\";i:2;s:9:\"entity_id\";i:3;s:4:\"uuid\";i:4;s:6:\"action\";i:5;s:14:\"allow_override\";i:6;s:8:\"redirect\";i:7;s:13:\"redirect_code\";i:8;s:24:\"redirect_fallback_action\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','block.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:5:\"block\";s:8:\"\0*\0class\";s:25:\"Drupal\\block\\Entity\\Block\";s:11:\"\0*\0provider\";s:5:\"block\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\block\\Entity\\Block\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:38:\"Drupal\\block\\BlockAccessControlHandler\";s:12:\"view_builder\";s:29:\"Drupal\\block\\BlockViewBuilder\";s:12:\"list_builder\";s:29:\"Drupal\\block\\BlockListBuilder\";s:4:\"form\";a:2:{s:7:\"default\";s:22:\"Drupal\\block\\BlockForm\";s:6:\"delete\";s:33:\"Drupal\\block\\Form\\BlockDeleteForm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:17:\"administer blocks\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:44:\"/admin/structure/block/manage/{block}/delete\";s:9:\"edit-form\";s:37:\"/admin/structure/block/manage/{block}\";s:6:\"enable\";s:44:\"/admin/structure/block/manage/{block}/enable\";s:7:\"disable\";s:45:\"/admin/structure/block/manage/{block}/disable\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:12:\"@count block\";s:6:\"plural\";s:13:\"@count blocks\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:17:\"config:block_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:2:{i:0;s:5:\"theme\";i:1;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"theme\";i:2;s:6:\"region\";i:3;s:6:\"weight\";i:4;s:8:\"provider\";i:5;s:6:\"plugin\";i:6;s:8:\"settings\";i:7;s:10:\"visibility\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','block_content.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:13:\"block_content\";s:8:\"\0*\0class\";s:40:\"Drupal\\block_content\\Entity\\BlockContent\";s:11:\"\0*\0provider\";s:13:\"block_content\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:0;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:6:\"bundle\";s:4:\"type\";s:5:\"label\";s:4:\"info\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\block_content\\Entity\\BlockContent\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:14:\"storage_schema\";s:46:\"Drupal\\block_content\\BlockContentStorageSchema\";s:6:\"access\";s:53:\"Drupal\\block_content\\BlockContentAccessControlHandler\";s:12:\"list_builder\";s:44:\"Drupal\\block_content\\BlockContentListBuilder\";s:12:\"view_builder\";s:44:\"Drupal\\block_content\\BlockContentViewBuilder\";s:10:\"views_data\";s:42:\"Drupal\\block_content\\BlockContentViewsData\";s:4:\"form\";a:6:{s:3:\"add\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:4:\"edit\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:6:\"delete\";s:48:\"Drupal\\block_content\\Form\\BlockContentDeleteForm\";s:7:\"default\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:14:\"route_provider\";a:1:{s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}s:11:\"translation\";s:51:\"Drupal\\block_content\\BlockContentTranslationHandler\";}s:19:\"\0*\0admin_permission\";s:24:\"administer block content\";s:24:\"\0*\0collection_permission\";s:20:\"access block library\";s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:8:{s:9:\"canonical\";s:36:\"/admin/content/block/{block_content}\";s:11:\"delete-form\";s:43:\"/admin/content/block/{block_content}/delete\";s:9:\"edit-form\";s:36:\"/admin/content/block/{block_content}\";s:10:\"collection\";s:20:\"/admin/content/block\";s:6:\"create\";s:6:\"/block\";s:20:\"revision-delete-form\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/delete\";s:20:\"revision-revert-form\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/revert\";s:15:\"version-history\";s:46:\"/admin/content/block/{block_content}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:18:\"block_content_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:13:\"block_content\";s:22:\"\0*\0revision_data_table\";s:28:\"block_content_field_revision\";s:17:\"\0*\0revision_table\";s:22:\"block_content_revision\";s:13:\"\0*\0data_table\";s:24:\"block_content_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Content blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"content blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:20:\"@count content block\";s:6:\"plural\";s:21:\"@count content blocks\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:35:\"entity.block_content_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"block_content_list\";}s:14:\"\0*\0constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:25:\"BlockContentEntityChanged\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:12:\"revision_log\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','block_content.field_storage_definitions',_binary 'a:16:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Content block ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"The content block ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The content block UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"The revision ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"The content block language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"The block type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:18:\"block_content_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:155;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:193;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:223;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_log\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The log entry explaining the changes in this revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:12:\"revision_log\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:260;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:302;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"info\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Block description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"A brief description of your block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"info\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:341;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"The time that the content block was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:384;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"reusable\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Reusable\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"A boolean indicating whether this block is reusable.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:0;s:12:\"revisionable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:8:\"reusable\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:415;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:458;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:501;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:543;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:18:\"block_content.body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ac53f9a6-7651-4e31-83f3-63793c128360\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:18:\"block_content.body\";s:13:\"\0*\0field_name\";s:4:\"body\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:17:\"text_with_summary\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','block_content_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:18:\"block_content_type\";s:8:\"\0*\0class\";s:44:\"Drupal\\block_content\\Entity\\BlockContentType\";s:11:\"\0*\0provider\";s:13:\"block_content\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:44:\"Drupal\\block_content\\Entity\\BlockContentType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:50:\"Drupal\\block_content\\BlockTypeAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:3:\"add\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:4:\"edit\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:6:\"delete\";s:52:\"Drupal\\block_content\\Form\\BlockContentTypeDeleteForm\";}s:14:\"route_provider\";a:2:{s:4:\"html\";s:49:\"Drupal\\Core\\Entity\\Routing\\AdminHtmlRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:48:\"Drupal\\block_content\\BlockContentTypeListBuilder\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer block types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/delete\";s:9:\"edit-form\";s:58:\"/admin/structure/block-content/manage/{block_content_type}\";s:23:\"entity-permissions-form\";s:70:\"/admin/structure/block-content/manage/{block_content_type}/permissions\";s:10:\"collection\";s:30:\"/admin/structure/block-content\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:13:\"block_content\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:17:\"@count block type\";s:6:\"plural\";s:18:\"@count block types\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:30:\"config:block_content_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:8:\"revision\";i:3;s:11:\"description\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','ckeditor5_template.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:18:\"ckeditor5_template\";s:8:\"\0*\0class\";s:63:\"Drupal\\ckeditor5_plugin_pack_templates\\Entity\\CKEditor5Template\";s:11:\"\0*\0provider\";s:31:\"ckeditor5_plugin_pack_templates\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:63:\"Drupal\\ckeditor5_plugin_pack_templates\\Entity\\CKEditor5Template\";s:11:\"\0*\0handlers\";a:5:{s:12:\"list_builder\";s:67:\"Drupal\\ckeditor5_plugin_pack_templates\\CKEditor5TemplateListBuilder\";s:4:\"form\";a:4:{s:7:\"default\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:3:\"add\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:4:\"edit\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:30:\"administer ckeditor5 templates\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:10:\"collection\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:8:\"add-form\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:9:\"edit-form\";s:72:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}\";s:11:\"delete-form\";s:61:\"/admin/config/ckeditor5-templates/{ckeditor5_template}/delete\";s:27:\"config-translation-overview\";s:82:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"CKEditor5 Template\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"CKEditor5 Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"CKEditor5 Template\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"CKEditor5 Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:25:\"@count ckeditor5 template\";s:6:\"plural\";s:26:\"@count ckeditor5 templates\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:30:\"config:ckeditor5_template_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:18:\"ckeditor5_template\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"status\";i:4;s:4:\"data\";i:5;s:4:\"icon\";i:6;s:11:\"textFormats\";i:7;s:6:\"weight\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','comment.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:7:\"comment\";s:8:\"\0*\0class\";s:29:\"Drupal\\comment\\Entity\\Comment\";s:11:\"\0*\0provider\";s:7:\"comment\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:3:\"cid\";s:6:\"bundle\";s:12:\"comment_type\";s:5:\"label\";s:7:\"subject\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:5:\"owner\";s:3:\"uid\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\comment\\Entity\\Comment\";s:11:\"\0*\0handlers\";a:8:{s:7:\"storage\";s:29:\"Drupal\\comment\\CommentStorage\";s:14:\"storage_schema\";s:35:\"Drupal\\comment\\CommentStorageSchema\";s:6:\"access\";s:42:\"Drupal\\comment\\CommentAccessControlHandler\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:12:\"view_builder\";s:33:\"Drupal\\comment\\CommentViewBuilder\";s:10:\"views_data\";s:31:\"Drupal\\comment\\CommentViewsData\";s:4:\"form\";a:2:{s:7:\"default\";s:26:\"Drupal\\comment\\CommentForm\";s:6:\"delete\";s:30:\"Drupal\\comment\\Form\\DeleteForm\";}s:11:\"translation\";s:40:\"Drupal\\comment\\CommentTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:9:\"canonical\";s:18:\"/comment/{comment}\";s:11:\"delete-form\";s:25:\"/comment/{comment}/delete\";s:20:\"delete-multiple-form\";s:29:\"/admin/content/comment/delete\";s:9:\"edit-form\";s:23:\"/comment/{comment}/edit\";s:6:\"create\";s:8:\"/comment\";}s:21:\"\0*\0bundle_entity_type\";s:12:\"comment_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:7:\"comment\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:18:\"comment_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Comment\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";N;s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"comment\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"comments\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:14:\"@count comment\";s:6:\"plural\";s:15:\"@count comments\";}s:15:\"\0*\0uri_callback\";s:11:\"comment_uri\";s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:29:\"entity.comment_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:12:\"comment_list\";}s:14:\"\0*\0constraints\";a:3:{s:11:\"CommentName\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','comment.field_storage_definitions',_binary 'a:20:{s:3:\"cid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Comment ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"The comment ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"cid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The comment UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The comment language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"comment_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment Type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The comment type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:12:\"comment_type\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"comment_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:116;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:22:\"default_value_callback\";s:47:\"Drupal\\comment\\Entity\\Comment::getDefaultStatus\";s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:154;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:52:\"Drupal\\comment\\Entity\\Comment::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"The user ID of the comment author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:194;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"pid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Parent ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The parent comment ID if this is a reply to a comment.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"pid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:7:\"comment\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:232;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"entity_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The ID of the entity of which this comment is a reply.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:9:\"entity_id\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:268;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"subject\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Subject\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"subject\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:64;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:305;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The comment author\'s name.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:60;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:342;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The comment author\'s email address.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:380;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"homepage\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Homepage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The comment author\'s home page address.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"homepage\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:14:\"field_item:uri\";s:8:\"settings\";a:2:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:411;}s:7:\"\0*\0type\";s:3:\"uri\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"hostname\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Hostname\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The comment author\'s hostname.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:49:\"Drupal\\comment\\Entity\\Comment::getDefaultHostname\";s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"hostname\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:445;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The time that the comment was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:481;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The time that the comment was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:511;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"thread\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Thread place\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:144:\"The alphadecimal representation of the comment\'s place in a thread, consisting of a base 36 string prefixed by an integer indicating its length.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:6:\"thread\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:541;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"entity_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Entity type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The entity type to which this comment is attached.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:11:\"entity_type\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:575;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"field_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Comment field name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The field name through which this comment was added.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:10:\"field_name\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:610;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:645;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"comment_body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:20:\"comment.comment_body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"e5ee7b1b-bd81-4fd0-af67-f92e6bae8313\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:20:\"comment.comment_body\";s:13:\"\0*\0field_name\";s:12:\"comment_body\";s:14:\"\0*\0entity_type\";s:7:\"comment\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','comment_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"comment_type\";s:8:\"\0*\0class\";s:33:\"Drupal\\comment\\Entity\\CommentType\";s:11:\"\0*\0provider\";s:7:\"comment\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\comment\\Entity\\CommentType\";s:11:\"\0*\0handlers\";a:5:{s:4:\"form\";a:4:{s:7:\"default\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:3:\"add\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:4:\"edit\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:6:\"delete\";s:41:\"Drupal\\comment\\Form\\CommentTypeDeleteForm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:37:\"Drupal\\comment\\CommentTypeListBuilder\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer comment types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:11:\"delete-form\";s:53:\"/admin/structure/comment/manage/{comment_type}/delete\";s:9:\"edit-form\";s:46:\"/admin/structure/comment/manage/{comment_type}\";s:8:\"add-form\";s:34:\"/admin/structure/comment/types/add\";s:23:\"entity-permissions-form\";s:58:\"/admin/structure/comment/manage/{comment_type}/permissions\";s:10:\"collection\";s:24:\"/admin/structure/comment\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:7:\"comment\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";N;s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"comment types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:19:\"@count comment type\";s:6:\"plural\";s:20:\"@count comment types\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:comment_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:21:\"target_entity_type_id\";i:3;s:11:\"description\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','configurable_language.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:21:\"configurable_language\";s:8:\"\0*\0class\";s:43:\"Drupal\\language\\Entity\\ConfigurableLanguage\";s:11:\"\0*\0provider\";s:8:\"language\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\language\\Entity\\ConfigurableLanguage\";s:11:\"\0*\0handlers\";a:4:{s:12:\"list_builder\";s:35:\"Drupal\\language\\LanguageListBuilder\";s:6:\"access\";s:44:\"Drupal\\language\\LanguageAccessControlHandler\";s:4:\"form\";a:3:{s:3:\"add\";s:36:\"Drupal\\language\\Form\\LanguageAddForm\";s:4:\"edit\";s:37:\"Drupal\\language\\Form\\LanguageEditForm\";s:6:\"delete\";s:39:\"Drupal\\language\\Form\\LanguageDeleteForm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:20:\"administer languages\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:11:\"delete-form\";s:62:\"/admin/config/regional/language/delete/{configurable_language}\";s:9:\"edit-form\";s:60:\"/admin/config/regional/language/edit/{configurable_language}\";s:10:\"collection\";s:31:\"/admin/config/regional/language\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Languages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"languages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:15:\"@count language\";s:6:\"plural\";s:16:\"@count languages\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:33:\"config:configurable_language_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:6:\"entity\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:9:\"direction\";i:3;s:6:\"weight\";i:4;s:6:\"locked\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','config_split.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"config_split\";s:8:\"\0*\0class\";s:44:\"Drupal\\config_split\\Entity\\ConfigSplitEntity\";s:11:\"\0*\0provider\";s:12:\"config_split\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:44:\"Drupal\\config_split\\Entity\\ConfigSplitEntity\";s:11:\"\0*\0handlers\";a:7:{s:12:\"view_builder\";s:48:\"Drupal\\config_split\\ConfigSplitEntityViewBuilder\";s:12:\"list_builder\";s:48:\"Drupal\\config_split\\ConfigSplitEntityListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:46:\"Drupal\\config_split\\Form\\ConfigSplitEntityForm\";s:4:\"edit\";s:46:\"Drupal\\config_split\\Form\\ConfigSplitEntityForm\";s:6:\"delete\";s:52:\"Drupal\\config_split\\Form\\ConfigSplitEntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:54:\"Drupal\\config_split\\ConfigSplitEntityHtmlRouteProvider\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:30:\"administer configuration split\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:12:{s:9:\"canonical\";s:67:\"/admin/config/development/configuration/config-split/{config_split}\";s:8:\"add-form\";s:56:\"/admin/config/development/configuration/config-split/add\";s:9:\"edit-form\";s:72:\"/admin/config/development/configuration/config-split/{config_split}/edit\";s:11:\"delete-form\";s:74:\"/admin/config/development/configuration/config-split/{config_split}/delete\";s:6:\"enable\";s:74:\"/admin/config/development/configuration/config-split/{config_split}/enable\";s:7:\"disable\";s:75:\"/admin/config/development/configuration/config-split/{config_split}/disable\";s:8:\"activate\";s:76:\"/admin/config/development/configuration/config-split/{config_split}/activate\";s:10:\"deactivate\";s:78:\"/admin/config/development/configuration/config-split/{config_split}/deactivate\";s:6:\"import\";s:74:\"/admin/config/development/configuration/config-split/{config_split}/import\";s:6:\"export\";s:74:\"/admin/config/development/configuration/config-split/{config_split}/export\";s:10:\"collection\";s:52:\"/admin/config/development/configuration/config-split\";s:27:\"config-translation-overview\";s:82:\"/admin/config/development/configuration/config-split/{config_split}/edit/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Configuration Split setting\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:config_split_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:12:\"config_split\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:12:\"config_split\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:13:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"weight\";i:4;s:6:\"status\";i:5;s:9:\"stackable\";i:6;s:7:\"storage\";i:7;s:6:\"folder\";i:8;s:6:\"module\";i:9;s:5:\"theme\";i:10;s:13:\"complete_list\";i:11;s:12:\"partial_list\";i:12;s:11:\"no_patching\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','contact_form.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"contact_form\";s:8:\"\0*\0class\";s:33:\"Drupal\\contact\\Entity\\ContactForm\";s:11:\"\0*\0provider\";s:7:\"contact\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\contact\\Entity\\ContactForm\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:46:\"Drupal\\contact\\ContactFormAccessControlHandler\";s:12:\"list_builder\";s:37:\"Drupal\\contact\\ContactFormListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:34:\"Drupal\\contact\\ContactFormEditForm\";s:4:\"edit\";s:34:\"Drupal\\contact\\ContactFormEditForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer contact forms\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:11:\"delete-form\";s:53:\"/admin/structure/contact/manage/{contact_form}/delete\";s:9:\"edit-form\";s:46:\"/admin/structure/contact/manage/{contact_form}\";s:23:\"entity-permissions-form\";s:58:\"/admin/structure/contact/manage/{contact_form}/permissions\";s:10:\"collection\";s:24:\"/admin/structure/contact\";s:9:\"canonical\";s:23:\"/contact/{contact_form}\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:15:\"contact_message\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:19:\"@count contact form\";s:6:\"plural\";s:20:\"@count contact forms\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:contact_form_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"form\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:10:\"recipients\";i:3;s:5:\"reply\";i:4;s:6:\"weight\";i:5;s:7:\"message\";i:6;s:8:\"redirect\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','contact_message.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:15:\"contact_message\";s:8:\"\0*\0class\";s:29:\"Drupal\\contact\\Entity\\Message\";s:11:\"\0*\0provider\";s:7:\"contact\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:6:{s:6:\"bundle\";s:12:\"contact_form\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\contact\\Entity\\Message\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:49:\"Drupal\\contact\\ContactMessageAccessControlHandler\";s:7:\"storage\";s:43:\"Drupal\\Core\\Entity\\ContentEntityNullStorage\";s:12:\"view_builder\";s:33:\"Drupal\\contact\\MessageViewBuilder\";s:4:\"form\";a:1:{s:7:\"default\";s:26:\"Drupal\\contact\\MessageForm\";}}s:19:\"\0*\0admin_permission\";s:24:\"administer contact forms\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";s:12:\"contact_form\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Contact message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Contact messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"contact message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"contact messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:22:\"@count contact message\";s:6:\"plural\";s:23:\"@count contact messages\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:29:\"entity.contact_form.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:20:\"contact_message_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','contact_message.field_storage_definitions',_binary 'a:9:{s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The message UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The message language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:28;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:12:\"contact_form\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Form ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The ID of the associated form.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:12:\"contact_form\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"contact_form\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:58;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The sender\'s name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"The name of the person that is sending the contact message.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:85;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"The sender\'s email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"The email of the person that is sending the contact message.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:110;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:7:\"subject\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Subject\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:7:\"subject\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:100;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:132;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:7:\"message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:4:\"rows\";i:12;}}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:0;s:5:\"label\";s:5:\"above\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:7:\"message\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:160;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"copy\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Copy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Whether to send a copy of the message to the sender.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"copy\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:194;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:9:\"recipient\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Recipient ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"The ID of the recipient user for personal contact messages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:9:\"recipient\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:224;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','date_format.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"date_format\";s:8:\"\0*\0class\";s:38:\"Drupal\\Core\\Datetime\\Entity\\DateFormat\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\Core\\Datetime\\Entity\\DateFormat\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\system\\DateFormatAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:4:\"form\";a:3:{s:3:\"add\";s:36:\"Drupal\\system\\Form\\DateFormatAddForm\";s:4:\"edit\";s:37:\"Drupal\\system\\Form\\DateFormatEditForm\";s:6:\"delete\";s:39:\"Drupal\\system\\Form\\DateFormatDeleteForm\";}s:12:\"list_builder\";s:35:\"Drupal\\system\\DateFormatListBuilder\";}s:19:\"\0*\0admin_permission\";s:29:\"administer site configuration\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"edit-form\";s:61:\"/admin/config/regional/date-time/formats/manage/{date_format}\";s:11:\"delete-form\";s:68:\"/admin/config/regional/date-time/formats/manage/{date_format}/delete\";s:10:\"collection\";s:40:\"/admin/config/regional/date-time/formats\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Date format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";N;s:17:\"\0*\0label_singular\";N;s:15:\"\0*\0label_plural\";N;s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:8:\"rendered\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"locked\";i:3;s:7:\"pattern\";}s:21:\"\0*\0mergedConfigExport\";a:10:{s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:6:\"status\";s:6:\"status\";s:12:\"dependencies\";s:12:\"dependencies\";s:20:\"third_party_settings\";s:20:\"third_party_settings\";s:5:\"_core\";s:5:\"_core\";s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"locked\";s:6:\"locked\";s:7:\"pattern\";s:7:\"pattern\";}}'),('entity.definitions.installed','editor.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:6:\"editor\";s:8:\"\0*\0class\";s:27:\"Drupal\\editor\\Entity\\Editor\";s:11:\"\0*\0provider\";s:6:\"editor\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:6:\"format\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\editor\\Entity\\Editor\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:40:\"Drupal\\editor\\EditorAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Text editor\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"text editor\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"text editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:18:\"@count text editor\";s:6:\"plural\";s:19:\"@count text editors\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"config:editor_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"RequiredConfigDependencies\";a:1:{i:0;s:13:\"filter_format\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:6:\"format\";i:1;s:6:\"editor\";i:2;s:8:\"settings\";i:3;s:12:\"image_upload\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_form_display.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"entity_form_display\";s:8:\"\0*\0class\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:70:\"Drupal\\Core\\Entity\\Entity\\Access\\EntityFormDisplayAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Entity form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";N;s:17:\"\0*\0label_singular\";N;s:15:\"\0*\0label_plural\";N;s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:entity_form_display_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";i:4;s:7:\"content\";i:5;s:6:\"hidden\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_form_mode.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"entity_form_mode\";s:8:\"\0*\0class\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityFormMode\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:11:\"description\";s:11:\"description\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityFormMode\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Form mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";N;s:17:\"\0*\0label_singular\";N;s:15:\"\0*\0label_plural\";N;s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:entity_form_mode_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:16:\"targetEntityType\";i:4;s:5:\"cache\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_view_display.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"entity_view_display\";s:8:\"\0*\0class\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:70:\"Drupal\\Core\\Entity\\Entity\\Access\\EntityViewDisplayAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Entity view display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";N;s:17:\"\0*\0label_singular\";N;s:15:\"\0*\0label_plural\";N;s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:entity_view_display_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";i:4;s:7:\"content\";i:5;s:6:\"hidden\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_view_mode.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"entity_view_mode\";s:8:\"\0*\0class\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityViewMode\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:11:\"description\";s:11:\"description\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityViewMode\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"View mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";N;s:17:\"\0*\0label_singular\";N;s:15:\"\0*\0label_plural\";N;s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:entity_view_mode_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:16:\"targetEntityType\";i:4;s:5:\"cache\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','field_config.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"field_config\";s:8:\"\0*\0class\";s:31:\"Drupal\\field\\Entity\\FieldConfig\";s:11:\"\0*\0provider\";s:5:\"field\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\field\\Entity\\FieldConfig\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:44:\"Drupal\\field\\FieldConfigAccessControlHandler\";s:7:\"storage\";s:31:\"Drupal\\field\\FieldConfigStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:12:\"@count field\";s:6:\"plural\";s:13:\"@count fields\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:field_config_list\";}s:14:\"\0*\0constraints\";a:2:{s:26:\"RequiredConfigDependencies\";a:1:{i:0;s:20:\"field_storage_config\";}s:19:\"ImmutableProperties\";a:5:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";i:3;s:6:\"bundle\";i:4;s:10:\"field_type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:5:\"field\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:6:\"bundle\";i:4;s:5:\"label\";i:5;s:11:\"description\";i:6;s:8:\"required\";i:7;s:12:\"translatable\";i:8;s:13:\"default_value\";i:9;s:22:\"default_value_callback\";i:10;s:8:\"settings\";i:11;s:10:\"field_type\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','field_storage_config.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:20:\"field_storage_config\";s:8:\"\0*\0class\";s:38:\"Drupal\\field\\Entity\\FieldStorageConfig\";s:11:\"\0*\0provider\";s:5:\"field\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:2:\"id\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\field\\Entity\\FieldStorageConfig\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:51:\"Drupal\\field\\FieldStorageConfigAccessControlHandler\";s:7:\"storage\";s:38:\"Drupal\\field\\FieldStorageConfigStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Field storage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Field storages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"field storage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"field storages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:20:\"@count field storage\";s:6:\"plural\";s:21:\"@count field storages\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:32:\"config:field_storage_config_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";i:3;s:4:\"type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:7:\"storage\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:4:\"type\";i:4;s:8:\"settings\";i:5;s:6:\"module\";i:6;s:6:\"locked\";i:7;s:11:\"cardinality\";i:8;s:12:\"translatable\";i:9;s:7:\"indexes\";i:10;s:22:\"persist_with_no_fields\";i:11;s:14:\"custom_storage\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','file.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"file\";s:8:\"\0*\0class\";s:23:\"Drupal\\file\\Entity\\File\";s:11:\"\0*\0provider\";s:4:\"file\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"fid\";s:5:\"label\";s:8:\"filename\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:5:\"owner\";s:3:\"uid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\file\\Entity\\File\";s:11:\"\0*\0handlers\";a:8:{s:7:\"storage\";s:23:\"Drupal\\file\\FileStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\file\\FileStorageSchema\";s:6:\"access\";s:36:\"Drupal\\file\\FileAccessControlHandler\";s:10:\"views_data\";s:25:\"Drupal\\file\\FileViewsData\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:4:\"form\";a:1:{s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\file\\Entity\\FileRouteProvider\";}s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:1:{s:11:\"delete-form\";s:19:\"/file/{file}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:12:\"file_managed\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"file\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:11:\"@count file\";s:6:\"plural\";s:12:\"@count files\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"file_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','file.field_storage_definitions',_binary 'a:11:{s:3:\"fid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"File ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The file ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"fid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The file UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The file language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:0;s:22:\"default_value_callback\";s:46:\"Drupal\\file\\Entity\\File::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"The user ID of the file.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filename\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Filename\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"Name of the file with no path components.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filename\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:153;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uri\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The URI to access the file (either local or remote).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:1:{s:13:\"FileUriUnique\";N;}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"uri\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:file_uri\";s:8:\"settings\";a:2:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:1;}}s:18:\"\0*\0fieldDefinition\";r:187;}s:7:\"\0*\0type\";s:8:\"file_uri\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:1;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filemime\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"File MIME type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"The file\'s MIME type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filemime\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:222;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filesize\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"File size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The size of the file in bytes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filesize\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:256;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Status\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"The status of the file, temporary (FALSE) and permanent (TRUE).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:293;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The timestamp that the file was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:334;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"The timestamp that the file was last changed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:363;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','filter_format.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:13:\"filter_format\";s:8:\"\0*\0class\";s:33:\"Drupal\\filter\\Entity\\FilterFormat\";s:11:\"\0*\0provider\";s:6:\"filter\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:6:\"format\";s:5:\"label\";s:4:\"name\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\filter\\Entity\\FilterFormat\";s:11:\"\0*\0handlers\";a:4:{s:4:\"form\";a:4:{s:3:\"add\";s:33:\"Drupal\\filter\\FilterFormatAddForm\";s:4:\"edit\";s:34:\"Drupal\\filter\\FilterFormatEditForm\";s:7:\"disable\";s:36:\"Drupal\\filter\\Form\\FilterDisableForm\";s:6:\"enable\";s:35:\"Drupal\\filter\\Form\\FilterEnableForm\";}s:12:\"list_builder\";s:37:\"Drupal\\filter\\FilterFormatListBuilder\";s:6:\"access\";s:46:\"Drupal\\filter\\FilterFormatAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:18:\"administer filters\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"edit-form\";s:52:\"/admin/config/content/formats/manage/{filter_format}\";s:7:\"disable\";s:60:\"/admin/config/content/formats/manage/{filter_format}/disable\";s:6:\"enable\";s:59:\"/admin/config/content/formats/manage/{filter_format}/enable\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Text format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"text format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"text formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:18:\"@count text format\";s:6:\"plural\";s:19:\"@count text formats\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:25:\"config:filter_format_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:6:\"format\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:4:\"name\";i:1;s:6:\"format\";i:2;s:6:\"weight\";i:3;s:5:\"roles\";i:4;s:7:\"filters\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','image_style.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"image_style\";s:8:\"\0*\0class\";s:30:\"Drupal\\image\\Entity\\ImageStyle\";s:11:\"\0*\0provider\";s:5:\"image\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:4:\"name\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:30:\"Drupal\\image\\Entity\\ImageStyle\";s:11:\"\0*\0handlers\";a:4:{s:4:\"form\";a:4:{s:3:\"add\";s:35:\"Drupal\\image\\Form\\ImageStyleAddForm\";s:4:\"edit\";s:36:\"Drupal\\image\\Form\\ImageStyleEditForm\";s:6:\"delete\";s:38:\"Drupal\\image\\Form\\ImageStyleDeleteForm\";s:5:\"flush\";s:37:\"Drupal\\image\\Form\\ImageStyleFlushForm\";}s:12:\"list_builder\";s:34:\"Drupal\\image\\ImageStyleListBuilder\";s:7:\"storage\";s:30:\"Drupal\\image\\ImageStyleStorage\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";}s:19:\"\0*\0admin_permission\";s:23:\"administer image styles\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:10:\"flush-form\";s:59:\"/admin/config/media/image-styles/manage/{image_style}/flush\";s:9:\"edit-form\";s:53:\"/admin/config/media/image-styles/manage/{image_style}\";s:11:\"delete-form\";s:60:\"/admin/config/media/image-styles/manage/{image_style}/delete\";s:10:\"collection\";s:32:\"/admin/config/media/image-styles\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Image style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"image style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:18:\"@count image style\";s:6:\"plural\";s:19:\"@count image styles\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:23:\"config:image_style_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:5:\"style\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:3:{i:0;s:4:\"name\";i:1;s:5:\"label\";i:2;s:7:\"effects\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','jsonapi_resource_config.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:23:\"jsonapi_resource_config\";s:8:\"\0*\0class\";s:50:\"Drupal\\jsonapi_extras\\Entity\\JsonapiResourceConfig\";s:11:\"\0*\0provider\";s:14:\"jsonapi_extras\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:50:\"Drupal\\jsonapi_extras\\Entity\\JsonapiResourceConfig\";s:11:\"\0*\0handlers\";a:6:{s:12:\"list_builder\";s:54:\"Drupal\\jsonapi_extras\\JsonapiResourceConfigListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:52:\"Drupal\\jsonapi_extras\\Form\\JsonapiResourceConfigForm\";s:4:\"edit\";s:52:\"Drupal\\jsonapi_extras\\Form\\JsonapiResourceConfigForm\";s:6:\"delete\";s:58:\"Drupal\\jsonapi_extras\\Form\\JsonapiResourceConfigDeleteForm\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:49:\"Drupal\\Core\\Entity\\Routing\\AdminHtmlRouteProvider\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:29:\"administer site configuration\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:75:\"/admin/config/services/jsonapi/add/resource_types/{entity_type_id}/{bundle}\";s:9:\"edit-form\";s:76:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit\";s:11:\"delete-form\";s:78:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/delete\";s:10:\"collection\";s:45:\"/admin/config/services/jsonapi/resource_types\";s:27:\"config-translation-overview\";s:86:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"JSON:API Resource override\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"JSON:API Resource overrides\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"JSON:API resource override\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"JSON:API resource overrides\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:33:\"@count JSON:API resource override\";s:6:\"plural\";s:34:\"@count JSON:API resource overrides\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:35:\"config:jsonapi_resource_config_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:23:\"jsonapi_resource_config\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:23:\"jsonapi_resource_config\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:8:\"disabled\";i:2;s:4:\"path\";i:3;s:12:\"resourceType\";i:4;s:14:\"resourceFields\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','language_content_settings.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:25:\"language_content_settings\";s:8:\"\0*\0class\";s:46:\"Drupal\\language\\Entity\\ContentLanguageSettings\";s:11:\"\0*\0provider\";s:8:\"language\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:46:\"Drupal\\language\\Entity\\ContentLanguageSettings\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:20:\"administer languages\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Content language settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Content language settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"content language setting\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"content languages settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:31:\"@count content language setting\";s:6:\"plural\";s:33:\"@count content languages settings\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:8:\"rendered\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:3:{i:0;s:2:\"id\";i:1;s:21:\"target_entity_type_id\";i:2;s:13:\"target_bundle\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:16:\"content_settings\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:21:\"target_entity_type_id\";i:2;s:13:\"target_bundle\";i:3;s:16:\"default_langcode\";i:4;s:18:\"language_alterable\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','linkit_profile.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:14:\"linkit_profile\";s:8:\"\0*\0class\";s:28:\"Drupal\\linkit\\Entity\\Profile\";s:11:\"\0*\0provider\";s:6:\"linkit\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:28:\"Drupal\\linkit\\Entity\\Profile\";s:11:\"\0*\0handlers\";a:5:{s:12:\"list_builder\";s:32:\"Drupal\\linkit\\ProfileListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:34:\"Drupal\\linkit\\Form\\Profile\\AddForm\";s:4:\"edit\";s:35:\"Drupal\\linkit\\Form\\Profile\\EditForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:26:\"administer linkit profiles\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:10:\"collection\";s:28:\"/admin/config/content/linkit\";s:9:\"edit-form\";s:52:\"/admin/config/content/linkit/manage/{linkit_profile}\";s:11:\"delete-form\";s:59:\"/admin/config/content/linkit/manage/{linkit_profile}/delete\";s:27:\"config-translation-overview\";s:62:\"/admin/config/content/linkit/manage/{linkit_profile}/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Linkit profile\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:26:\"config:linkit_profile_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:14:\"linkit_profile\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:5:\"label\";i:1;s:2:\"id\";i:2;s:11:\"description\";i:3;s:8:\"matchers\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','menu.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:4:\"menu\";s:8:\"\0*\0class\";s:25:\"Drupal\\system\\Entity\\Menu\";s:11:\"\0*\0provider\";s:6:\"system\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\system\\Entity\\Menu\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:38:\"Drupal\\system\\MenuAccessControlHandler\";s:7:\"storage\";s:25:\"Drupal\\system\\MenuStorage\";}s:19:\"\0*\0admin_permission\";s:15:\"administer menu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:11:\"@count menu\";s:6:\"plural\";s:12:\"@count menus\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:16:\"config:menu_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"locked\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','menu_link_content.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:17:\"menu_link_content\";s:8:\"\0*\0class\";s:60:\"Drupal\\menu_item_extras\\Entity\\MenuItemExtrasMenuLinkContent\";s:11:\"\0*\0provider\";s:17:\"menu_link_content\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:6:\"bundle\";s:9:\"published\";s:7:\"enabled\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:47:\"Drupal\\menu_link_content\\Entity\\MenuLinkContent\";s:11:\"\0*\0handlers\";a:8:{s:7:\"storage\";s:47:\"Drupal\\menu_link_content\\MenuLinkContentStorage\";s:14:\"storage_schema\";s:53:\"Drupal\\menu_link_content\\MenuLinkContentStorageSchema\";s:6:\"access\";s:60:\"Drupal\\menu_link_content\\MenuLinkContentAccessControlHandler\";s:4:\"form\";a:2:{s:7:\"default\";s:49:\"Drupal\\menu_link_content\\Form\\MenuLinkContentForm\";s:6:\"delete\";s:55:\"Drupal\\menu_link_content\\Form\\MenuLinkContentDeleteForm\";}s:12:\"list_builder\";s:44:\"Drupal\\menu_link_content\\MenuLinkListBuilder\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:10:\"views_data\";s:48:\"Drupal\\menu_item_extras\\MenuLinkContentViewsData\";s:10:\"moderation\";s:0:\"\";}s:19:\"\0*\0admin_permission\";s:15:\"administer menu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:9:\"edit-form\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:11:\"delete-form\";s:53:\"/admin/structure/menu/item/{menu_link_content}/delete\";}s:21:\"\0*\0bundle_entity_type\";s:4:\"menu\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:17:\"menu_link_content\";s:22:\"\0*\0revision_data_table\";s:32:\"menu_link_content_field_revision\";s:17:\"\0*\0revision_table\";s:26:\"menu_link_content_revision\";s:13:\"\0*\0data_table\";s:22:\"menu_link_content_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Custom menu links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"custom menu links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:23:\"@count custom menu link\";s:6:\"plural\";s:24:\"@count custom menu links\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:21:\"entity.menu.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:22:\"menu_link_content_list\";}s:14:\"\0*\0constraints\";a:3:{s:17:\"MenuTreeHierarchy\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:17:\"menu_link_content\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','menu_link_content.field_storage_definitions',_binary 'a:23:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"The entity ID for this menu link content entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"The content menu link UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"The menu link language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"bundle\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";s:4:\"Menu\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"The content menu link bundle.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"bundle\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"menu\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;}}s:18:\"\0*\0fieldDefinition\";r:151;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:188;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:218;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:255;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"enabled\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Enabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"A flag for whether the link should be enabled in menus or hidden.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:7:\"boolean\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:-1;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:7:\"enabled\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:294;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Menu link title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:348;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"description\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Shown when hovering over the menu link.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:11:\"description\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:392;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"menu_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Menu name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:93:\"The menu name. All links with the same menu name (such as \"tools\") are part of the same menu.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:5:\"tools\";}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:9:\"menu_name\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:438;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"link\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:-2;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:4:\"link\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}}s:18:\"\0*\0fieldDefinition\";r:475;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"external\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"External\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:120:\"A flag to indicate if the link points to a full URL starting with a protocol, like http:// (1 = external, 0 = internal).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"external\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:524;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"rediscover\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Indicates whether the menu link should be rediscovered\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:10:\"rediscover\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:566;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:172:\"Link weight among links in the same menu at the same depth. In the menu, the links with high weight will sink and links with a low weight will be positioned nearer the top.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:14:\"number_integer\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:20;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:603;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"expanded\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Show as expanded\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:164:\"If selected and this menu link has children, the menu will always appear expanded. This option may be overridden for the entire menu tree when placing a menu block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:7:\"boolean\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:0;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"expanded\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:653;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"parent\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Parent plugin ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:94:\"The ID of the parent menu link plugin, or empty string when at the top level of the hierarchy.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"parent\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:705;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"The time that the menu link was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:739;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:770;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:813;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:855;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"view_mode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"View mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Per item view mode selector.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:42:\"menu_item_extras_view_mode_selector_select\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:16:\"menu_item_extras\";s:10:\"field_name\";s:9:\"view_mode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:896;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','metatag_defaults.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"metatag_defaults\";s:8:\"\0*\0class\";s:37:\"Drupal\\metatag\\Entity\\MetatagDefaults\";s:11:\"\0*\0provider\";s:7:\"metatag\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:37:\"Drupal\\metatag\\Entity\\MetatagDefaults\";s:11:\"\0*\0handlers\";a:5:{s:12:\"list_builder\";s:41:\"Drupal\\metatag\\MetatagDefaultsListBuilder\";s:4:\"form\";a:4:{s:3:\"add\";s:39:\"Drupal\\metatag\\Form\\MetatagDefaultsForm\";s:4:\"edit\";s:39:\"Drupal\\metatag\\Form\\MetatagDefaultsForm\";s:6:\"delete\";s:45:\"Drupal\\metatag\\Form\\MetatagDefaultsDeleteForm\";s:6:\"revert\";s:45:\"Drupal\\metatag\\Form\\MetatagDefaultsRevertForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:20:\"administer meta tags\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:9:\"edit-form\";s:52:\"/admin/config/search/metatag/{metatag_defaults}/edit\";s:11:\"delete-form\";s:54:\"/admin/config/search/metatag/{metatag_defaults}/delete\";s:11:\"revert-form\";s:54:\"/admin/config/search/metatag/{metatag_defaults}/revert\";s:10:\"collection\";s:28:\"/admin/config/search/metatag\";s:27:\"config-translation-overview\";s:62:\"/admin/config/search/metatag/{metatag_defaults}/edit/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Metatag defaults\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:metatag_defaults_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:16:\"metatag_defaults\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:16:\"metatag_defaults\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"tags\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','node.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"node\";s:8:\"\0*\0class\";s:23:\"Drupal\\node\\Entity\\Node\";s:11:\"\0*\0provider\";s:4:\"node\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:12:{s:2:\"id\";s:3:\"nid\";s:8:\"revision\";s:3:\"vid\";s:6:\"bundle\";s:4:\"type\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"status\";s:6:\"status\";s:9:\"published\";s:6:\"status\";s:3:\"uid\";s:3:\"uid\";s:5:\"owner\";s:3:\"uid\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\node\\Entity\\Node\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:23:\"Drupal\\node\\NodeStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\node\\NodeStorageSchema\";s:12:\"view_builder\";s:27:\"Drupal\\node\\NodeViewBuilder\";s:6:\"access\";s:36:\"Drupal\\node\\NodeAccessControlHandler\";s:10:\"views_data\";s:25:\"Drupal\\node\\NodeViewsData\";s:4:\"form\";a:4:{s:7:\"default\";s:20:\"Drupal\\node\\NodeForm\";s:6:\"delete\";s:31:\"Drupal\\node\\Form\\NodeDeleteForm\";s:4:\"edit\";s:20:\"Drupal\\node\\NodeForm\";s:23:\"delete-multiple-confirm\";s:31:\"Drupal\\node\\Form\\DeleteMultiple\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\node\\Entity\\NodeRouteProvider\";}s:12:\"list_builder\";s:27:\"Drupal\\node\\NodeListBuilder\";s:11:\"translation\";s:34:\"Drupal\\node\\NodeTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";s:23:\"access content overview\";s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:7:{s:9:\"canonical\";s:12:\"/node/{node}\";s:11:\"delete-form\";s:19:\"/node/{node}/delete\";s:20:\"delete-multiple-form\";s:26:\"/admin/content/node/delete\";s:9:\"edit-form\";s:17:\"/node/{node}/edit\";s:15:\"version-history\";s:22:\"/node/{node}/revisions\";s:8:\"revision\";s:43:\"/node/{node}/revisions/{node_revision}/view\";s:6:\"create\";s:5:\"/node\";}s:21:\"\0*\0bundle_entity_type\";s:9:\"node_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:4:\"node\";s:22:\"\0*\0revision_data_table\";s:19:\"node_field_revision\";s:17:\"\0*\0revision_table\";s:13:\"node_revision\";s:13:\"\0*\0data_table\";s:15:\"node_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"content item\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:19:\"@count content item\";s:6:\"plural\";s:20:\"@count content items\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:26:\"entity.node_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:1:{i:0;s:21:\"user.node_grants:view\";}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"node_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:12:\"revision_uid\";s:16:\"revision_created\";s:18:\"revision_timestamp\";s:20:\"revision_log_message\";s:12:\"revision_log\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','node.field_storage_definitions',_binary 'a:27:{s:3:\"nid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"nid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:12:\"Content type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:9:\"node_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:139;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"revision_timestamp\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:18:\"revision_timestamp\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:170;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:12:\"revision_uid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:200;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_log\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:12:\"revision_log\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:237;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:120;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:279;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:46:\"Drupal\\node\\Entity\\Node::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The username of the content author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"author\";s:6:\"weight\";i:0;}}s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:3:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";s:2:\"60\";s:11:\"placeholder\";s:0:\"\";}}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:326;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:380;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The date and time that the content was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:9:\"timestamp\";s:6:\"weight\";i:0;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:424;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the node was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:466;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"promote\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Promoted to front page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:15;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:497;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"sticky\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Sticky at top of lists\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:16;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:6:\"sticky\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:544;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:591;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:634;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:676;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"node.body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8a930e87-45e4-410a-af3d-198c8f27a1a8\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:9:\"node.body\";s:13:\"\0*\0field_name\";s:4:\"body\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:17:\"text_with_summary\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:11:\"field_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:16:\"node.field_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"2e760d93-d8f1-4cc0-a846-8a1be50ab6b9\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:16:\"node.field_image\";s:13:\"\0*\0field_name\";s:11:\"field_image\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:10:\"\0*\0deleted\";b:0;}s:7:\"comment\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:12:\"node.comment\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d8ddfd2c-c777-440f-a0e1-ce7cea17d4dd\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ktCna9xmWvYZIUfOCUyDQvedn5RtnS4CRmEIwNmvYjc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"node\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:12:\"node.comment\";s:13:\"\0*\0field_name\";s:7:\"comment\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:7:\"comment\";s:9:\"\0*\0module\";s:7:\"comment\";s:11:\"\0*\0settings\";a:1:{s:12:\"comment_type\";s:7:\"comment\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:10:\"field_tags\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:15:\"node.field_tags\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"81b92d69-01d7-4755-b08e-038fae9ed965\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:15:\"node.field_tags\";s:13:\"\0*\0field_name\";s:10:\"field_tags\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"webform\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:12:\"node.webform\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ad237af2-b5d3-4fac-8674-82493f95d005\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SJRNyZvo1lWcPLKxH_u6giTk1y51ymXvpKX65YUNd7w\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:12:\"webform_node\";}}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:12:\"node.webform\";s:13:\"\0*\0field_name\";s:7:\"webform\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:7:\"webform\";s:9:\"\0*\0module\";s:7:\"webform\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:9:\"rh_action\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:10:\"field_name\";s:9:\"rh_action\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Rabbit Hole action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Specifies which action that Rabbit Hole should take.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"rh_node\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:911;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"rh_redirect\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:10:\"field_name\";s:11:\"rh_redirect\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Rabbit Hole redirect path.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The path to where the user should get redirected to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"rh_node\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:946;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"rh_redirect_response\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:10:\"field_name\";s:20:\"rh_redirect_response\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Rabbit Hole redirect response code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"Specifies the HTTP response code that should be used when perform a redirect.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"rh_node\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:981;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:27:\"rh_redirect_fallback_action\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:10:\"field_name\";s:27:\"rh_redirect_fallback_action\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Rabbit Hole redirect fallback action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:84:\"Specifies the action that should be used when the redirect path is invalid or empty.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"rh_node\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:1019;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','node_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:9:\"node_type\";s:8:\"\0*\0class\";s:27:\"Drupal\\node\\Entity\\NodeType\";s:11:\"\0*\0provider\";s:4:\"node\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:4:\"type\";s:5:\"label\";s:4:\"name\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\node\\Entity\\NodeType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:40:\"Drupal\\node\\NodeTypeAccessControlHandler\";s:4:\"form\";a:3:{s:3:\"add\";s:24:\"Drupal\\node\\NodeTypeForm\";s:4:\"edit\";s:24:\"Drupal\\node\\NodeTypeForm\";s:6:\"delete\";s:38:\"Drupal\\node\\Form\\NodeTypeDeleteConfirm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:31:\"Drupal\\node\\NodeTypeListBuilder\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer content types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"edit-form\";s:41:\"/admin/structure/types/manage/{node_type}\";s:11:\"delete-form\";s:48:\"/admin/structure/types/manage/{node_type}/delete\";s:23:\"entity-permissions-form\";s:53:\"/admin/structure/types/manage/{node_type}/permissions\";s:10:\"collection\";s:22:\"/admin/structure/types\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:4:\"node\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:19:\"@count content type\";s:6:\"plural\";s:20:\"@count content types\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:21:\"config:node_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:4:\"name\";i:1;s:4:\"type\";i:2;s:11:\"description\";i:3;s:4:\"help\";i:4;s:12:\"new_revision\";i:5;s:12:\"preview_mode\";i:6;s:17:\"display_submitted\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','pathauto_pattern.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"pathauto_pattern\";s:8:\"\0*\0class\";s:38:\"Drupal\\pathauto\\Entity\\PathautoPattern\";s:11:\"\0*\0provider\";s:8:\"pathauto\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\pathauto\\Entity\\PathautoPattern\";s:11:\"\0*\0handlers\";a:6:{s:12:\"list_builder\";s:42:\"Drupal\\pathauto\\PathautoPatternListBuilder\";s:4:\"form\";a:5:{s:7:\"default\";s:36:\"Drupal\\pathauto\\Form\\PatternEditForm\";s:9:\"duplicate\";s:41:\"Drupal\\pathauto\\Form\\PatternDuplicateForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";s:6:\"enable\";s:38:\"Drupal\\pathauto\\Form\\PatternEnableForm\";s:7:\"disable\";s:39:\"Drupal\\pathauto\\Form\\PatternDisableForm\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:51:\"Drupal\\Core\\Entity\\Routing\\DefaultHtmlRouteProvider\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:19:\"administer pathauto\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:7:{s:10:\"collection\";s:34:\"/admin/config/search/path/patterns\";s:9:\"edit-form\";s:53:\"/admin/config/search/path/patterns/{pathauto_pattern}\";s:11:\"delete-form\";s:60:\"/admin/config/search/path/patterns/{pathauto_pattern}/delete\";s:6:\"enable\";s:60:\"/admin/config/search/path/patterns/{pathauto_pattern}/enable\";s:7:\"disable\";s:61:\"/admin/config/search/path/patterns/{pathauto_pattern}/disable\";s:14:\"duplicate-form\";s:63:\"/admin/config/search/path/patterns/{pathauto_pattern}/duplicate\";s:27:\"config-translation-overview\";s:63:\"/admin/config/search/path/patterns/{pathauto_pattern}/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Pathauto pattern\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:pathauto_pattern_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:16:\"pathauto_pattern\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:7:\"pattern\";s:14:\"\0*\0lookup_keys\";a:3:{i:0;s:4:\"type\";i:1;s:6:\"status\";i:2;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"type\";i:3;s:7:\"pattern\";i:4;s:18:\"selection_criteria\";i:5;s:15:\"selection_logic\";i:6;s:6:\"weight\";i:7;s:13:\"relationships\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','path_alias.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:10:\"path_alias\";s:8:\"\0*\0class\";s:34:\"Drupal\\path_alias\\Entity\\PathAlias\";s:11:\"\0*\0provider\";s:10:\"path_alias\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\path_alias\\Entity\\PathAlias\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:34:\"Drupal\\path_alias\\PathAliasStorage\";s:14:\"storage_schema\";s:40:\"Drupal\\path_alias\\PathAliasStorageSchema\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:22:\"administer url aliases\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:10:\"path_alias\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";s:19:\"path_alias_revision\";s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:16:\"@count URL alias\";s:6:\"plural\";s:18:\"@count URL aliases\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:11:\"route_match\";}s:14:\"\0*\0constraints\";a:2:{s:15:\"UniquePathAlias\";a:0:{}s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','path_alias.field_storage_definitions',_binary 'a:8:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"und\";}}s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"path\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"System path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The path that this alias belongs to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:4:\"path\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:9:\"ValidPath\";a:0:{}s:5:\"Regex\";a:2:{s:7:\"pattern\";s:6:\"/^\\//i\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The source path has to start with a slash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:18:\"\0*\0fieldDefinition\";r:141;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"alias\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"An alias used with this path.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:5:\"alias\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:5:\"Regex\";a:2:{s:7:\"pattern\";s:6:\"/^\\//i\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"The alias path has to start with a slash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:18:\"\0*\0fieldDefinition\";r:187;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:232;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:271;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','redirect.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:8:\"redirect\";s:8:\"\0*\0class\";s:31:\"Drupal\\redirect\\Entity\\Redirect\";s:11:\"\0*\0provider\";s:8:\"redirect\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:3:\"rid\";s:5:\"label\";s:15:\"redirect_source\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:4:\"type\";s:8:\"langcode\";s:8:\"language\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\redirect\\Entity\\Redirect\";s:11:\"\0*\0handlers\";a:7:{s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:4:\"form\";a:3:{s:7:\"default\";s:33:\"Drupal\\redirect\\Form\\RedirectForm\";s:6:\"delete\";s:39:\"Drupal\\redirect\\Form\\RedirectDeleteForm\";s:4:\"edit\";s:33:\"Drupal\\redirect\\Form\\RedirectForm\";}s:10:\"views_data\";s:33:\"Drupal\\redirect\\RedirectViewsData\";s:14:\"storage_schema\";s:38:\"\\Drupal\\redirect\\RedirectStorageSchema\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:20:\"administer redirects\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:45:\"/admin/config/search/redirect/edit/{redirect}\";s:11:\"delete-form\";s:47:\"/admin/config/search/redirect/delete/{redirect}\";s:9:\"edit-form\";s:45:\"/admin/config/search/redirect/edit/{redirect}\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Redirect type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:8:\"redirect\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Redirect\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:13:\"redirect_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:8:\"redirect\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','redirect.field_storage_definitions',_binary 'a:10:{s:3:\"rid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Redirect ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"The redirect ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:3:\"rid\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"The record UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"hash\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Hash\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"The redirect hash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:4:\"hash\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:64;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"The redirect type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:31:\"The user ID of the node author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:22:\"default_value_callback\";s:50:\"\\Drupal\\redirect\\Entity\\Redirect::getCurrentUserId\";s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:145;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:15:\"redirect_source\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"From\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:152:\"Enter an internal Drupal path or path alias to redirect (e.g. %example1 or %example2). Fragment anchors (e.g. %anchor) are <strong>not</strong> allowed.\";s:12:\"\0*\0arguments\";a:3:{s:9:\"%example1\";s:8:\"node/123\";s:9:\"%example2\";s:17:\"taxonomy/term/123\";s:7:\"%anchor\";s:7:\"#anchor\";}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:13:\"redirect_link\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:15:\"redirect_source\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:26:\"field_item:redirect_source\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:182;}s:7:\"\0*\0type\";s:15:\"redirect_source\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:2:{s:4:\"path\";a:3:{s:11:\"description\";s:15:\"The source path\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"query\";a:4:{s:11:\"description\";s:32:\"Serialized array of path queries\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:4:\"path\";a:1:{i:0;a:2:{i:0;s:4:\"path\";i:1;i:50;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:17:\"redirect_redirect\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"To\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:4:\"link\";s:6:\"weight\";i:-4;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:17:\"redirect_redirect\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}}s:18:\"\0*\0fieldDefinition\";r:233;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"language\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"The redirect language.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:8:\"language\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:283;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"status_code\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Status code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The redirect status code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:11:\"status_code\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:319;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The date when the redirect was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:359;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','rest_resource_config.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:20:\"rest_resource_config\";s:8:\"\0*\0class\";s:37:\"Drupal\\rest\\Entity\\RestResourceConfig\";s:11:\"\0*\0provider\";s:4:\"rest\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:37:\"Drupal\\rest\\Entity\\RestResourceConfig\";s:11:\"\0*\0handlers\";a:3:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:25:\"administer rest resources\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"REST resource configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"REST resource configurations\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"REST resource configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"REST resource configurations\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:34:\"@count REST resource configuration\";s:6:\"plural\";s:35:\"@count REST resource configurations\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:32:\"config:rest_resource_config_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:20:\"rest_resource_config\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:8:\"resource\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:9:\"plugin_id\";i:2;s:11:\"granularity\";i:3;s:13:\"configuration\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','shortcut.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:8:\"shortcut\";s:8:\"\0*\0class\";s:31:\"Drupal\\shortcut\\Entity\\Shortcut\";s:11:\"\0*\0provider\";s:8:\"shortcut\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:12:\"shortcut_set\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\shortcut\\Entity\\Shortcut\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\shortcut\\ShortcutAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:3:\"add\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:4:\"edit\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:6:\"delete\";s:39:\"Drupal\\shortcut\\Form\\ShortcutDeleteForm\";}s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:11:\"delete-form\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete\";s:9:\"edit-form\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";}s:21:\"\0*\0bundle_entity_type\";s:12:\"shortcut_set\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:8:\"shortcut\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:19:\"shortcut_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Shortcut link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Shortcut links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"shortcut link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"shortcut links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:20:\"@count shortcut link\";s:6:\"plural\";s:21:\"@count shortcut links\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:shortcut_set_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','shortcut.field_storage_definitions',_binary 'a:8:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The ID of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The UUID of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"The language code of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"shortcut_set\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"The bundle of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:12:\"shortcut_set\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"shortcut_set\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:116;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The name of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-10;s:8:\"settings\";a:1:{s:4:\"size\";i:40;}}}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:154;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Weight among shortcuts in the same shortcut set.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:197;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"link\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"The location this shortcut points to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:4:\"link\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:1;}}s:18:\"\0*\0fieldDefinition\";r:234;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:287;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','shortcut_set.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"shortcut_set\";s:8:\"\0*\0class\";s:34:\"Drupal\\shortcut\\Entity\\ShortcutSet\";s:11:\"\0*\0provider\";s:8:\"shortcut\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\shortcut\\Entity\\ShortcutSet\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:34:\"Drupal\\shortcut\\ShortcutSetStorage\";s:6:\"access\";s:47:\"Drupal\\shortcut\\ShortcutSetAccessControlHandler\";s:12:\"list_builder\";s:38:\"Drupal\\shortcut\\ShortcutSetListBuilder\";s:4:\"form\";a:5:{s:7:\"default\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:3:\"add\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:4:\"edit\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:9:\"customize\";s:33:\"Drupal\\shortcut\\Form\\SetCustomize\";s:6:\"delete\";s:42:\"Drupal\\shortcut\\Form\\ShortcutSetDeleteForm\";}}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:14:\"customize-form\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize\";s:11:\"delete-form\";s:66:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete\";s:9:\"edit-form\";s:59:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}\";s:10:\"collection\";s:37:\"/admin/config/user-interface/shortcut\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:8:\"shortcut\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Shortcut sets\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"shortcut sets\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:19:\"@count shortcut set\";s:6:\"plural\";s:20:\"@count shortcut sets\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:shortcut_set_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:3:\"set\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:2:{i:0;s:2:\"id\";i:1;s:5:\"label\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','simple_sitemap.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:14:\"simple_sitemap\";s:8:\"\0*\0class\";s:42:\"Drupal\\simple_sitemap\\Entity\\SimpleSitemap\";s:11:\"\0*\0provider\";s:14:\"simple_sitemap\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:5:\"label\";s:5:\"label\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:42:\"Drupal\\simple_sitemap\\Entity\\SimpleSitemap\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:50:\"\\Drupal\\simple_sitemap\\Entity\\SimpleSitemapStorage\";s:12:\"list_builder\";s:47:\"\\Drupal\\simple_sitemap\\SimpleSitemapListBuilder\";s:4:\"form\";a:4:{s:7:\"default\";s:51:\"\\Drupal\\simple_sitemap\\Form\\SimpleSitemapEntityForm\";s:3:\"add\";s:51:\"\\Drupal\\simple_sitemap\\Form\\SimpleSitemapEntityForm\";s:4:\"edit\";s:51:\"\\Drupal\\simple_sitemap\\Form\\SimpleSitemapEntityForm\";s:6:\"delete\";s:36:\"\\Drupal\\Core\\Entity\\EntityDeleteForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:27:\"administer sitemap settings\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:47:\"/admin/config/search/simplesitemap/variants/add\";s:9:\"edit-form\";s:60:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}\";s:11:\"delete-form\";s:67:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}/delete\";s:10:\"collection\";s:34:\"/admin/config/search/simplesitemap\";s:27:\"config-translation-overview\";s:70:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Sitemap\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Sitemaps\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"sitemap\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"sitemaps\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:14:\"@count sitemap\";s:6:\"plural\";s:15:\"@count sitemaps\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:26:\"config:simple_sitemap_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:14:\"simple_sitemap\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:7:\"sitemap\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:4:\"type\";i:4;s:6:\"weight\";i:5;s:6:\"status\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','simple_sitemap_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"simple_sitemap_type\";s:8:\"\0*\0class\";s:46:\"Drupal\\simple_sitemap\\Entity\\SimpleSitemapType\";s:11:\"\0*\0provider\";s:14:\"simple_sitemap\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:46:\"Drupal\\simple_sitemap\\Entity\\SimpleSitemapType\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:54:\"\\Drupal\\simple_sitemap\\Entity\\SimpleSitemapTypeStorage\";s:12:\"list_builder\";s:51:\"\\Drupal\\simple_sitemap\\SimpleSitemapTypeListBuilder\";s:4:\"form\";a:4:{s:7:\"default\";s:55:\"\\Drupal\\simple_sitemap\\Form\\SimpleSitemapTypeEntityForm\";s:3:\"add\";s:55:\"\\Drupal\\simple_sitemap\\Form\\SimpleSitemapTypeEntityForm\";s:4:\"edit\";s:55:\"\\Drupal\\simple_sitemap\\Form\\SimpleSitemapTypeEntityForm\";s:6:\"delete\";s:36:\"\\Drupal\\Core\\Entity\\EntityDeleteForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:27:\"administer sitemap settings\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:44:\"/admin/config/search/simplesitemap/types/add\";s:9:\"edit-form\";s:62:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}\";s:11:\"delete-form\";s:69:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}/delete\";s:10:\"collection\";s:40:\"/admin/config/search/simplesitemap/types\";s:27:\"config-translation-overview\";s:72:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Simple XML sitemap type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Sitemap types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"sitemap type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"sitemap types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count sitemap type\";s:6:\"plural\";s:20:\"@count sitemap types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:simple_sitemap_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:19:\"simple_sitemap_type\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:17:\"sitemap_generator\";i:4;s:14:\"url_generators\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','taxonomy_term.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:13:\"taxonomy_term\";s:8:\"\0*\0class\";s:27:\"Drupal\\taxonomy\\Entity\\Term\";s:11:\"\0*\0provider\";s:8:\"taxonomy\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"tid\";s:8:\"revision\";s:11:\"revision_id\";s:6:\"bundle\";s:3:\"vid\";s:5:\"label\";s:4:\"name\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\taxonomy\\Entity\\Term\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:27:\"Drupal\\taxonomy\\TermStorage\";s:14:\"storage_schema\";s:33:\"Drupal\\taxonomy\\TermStorageSchema\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:6:\"access\";s:40:\"Drupal\\taxonomy\\TermAccessControlHandler\";s:10:\"views_data\";s:29:\"Drupal\\taxonomy\\TermViewsData\";s:4:\"form\";a:4:{s:7:\"default\";s:24:\"Drupal\\taxonomy\\TermForm\";s:6:\"delete\";s:35:\"Drupal\\taxonomy\\Form\\TermDeleteForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:14:\"route_provider\";a:1:{s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}s:11:\"translation\";s:38:\"Drupal\\taxonomy\\TermTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";s:24:\"access taxonomy overview\";s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:8:{s:9:\"canonical\";s:30:\"/taxonomy/term/{taxonomy_term}\";s:11:\"delete-form\";s:37:\"/taxonomy/term/{taxonomy_term}/delete\";s:9:\"edit-form\";s:35:\"/taxonomy/term/{taxonomy_term}/edit\";s:6:\"create\";s:14:\"/taxonomy/term\";s:8:\"revision\";s:69:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view\";s:20:\"revision-delete-form\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete\";s:20:\"revision-revert-form\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert\";s:15:\"version-history\";s:40:\"/taxonomy/term/{taxonomy_term}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:19:\"taxonomy_vocabulary\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:18:\"taxonomy_term_data\";s:22:\"\0*\0revision_data_table\";s:28:\"taxonomy_term_field_revision\";s:17:\"\0*\0revision_table\";s:22:\"taxonomy_term_revision\";s:13:\"\0*\0data_table\";s:24:\"taxonomy_term_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Taxonomy term\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Taxonomy terms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"taxonomy term\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"taxonomy terms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:20:\"@count taxonomy term\";s:6:\"plural\";s:21:\"@count taxonomy terms\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:40:\"entity.taxonomy_vocabulary.overview_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"taxonomy_term_list\";}s:14:\"\0*\0constraints\";a:3:{s:17:\"TaxonomyHierarchy\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','taxonomy_term.field_storage_definitions',_binary 'a:21:{s:3:\"tid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Term ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The term ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:3:\"tid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The term UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The term language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"The vocabulary to which the term is assigned.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:19:\"taxonomy_vocabulary\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:151;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:189;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:219;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:256;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:100;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"class\";s:22:\"Drupal\\user\\StatusItem\";}s:18:\"\0*\0fieldDefinition\";r:298;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:346;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"description\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:14:\"text_textfield\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:11:\"description\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:text_long\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:390;}s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:2:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}s:6:\"format\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;}}s:7:\"indexes\";a:1:{s:6:\"format\";a:1:{i:0;s:6:\"format\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"The weight of this term in relation to other terms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:436;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"parent\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Term Parents\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The parents of this term.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"cardinality\";i:-1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"parent\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:13:\"taxonomy_term\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:476;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the term was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:512;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:543;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:586;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:628;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"rh_action\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:10:\"field_name\";s:9:\"rh_action\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Rabbit Hole action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Specifies which action that Rabbit Hole should take.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:11:\"rh_taxonomy\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:669;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"rh_redirect\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:10:\"field_name\";s:11:\"rh_redirect\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Rabbit Hole redirect path.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The path to where the user should get redirected to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:11:\"rh_taxonomy\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:704;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"rh_redirect_response\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:10:\"field_name\";s:20:\"rh_redirect_response\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Rabbit Hole redirect response code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"Specifies the HTTP response code that should be used when perform a redirect.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:11:\"rh_taxonomy\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:739;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:27:\"rh_redirect_fallback_action\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:10:\"field_name\";s:27:\"rh_redirect_fallback_action\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Rabbit Hole redirect fallback action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:84:\"Specifies the action that should be used when the redirect path is invalid or empty.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:11:\"rh_taxonomy\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:777;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','taxonomy_vocabulary.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"taxonomy_vocabulary\";s:8:\"\0*\0class\";s:33:\"Drupal\\taxonomy\\Entity\\Vocabulary\";s:11:\"\0*\0provider\";s:8:\"taxonomy\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"vid\";s:5:\"label\";s:4:\"name\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\taxonomy\\Entity\\Vocabulary\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:33:\"Drupal\\taxonomy\\VocabularyStorage\";s:12:\"list_builder\";s:37:\"Drupal\\taxonomy\\VocabularyListBuilder\";s:6:\"access\";s:46:\"Drupal\\taxonomy\\VocabularyAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:30:\"Drupal\\taxonomy\\VocabularyForm\";s:5:\"reset\";s:40:\"Drupal\\taxonomy\\Form\\VocabularyResetForm\";s:6:\"delete\";s:41:\"Drupal\\taxonomy\\Form\\VocabularyDeleteForm\";s:8:\"overview\";s:34:\"Drupal\\taxonomy\\Form\\OverviewTerms\";}s:14:\"route_provider\";a:2:{s:4:\"html\";s:54:\"Drupal\\taxonomy\\Entity\\Routing\\VocabularyRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}}s:19:\"\0*\0admin_permission\";s:19:\"administer taxonomy\";s:24:\"\0*\0collection_permission\";s:24:\"access taxonomy overview\";s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:7:{s:8:\"add-form\";s:29:\"/admin/structure/taxonomy/add\";s:11:\"delete-form\";s:61:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete\";s:10:\"reset-form\";s:60:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset\";s:13:\"overview-form\";s:63:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview\";s:9:\"edit-form\";s:54:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}\";s:23:\"entity-permissions-form\";s:75:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions\";s:10:\"collection\";s:25:\"/admin/structure/taxonomy\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:13:\"taxonomy_term\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Taxonomy vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Taxonomy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"vocabularies\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:17:\"@count vocabulary\";s:6:\"plural\";s:19:\"@count vocabularies\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:taxonomy_vocabulary_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:10:\"vocabulary\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:4:\"name\";i:1;s:3:\"vid\";i:2;s:11:\"description\";i:3;s:6:\"weight\";i:4;s:12:\"new_revision\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','user.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"user\";s:8:\"\0*\0class\";s:23:\"Drupal\\user\\Entity\\User\";s:11:\"\0*\0provider\";s:4:\"user\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:3:\"uid\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\user\\Entity\\User\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:23:\"Drupal\\user\\UserStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\user\\UserStorageSchema\";s:6:\"access\";s:36:\"Drupal\\user\\UserAccessControlHandler\";s:12:\"list_builder\";s:27:\"Drupal\\user\\UserListBuilder\";s:10:\"views_data\";s:25:\"Drupal\\user\\UserViewsData\";s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\user\\Entity\\UserRouteProvider\";}s:4:\"form\";a:3:{s:7:\"default\";s:23:\"Drupal\\user\\ProfileForm\";s:6:\"cancel\";s:31:\"Drupal\\user\\Form\\UserCancelForm\";s:8:\"register\";s:24:\"Drupal\\user\\RegisterForm\";}s:11:\"translation\";s:37:\"Drupal\\user\\ProfileTranslationHandler\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:16:\"administer users\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"canonical\";s:12:\"/user/{user}\";s:9:\"edit-form\";s:17:\"/user/{user}/edit\";s:11:\"cancel-form\";s:19:\"/user/{user}/cancel\";s:10:\"collection\";s:13:\"/admin/people\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:5:\"users\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:16:\"users_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"User\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Users\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"users\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:11:\"@count user\";s:6:\"plural\";s:12:\"@count users\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:22:\"entity.user.admin_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"user_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','user.field_storage_definitions',_binary 'a:18:{s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The user ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The user UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The user language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"preferred_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Preferred language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"The user\'s preferred language code for receiving emails and viewing the site.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:18:\"preferred_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:60:\"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes\";}s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:24:\"preferred_admin_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Preferred admin language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:68:\"The user\'s preferred language code for viewing administration pages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";N;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:24:\"preferred_admin_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:60:\"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes\";}s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}}s:18:\"\0*\0fieldDefinition\";r:152;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"The name of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"constraints\";a:2:{s:8:\"UserName\";a:0:{}s:14:\"UserNameUnique\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:5:\"class\";s:25:\"\\Drupal\\user\\UserNameItem\";}s:18:\"\0*\0fieldDefinition\";r:192;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"pass\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Password\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The password of this user (hashed).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:1:{s:18:\"ProtectedUserField\";N;}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"pass\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:password\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:231;}s:7:\"\0*\0type\";s:8:\"password\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The email of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:11:\"constraints\";a:3:{s:14:\"UserMailUnique\";N;s:16:\"UserMailRequired\";N;s:18:\"ProtectedUserField\";N;}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:267;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"timezone\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Timezone\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The timezone of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:8:\"timezone\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:4:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:44:\"Drupal\\user\\Entity\\User::getAllowedTimezones\";}}}}s:5:\"class\";s:24:\"Drupal\\user\\TimeZoneItem\";}s:18:\"\0*\0fieldDefinition\";r:304;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"User status\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Whether the user is active or blocked.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"class\";s:22:\"Drupal\\user\\StatusItem\";}s:18:\"\0*\0fieldDefinition\";r:344;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The time that the user was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:386;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the user was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:415;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"access\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Last access\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"The time that the user last accessed the site.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:6:\"access\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:445;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"login\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Last login\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The time that the user last logged in.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:5:\"login\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:477;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"init\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Initial email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The email address used for initial account creation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"init\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:509;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"roles\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"cardinality\";i:-1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The roles the user has.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:5:\"roles\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:9:\"user_role\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:542;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:578;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"user_picture\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:17:\"user.user_picture\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"dfa0301c-438e-4abc-a17f-d0d555a64089\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:17:\"user.user_picture\";s:13:\"\0*\0field_name\";s:12:\"user_picture\";s:14:\"\0*\0entity_type\";s:4:\"user\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','user_role.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:9:\"user_role\";s:8:\"\0*\0class\";s:23:\"Drupal\\user\\Entity\\Role\";s:11:\"\0*\0provider\";s:4:\"user\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:6:\"weight\";s:6:\"weight\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\user\\Entity\\Role\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:23:\"Drupal\\user\\RoleStorage\";s:6:\"access\";s:36:\"Drupal\\user\\RoleAccessControlHandler\";s:12:\"list_builder\";s:27:\"Drupal\\user\\RoleListBuilder\";s:4:\"form\";a:2:{s:7:\"default\";s:20:\"Drupal\\user\\RoleForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}}s:19:\"\0*\0admin_permission\";s:22:\"administer permissions\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:45:\"/admin/people/roles/manage/{user_role}/delete\";s:9:\"edit-form\";s:38:\"/admin/people/roles/manage/{user_role}\";s:21:\"edit-permissions-form\";s:37:\"/admin/people/permissions/{user_role}\";s:10:\"collection\";s:19:\"/admin/people/roles\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:11:\"@count role\";s:6:\"plural\";s:12:\"@count roles\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:21:\"config:user_role_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"role\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"weight\";i:3;s:8:\"is_admin\";i:4;s:11:\"permissions\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','view.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:4:\"view\";s:8:\"\0*\0class\";s:24:\"Drupal\\views\\Entity\\View\";s:11:\"\0*\0provider\";s:5:\"views\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:24:\"Drupal\\views\\Entity\\View\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:16:\"administer views\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"View\";s:12:\"\0*\0arguments\";a:1:{s:7:\"context\";s:16:\"View entity type\";}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Views\";s:12:\"\0*\0arguments\";a:1:{s:7:\"context\";s:16:\"View entity type\";}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"view\";s:12:\"\0*\0arguments\";a:1:{s:7:\"context\";s:16:\"View entity type\";}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"views\";s:12:\"\0*\0arguments\";a:1:{s:7:\"context\";s:16:\"View entity type\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:2:{s:8:\"singular\";s:11:\"@count view\";s:6:\"plural\";s:12:\"@count views\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:16:\"config:view_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"module\";i:3;s:11:\"description\";i:4;s:3:\"tag\";i:5;s:10:\"base_table\";i:6;s:10:\"base_field\";i:7;s:7:\"display\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','webform.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:7:\"webform\";s:8:\"\0*\0class\";s:29:\"Drupal\\webform\\Entity\\Webform\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"title\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\webform\\Entity\\Webform\";s:11:\"\0*\0handlers\";a:6:{s:7:\"storage\";s:36:\"\\Drupal\\webform\\WebformEntityStorage\";s:12:\"view_builder\";s:39:\"Drupal\\webform\\WebformEntityViewBuilder\";s:12:\"list_builder\";s:39:\"Drupal\\webform\\WebformEntityListBuilder\";s:6:\"access\";s:48:\"Drupal\\webform\\WebformEntityAccessControlHandler\";s:4:\"form\";a:14:{s:3:\"add\";s:35:\"Drupal\\webform\\WebformEntityAddForm\";s:9:\"duplicate\";s:35:\"Drupal\\webform\\WebformEntityAddForm\";s:6:\"delete\";s:38:\"Drupal\\webform\\WebformEntityDeleteForm\";s:23:\"delete-multiple-confirm\";s:51:\"Drupal\\webform\\Form\\WebformEntityDeleteMultipleForm\";s:4:\"edit\";s:40:\"Drupal\\webform\\WebformEntityElementsForm\";s:6:\"export\";s:38:\"Drupal\\webform\\WebformEntityExportForm\";s:8:\"settings\";s:62:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsGeneralForm\";s:13:\"settings_form\";s:59:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsFormForm\";s:20:\"settings_submissions\";s:66:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsSubmissionsForm\";s:21:\"settings_confirmation\";s:67:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsConfirmationForm\";s:15:\"settings_assets\";s:61:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsAssetsForm\";s:15:\"settings_access\";s:61:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsAccessForm\";s:8:\"handlers\";s:40:\"Drupal\\webform\\WebformEntityHandlersForm\";s:8:\"variants\";s:40:\"Drupal\\webform\\WebformEntityVariantsForm\";}s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:24:{s:9:\"canonical\";s:18:\"/webform/{webform}\";s:13:\"access-denied\";s:32:\"/webform/{webform}/access-denied\";s:11:\"submissions\";s:30:\"/webform/{webform}/submissions\";s:8:\"add-form\";s:18:\"/webform/{webform}\";s:9:\"edit-form\";s:50:\"/admin/structure/webform/manage/{webform}/elements\";s:9:\"test-form\";s:23:\"/webform/{webform}/test\";s:14:\"duplicate-form\";s:51:\"/admin/structure/webform/manage/{webform}/duplicate\";s:11:\"delete-form\";s:48:\"/admin/structure/webform/manage/{webform}/delete\";s:20:\"delete-multiple-form\";s:31:\"/admin/structure/webform/delete\";s:11:\"export-form\";s:48:\"/admin/structure/webform/manage/{webform}/export\";s:8:\"settings\";s:50:\"/admin/structure/webform/manage/{webform}/settings\";s:13:\"settings-form\";s:55:\"/admin/structure/webform/manage/{webform}/settings/form\";s:20:\"settings-submissions\";s:62:\"/admin/structure/webform/manage/{webform}/settings/submissions\";s:21:\"settings-confirmation\";s:63:\"/admin/structure/webform/manage/{webform}/settings/confirmation\";s:15:\"settings-assets\";s:57:\"/admin/structure/webform/manage/{webform}/settings/assets\";s:15:\"settings-access\";s:57:\"/admin/structure/webform/manage/{webform}/settings/access\";s:8:\"handlers\";s:50:\"/admin/structure/webform/manage/{webform}/handlers\";s:8:\"variants\";s:50:\"/admin/structure/webform/manage/{webform}/variants\";s:19:\"results-submissions\";s:61:\"/admin/structure/webform/manage/{webform}/results/submissions\";s:14:\"results-export\";s:58:\"/admin/structure/webform/manage/{webform}/results/download\";s:11:\"results-log\";s:53:\"/admin/structure/webform/manage/{webform}/results/log\";s:13:\"results-clear\";s:55:\"/admin/structure/webform/manage/{webform}/results/clear\";s:10:\"collection\";s:24:\"/admin/structure/webform\";s:27:\"config-translation-overview\";s:60:\"/admin/structure/webform/manage/{webform}/elements/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:18:\"webform_submission\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:14:\"@count webform\";s:6:\"plural\";s:15:\"@count webforms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:19:\"config:webform_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:7:\"webform\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:3:{i:0;s:6:\"status\";i:1;s:8:\"template\";i:2;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:20:{i:0;s:6:\"status\";i:1;s:4:\"open\";i:2;s:5:\"close\";i:3;s:6:\"weight\";i:4;s:3:\"uid\";i:5;s:8:\"template\";i:6;s:7:\"archive\";i:7;s:2:\"id\";i:8;s:4:\"uuid\";i:9;s:5:\"title\";i:10;s:11:\"description\";i:11;s:10:\"categories\";i:12;s:8:\"elements\";i:13;s:3:\"css\";i:14;s:10:\"javascript\";i:15;s:8:\"settings\";i:16;s:6:\"access\";i:17;s:8:\"handlers\";i:18;s:8:\"variants\";i:19;s:20:\"third_party_settings\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','webform_access_group.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:20:\"webform_access_group\";s:8:\"\0*\0class\";s:47:\"Drupal\\webform_access\\Entity\\WebformAccessGroup\";s:11:\"\0*\0provider\";s:14:\"webform_access\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:47:\"Drupal\\webform_access\\Entity\\WebformAccessGroup\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:48:\"\\Drupal\\webform_access\\WebformAccessGroupStorage\";s:6:\"access\";s:60:\"Drupal\\webform_access\\WebformAccessGroupAccessControlHandler\";s:12:\"list_builder\";s:51:\"Drupal\\webform_access\\WebformAccessGroupListBuilder\";s:4:\"form\";a:4:{s:3:\"add\";s:44:\"Drupal\\webform_access\\WebformAccessGroupForm\";s:4:\"edit\";s:44:\"Drupal\\webform_access\\WebformAccessGroupForm\";s:9:\"duplicate\";s:44:\"Drupal\\webform_access\\WebformAccessGroupForm\";s:6:\"delete\";s:50:\"Drupal\\webform_access\\WebformAccessGroupDeleteForm\";}s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:6:{s:8:\"add-form\";s:55:\"/admin/structure/webform/config/access/group/manage/add\";s:9:\"edit-form\";s:74:\"/admin/structure/webform/config/access/group/manage/{webform_access_group}\";s:14:\"duplicate-form\";s:84:\"/admin/structure/webform/config/access/group/manage/{webform_access_group}/duplicate\";s:11:\"delete-form\";s:81:\"/admin/structure/webform/config/access/group/manage/{webform_access_group}/delete\";s:10:\"collection\";s:51:\"/admin/structure/webform/config/access/group/manage\";s:27:\"config-translation-overview\";s:84:\"/admin/structure/webform/config/access/group/manage/{webform_access_group}/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Webform access group\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Access groups\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"access group\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"access groups\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count access group\";s:6:\"plural\";s:20:\"@count access groups\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:32:\"config:webform_access_group_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:20:\"webform_access_group\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:2:\"id\";i:1;s:4:\"uuid\";i:2;s:5:\"label\";i:3;s:11:\"description\";i:4;s:4:\"type\";i:5;s:11:\"permissions\";i:6;s:6:\"emails\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','webform_access_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"webform_access_type\";s:8:\"\0*\0class\";s:46:\"Drupal\\webform_access\\Entity\\WebformAccessType\";s:11:\"\0*\0provider\";s:14:\"webform_access\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:46:\"Drupal\\webform_access\\Entity\\WebformAccessType\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:47:\"\\Drupal\\webform_access\\WebformAccessTypeStorage\";s:6:\"access\";s:59:\"Drupal\\webform_access\\WebformAccessTypeAccessControlHandler\";s:12:\"list_builder\";s:50:\"Drupal\\webform_access\\WebformAccessTypeListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:43:\"Drupal\\webform_access\\WebformAccessTypeForm\";s:4:\"edit\";s:43:\"Drupal\\webform_access\\WebformAccessTypeForm\";s:6:\"delete\";s:49:\"Drupal\\webform_access\\WebformAccessTypeDeleteForm\";}s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:54:\"/admin/structure/webform/config/access/type/manage/add\";s:9:\"edit-form\";s:72:\"/admin/structure/webform/config/access/type/manage/{webform_access_type}\";s:11:\"delete-form\";s:79:\"/admin/structure/webform/config/access/type/manage/{webform_access_type}/delete\";s:10:\"collection\";s:50:\"/admin/structure/webform/config/access/type/manage\";s:27:\"config-translation-overview\";s:82:\"/admin/structure/webform/config/access/type/manage/{webform_access_type}/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Webform access type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Access types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"access type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"access types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count access type\";s:6:\"plural\";s:19:\"@count access types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:webform_access_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:19:\"webform_access_type\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:3:{i:0;s:2:\"id\";i:1;s:4:\"uuid\";i:2;s:5:\"label\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','webform_options.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:15:\"webform_options\";s:8:\"\0*\0class\";s:36:\"Drupal\\webform\\Entity\\WebformOptions\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:36:\"Drupal\\webform\\Entity\\WebformOptions\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:37:\"\\Drupal\\webform\\WebformOptionsStorage\";s:6:\"access\";s:49:\"Drupal\\webform\\WebformOptionsAccessControlHandler\";s:12:\"list_builder\";s:40:\"Drupal\\webform\\WebformOptionsListBuilder\";s:4:\"form\";a:4:{s:3:\"add\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:4:\"edit\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:9:\"duplicate\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:6:\"delete\";s:39:\"Drupal\\webform\\WebformOptionsDeleteForm\";}s:23:\"config_translation_list\";s:71:\"Drupal\\config_translation\\Controller\\ConfigTranslationEntityListBuilder\";}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:6:{s:8:\"add-form\";s:43:\"/admin/structure/webform/options/manage/add\";s:9:\"edit-form\";s:62:\"/admin/structure/webform/options/manage/{webform_options}/edit\";s:14:\"duplicate-form\";s:67:\"/admin/structure/webform/options/manage/{webform_options}/duplicate\";s:11:\"delete-form\";s:64:\"/admin/structure/webform/options/manage/{webform_options}/delete\";s:10:\"collection\";s:39:\"/admin/structure/webform/options/manage\";s:27:\"config-translation-overview\";s:72:\"/admin/structure/webform/options/manage/{webform_options}/edit/translate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count webform options\";s:6:\"plural\";s:22:\"@count webform options\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:27:\"config:webform_options_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:15:\"webform_options\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:4:\"uuid\";i:2;s:5:\"label\";i:3;s:8:\"category\";i:4;s:6:\"likert\";i:5;s:7:\"options\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','webform_submission.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:18:\"webform_submission\";s:8:\"\0*\0class\";s:39:\"Drupal\\webform\\Entity\\WebformSubmission\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:3:\"sid\";s:6:\"bundle\";s:10:\"webform_id\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:39:\"Drupal\\webform\\Entity\\WebformSubmission\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:39:\"Drupal\\webform\\WebformSubmissionStorage\";s:14:\"storage_schema\";s:45:\"Drupal\\webform\\WebformSubmissionStorageSchema\";s:10:\"views_data\";s:41:\"Drupal\\webform\\WebformSubmissionViewsData\";s:12:\"view_builder\";s:43:\"Drupal\\webform\\WebformSubmissionViewBuilder\";s:12:\"list_builder\";s:43:\"Drupal\\webform\\WebformSubmissionListBuilder\";s:6:\"access\";s:52:\"Drupal\\webform\\WebformSubmissionAccessControlHandler\";s:4:\"form\";a:8:{s:3:\"add\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:4:\"edit\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:8:\"edit_all\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:3:\"api\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:4:\"test\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:5:\"notes\";s:41:\"Drupal\\webform\\WebformSubmissionNotesForm\";s:9:\"duplicate\";s:45:\"Drupal\\webform\\WebformSubmissionDuplicateForm\";s:6:\"delete\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionDeleteForm\";}}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:11:{s:9:\"canonical\";s:73:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}\";s:13:\"access-denied\";s:87:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied\";s:5:\"table\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table\";s:4:\"text\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text\";s:4:\"yaml\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml\";s:9:\"edit-form\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit\";s:10:\"notes-form\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes\";s:11:\"resend-form\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend\";s:14:\"duplicate-form\";s:83:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate\";s:11:\"delete-form\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete\";s:10:\"collection\";s:48:\"/admin/structure/webform/submissions/manage/list\";}s:21:\"\0*\0bundle_entity_type\";s:7:\"webform\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:18:\"webform_submission\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Webform submission\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"submission\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count submission\";s:6:\"plural\";s:18:\"@count submissions\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:1:{i:0;s:4:\"user\";}s:18:\"\0*\0list_cache_tags\";a:2:{i:0;s:19:\"config:webform_list\";i:1;s:23:\"webform_submission_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:18:\"webform_submission\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','webform_submission.field_storage_definitions',_binary 'a:19:{s:6:\"serial\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Serial number\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"The serial number of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"serial\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"sid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Submission ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The ID of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"sid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:39;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Submission UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The UUID of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:76;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"token\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Token\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"A secure token used to look up a submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:5:\"token\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:112;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uri\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Submission URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The URI the user submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"uri\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:2000;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:146;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2000;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"The time that the webform submission was first saved as draft or submitted.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:180;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"completed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Completed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"The time that the webform submission was submitted as complete (not draft).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:9:\"completed\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:208;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"The time that the webform submission was last saved (complete or draft).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:236;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"in_draft\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Is draft\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Is this a draft of the submission?\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:8:\"in_draft\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:264;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"current_page\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Current page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"The current wizard page.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:12:\"current_page\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:304;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"remote_addr\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Remote IP address\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The IP address of the user that submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:11:\"remote_addr\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:337;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Submitted by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The username of the user that submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:22:\"default_value_callback\";s:57:\"Drupal\\webform\\Entity\\WebformSubmission::getCurrentUserId\";s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:370;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"The submission language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:406;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"webform_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The associated webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:7:\"webform\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:435;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"entity_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Submitted to: Entity type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"The entity type to which this submission was submitted from.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:470;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"entity_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Submitted to: Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:73:\"The ID of the entity of which this webform submission was submitted from.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:503;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"locked\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Locked\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"A flag that indicates a locked webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"locked\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:536;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"sticky\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Sticky\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag that indicate the status of the webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"sticky\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:576;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"notes\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Notes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"Administrative notes about the webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:5:\"notes\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:616;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.storage_schema.sql','block_content.entity_schema_data',_binary 'a:4:{s:13:\"block_content\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:26:\"block_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"block_content_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:17:\"block_content__id\";a:1:{i:0;s:2:\"id\";}}}s:24:\"block_content_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:45:\"block_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:26:\"block_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"block_content__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:2:\"id\";}}}s:28:\"block_content_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:45:\"block_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.body',_binary 'a:2:{s:19:\"block_content__body\";a:4:{s:11:\"description\";s:42:\"Data storage for block_content field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}s:28:\"block_content_revision__body\";a:4:{s:11:\"description\";s:54:\"Revision archive storage for block_content field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.changed',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.default_langcode',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.id',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.info',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"info\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"info\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.langcode',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.reusable',_binary 'a:1:{s:24:\"block_content_field_data\";a:2:{s:6:\"fields\";a:1:{s:8:\"reusable\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:29:\"block_content_field__reusable\";a:1:{i:0;s:8:\"reusable\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_created',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_default',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_id',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_log',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:12:\"revision_log\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_translation_affected',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_user',_binary 'a:1:{s:22:\"block_content_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:45:\"block_content_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.status',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.type',_binary 'a:2:{s:13:\"block_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:36:\"block_content_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:24:\"block_content_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:36:\"block_content_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.uuid',_binary 'a:1:{s:13:\"block_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:32:\"block_content_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','comment.entity_schema_data',_binary 'a:2:{s:7:\"comment\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"cid\";}}s:18:\"comment_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"cid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:39:\"comment__id__default_langcode__langcode\";a:3:{i:0;s:3:\"cid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:28:\"comment__status_comment_type\";a:3:{i:0;s:6:\"status\";i:1;s:12:\"comment_type\";i:2;s:3:\"cid\";}s:19:\"comment__status_pid\";a:2:{i:0;s:3:\"pid\";i:1;s:6:\"status\";}s:16:\"comment__num_new\";a:7:{i:0;s:9:\"entity_id\";i:1;s:11:\"entity_type\";i:2;s:12:\"comment_type\";i:3;s:6:\"status\";i:4;s:7:\"created\";i:5;s:3:\"cid\";i:6;s:6:\"thread\";}s:24:\"comment__entity_langcode\";a:4:{i:0;s:9:\"entity_id\";i:1;s:11:\"entity_type\";i:2;s:12:\"comment_type\";i:3;s:16:\"default_langcode\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.changed',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.cid',_binary 'a:2:{s:7:\"comment\";a:1:{s:6:\"fields\";a:1:{s:3:\"cid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"cid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.comment_body',_binary 'a:1:{s:21:\"comment__comment_body\";a:4:{s:11:\"description\";s:44:\"Data storage for comment field comment_body.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:18:\"comment_body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:19:\"comment_body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:19:\"comment_body_format\";a:1:{i:0;s:19:\"comment_body_format\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.comment_type',_binary 'a:2:{s:7:\"comment\";a:2:{s:6:\"fields\";a:1:{s:12:\"comment_type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:38:\"comment_field__comment_type__target_id\";a:1:{i:0;s:12:\"comment_type\";}}}s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:12:\"comment_type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:38:\"comment_field__comment_type__target_id\";a:1:{i:0;s:12:\"comment_type\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.created',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:22:\"comment_field__created\";a:1:{i:0;s:7:\"created\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.default_langcode',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.entity_id',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:9:\"entity_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','comment.field_schema_data.entity_type',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"entity_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.field_name',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:10:\"field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.homepage',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"homepage\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.hostname',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"hostname\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.langcode',_binary 'a:2:{s:7:\"comment\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.mail',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"mail\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.name',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.pid',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"pid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','comment.field_schema_data.status',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.subject',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"subject\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.thread',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"thread\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.uid',_binary 'a:1:{s:18:\"comment_field_data\";a:3:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:29:\"comment_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}s:12:\"foreign keys\";a:1:{s:18:\"comment_field__uid\";a:2:{s:5:\"table\";s:5:\"users\";s:7:\"columns\";a:1:{s:3:\"uid\";s:3:\"uid\";}}}}}'),('entity.storage_schema.sql','comment.field_schema_data.uuid',_binary 'a:1:{s:7:\"comment\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:26:\"comment_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','file.entity_schema_data',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"fid\";}}}'),('entity.storage_schema.sql','file.field_schema_data.changed',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"file_field__changed\";a:1:{i:0;s:7:\"changed\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.created',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.fid',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:3:\"fid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filemime',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filemime\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filename',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filename\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filesize',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filesize\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.langcode',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','file.field_schema_data.status',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:18:\"file_field__status\";a:1:{i:0;s:6:\"status\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uid',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:26:\"file_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uri',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:3:\"uri\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:15:\"file_field__uri\";a:1:{i:0;s:3:\"uri\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uuid',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"file_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','menu_link_content.entity_schema_data',_binary 'a:4:{s:17:\"menu_link_content\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:30:\"menu_link_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:26:\"menu_link_content_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:21:\"menu_link_content__id\";a:1:{i:0;s:2:\"id\";}}}s:22:\"menu_link_content_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:49:\"menu_link_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:30:\"menu_link_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"menu_link_content__enabled_bundle\";a:3:{i:0;s:7:\"enabled\";i:1;s:6:\"bundle\";i:2;s:2:\"id\";}}}s:32:\"menu_link_content_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:49:\"menu_link_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.bundle',_binary 'a:2:{s:17:\"menu_link_content\";a:2:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:42:\"menu_link_content_field__bundle__target_id\";a:1:{i:0;s:6:\"bundle\";}}}s:22:\"menu_link_content_data\";a:2:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:42:\"menu_link_content_field__bundle__target_id\";a:1:{i:0;s:6:\"bundle\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.changed',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.default_langcode',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.description',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"description\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"description\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.enabled',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"enabled\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"enabled\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.expanded',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"expanded\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.external',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"external\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"external\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.id',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.langcode',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.link',_binary 'a:2:{s:22:\"menu_link_content_data\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:34:\"menu_link_content_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}s:32:\"menu_link_content_field_revision\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:34:\"menu_link_content_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.menu_name',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"menu_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.parent',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"parent\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.rediscover',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:10:\"rediscover\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_created',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_default',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_id',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_log_message',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_translation_affected',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_user',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:29:\"menu_link_content__ef029a1897\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.title',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.uuid',_binary 'a:1:{s:17:\"menu_link_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:36:\"menu_link_content_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.view_mode',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"view_mode\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.weight',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.entity_schema_data',_binary 'a:4:{s:4:\"node\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"nid\";}s:11:\"unique keys\";a:1:{s:9:\"node__vid\";a:1:{i:0;s:3:\"vid\";}}}s:13:\"node_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"vid\";}s:7:\"indexes\";a:1:{s:9:\"node__nid\";a:1:{i:0;s:3:\"nid\";}}}s:15:\"node_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"nid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:36:\"node__id__default_langcode__langcode\";a:3:{i:0;s:3:\"nid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:9:\"node__vid\";a:1:{i:0;s:3:\"vid\";}s:17:\"node__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:3:\"nid\";}s:15:\"node__frontpage\";a:4:{i:0;s:7:\"promote\";i:1;s:6:\"status\";i:2;s:6:\"sticky\";i:3;s:7:\"created\";}s:16:\"node__title_type\";a:2:{i:0;s:5:\"title\";i:1;a:2:{i:0;s:4:\"type\";i:1;i:4;}}}}s:19:\"node_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"vid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:36:\"node__id__default_langcode__langcode\";a:3:{i:0;s:3:\"nid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.body',_binary 'a:2:{s:10:\"node__body\";a:4:{s:11:\"description\";s:33:\"Data storage for node field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}s:19:\"node_revision__body\";a:4:{s:11:\"description\";s:45:\"Revision archive storage for node field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.changed',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"node_field__changed\";a:1:{i:0;s:7:\"changed\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.comment',_binary 'a:2:{s:13:\"node__comment\";a:4:{s:11:\"description\";s:36:\"Data storage for node field comment.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:14:\"comment_status\";a:4:{s:11:\"description\";s:99:\"Whether comments are allowed on this entity: 0 = no, 1 = closed (read only), 2 = open (read/write).\";s:4:\"type\";s:3:\"int\";s:7:\"default\";i:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"node_revision__comment\";a:4:{s:11:\"description\";s:48:\"Revision archive storage for node field comment.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:14:\"comment_status\";a:4:{s:11:\"description\";s:99:\"Whether comments are allowed on this entity: 0 = no, 1 = closed (read only), 2 = open (read/write).\";s:4:\"type\";s:3:\"int\";s:7:\"default\";i:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.created',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"node_field__created\";a:1:{i:0;s:7:\"created\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.default_langcode',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.field_image',_binary 'a:2:{s:17:\"node__field_image\";a:5:{s:11:\"description\";s:40:\"Data storage for node field field_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:15:\"field_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:17:\"field_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:17:\"field_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:18:\"field_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_image_target_id\";a:1:{i:0;s:21:\"field_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:21:\"field_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:21:\"field_image_target_id\";s:3:\"fid\";}}}}s:26:\"node_revision__field_image\";a:5:{s:11:\"description\";s:52:\"Revision archive storage for node field field_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:15:\"field_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:17:\"field_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:17:\"field_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:18:\"field_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_image_target_id\";a:1:{i:0;s:21:\"field_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:21:\"field_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:21:\"field_image_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','node.field_schema_data.field_tags',_binary 'a:2:{s:16:\"node__field_tags\";a:4:{s:11:\"description\";s:39:\"Data storage for node field field_tags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_tags_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:20:\"field_tags_target_id\";a:1:{i:0;s:20:\"field_tags_target_id\";}}}s:25:\"node_revision__field_tags\";a:4:{s:11:\"description\";s:51:\"Revision archive storage for node field field_tags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_tags_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:20:\"field_tags_target_id\";a:1:{i:0;s:20:\"field_tags_target_id\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.langcode',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:2:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:20:\"node_field__langcode\";a:1:{i:0;s:8:\"langcode\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.nid',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.promote',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"promote\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"promote\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_default',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_log',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:12:\"revision_log\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_timestamp',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:18:\"revision_timestamp\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_translation_affected',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_uid',_binary 'a:1:{s:13:\"node_revision\";a:3:{s:6:\"fields\";a:1:{s:12:\"revision_uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:35:\"node_field__revision_uid__target_id\";a:1:{i:0;s:12:\"revision_uid\";}}s:12:\"foreign keys\";a:1:{s:24:\"node_field__revision_uid\";a:2:{s:5:\"table\";s:5:\"users\";s:7:\"columns\";a:1:{s:12:\"revision_uid\";s:3:\"uid\";}}}}}'),('entity.storage_schema.sql','node.field_schema_data.rh_action',_binary 'a:1:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"rh_action\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.rh_redirect',_binary 'a:1:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"rh_redirect\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.rh_redirect_fallback_action',_binary 'a:1:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:27:\"rh_redirect_fallback_action\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.rh_redirect_response',_binary 'a:1:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:20:\"rh_redirect_response\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.status',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.sticky',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.title',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.type',_binary 'a:2:{s:4:\"node\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"node_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"node_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.uid',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:26:\"node_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}s:19:\"node_field_revision\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:26:\"node_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.uuid',_binary 'a:1:{s:4:\"node\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"node_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.vid',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.webform',_binary 'a:2:{s:13:\"node__webform\";a:4:{s:11:\"description\";s:36:\"Data storage for node field webform.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:17:\"webform_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:20:\"webform_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:14:\"webform_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:12:\"webform_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:13:\"webform_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:17:\"webform_target_id\";a:1:{i:0;s:17:\"webform_target_id\";}}}s:22:\"node_revision__webform\";a:4:{s:11:\"description\";s:48:\"Revision archive storage for node field webform.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:17:\"webform_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:20:\"webform_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:14:\"webform_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:12:\"webform_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:13:\"webform_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:17:\"webform_target_id\";a:1:{i:0;s:17:\"webform_target_id\";}}}}'),('entity.storage_schema.sql','path_alias.entity_schema_data',_binary 'a:2:{s:10:\"path_alias\";a:3:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:7:\"indexes\";a:2:{s:36:\"path_alias__alias_langcode_id_status\";a:4:{i:0;s:5:\"alias\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}s:35:\"path_alias__path_langcode_id_status\";a:4:{i:0;s:4:\"path\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}}s:11:\"unique keys\";a:1:{s:23:\"path_alias__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:19:\"path_alias_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:3:{s:14:\"path_alias__id\";a:1:{i:0;s:2:\"id\";}s:45:\"path_alias_revision__alias_langcode_id_status\";a:4:{i:0;s:5:\"alias\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}s:44:\"path_alias_revision__path_langcode_id_status\";a:4:{i:0;s:4:\"path\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.alias',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:5:\"alias\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"alias\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.id',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.langcode',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.path',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:4:\"path\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"path\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.revision_default',_binary 'a:1:{s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.revision_id',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.status',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.uuid',_binary 'a:1:{s:10:\"path_alias\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:29:\"path_alias_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','redirect.entity_schema_data',_binary 'a:1:{s:8:\"redirect\";a:3:{s:11:\"primary key\";a:1:{i:0;s:3:\"rid\";}s:7:\"indexes\";a:1:{s:15:\"source_language\";a:2:{i:0;a:2:{i:0;s:21:\"redirect_source__path\";i:1;i:191;}i:1;s:8:\"language\";}}s:11:\"unique keys\";a:1:{s:4:\"hash\";a:1:{i:0;s:4:\"hash\";}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.created',_binary 'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.hash',_binary 'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:4:\"hash\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.language',_binary 'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:8:\"language\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.redirect_redirect',_binary 'a:1:{s:8:\"redirect\";a:2:{s:6:\"fields\";a:3:{s:22:\"redirect_redirect__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:24:\"redirect_redirect__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"redirect_redirect__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:38:\"redirect_field__redirect_redirect__uri\";a:1:{i:0;a:2:{i:0;s:22:\"redirect_redirect__uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.redirect_source',_binary 'a:1:{s:8:\"redirect\";a:2:{s:6:\"fields\";a:2:{s:21:\"redirect_source__path\";a:4:{s:11:\"description\";s:15:\"The source path\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:22:\"redirect_source__query\";a:5:{s:11:\"description\";s:32:\"Serialized array of path queries\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:37:\"redirect_field__redirect_source__path\";a:1:{i:0;a:2:{i:0;s:21:\"redirect_source__path\";i:1;i:50;}}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.rid',_binary 'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:3:\"rid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.status_code',_binary 'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:11:\"status_code\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.type',_binary 'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.uid',_binary 'a:1:{s:8:\"redirect\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:30:\"redirect_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','redirect.field_schema_data.uuid',_binary 'a:1:{s:8:\"redirect\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:27:\"redirect_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','shortcut.entity_schema_data',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}}s:19:\"shortcut_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:40:\"shortcut__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.default_langcode',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.id',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.langcode',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.link',_binary 'a:1:{s:19:\"shortcut_field_data\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:25:\"shortcut_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.shortcut_set',_binary 'a:2:{s:8:\"shortcut\";a:2:{s:6:\"fields\";a:1:{s:12:\"shortcut_set\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:39:\"shortcut_field__shortcut_set__target_id\";a:1:{i:0;s:12:\"shortcut_set\";}}}s:19:\"shortcut_field_data\";a:2:{s:6:\"fields\";a:1:{s:12:\"shortcut_set\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:39:\"shortcut_field__shortcut_set__target_id\";a:1:{i:0;s:12:\"shortcut_set\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.title',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.uuid',_binary 'a:1:{s:8:\"shortcut\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:27:\"shortcut_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.weight',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.entity_schema_data',_binary 'a:5:{s:18:\"taxonomy_term_data\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"tid\";}s:11:\"unique keys\";a:1:{s:26:\"taxonomy_term__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"taxonomy_term_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:18:\"taxonomy_term__tid\";a:1:{i:0;s:3:\"tid\";}}}s:24:\"taxonomy_term_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"tid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:45:\"taxonomy_term__id__default_langcode__langcode\";a:3:{i:0;s:3:\"tid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:26:\"taxonomy_term__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"taxonomy_term__status_vid\";a:3:{i:0;s:6:\"status\";i:1;s:3:\"vid\";i:2;s:3:\"tid\";}s:19:\"taxonomy_term__tree\";a:3:{i:0;s:3:\"vid\";i:1;s:6:\"weight\";i:2;s:4:\"name\";}s:23:\"taxonomy_term__vid_name\";a:2:{i:0;s:3:\"vid\";i:1;s:4:\"name\";}}}s:28:\"taxonomy_term_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:45:\"taxonomy_term__id__default_langcode__langcode\";a:3:{i:0;s:3:\"tid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}s:14:\"taxonomy_index\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"nid\";i:1;s:3:\"tid\";}s:7:\"indexes\";a:1:{s:9:\"term_node\";a:4:{i:0;s:3:\"tid\";i:1;s:6:\"status\";i:2;s:6:\"sticky\";i:3;s:7:\"created\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.changed',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.default_langcode',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.description',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:2:{s:18:\"description__value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:19:\"description__format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}s:28:\"taxonomy_term_field_revision\";a:2:{s:6:\"fields\";a:2:{s:18:\"description__value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:19:\"description__format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:40:\"taxonomy_term_field__description__format\";a:1:{i:0;s:19:\"description__format\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.langcode',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.name',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:25:\"taxonomy_term_field__name\";a:1:{i:0;s:4:\"name\";}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.parent',_binary 'a:2:{s:21:\"taxonomy_term__parent\";a:4:{s:11:\"description\";s:44:\"Data storage for taxonomy_term field parent.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:16:\"parent_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:16:\"parent_target_id\";a:1:{i:0;s:16:\"parent_target_id\";}s:22:\"bundle_delta_target_id\";a:3:{i:0;s:6:\"bundle\";i:1;s:5:\"delta\";i:2;s:16:\"parent_target_id\";}}}s:30:\"taxonomy_term_revision__parent\";a:4:{s:11:\"description\";s:56:\"Revision archive storage for taxonomy_term field parent.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:16:\"parent_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:16:\"parent_target_id\";a:1:{i:0;s:16:\"parent_target_id\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_created',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_default',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_id',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_log_message',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_translation_affected',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_user',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:45:\"taxonomy_term_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.rh_action',_binary 'a:1:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"rh_action\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.rh_redirect',_binary 'a:1:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"rh_redirect\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.rh_redirect_fallback_action',_binary 'a:1:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:27:\"rh_redirect_fallback_action\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.rh_redirect_response',_binary 'a:1:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:20:\"rh_redirect_response\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.status',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.tid',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.uuid',_binary 'a:1:{s:18:\"taxonomy_term_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:32:\"taxonomy_term_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.vid',_binary 'a:2:{s:18:\"taxonomy_term_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:35:\"taxonomy_term_field__vid__target_id\";a:1:{i:0;s:3:\"vid\";}}}s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.weight',_binary 'a:1:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.entity_schema_data',_binary 'a:2:{s:5:\"users\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"uid\";}}s:16:\"users_field_data\";a:3:{s:11:\"primary key\";a:2:{i:0;s:3:\"uid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:36:\"user__id__default_langcode__langcode\";a:3:{i:0;s:3:\"uid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}s:11:\"unique keys\";a:1:{s:10:\"user__name\";a:2:{i:0;s:4:\"name\";i:1;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.access',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:6:\"access\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:18:\"user_field__access\";a:1:{i:0;s:6:\"access\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.changed',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.created',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"user_field__created\";a:1:{i:0;s:7:\"created\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.default_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.init',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"init\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.langcode',_binary 'a:2:{s:5:\"users\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.login',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"login\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.mail',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"mail\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:16:\"user_field__mail\";a:1:{i:0;s:4:\"mail\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.name',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.pass',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"pass\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.preferred_admin_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:24:\"preferred_admin_langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.preferred_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:18:\"preferred_langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.roles',_binary 'a:1:{s:11:\"user__roles\";a:4:{s:11:\"description\";s:34:\"Data storage for user field roles.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:15:\"roles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:15:\"roles_target_id\";a:1:{i:0;s:15:\"roles_target_id\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.status',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.timezone',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"timezone\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.uid',_binary 'a:2:{s:5:\"users\";a:1:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.user_picture',_binary 'a:1:{s:18:\"user__user_picture\";a:5:{s:11:\"description\";s:41:\"Data storage for user field user_picture.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"user_picture_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:16:\"user_picture_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:18:\"user_picture_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:18:\"user_picture_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:19:\"user_picture_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"user_picture_target_id\";a:1:{i:0;s:22:\"user_picture_target_id\";}}s:12:\"foreign keys\";a:1:{s:22:\"user_picture_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:22:\"user_picture_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','user.field_schema_data.uuid',_binary 'a:1:{s:5:\"users\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"user_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','webform_submission.entity_schema_data',_binary 'a:2:{s:18:\"webform_submission\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"sid\";}}s:23:\"webform_submission_data\";a:2:{s:11:\"primary key\";a:4:{i:0;s:3:\"sid\";i:1;s:4:\"name\";i:2;s:8:\"property\";i:3;s:5:\"delta\";}s:7:\"indexes\";a:2:{s:10:\"webform_id\";a:1:{i:0;s:10:\"webform_id\";}s:14:\"sid_webform_id\";a:2:{i:0;s:3:\"sid\";i:1;s:10:\"webform_id\";}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.changed',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.completed',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:9:\"completed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.created',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.current_page',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:12:\"current_page\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.entity_id',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:9:\"entity_id\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.entity_type',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:11:\"entity_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.in_draft',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:8:\"in_draft\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.langcode',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.locked',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"locked\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.notes',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:5:\"notes\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.remote_addr',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:11:\"remote_addr\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.serial',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"serial\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.sid',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:3:\"sid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.sticky',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.token',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:5:\"token\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.uid',_binary 'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:40:\"webform_submission_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.uri',_binary 'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:3:\"uri\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2000;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.uuid',_binary 'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:37:\"webform_submission_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','webform_submission.field_schema_data.webform_id',_binary 'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:10:\"webform_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:47:\"webform_submission_field__webform_id__target_id\";a:1:{i:0;s:10:\"webform_id\";}}}}'),('entity_autocomplete','2OK8JIoDgqOAFKcbl_4ITXc9CKV55W5PuZXBBcbDdvo',_binary 'a:5:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','oupZmio9jZBS_uk1Wv3mgSfPKDtTJuFAQ2n-RvgZFwE',_binary 'a:0:{}'),('entity_autocomplete','RcbQW1ZpCoUT791cVn9IYqIxYrcsXaSl0AeIRIW7fTI',_binary 'a:2:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','x4XuA_irA0mN6yAetckqJEj_MyvfxdfDzZ0aGG-pbkE',_binary 'a:1:{s:17:\"include_anonymous\";b:0;}'),('pathauto_state.node','1',_binary 'i:1;'),('pathauto_state.node','2',_binary 'i:1;'),('pathauto_state.node','3',_binary 'i:1;'),('pathauto_state.node','4',_binary 'i:1;'),('pathauto_state.taxonomy_term','1',_binary 'i:0;'),('pathauto_state.taxonomy_term','2',_binary 'i:1;'),('pathauto_state.taxonomy_term','3',_binary 'i:1;'),('post_update','existing_updates',_binary 'a:188:{i:0;s:70:\"system_post_update_convert_empty_country_and_timezone_settings_to_null\";i:1;s:46:\"system_post_update_remove_rss_cdata_subscriber\";i:2;s:32:\"system_post_update_sdc_uninstall\";i:3;s:64:\"system_post_update_recalculate_configuration_entity_dependencies\";i:4;s:48:\"system_post_update_add_region_to_entity_displays\";i:5;s:37:\"system_post_update_hashes_clear_cache\";i:6;s:36:\"system_post_update_timestamp_plugins\";i:7;s:41:\"system_post_update_classy_message_library\";i:8;s:37:\"system_post_update_field_type_plugins\";i:9;s:48:\"system_post_update_field_formatter_entity_schema\";i:10;s:36:\"system_post_update_fix_jquery_extend\";i:11;s:40:\"system_post_update_change_action_plugins\";i:12;s:47:\"system_post_update_change_delete_action_plugins\";i:13;s:41:\"system_post_update_language_item_callback\";i:14;s:31:\"system_post_update_extra_fields\";i:15;s:37:\"system_post_update_states_clear_cache\";i:16;s:64:\"system_post_update_add_expand_all_items_key_in_system_menu_block\";i:17;s:35:\"system_post_update_clear_menu_cache\";i:18;s:46:\"system_post_update_layout_plugin_schema_change\";i:19;s:60:\"system_post_update_entity_reference_autocomplete_match_limit\";i:20;s:44:\"system_post_update_extra_fields_form_display\";i:21;s:39:\"system_post_update_uninstall_simpletest\";i:22;s:52:\"system_post_update_uninstall_entity_reference_module\";i:23;s:54:\"system_post_update_entity_revision_metadata_bc_cleanup\";i:24;s:35:\"system_post_update_uninstall_classy\";i:25;s:35:\"system_post_update_uninstall_stable\";i:26;s:44:\"system_post_update_claro_dropbutton_variants\";i:27;s:37:\"system_post_update_schema_version_int\";i:28;s:38:\"system_post_update_delete_rss_settings\";i:29;s:52:\"system_post_update_remove_key_value_expire_all_index\";i:30;s:44:\"system_post_update_service_advisory_settings\";i:31;s:44:\"system_post_update_delete_authorize_settings\";i:32;s:34:\"system_post_update_sort_all_config\";i:33;s:50:\"system_post_update_enable_provider_database_driver\";i:34;s:35:\"system_post_update_linkset_settings\";i:35;s:48:\"system_post_update_enable_password_compatibility\";i:36;s:39:\"system_post_update_remove_asset_entries\";i:37;s:44:\"system_post_update_remove_asset_query_string\";i:38;s:54:\"system_post_update_add_description_to_entity_view_mode\";i:39;s:54:\"system_post_update_add_description_to_entity_form_mode\";i:40;s:44:\"system_post_update_set_blank_log_url_to_null\";i:41;s:38:\"system_post_update_mailer_dsn_settings\";i:42;s:49:\"system_post_update_mailer_structured_dsn_settings\";i:43;s:47:\"system_post_update_amend_config_sync_readme_url\";i:44;s:44:\"system_post_update_mail_notification_setting\";i:45;s:54:\"system_post_update_set_cron_logging_setting_to_boolean\";i:46;s:56:\"system_post_update_move_development_settings_to_keyvalue\";i:47;s:58:\"system_post_update_add_langcode_to_all_translatable_config\";i:48;s:45:\"user_post_update_enforce_order_of_permissions\";i:49;s:29:\"user_post_update_update_roles\";i:50;s:33:\"user_post_update_sort_permissions\";i:51;s:39:\"user_post_update_sort_permissions_again\";i:52;s:57:\"path_alias_post_update_update_path_alias_revision_indexes\";i:53;s:51:\"path_alias_post_update_drop_path_alias_status_index\";i:54;s:62:\"contact_post_update_add_message_redirect_field_to_contact_form\";i:55;s:50:\"contact_post_update_set_empty_default_form_to_null\";i:56;s:35:\"help_post_update_help_topics_search\";i:57;s:38:\"help_post_update_help_topics_uninstall\";i:58;s:41:\"help_post_update_add_permissions_to_roles\";i:59;s:39:\"big_pipe_post_update_html5_placeholders\";i:60;s:49:\"dblog_post_update_convert_recent_messages_to_view\";i:61;s:37:\"block_post_update_make_weight_integer\";i:62;s:54:\"block_post_update_disable_blocks_with_missing_contexts\";i:63;s:40:\"block_post_update_disabled_region_update\";i:64;s:42:\"block_post_update_fix_negate_in_conditions\";i:65;s:45:\"block_post_update_replace_node_type_condition\";i:66;s:46:\"field_post_update_save_custom_storage_property\";i:67;s:50:\"field_post_update_entity_reference_handler_setting\";i:68;s:43:\"field_post_update_email_widget_size_setting\";i:69;s:47:\"field_post_update_remove_handler_submit_setting\";i:70;s:31:\"filter_post_update_sort_filters\";i:71;s:44:\"filter_post_update_consolidate_filter_config\";i:72;s:42:\"text_post_update_add_required_summary_flag\";i:73;s:55:\"text_post_update_add_required_summary_flag_form_display\";i:74;s:32:\"text_post_update_allowed_formats\";i:75;s:51:\"block_content_post_update_add_views_reusable_filter\";i:76;s:51:\"block_content_post_update_entity_changed_constraint\";i:77;s:51:\"block_content_post_update_move_custom_block_library\";i:78;s:55:\"block_content_post_update_block_library_view_permission\";i:79;s:42:\"block_content_post_update_sort_permissions\";i:80;s:39:\"block_content_post_update_revision_type\";i:81;s:54:\"file_post_update_add_txt_if_allows_insecure_extensions\";i:82;s:41:\"file_post_update_add_permissions_to_roles\";i:83;s:64:\"file_post_update_add_default_filename_sanitization_configuration\";i:84;s:56:\"editor_post_update_clear_cache_for_file_reference_filter\";i:85;s:34:\"editor_post_update_image_lazy_load\";i:86;s:49:\"editor_post_update_sanitize_image_upload_settings\";i:87;s:39:\"ckeditor5_post_update_alignment_buttons\";i:88;s:40:\"ckeditor5_post_update_image_toolbar_item\";i:89;s:51:\"ckeditor5_post_update_plugins_settings_export_order\";i:90;s:32:\"ckeditor5_post_update_code_block\";i:91;s:37:\"ckeditor5_post_update_list_multiblock\";i:92;s:41:\"ckeditor5_post_update_list_start_reversed\";i:93;s:45:\"comment_post_update_enable_comment_admin_view\";i:94;s:42:\"comment_post_update_add_ip_address_setting\";i:95;s:48:\"contextual_post_update_fixed_endpoint_and_markup\";i:96;s:46:\"node_post_update_configure_status_field_widget\";i:97;s:41:\"node_post_update_node_revision_views_data\";i:98;s:40:\"node_post_update_glossary_view_published\";i:99;s:45:\"node_post_update_rebuild_node_revision_routes\";i:100;s:50:\"node_post_update_modify_base_field_author_override\";i:101;s:59:\"node_post_update_set_node_type_description_and_help_to_null\";i:102;s:42:\"image_post_update_image_style_dependencies\";i:103;s:50:\"image_post_update_scale_and_crop_effect_add_anchor\";i:104;s:41:\"image_post_update_image_loading_attribute\";i:105;s:47:\"views_post_update_views_data_argument_plugin_id\";i:106;s:46:\"views_post_update_update_cacheability_metadata\";i:107;s:46:\"views_post_update_cleanup_duplicate_views_data\";i:108;s:46:\"views_post_update_field_formatter_dependencies\";i:109;s:36:\"views_post_update_taxonomy_index_tid\";i:110;s:41:\"views_post_update_serializer_dependencies\";i:111;s:39:\"views_post_update_boolean_filter_values\";i:112;s:33:\"views_post_update_grouped_filters\";i:113;s:42:\"views_post_update_revision_metadata_fields\";i:114;s:33:\"views_post_update_entity_link_url\";i:115;s:34:\"views_post_update_bulk_field_moved\";i:116;s:41:\"views_post_update_filter_placeholder_text\";i:117;s:47:\"views_post_update_views_data_table_dependencies\";i:118;s:45:\"views_post_update_table_display_cache_max_age\";i:119;s:53:\"views_post_update_exposed_filter_blocks_label_display\";i:120;s:48:\"views_post_update_make_placeholders_translatable\";i:121;s:41:\"views_post_update_limit_operator_defaults\";i:122;s:33:\"views_post_update_remove_core_key\";i:123;s:51:\"views_post_update_field_names_for_multivalue_fields\";i:124;s:52:\"views_post_update_configuration_entity_relationships\";i:125;s:48:\"views_post_update_rename_default_display_setting\";i:126;s:50:\"views_post_update_remove_sorting_global_text_field\";i:127;s:36:\"views_post_update_title_translations\";i:128;s:33:\"views_post_update_sort_identifier\";i:129;s:53:\"views_post_update_provide_revision_table_relationship\";i:130;s:33:\"views_post_update_image_lazy_load\";i:131;s:39:\"views_post_update_boolean_custom_titles\";i:132;s:35:\"views_post_update_oembed_eager_load\";i:133;s:44:\"views_post_update_responsive_image_lazy_load\";i:134;s:37:\"views_post_update_timestamp_formatter\";i:135;s:38:\"views_post_update_fix_revision_id_part\";i:136;s:36:\"views_post_update_add_missing_labels\";i:137;s:43:\"views_post_update_remove_skip_cache_setting\";i:138;s:50:\"views_post_update_remove_default_argument_skip_url\";i:139;s:46:\"views_post_update_taxonomy_filter_user_context\";i:140;s:31:\"views_post_update_pager_heading\";i:141;s:54:\"views_post_update_rendered_entity_field_cache_metadata\";i:142;s:65:\"menu_link_content_post_update_make_menu_link_content_revisionable\";i:143;s:49:\"path_post_update_create_language_content_settings\";i:144;s:43:\"taxonomy_post_update_clear_views_data_cache\";i:145;s:64:\"taxonomy_post_update_clear_entity_bundle_field_definitions_cache\";i:146;s:63:\"taxonomy_post_update_handle_publishing_status_addition_in_views\";i:147;s:55:\"taxonomy_post_update_remove_hierarchy_from_vocabularies\";i:148;s:52:\"taxonomy_post_update_make_taxonomy_term_revisionable\";i:149;s:50:\"taxonomy_post_update_configure_status_field_widget\";i:150;s:65:\"taxonomy_post_update_clear_views_argument_validator_plugins_cache\";i:151;s:37:\"taxonomy_post_update_set_new_revision\";i:152;s:55:\"taxonomy_post_update_set_vocabulary_description_to_null\";i:153;s:45:\"olivero_post_update_add_olivero_primary_color\";i:154;s:42:\"gin_toolbar_post_update_gin_toolbar_beta19\";i:155;s:42:\"gin_toolbar_post_update_gin_toolbar_beta21\";i:156;s:42:\"gin_toolbar_post_update_gin_toolbar_beta22\";i:157;s:42:\"gin_toolbar_post_update_update_gin_alpha32\";i:158;s:43:\"language_post_update_language_select_widget\";i:159;s:51:\"locale_post_update_clear_cache_for_old_translations\";i:160;s:41:\"metatag_post_update_convert_author_config\";i:161;s:39:\"metatag_post_update_convert_author_data\";i:162;s:53:\"metatag_post_update_convert_mask_icon_to_array_values\";i:163;s:46:\"metatag_post_update_remove_robots_noydir_noodp\";i:164;s:47:\"metatag_post_update_v2_01_change_fields_to_json\";i:165;s:46:\"metatag_post_update_v2_02_remove_entity_values\";i:166;s:46:\"metatag_post_update_v2_03_remove_config_values\";i:167;s:43:\"metatag_post_update_v2_04_uninstall_modules\";i:168;s:46:\"metatag_post_update_v2_05_twitter_type_changes\";i:169;s:31:\"simple_sitemap_post_update_8403\";i:170;s:31:\"simple_sitemap_post_update_8404\";i:171;s:28:\"field_group_post_update_0001\";i:172;s:37:\"menu_item_extras_post_update_1x_to_2x\";i:173;s:83:\"rabbit_hole_post_update_entity_type_id_and_entity_id_for_existing_behavior_settings\";i:174;s:49:\"webform_post_update_authenticated_user_permission\";i:175;s:28:\"webform_post_update_ckeditor\";i:176;s:30:\"webform_post_update_ckeditor01\";i:177;s:45:\"webform_post_update_confirmation_page_noindex\";i:178;s:50:\"webform_post_update_deprecate_jquery_ui_datepicker\";i:179;s:45:\"webform_post_update_deprecate_location_places\";i:180;s:39:\"webform_post_update_multiple_categories\";i:181;s:41:\"serialization_post_update_delete_settings\";i:182;s:65:\"jsonapi_extras_post_update_set_default_value_for_default_disabled\";i:183;s:53:\"rest_post_update_create_rest_resource_config_entities\";i:184;s:37:\"rest_post_update_resource_granularity\";i:185;s:23:\"rest_post_update_161923\";i:186;s:32:\"rest_post_update_delete_settings\";i:187;s:39:\"restui_post_update_resource_granularity\";}'),('simple_sitemap','queue_items_initial_amount',_binary 'i:1;'),('state','announcements_feed.last_fetch',_binary 'i:1743931974;'),('state','asset.css_js_query_string',_binary 's:6:\"suai8m\";'),('state','comment.maintain_entity_statistics',_binary 'b:1;'),('state','comment.node_comment_statistics_scale',_binary 'd:1;'),('state','help_search_unindexed_count',_binary 's:1:\"0\";'),('state','install_task',_binary 's:4:\"done\";'),('state','install_time',_binary 'i:1742073849;'),('state','node.min_max_update_time',_binary 'a:2:{s:11:\"min_created\";s:10:\"1742136181\";s:11:\"max_created\";s:10:\"1742757271\";}'),('state','router.path_roots',_binary 'a:38:{i:0;s:5:\"admin\";i:1;s:8:\"big_pipe\";i:2;s:14:\"block-category\";i:3;s:5:\"block\";i:4;s:9:\"ckeditor5\";i:5;s:7:\"comment\";i:6;s:8:\"comments\";i:7;s:7:\"contact\";i:8;s:4:\"user\";i:9;s:10:\"contextual\";i:10;s:4:\"node\";i:11;s:6:\"editor\";i:12;s:4:\"file\";i:13;s:6:\"filter\";i:14;s:7:\"history\";i:15;s:5:\"sites\";i:16;s:6:\"system\";i:17;s:7:\"jsonapi\";i:18;s:6:\"linkit\";i:19;s:11:\"sitemap.xml\";i:20;s:8:\"sitemaps\";i:21;s:17:\"sitemap_generator\";i:22;s:4:\"cron\";i:23;s:0:\"\";i:24;s:9:\"<current>\";i:25;s:5:\"batch\";i:26;s:10:\"update.php\";i:27;s:29:\"entity_reference_autocomplete\";i:28;s:7:\"session\";i:29;s:8:\"taxonomy\";i:30;s:5:\"token\";i:31;s:7:\"toolbar\";i:32;s:11:\".well-known\";i:33;s:7:\"webform\";i:34;s:7:\"rss.xml\";i:35;s:5:\"views\";i:36;s:6:\"entity\";i:37;s:12:\"webform_rest\";}'),('state','routing.menu_masks.router',_binary 'a:70:{i:0;i:1973;i:1;i:1013;i:2;i:1005;i:3;i:996;i:4;i:985;i:5;i:981;i:6;i:501;i:7;i:498;i:8;i:495;i:9;i:494;i:10;i:493;i:11;i:492;i:12;i:491;i:13;i:489;i:14;i:464;i:15;i:254;i:16;i:253;i:17;i:252;i:18;i:251;i:19;i:250;i:20;i:249;i:21;i:247;i:22;i:246;i:23;i:245;i:24;i:244;i:25;i:232;i:26;i:127;i:27;i:126;i:28;i:125;i:29;i:124;i:30;i:123;i:31;i:122;i:32;i:117;i:33;i:116;i:34;i:95;i:35;i:94;i:36;i:91;i:37;i:88;i:38;i:84;i:39;i:63;i:40;i:62;i:41;i:61;i:42;i:60;i:43;i:59;i:44;i:53;i:45;i:49;i:46;i:47;i:47;i:45;i:48;i:42;i:49;i:31;i:50;i:30;i:51;i:29;i:52;i:28;i:53;i:24;i:54;i:23;i:55;i:22;i:56;i:21;i:57;i:15;i:58;i:14;i:59;i:13;i:60;i:12;i:61;i:11;i:62;i:10;i:63;i:8;i:64;i:7;i:65;i:6;i:66;i:5;i:67;i:3;i:68;i:2;i:69;i:1;}'),('state','routing.non_admin_routes',_binary 'a:136:{i:0;s:13:\"big_pipe.nojs\";i:1;s:27:\"block.category_autocomplete\";i:2;s:22:\"block_content.add_page\";i:3;s:22:\"block_content.add_form\";i:4;s:31:\"ckeditor5.media_entity_metadata\";i:5;s:24:\"entity.comment.edit_form\";i:6;s:15:\"comment.approve\";i:7;s:24:\"entity.comment.canonical\";i:8;s:26:\"entity.comment.delete_form\";i:9;s:13:\"comment.reply\";i:10;s:31:\"comment.new_comments_node_links\";i:11;s:21:\"comment.node_redirect\";i:12;s:17:\"contact.site_page\";i:13;s:29:\"entity.contact_form.canonical\";i:14;s:24:\"entity.user.contact_form\";i:15;s:17:\"contextual.render\";i:16;s:19:\"diff.revisions_diff\";i:17;s:17:\"editor.filter_xss\";i:18;s:18:\"file.ajax_progress\";i:19;s:15:\"filter.tips_all\";i:20;s:11:\"filter.tips\";i:21;s:26:\"history.get_last_node_view\";i:22;s:17:\"history.read_node\";i:23;s:18:\"image.style_public\";i:24;s:19:\"image.style_private\";i:25;s:19:\"linkit.autocomplete\";i:26;s:13:\"node.add_page\";i:27;s:8:\"node.add\";i:28;s:19:\"entity.node.preview\";i:29;s:27:\"entity.node.version_history\";i:30;s:20:\"entity.node.revision\";i:31;s:28:\"node.revision_revert_confirm\";i:32;s:40:\"node.revision_revert_translation_confirm\";i:33;s:28:\"node.revision_delete_confirm\";i:34;s:19:\"shortcut.set_switch\";i:35;s:30:\"simple_sitemap.sitemap_default\";i:36;s:30:\"simple_sitemap.sitemap_variant\";i:37;s:26:\"simple_sitemap.sitemap_xsl\";i:38;s:16:\"system.css_asset\";i:39;s:15:\"system.js_asset\";i:40;s:10:\"system.401\";i:41;s:10:\"system.403\";i:42;s:10:\"system.404\";i:43;s:10:\"system.4xx\";i:44;s:11:\"system.cron\";i:45;s:12:\"system.files\";i:46;s:28:\"system.private_file_download\";i:47;s:16:\"system.temporary\";i:48;s:7:\"<front>\";i:49;s:6:\"<none>\";i:50;s:8:\"<nolink>\";i:51;s:8:\"<button>\";i:52;s:9:\"<current>\";i:53;s:15:\"system.timezone\";i:54;s:22:\"system.batch_page.html\";i:55;s:16:\"system.db_update\";i:56;s:26:\"system.entity_autocomplete\";i:57;s:16:\"system.csrftoken\";i:58;s:30:\"entity.taxonomy_term.edit_form\";i:59;s:32:\"entity.taxonomy_term.delete_form\";i:60;s:10:\"token.tree\";i:61;s:16:\"toolbar.subtrees\";i:62;s:13:\"user.register\";i:63;s:11:\"user.logout\";i:64;s:19:\"user.logout.confirm\";i:65;s:9:\"user.pass\";i:66;s:9:\"user.page\";i:67;s:9:\"user.edit\";i:68;s:10:\"user.login\";i:69;s:19:\"user.cancel_confirm\";i:70;s:16:\"user.reset.login\";i:71;s:10:\"user.reset\";i:72;s:15:\"user.reset.form\";i:73;s:31:\"user.well-known.change_password\";i:74;s:24:\"entity.webform.canonical\";i:75;s:28:\"entity.webform.access_denied\";i:76;s:32:\"entity.webform.assets.javascript\";i:77;s:25:\"entity.webform.assets.css\";i:78;s:27:\"entity.webform.confirmation\";i:79;s:31:\"entity.webform.user.submissions\";i:80;s:26:\"entity.webform.user.drafts\";i:81;s:30:\"entity.webform.user.submission\";i:82;s:35:\"entity.webform.user.submission.edit\";i:83;s:37:\"entity.webform.user.submission.delete\";i:84;s:40:\"entity.webform.user.submission.duplicate\";i:85;s:24:\"entity.webform.test_form\";i:86;s:30:\"entity.webform_submission.user\";i:87;s:28:\"webform.element.autocomplete\";i:88;s:29:\"webform.element.message.close\";i:89;s:41:\"entity.webform.user.submission.attachment\";i:90;s:32:\"entity.node.webform.confirmation\";i:91;s:36:\"entity.node.webform.user.submissions\";i:92;s:31:\"entity.node.webform.user.drafts\";i:93;s:35:\"entity.node.webform.user.submission\";i:94;s:40:\"entity.node.webform.user.submission.edit\";i:95;s:42:\"entity.node.webform.user.submission.delete\";i:96;s:45:\"entity.node.webform.user.submission.duplicate\";i:97;s:29:\"entity.node.webform.test_form\";i:98;s:39:\"entity.node.webform.results_submissions\";i:99;s:46:\"entity.node.webform.results_submissions.custom\";i:100;s:51:\"entity.node.webform.results_submissions.custom.user\";i:101;s:34:\"entity.node.webform.results_export\";i:102;s:39:\"entity.node.webform.results_export_file\";i:103;s:33:\"entity.node.webform.results_clear\";i:104;s:40:\"entity.node.webform_submission.canonical\";i:105;s:36:\"entity.node.webform_submission.table\";i:106;s:35:\"entity.node.webform_submission.text\";i:107;s:35:\"entity.node.webform_submission.yaml\";i:108;s:40:\"entity.node.webform_submission.edit_form\";i:109;s:44:\"entity.node.webform_submission.edit_form.all\";i:110;s:41:\"entity.node.webform_submission.notes_form\";i:111;s:42:\"entity.node.webform_submission.resend_form\";i:112;s:45:\"entity.node.webform_submission.duplicate_form\";i:113;s:42:\"entity.node.webform_submission.delete_form\";i:114;s:40:\"entity.node.webform.entity_reference.set\";i:115;s:41:\"entity.node.webform_options_limit.summary\";i:116;s:59:\"entity.node.webform_submission_export_import.results_import\";i:117;s:76:\"entity.node.webform_submission_export_import.results_import.example.download\";i:118;s:72:\"entity.node.webform_submission_export_import.results_import.example.view\";i:119;s:21:\"view.frontpage.feed_1\";i:120;s:21:\"view.frontpage.page_1\";i:121;s:25:\"view.taxonomy_term.feed_1\";i:122;s:25:\"view.taxonomy_term.page_1\";i:123;s:10:\"views.ajax\";i:124;s:23:\"entity.file.delete_form\";i:125;s:21:\"entity.node.canonical\";i:126;s:23:\"entity.node.delete_form\";i:127;s:21:\"entity.node.edit_form\";i:128;s:36:\"entity.taxonomy_term.version_history\";i:129;s:29:\"entity.taxonomy_term.revision\";i:130;s:41:\"entity.taxonomy_term.revision_revert_form\";i:131;s:41:\"entity.taxonomy_term.revision_delete_form\";i:132;s:21:\"entity.user.canonical\";i:133;s:21:\"entity.user.edit_form\";i:134;s:23:\"entity.user.cancel_form\";i:135;s:30:\"entity.taxonomy_term.canonical\";}'),('state','simple_sitemap.last_cron_generate',_binary 'i:1743931974;'),('state','system.cron_key',_binary 's:74:\"SYl_dYqno4hHpmY_I1j2o73UxKltskLCEnFdFRHIpZwxKepBYxgL6oVjC1dAPg-VmsBKzXpINg\";'),('state','system.cron_last',_binary 'i:1743931974;'),('state','system.javascript_parsed',_binary 'a:169:{i:0;s:39:\"core/assets/vendor/jquery/jquery.min.js\";i:1;s:33:\"core/misc/drupalSettingsLoader.js\";i:2;s:19:\"core/misc/drupal.js\";i:3;s:24:\"core/misc/drupal.init.js\";i:4;s:21:\"core/misc/progress.js\";i:5;s:35:\"core/assets/vendor/once/once.min.js\";i:6;s:44:\"core/assets/vendor/tabbable/index.umd.min.js\";i:7;s:39:\"core/assets/vendor/loadjs/loadjs.min.js\";i:8;s:21:\"core/misc/debounce.js\";i:9;s:21:\"core/misc/announce.js\";i:10;s:20:\"core/misc/message.js\";i:11;s:32:\"core/themes/claro/js/messages.js\";i:12;s:38:\"themes/contrib/gin/dist/js/messages.js\";i:13;s:28:\"core/themes/claro/js/ajax.js\";i:14;s:17:\"core/misc/ajax.js\";i:15;s:36:\"core/modules/big_pipe/js/big_pipe.js\";i:16;s:32:\"core/themes/claro/js/nav-tabs.js\";i:17;s:47:\"core/assets/vendor/underscore/underscore-min.js\";i:18;s:43:\"core/assets/vendor/backbone/backbone-min.js\";i:19;s:29:\"core/misc/touchevents-test.js\";i:20;s:40:\"core/modules/contextual/js/contextual.js\";i:21;s:47:\"core/modules/contextual/js/models/StateModel.js\";i:22;s:45:\"core/modules/contextual/js/views/AuralView.js\";i:23;s:48:\"core/modules/contextual/js/views/KeyboardView.js\";i:24;s:46:\"core/modules/contextual/js/views/RegionView.js\";i:25;s:46:\"core/modules/contextual/js/views/VisualView.js\";i:26;s:27:\"core/misc/tabbingmanager.js\";i:27;s:48:\"core/modules/contextual/js/contextual.toolbar.js\";i:28;s:55:\"core/modules/contextual/js/toolbar/models/StateModel.js\";i:29;s:53:\"core/modules/contextual/js/toolbar/views/AuralView.js\";i:30;s:54:\"core/modules/contextual/js/toolbar/views/VisualView.js\";i:31;s:24:\"core/misc/active-link.js\";i:32;s:36:\"themes/contrib/gin/dist/js/accent.js\";i:33;s:34:\"themes/contrib/gin/dist/js/init.js\";i:34;s:75:\"themes/contrib/gin/js/navigation/vendor/floating-ui/floating-ui.core.umd.js\";i:35;s:74:\"themes/contrib/gin/js/navigation/vendor/floating-ui/floating-ui.dom.umd.js\";i:36;s:42:\"themes/contrib/gin/dist/js/escape_admin.js\";i:37;s:21:\"core/misc/displace.js\";i:38;s:46:\"themes/contrib/gin/js/navigation/navigation.js\";i:39;s:37:\"themes/contrib/gin/dist/js/tooltip.js\";i:40;s:36:\"themes/contrib/gin/dist/js/sticky.js\";i:41;s:41:\"modules/contrib/glightbox/js/glightbox.js\";i:42;s:44:\"libraries/glightbox/dist/js/glightbox.min.js\";i:43;s:73:\"modules/contrib/glightbox/modules/glightbox_inline/js/glightbox_inline.js\";i:44;s:55:\"modules/contrib/hotkeys_for_save/js/hotkeys_for_save.js\";i:45;s:40:\"core/modules/system/js/system.modules.js\";i:46;s:39:\"core/modules/toolbar/js/toolbar.menu.js\";i:47;s:47:\"core/modules/toolbar/js/toolbar.anti-flicker.js\";i:48;s:34:\"core/modules/toolbar/js/toolbar.js\";i:49;s:43:\"core/modules/toolbar/js/models/MenuModel.js\";i:50;s:46:\"core/modules/toolbar/js/models/ToolbarModel.js\";i:51;s:47:\"core/modules/toolbar/js/views/BodyVisualView.js\";i:52;s:47:\"core/modules/toolbar/js/views/MenuVisualView.js\";i:53;s:49:\"core/modules/toolbar/js/views/ToolbarAuralView.js\";i:54;s:50:\"core/modules/toolbar/js/views/ToolbarVisualView.js\";i:55;s:38:\"core/modules/toolbar/js/escapeAdmin.js\";i:56;s:42:\"core/themes/olivero/js/navigation-utils.js\";i:57;s:34:\"core/themes/olivero/js/checkbox.js\";i:58;s:34:\"core/themes/olivero/js/messages.js\";i:59;s:39:\"core/themes/olivero/js/message.theme.js\";i:60;s:34:\"core/modules/history/js/history.js\";i:61;s:39:\"core/modules/history/js/mark-as-read.js\";i:62;s:36:\"core/themes/olivero/js/navigation.js\";i:63;s:49:\"core/themes/olivero/js/second-level-navigation.js\";i:64;s:36:\"core/themes/olivero/js/nav-resize.js\";i:65;s:30:\"core/themes/olivero/js/tabs.js\";i:66;s:114:\"modules/contrib/ckeditor5_plugin_pack/modules/ckeditor5_plugin_pack_templates/js/ckeditor5_distribution_channel.js\";i:67;s:59:\"core/assets/vendor/ckeditor5/ckeditor5-dll/ckeditor5-dll.js\";i:68;s:56:\"libraries/ckeditor5-anchor-drupal/build/anchor-drupal.js\";i:69;s:61:\"core/assets/vendor/ckeditor5/editor-classic/editor-classic.js\";i:70;s:57:\"core/assets/vendor/ckeditor5/html-support/html-support.js\";i:71;s:65:\"core/assets/vendor/ckeditor5/editor-decoupled/editor-decoupled.js\";i:72;s:45:\"core/assets/vendor/jquery.ui/ui/labels-min.js\";i:73;s:43:\"core/assets/vendor/jquery.ui/ui/data-min.js\";i:74;s:56:\"core/assets/vendor/jquery.ui/ui/disable-selection-min.js\";i:75;s:51:\"core/assets/vendor/jquery.ui/ui/jquery-patch-min.js\";i:76;s:52:\"core/assets/vendor/jquery.ui/ui/scroll-parent-min.js\";i:77;s:48:\"core/assets/vendor/jquery.ui/ui/unique-id-min.js\";i:78;s:48:\"core/assets/vendor/jquery.ui/ui/focusable-min.js\";i:79;s:46:\"core/assets/vendor/jquery.ui/ui/keycode-min.js\";i:80;s:45:\"core/assets/vendor/jquery.ui/ui/plugin-min.js\";i:81;s:45:\"core/assets/vendor/jquery.ui/ui/widget-min.js\";i:82;s:46:\"core/assets/vendor/jquery.ui/ui/version-min.js\";i:83;s:21:\"core/misc/position.js\";i:84;s:38:\"core/misc/dialog/dialog-deprecation.js\";i:85;s:26:\"core/misc/dialog/dialog.js\";i:86;s:35:\"core/misc/dialog/dialog.position.js\";i:87;s:36:\"core/misc/dialog/dialog.jquery-ui.js\";i:88;s:53:\"core/assets/vendor/jquery.ui/ui/widgets/dialog-min.js\";i:89;s:53:\"core/assets/vendor/jquery.ui/ui/widgets/button-min.js\";i:90;s:60:\"core/assets/vendor/jquery.ui/ui/widgets/checkboxradio-min.js\";i:91;s:56:\"core/assets/vendor/jquery.ui/ui/widgets/draggable-min.js\";i:92;s:56:\"core/assets/vendor/jquery.ui/ui/widgets/resizable-min.js\";i:93;s:59:\"core/assets/vendor/jquery.ui/ui/widgets/controlgroup-min.js\";i:94;s:55:\"core/assets/vendor/jquery.ui/ui/form-reset-mixin-min.js\";i:95;s:52:\"core/assets/vendor/jquery.ui/ui/widgets/mouse-min.js\";i:96;s:58:\"core/assets/vendor/tua-body-scroll-lock/tua-bsl.umd.min.js\";i:97;s:49:\"core/modules/ckeditor5/js/ckeditor5.dialog.fix.js\";i:98;s:32:\"core/modules/editor/js/editor.js\";i:99;s:38:\"core/modules/ckeditor5/js/ckeditor5.js\";i:100;s:57:\"core/assets/vendor/ckeditor5/basic-styles/basic-styles.js\";i:101;s:49:\"core/modules/ckeditor5/js/build/drupalEmphasis.js\";i:102;s:47:\"core/assets/vendor/ckeditor5/heading/heading.js\";i:103;s:53:\"core/assets/vendor/ckeditor5/essentials/essentials.js\";i:104;s:51:\"core/modules/ckeditor5/js/build/drupalHtmlEngine.js\";i:105;s:43:\"core/assets/vendor/ckeditor5/image/image.js\";i:106;s:46:\"core/modules/ckeditor5/js/build/drupalImage.js\";i:107;s:65:\"modules/contrib/ckeditor5_plugin_pack/js/build/drupalPoweredBy.js\";i:108;s:106:\"modules/contrib/ckeditor5_plugin_pack/modules/ckeditor5_plugin_pack_highlight/js/build/highlightAdapter.js\";i:109;s:125:\"modules/contrib/ckeditor5_plugin_pack/modules/ckeditor5_plugin_pack_text_transformation/js/build/textTransformationAdapter.js\";i:110;s:111:\"modules/contrib/ckeditor5_premium_features/modules/ckeditor5_premium_features_fullscreen/js/build/fullscreen.js\";i:111;s:51:\"core/assets/vendor/ckeditor5/alignment/alignment.js\";i:112;s:53:\"core/assets/vendor/ckeditor5/autoformat/autoformat.js\";i:113;s:55:\"core/assets/vendor/ckeditor5/block-quote/block-quote.js\";i:114;s:53:\"core/assets/vendor/ckeditor5/code-block/code-block.js\";i:115;s:63:\"core/assets/vendor/ckeditor5/horizontal-line/horizontal-line.js\";i:116;s:45:\"core/assets/vendor/ckeditor5/indent/indent.js\";i:117;s:49:\"core/assets/vendor/ckeditor5/language/language.js\";i:118;s:41:\"core/assets/vendor/ckeditor5/link/link.js\";i:119;s:41:\"core/assets/vendor/ckeditor5/list/list.js\";i:120;s:67:\"core/assets/vendor/ckeditor5/paste-from-office/paste-from-office.js\";i:121;s:59:\"core/assets/vendor/ckeditor5/remove-format/remove-format.js\";i:122;s:55:\"core/assets/vendor/ckeditor5/show-blocks/show-blocks.js\";i:123;s:61:\"core/assets/vendor/ckeditor5/source-editing/source-editing.js\";i:124;s:69:\"core/assets/vendor/ckeditor5/special-characters/special-characters.js\";i:125;s:43:\"core/assets/vendor/ckeditor5/style/style.js\";i:126;s:43:\"core/assets/vendor/ckeditor5/table/table.js\";i:127;s:17:\"core/misc/form.js\";i:128;s:39:\"core/misc/details-summarized-content.js\";i:129;s:25:\"core/misc/details-aria.js\";i:130;s:20:\"core/misc/details.js\";i:131;s:31:\"core/themes/claro/js/details.js\";i:132;s:31:\"core/misc/dialog/dialog.ajax.js\";i:133;s:34:\"core/misc/dropbutton/dropbutton.js\";i:134;s:34:\"core/themes/claro/js/dropbutton.js\";i:135;s:40:\"themes/contrib/gin/dist/js/dropbutton.js\";i:136;s:19:\"core/misc/states.js\";i:137;s:28:\"core/misc/tableresponsive.js\";i:138;s:32:\"core/modules/filter/js/filter.js\";i:139;s:42:\"themes/contrib/gin/dist/js/more_actions.js\";i:140;s:37:\"themes/contrib/gin/dist/js/sidebar.js\";i:141;s:25:\"core/misc/autocomplete.js\";i:142;s:59:\"core/assets/vendor/jquery.ui/ui/widgets/autocomplete-min.js\";i:143;s:51:\"core/assets/vendor/jquery.ui/ui/widgets/menu-min.js\";i:144;s:36:\"core/themes/claro/js/autocomplete.js\";i:145;s:41:\"modules/contrib/linkit/js/build/linkit.js\";i:146;s:34:\"core/modules/menu_ui/js/menu_ui.js\";i:147;s:24:\"core/misc/entity-form.js\";i:148;s:28:\"core/modules/node/js/node.js\";i:149;s:28:\"core/modules/path/js/path.js\";i:150;s:36:\"modules/contrib/pathauto/pathauto.js\";i:151;s:54:\"modules/contrib/rabbit_hole/modules/rh_node/rh-node.js\";i:152;s:28:\"core/modules/text/js/text.js\";i:153;s:44:\"modules/contrib/token/js/jquery.treetable.js\";i:154;s:33:\"modules/contrib/token/js/token.js\";i:155;s:44:\"themes/contrib/gin/js/overrides/tabledrag.js\";i:156;s:33:\"core/themes/claro/js/tabledrag.js\";i:157;s:43:\"core/assets/vendor/sortable/Sortable.min.js\";i:158;s:26:\"core/misc/vertical-tabs.js\";i:159;s:37:\"core/themes/claro/js/vertical-tabs.js\";i:160;s:51:\"core/modules/ckeditor5/js/ckeditor5.filter.admin.js\";i:161;s:38:\"core/modules/filter/js/filter.admin.js\";i:162;s:44:\"core/modules/ckeditor5/js/ckeditor5.admin.js\";i:163;s:50:\"core/modules/ckeditor5/js/ckeditor5.image.admin.js\";i:164;s:50:\"core/modules/ckeditor5/js/ckeditor5.style.admin.js\";i:165;s:52:\"core/assets/vendor/transliteration/bundle.umd.min.js\";i:166;s:25:\"core/misc/machine-name.js\";i:167;s:24:\"core/misc/jquery.form.js\";i:168;s:31:\"modules/contrib/diff/js/diff.js\";}'),('state','system.private_key',_binary 's:74:\"D8faZiFYeS6cB1DeIrFZ9Nuwxk72DJlxo2FbLVkCEeW4JYTDAeuLicN_HhePQSdygmKgiy6ykg\";'),('state','system.profile.files',_binary 'a:4:{s:10:\"demo_umami\";s:44:\"core/profiles/demo_umami/demo_umami.info.yml\";s:4:\"fast\";s:27:\"profiles/fast/fast.info.yml\";s:7:\"minimal\";s:38:\"core/profiles/minimal/minimal.info.yml\";s:8:\"standard\";s:40:\"core/profiles/standard/standard.info.yml\";}'),('state','system.theme.files',_binary 'a:6:{s:5:\"claro\";s:32:\"core/themes/claro/claro.info.yml\";s:3:\"gin\";s:31:\"themes/contrib/gin/gin.info.yml\";s:7:\"olivero\";s:36:\"core/themes/olivero/olivero.info.yml\";s:7:\"stable9\";s:36:\"core/themes/stable9/stable9.info.yml\";s:5:\"stark\";s:32:\"core/themes/stark/stark.info.yml\";s:16:\"starterkit_theme\";s:54:\"core/themes/starterkit_theme/starterkit_theme.info.yml\";}'),('state','twig_extension_hash_prefix',_binary 'a:2:{s:19:\"twig_extension_hash\";s:43:\"7-BCbuxtggjpJj7RCQjH4XkK601H2b_-s4-3y002j4o\";s:17:\"twig_cache_prefix\";s:13:\"67f248f28a1f9\";}'),('state','update.last_check',_binary 'i:1743932020;'),('state','views.view_route_names',_binary 'a:13:{s:13:\"watchdog.page\";s:14:\"dblog.overview\";s:24:\"user_admin_people.page_1\";s:22:\"entity.user.collection\";s:20:\"taxonomy_term.page_1\";s:30:\"entity.taxonomy_term.canonical\";s:15:\"redirect.page_1\";s:13:\"redirect.list\";s:14:\"content.page_1\";s:20:\"system.admin_content\";s:23:\"comment.page_unapproved\";s:22:\"comment.admin_approval\";s:22:\"comment.page_published\";s:13:\"comment.admin\";s:20:\"block_content.page_1\";s:31:\"entity.block_content.collection\";s:12:\"files.page_1\";s:17:\"view.files.page_1\";s:12:\"files.page_2\";s:17:\"view.files.page_2\";s:16:\"frontpage.feed_1\";s:21:\"view.frontpage.feed_1\";s:16:\"frontpage.page_1\";s:21:\"view.frontpage.page_1\";s:20:\"taxonomy_term.feed_1\";s:25:\"view.taxonomy_term.feed_1\";}'),('state','webform.element.message',_binary 'a:1:{s:25:\"webform.help.installation\";b:1;}'),('state','webform.version',_binary 's:11:\"6.3.0-beta2\";'),('system.schema','anchor_link',_binary 'i:8000;'),('system.schema','announcements_feed',_binary 'i:8000;'),('system.schema','automated_cron',_binary 'i:8000;'),('system.schema','big_pipe',_binary 'i:8000;'),('system.schema','block',_binary 'i:8003;'),('system.schema','block_content',_binary 'i:10300;'),('system.schema','breakpoint',_binary 'i:8000;'),('system.schema','ckeditor5',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_auto_image',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_bookmark',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_find_and_replace',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_font',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_highlight',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_indent_block',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_page_break',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_select_all',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_templates',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_text_transformation',_binary 'i:8000;'),('system.schema','ckeditor5_premium_features_fullscreen',_binary 'i:8000;'),('system.schema','comment',_binary 'i:10100;'),('system.schema','config',_binary 'i:8000;'),('system.schema','config_ignore',_binary 'i:8302;'),('system.schema','config_split',_binary 'i:8003;'),('system.schema','config_translation',_binary 'i:8000;'),('system.schema','contact',_binary 'i:8000;'),('system.schema','contextual',_binary 'i:8000;'),('system.schema','datetime',_binary 'i:8000;'),('system.schema','dblog',_binary 'i:10101;'),('system.schema','diff',_binary 'i:8010;'),('system.schema','dynamic_page_cache',_binary 'i:8000;'),('system.schema','editor',_binary 'i:8001;'),('system.schema','fast',_binary 'i:8000;'),('system.schema','field',_binary 'i:8500;'),('system.schema','field_group',_binary 'i:8303;'),('system.schema','field_ui',_binary 'i:8000;'),('system.schema','file',_binary 'i:8700;'),('system.schema','filter',_binary 'i:8000;'),('system.schema','gin_toolbar',_binary 'i:8000;'),('system.schema','glightbox',_binary 'i:8000;'),('system.schema','glightbox_inline',_binary 'i:8000;'),('system.schema','help',_binary 'i:10200;'),('system.schema','history',_binary 'i:10100;'),('system.schema','hotkeys_for_save',_binary 'i:8000;'),('system.schema','image',_binary 'i:8201;'),('system.schema','jsonapi',_binary 'i:9401;'),('system.schema','jsonapi_defaults',_binary 'i:8001;'),('system.schema','jsonapi_extras',_binary 'i:9001;'),('system.schema','jsonapi_menu_items',_binary 'i:8001;'),('system.schema','jsonapi_resources',_binary 'i:8000;'),('system.schema','jsonapi_response_alter',_binary 'i:8000;'),('system.schema','jsonapi_views',_binary 'i:8001;'),('system.schema','language',_binary 'i:8001;'),('system.schema','link',_binary 'i:8000;'),('system.schema','linkit',_binary 'i:8503;'),('system.schema','linkit_attributes',_binary 'i:8000;'),('system.schema','link_attributes',_binary 'i:9001;'),('system.schema','link_attributes_menu_link_content',_binary 'i:8000;'),('system.schema','locale',_binary 'i:10300;'),('system.schema','media_library_edit',_binary 'i:8000;'),('system.schema','menu_item_extras',_binary 'i:8024;'),('system.schema','menu_link_content',_binary 'i:8601;'),('system.schema','menu_ui',_binary 'i:8000;'),('system.schema','metatag',_binary 'i:9401;'),('system.schema','node',_binary 'i:8700;'),('system.schema','options',_binary 'i:8000;'),('system.schema','page_cache',_binary 'i:8000;'),('system.schema','path',_binary 'i:8200;'),('system.schema','pathauto',_binary 'i:8108;'),('system.schema','path_alias',_binary 'i:8000;'),('system.schema','rabbit_hole',_binary 'i:8101;'),('system.schema','redirect',_binary 'i:8109;'),('system.schema','rel_to_abs',_binary 'i:8000;'),('system.schema','rest',_binary 'i:8401;'),('system.schema','restui',_binary 'i:8000;'),('system.schema','rest_absolute_urls',_binary 'i:8000;'),('system.schema','rh_node',_binary 'i:8000;'),('system.schema','rh_taxonomy',_binary 'i:8000;'),('system.schema','serialization',_binary 'i:8401;'),('system.schema','shortcut',_binary 'i:8000;'),('system.schema','simple_sitemap',_binary 'i:8408;'),('system.schema','svg_image',_binary 'i:8000;'),('system.schema','system',_binary 'i:11102;'),('system.schema','taxonomy',_binary 'i:10100;'),('system.schema','text',_binary 'i:8000;'),('system.schema','token',_binary 'i:8000;'),('system.schema','toolbar',_binary 'i:8000;'),('system.schema','update',_binary 'i:8001;'),('system.schema','user',_binary 'i:10000;'),('system.schema','views',_binary 'i:8500;'),('system.schema','views_ui',_binary 'i:8000;'),('system.schema','webform',_binary 'i:8639;'),('system.schema','webform_access',_binary 'i:8003;'),('system.schema','webform_attachment',_binary 'i:8000;'),('system.schema','webform_node',_binary 'i:8000;'),('system.schema','webform_options_limit',_binary 'i:8002;'),('system.schema','webform_rest',_binary 'i:8000;'),('system.schema','webform_schema',_binary 'i:8000;'),('system.schema','webform_submission_export_import',_binary 'i:8000;'),('system.schema','webform_ui',_binary 'i:8000;'),('update_fetch_task','anchor_link',_binary 'a:6:{s:4:\"name\";s:11:\"anchor_link\";s:4:\"info\";a:6:{s:4:\"name\";s:20:\"CKEditor Anchor Link\";s:7:\"package\";s:8:\"CKEditor\";s:7:\"version\";s:11:\"3.0.0-beta1\";s:7:\"project\";s:11:\"anchor_link\";s:9:\"datestamp\";i:1718825064;s:16:\"_info_file_ctime\";i:1743933648;}s:9:\"datestamp\";i:1718825064;s:8:\"includes\";a:1:{s:11:\"anchor_link\";s:20:\"CKEditor Anchor Link\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ckeditor5_plugin_pack',_binary 'a:6:{s:4:\"name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.3.1\";s:7:\"project\";s:21:\"ckeditor5_plugin_pack\";s:9:\"datestamp\";i:1742472945;s:16:\"_info_file_ctime\";i:1743933784;}s:9:\"datestamp\";i:1742472945;s:8:\"includes\";a:11:{s:21:\"ckeditor5_plugin_pack\";s:22:\"CKEditor 5 Plugin Pack\";s:32:\"ckeditor5_plugin_pack_auto_image\";s:21:\"CKEditor 5 Auto Image\";s:30:\"ckeditor5_plugin_pack_bookmark\";s:20:\"CKEditor 5 Bookmarks\";s:38:\"ckeditor5_plugin_pack_find_and_replace\";s:27:\"CKEditor 5 Find And Replace\";s:26:\"ckeditor5_plugin_pack_font\";s:23:\"CKEditor 5 Font Plugins\";s:31:\"ckeditor5_plugin_pack_highlight\";s:20:\"CKEditor 5 Highlight\";s:34:\"ckeditor5_plugin_pack_indent_block\";s:28:\"CKEditor 5 Block Indentation\";s:32:\"ckeditor5_plugin_pack_page_break\";s:21:\"CKEditor 5 Page Break\";s:32:\"ckeditor5_plugin_pack_select_all\";s:21:\"CKEditor 5 Select All\";s:31:\"ckeditor5_plugin_pack_templates\";s:20:\"CKEditor 5 Templates\";s:41:\"ckeditor5_plugin_pack_text_transformation\";s:30:\"CKEditor 5 Text Transformation\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','ckeditor5_premium_features',_binary 'a:6:{s:4:\"name\";s:26:\"ckeditor5_premium_features\";s:4:\"info\";a:6:{s:4:\"name\";s:27:\"CKEditor 5 Full-screen Mode\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.4.1\";s:7:\"project\";s:26:\"ckeditor5_premium_features\";s:9:\"datestamp\";i:1742472692;s:16:\"_info_file_ctime\";i:1743933784;}s:9:\"datestamp\";i:1742472692;s:8:\"includes\";a:1:{s:37:\"ckeditor5_premium_features_fullscreen\";s:27:\"CKEditor 5 Full-screen Mode\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','config_ignore',_binary 'a:6:{s:4:\"name\";s:13:\"config_ignore\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Config Ignore\";s:7:\"package\";s:6:\"Config\";s:7:\"version\";s:7:\"8.x-3.3\";s:7:\"project\";s:13:\"config_ignore\";s:9:\"datestamp\";i:1713299497;s:16:\"_info_file_ctime\";i:1743933651;}s:9:\"datestamp\";i:1713299497;s:8:\"includes\";a:1:{s:13:\"config_ignore\";s:13:\"Config Ignore\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','config_split',_binary 'a:6:{s:4:\"name\";s:12:\"config_split\";s:4:\"info\";a:6:{s:4:\"name\";s:12:\"Config Split\";s:7:\"package\";s:6:\"Config\";s:7:\"version\";s:5:\"2.0.2\";s:7:\"project\";s:12:\"config_split\";s:9:\"datestamp\";i:1739356082;s:16:\"_info_file_ctime\";i:1743933651;}s:9:\"datestamp\";i:1739356082;s:8:\"includes\";a:1:{s:12:\"config_split\";s:12:\"Config Split\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','diff',_binary 'a:6:{s:4:\"name\";s:4:\"diff\";s:4:\"info\";a:6:{s:4:\"name\";s:4:\"Diff\";s:7:\"version\";s:7:\"8.x-1.8\";s:7:\"project\";s:4:\"diff\";s:9:\"datestamp\";i:1727849726;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1727849726;s:8:\"includes\";a:1:{s:4:\"diff\";s:4:\"Diff\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','drupal',_binary 'a:6:{s:4:\"name\";s:6:\"drupal\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Announcements\";s:7:\"version\";s:6:\"11.1.5\";s:7:\"package\";s:4:\"Core\";s:7:\"project\";s:6:\"drupal\";s:16:\"_info_file_ctime\";i:1743933783;s:9:\"datestamp\";i:0;}s:9:\"datestamp\";i:0;s:8:\"includes\";a:45:{s:18:\"announcements_feed\";s:13:\"Announcements\";s:14:\"automated_cron\";s:14:\"Automated Cron\";s:8:\"big_pipe\";s:7:\"BigPipe\";s:5:\"block\";s:5:\"Block\";s:13:\"block_content\";s:13:\"Block Content\";s:10:\"breakpoint\";s:10:\"Breakpoint\";s:9:\"ckeditor5\";s:10:\"CKEditor 5\";s:7:\"comment\";s:7:\"Comment\";s:6:\"config\";s:21:\"Configuration Manager\";s:18:\"config_translation\";s:25:\"Configuration Translation\";s:7:\"contact\";s:7:\"Contact\";s:10:\"contextual\";s:16:\"Contextual Links\";s:8:\"datetime\";s:8:\"Datetime\";s:5:\"dblog\";s:16:\"Database Logging\";s:18:\"dynamic_page_cache\";s:27:\"Internal Dynamic Page Cache\";s:6:\"editor\";s:11:\"Text Editor\";s:5:\"field\";s:5:\"Field\";s:8:\"field_ui\";s:8:\"Field UI\";s:4:\"file\";s:4:\"File\";s:6:\"filter\";s:6:\"Filter\";s:4:\"help\";s:4:\"Help\";s:7:\"history\";s:7:\"History\";s:5:\"image\";s:5:\"Image\";s:7:\"jsonapi\";s:8:\"JSON:API\";s:8:\"language\";s:8:\"Language\";s:4:\"link\";s:4:\"Link\";s:6:\"locale\";s:21:\"Interface Translation\";s:17:\"menu_link_content\";s:17:\"Custom Menu Links\";s:7:\"menu_ui\";s:7:\"Menu UI\";s:4:\"node\";s:4:\"Node\";s:7:\"options\";s:7:\"Options\";s:10:\"page_cache\";s:19:\"Internal Page Cache\";s:4:\"path\";s:4:\"Path\";s:10:\"path_alias\";s:10:\"Path alias\";s:4:\"rest\";s:20:\"RESTful Web Services\";s:13:\"serialization\";s:13:\"Serialization\";s:8:\"shortcut\";s:8:\"Shortcut\";s:6:\"system\";s:6:\"System\";s:8:\"taxonomy\";s:8:\"Taxonomy\";s:4:\"text\";s:4:\"Text\";s:7:\"toolbar\";s:7:\"Toolbar\";s:6:\"update\";s:14:\"Update Manager\";s:4:\"user\";s:4:\"User\";s:5:\"views\";s:5:\"Views\";s:8:\"views_ui\";s:8:\"Views UI\";}s:12:\"project_type\";s:4:\"core\";s:14:\"project_status\";b:1;}'),('update_fetch_task','fast_distribution',_binary 'a:6:{s:4:\"name\";s:17:\"fast_distribution\";s:4:\"info\";a:6:{s:4:\"name\";s:4:\"Fast\";s:7:\"version\";s:5:\"1.0.1\";s:7:\"project\";s:17:\"fast_distribution\";s:9:\"datestamp\";i:1729499894;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933884;}s:9:\"datestamp\";i:1729499894;s:8:\"includes\";a:1:{s:4:\"fast\";s:4:\"Fast\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','field_group',_binary 'a:6:{s:4:\"name\";s:11:\"field_group\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Field Group\";s:7:\"package\";s:6:\"Fields\";s:7:\"version\";s:7:\"8.x-3.6\";s:7:\"project\";s:11:\"field_group\";s:9:\"datestamp\";i:1722672513;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1722672513;s:8:\"includes\";a:1:{s:11:\"field_group\";s:11:\"Field Group\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','gin',_binary 'a:6:{s:4:\"name\";s:3:\"gin\";s:4:\"info\";a:5:{s:4:\"name\";s:3:\"Gin\";s:7:\"version\";s:5:\"4.0.6\";s:7:\"project\";s:3:\"gin\";s:9:\"datestamp\";i:1740738975;s:16:\"_info_file_ctime\";i:1743933667;}s:9:\"datestamp\";i:1740738975;s:8:\"includes\";a:1:{s:3:\"gin\";s:3:\"Gin\";}s:12:\"project_type\";s:5:\"theme\";s:14:\"project_status\";b:1;}'),('update_fetch_task','gin_toolbar',_binary 'a:6:{s:4:\"name\";s:11:\"gin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Gin Toolbar\";s:7:\"version\";s:5:\"2.0.0\";s:7:\"project\";s:11:\"gin_toolbar\";s:9:\"datestamp\";i:1734698923;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1734698923;s:8:\"includes\";a:1:{s:11:\"gin_toolbar\";s:11:\"Gin Toolbar\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','glightbox',_binary 'a:6:{s:4:\"name\";s:9:\"glightbox\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"GLightbox\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:6:\"1.0.14\";s:7:\"project\";s:9:\"glightbox\";s:9:\"datestamp\";i:1741428235;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1741428235;s:8:\"includes\";a:2:{s:9:\"glightbox\";s:9:\"GLightbox\";s:16:\"glightbox_inline\";s:16:\"GLightbox Inline\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','hotkeys_for_save',_binary 'a:6:{s:4:\"name\";s:16:\"hotkeys_for_save\";s:4:\"info\";a:6:{s:4:\"name\";s:16:\"Hotkeys for Save\";s:7:\"package\";s:16:\"Hotkeys for Save\";s:7:\"version\";s:5:\"2.0.1\";s:7:\"project\";s:16:\"hotkeys_for_save\";s:9:\"datestamp\";i:1699460197;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1699460197;s:8:\"includes\";a:1:{s:16:\"hotkeys_for_save\";s:16:\"Hotkeys for Save\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','jsonapi_extras',_binary 'a:6:{s:4:\"name\";s:14:\"jsonapi_extras\";s:4:\"info\";a:6:{s:4:\"name\";s:15:\"JSON:API Extras\";s:7:\"package\";s:12:\"Web services\";s:7:\"version\";s:8:\"8.x-3.26\";s:7:\"project\";s:14:\"jsonapi_extras\";s:9:\"datestamp\";i:1727787966;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1727787966;s:8:\"includes\";a:2:{s:14:\"jsonapi_extras\";s:15:\"JSON:API Extras\";s:16:\"jsonapi_defaults\";s:17:\"JSON:API Defaults\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','jsonapi_menu_items',_binary 'a:6:{s:4:\"name\";s:18:\"jsonapi_menu_items\";s:4:\"info\";a:6:{s:4:\"name\";s:19:\"JSON:API Menu items\";s:7:\"version\";s:5:\"1.2.6\";s:7:\"project\";s:18:\"jsonapi_menu_items\";s:9:\"datestamp\";i:1722543503;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1722543503;s:8:\"includes\";a:1:{s:18:\"jsonapi_menu_items\";s:19:\"JSON:API Menu items\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','jsonapi_resources',_binary 'a:6:{s:4:\"name\";s:17:\"jsonapi_resources\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"JSON:API Resources\";s:7:\"version\";s:7:\"8.x-1.2\";s:7:\"project\";s:17:\"jsonapi_resources\";s:9:\"datestamp\";i:1719872298;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1719872298;s:8:\"includes\";a:1:{s:17:\"jsonapi_resources\";s:18:\"JSON:API Resources\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','jsonapi_response_alter',_binary 'a:6:{s:4:\"name\";s:22:\"jsonapi_response_alter\";s:4:\"info\";a:6:{s:4:\"name\";s:23:\"JSON:API Response Alter\";s:7:\"package\";s:6:\"Custom\";s:7:\"version\";s:5:\"2.0.1\";s:7:\"project\";s:22:\"jsonapi_response_alter\";s:9:\"datestamp\";i:1718696572;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1718696572;s:8:\"includes\";a:1:{s:22:\"jsonapi_response_alter\";s:23:\"JSON:API Response Alter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','jsonapi_views',_binary 'a:6:{s:4:\"name\";s:13:\"jsonapi_views\";s:4:\"info\";a:6:{s:4:\"name\";s:14:\"JSON:API Views\";s:7:\"version\";s:7:\"8.x-1.1\";s:7:\"project\";s:13:\"jsonapi_views\";s:9:\"datestamp\";i:1675998789;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1675998789;s:8:\"includes\";a:1:{s:13:\"jsonapi_views\";s:14:\"JSON:API Views\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','linkit',_binary 'a:6:{s:4:\"name\";s:6:\"linkit\";s:4:\"info\";a:6:{s:4:\"name\";s:6:\"Linkit\";s:7:\"package\";s:14:\"User interface\";s:7:\"version\";s:5:\"7.0.3\";s:7:\"project\";s:6:\"linkit\";s:9:\"datestamp\";i:1738264706;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1738264706;s:8:\"includes\";a:1:{s:6:\"linkit\";s:6:\"Linkit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','link_attributes',_binary 'a:6:{s:4:\"name\";s:15:\"link_attributes\";s:4:\"info\";a:6:{s:4:\"name\";s:15:\"Link attributes\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:15:\"link_attributes\";s:9:\"datestamp\";i:1721366574;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1721366574;s:8:\"includes\";a:3:{s:15:\"link_attributes\";s:15:\"Link attributes\";s:33:\"link_attributes_menu_link_content\";s:46:\"Link attributes: Menu Link Content integration\";s:17:\"linkit_attributes\";s:17:\"Linkit attributes\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','media_library_edit',_binary 'a:6:{s:4:\"name\";s:18:\"media_library_edit\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"Media Library Edit\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"3.0.4\";s:7:\"project\";s:18:\"media_library_edit\";s:9:\"datestamp\";i:1724357847;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1724357847;s:8:\"includes\";a:1:{s:18:\"media_library_edit\";s:18:\"Media Library Edit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','menu_item_extras',_binary 'a:6:{s:4:\"name\";s:16:\"menu_item_extras\";s:4:\"info\";a:6:{s:4:\"name\";s:16:\"Menu Item Extras\";s:7:\"package\";s:4:\"Menu\";s:7:\"version\";s:5:\"3.1.0\";s:7:\"project\";s:16:\"menu_item_extras\";s:9:\"datestamp\";i:1725022063;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1725022063;s:8:\"includes\";a:1:{s:16:\"menu_item_extras\";s:16:\"Menu Item Extras\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','metatag',_binary 'a:6:{s:4:\"name\";s:7:\"metatag\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"Metatag\";s:7:\"package\";s:3:\"SEO\";s:7:\"version\";s:5:\"2.1.0\";s:7:\"project\";s:7:\"metatag\";s:9:\"datestamp\";i:1731004045;s:16:\"_info_file_ctime\";i:1743933654;}s:9:\"datestamp\";i:1731004045;s:8:\"includes\";a:1:{s:7:\"metatag\";s:7:\"Metatag\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','pathauto',_binary 'a:6:{s:4:\"name\";s:8:\"pathauto\";s:4:\"info\";a:6:{s:4:\"name\";s:8:\"Pathauto\";s:7:\"version\";s:8:\"8.x-1.13\";s:7:\"project\";s:8:\"pathauto\";s:9:\"datestamp\";i:1722507674;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1722507674;s:8:\"includes\";a:1:{s:8:\"pathauto\";s:8:\"Pathauto\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','rabbit_hole',_binary 'a:6:{s:4:\"name\";s:11:\"rabbit_hole\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Rabbit Hole nodes\";s:7:\"version\";s:7:\"8.x-1.0\";s:7:\"project\";s:11:\"rabbit_hole\";s:9:\"datestamp\";i:1721413115;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1721413115;s:8:\"includes\";a:3:{s:7:\"rh_node\";s:17:\"Rabbit Hole nodes\";s:11:\"rh_taxonomy\";s:20:\"Rabbit Hole taxonomy\";s:11:\"rabbit_hole\";s:11:\"Rabbit Hole\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','redirect',_binary 'a:6:{s:4:\"name\";s:8:\"redirect\";s:4:\"info\";a:6:{s:4:\"name\";s:8:\"Redirect\";s:7:\"version\";s:8:\"8.x-1.11\";s:7:\"project\";s:8:\"redirect\";s:9:\"datestamp\";i:1737382888;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1737382888;s:8:\"includes\";a:1:{s:8:\"redirect\";s:8:\"Redirect\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','restui',_binary 'a:6:{s:4:\"name\";s:6:\"restui\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"REST UI\";s:7:\"package\";s:12:\"Web services\";s:7:\"version\";s:8:\"8.x-1.22\";s:7:\"project\";s:6:\"restui\";s:9:\"datestamp\";i:1721134192;s:16:\"_info_file_ctime\";i:1743933840;}s:9:\"datestamp\";i:1721134192;s:8:\"includes\";a:1:{s:6:\"restui\";s:7:\"REST UI\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','rest_absolute_urls',_binary 'a:6:{s:4:\"name\";s:18:\"rest_absolute_urls\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"REST Absolute URLs\";s:7:\"version\";s:5:\"2.0.0\";s:7:\"project\";s:18:\"rest_absolute_urls\";s:9:\"datestamp\";i:1725017289;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933859;}s:9:\"datestamp\";i:1725017289;s:8:\"includes\";a:1:{s:18:\"rest_absolute_urls\";s:18:\"REST Absolute URLs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','simple_sitemap',_binary 'a:6:{s:4:\"name\";s:14:\"simple_sitemap\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"Simple XML Sitemap\";s:7:\"package\";s:3:\"SEO\";s:7:\"version\";s:5:\"4.2.2\";s:7:\"project\";s:14:\"simple_sitemap\";s:9:\"datestamp\";i:1732485887;s:16:\"_info_file_ctime\";i:1743933657;}s:9:\"datestamp\";i:1732485887;s:8:\"includes\";a:1:{s:14:\"simple_sitemap\";s:18:\"Simple XML Sitemap\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','svg_image',_binary 'a:6:{s:4:\"name\";s:9:\"svg_image\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"SVG image\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"3.2.1\";s:7:\"project\";s:9:\"svg_image\";s:9:\"datestamp\";i:1736865069;s:16:\"_info_file_ctime\";i:1743933658;}s:9:\"datestamp\";i:1736865069;s:8:\"includes\";a:1:{s:9:\"svg_image\";s:9:\"SVG image\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','token',_binary 'a:6:{s:4:\"name\";s:5:\"token\";s:4:\"info\";a:6:{s:4:\"name\";s:5:\"Token\";s:7:\"version\";s:8:\"8.x-1.15\";s:7:\"project\";s:5:\"token\";s:9:\"datestamp\";i:1722206215;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933658;}s:9:\"datestamp\";i:1722206215;s:8:\"includes\";a:1:{s:5:\"token\";s:5:\"Token\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','webform',_binary 'a:6:{s:4:\"name\";s:7:\"webform\";s:4:\"info\";a:6:{s:4:\"name\";s:14:\"Webform Access\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:11:\"6.3.0-beta2\";s:7:\"project\";s:7:\"webform\";s:9:\"datestamp\";i:1742581873;s:16:\"_info_file_ctime\";i:1743933787;}s:9:\"datestamp\";i:1742581873;s:8:\"includes\";a:8:{s:14:\"webform_access\";s:14:\"Webform Access\";s:18:\"webform_attachment\";s:18:\"Webform Attachment\";s:12:\"webform_node\";s:12:\"Webform Node\";s:21:\"webform_options_limit\";s:21:\"Webform Options Limit\";s:14:\"webform_schema\";s:14:\"Webform Schema\";s:32:\"webform_submission_export_import\";s:32:\"Webform Submission Export/Import\";s:10:\"webform_ui\";s:10:\"Webform UI\";s:7:\"webform\";s:7:\"Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','webform_rest',_binary 'a:6:{s:4:\"name\";s:12:\"webform_rest\";s:4:\"info\";a:6:{s:4:\"name\";s:12:\"Webform REST\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:5:\"4.2.0\";s:7:\"project\";s:12:\"webform_rest\";s:9:\"datestamp\";i:1736288233;s:16:\"_info_file_ctime\";i:1743933666;}s:9:\"datestamp\";i:1736288233;s:8:\"includes\";a:1:{s:12:\"webform_rest\";s:12:\"Webform REST\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}');
/*!40000 ALTER TABLE `key_value` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `key_value_expire`
--

DROP TABLE IF EXISTS `key_value_expire`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `key_value_expire` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key/value pair.',
  `value` longblob NOT NULL COMMENT 'The value of the key/value pair.',
  `expire` int NOT NULL DEFAULT '2147483647' COMMENT 'The time since Unix epoch in seconds when this item expires. Defaults to the maximum possible time.',
  PRIMARY KEY (`collection`,`name`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Generic key/value storage table with an expiration.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `key_value_expire`
--

LOCK TABLES `key_value_expire` WRITE;
/*!40000 ALTER TABLE `key_value_expire` DISABLE KEYS */;
INSERT INTO `key_value_expire` VALUES ('announcements_feed','announcements',_binary 'a:13:{i:0;a:7:{s:2:\"id\";s:7:\"3509234\";s:5:\"title\";s:48:\"DrupalCon Atlanta is almost here! 24-27 of March\";s:12:\"content_html\";s:444:\"<p>DrupalCon is an exciting and invaluable event for anyone involved in the Drupal community, whether you’re a developer, website owner, or digital professional. If you’re heading to <a href=\"https://events.drupal.org/atlanta2025\" rel=\"nofollow\">DrupalCon Atlanta 2025</a> for the first time, you’re in for a treat! Here\'s everything you need to know to make the most of your experience, along with some top tips for how to prepare.</p>\";s:3:\"url\";s:95:\"https://www.drupal.org/about/announcements/blog/drupalcon-atlanta-is-almost-here-24-27-of-march\";s:13:\"date_modified\";s:25:\"2025-02-26T20:33:54+00:00\";s:14:\"date_published\";s:25:\"2025-02-26T20:33:27+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:3:\">=7\";}}i:1;a:7:{s:2:\"id\";s:7:\"3499892\";s:5:\"title\";s:32:\"Drupal CMS 1.0 is now available!\";s:12:\"content_html\";s:436:\"<p>We’re excited to share that Drupal CMS 1.0 has officially launched! This new platform is designed to make it easier than ever for marketers and content teams to create amazing digital experiences, all while staying true to Drupal’s open-source roots.</p>\n<p><img alt=\"Getting started takes minutes\" height=\"720\" src=\"/files/CMS1-1_1.png\" width=\"1280\" /></p>\n<p>Drupal CMS 1.0 is packed with features to make your life easier:</p>\";s:3:\"url\";s:42:\"https://www.drupal.org/blog/drupal-cms-1-0\";s:13:\"date_modified\";s:25:\"2025-01-15T18:40:24+00:00\";s:14:\"date_published\";s:25:\"2025-01-15T17:00:28+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:2:\">7\";}}i:3;a:7:{s:2:\"id\";s:7:\"3494304\";s:5:\"title\";s:30:\"Drupal 11.1.0 is now available\";s:12:\"content_html\";s:263:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/11.1.0\" rel=\"nofollow\">first feature release of Drupal 11</a> improves the recipe system, introduces support for hooks written as classes, makes Workspaces more flexible and enhances performance.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-11-1-0\";s:13:\"date_modified\";s:25:\"2024-12-16T20:28:53+00:00\";s:14:\"date_published\";s:25:\"2024-12-16T17:50:29+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:5;a:7:{s:2:\"id\";s:7:\"3480615\";s:5:\"title\";s:58:\"DrupalCon Singapore 2024: What Awaits You in the Lion City\";s:12:\"content_html\";s:528:\"<p>It’s time to dust off those suitcases and start thinking about where your passport is - <a href=\"https://events.drupal.org/singapore2024\" rel=\"nofollow\">DrupalCon Singapore 2024</a> is just around the corner, and this year’s event promises to be amazing! From 9-11 December, our much-anticipated event will bring together the brightest minds and most passionate contributors from the Drupal community for three days of innovation, learning, and inspiration at the luxurious Parkroyal Collection Marina Bay, Singapore.</p>\";s:3:\"url\";s:105:\"https://www.drupal.org/about/announcements/blog/drupalcon-singapore-2024-what-awaits-you-in-the-lion-city\";s:13:\"date_modified\";s:25:\"2024-10-14T16:49:44+00:00\";s:14:\"date_published\";s:25:\"2024-10-14T16:49:44+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:6;a:7:{s:2:\"id\";s:7:\"3465580\";s:5:\"title\";s:18:\"Drupal 11 released\";s:12:\"content_html\";s:114:\"<p>Today is a big day for <a href=\"https://www.drupal.org/\">Drupal</a> as we officially released Drupal 11!</p>\n\";s:3:\"url\";s:46:\"https://www.drupal.org/blog/drupal-11-released\";s:13:\"date_modified\";s:25:\"2024-08-15T15:10:39+00:00\";s:14:\"date_published\";s:25:\"2024-08-01T22:57:58+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:1:\"*\";}}i:7;a:7:{s:2:\"id\";s:7:\"3456034\";s:5:\"title\";s:28:\"Drupal 10.3 is now available\";s:12:\"content_html\";s:370:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/10.3.0\" rel=\"nofollow\">third and final feature release of Drupal 10</a> ships with a new experimental Navigation user interface, stable Workspaces functionality, stable Single-Directory Components support, simplified menu editing, taxonomy moderation support, new recipe and access policy APIs and more.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-3-0\";s:13:\"date_modified\";s:25:\"2024-09-05T23:00:47+00:00\";s:14:\"date_published\";s:25:\"2024-06-20T20:00:04+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:9;a:7:{s:2:\"id\";s:7:\"3427138\";s:5:\"title\";s:52:\"You\'re invited to DrupalCon Portland | 6-9 May, 2024\";s:12:\"content_html\";s:384:\"<p>DrupalCon is an event for developers, marketers/content editors, site owners, and the Drupal-curious to join with the community. You\'ll find incredible keynotes, session content from expert speakers who have helped to build Drupal, networking opportunities with your peers, fun social events, and the chance to deepen your connection by contributing to the open source project.</p>\";s:3:\"url\";s:96:\"https://www.drupal.org/about/announcements/blog/youre-invited-to-drupalcon-portland-6-9-may-2024\";s:13:\"date_modified\";s:25:\"2024-03-18T19:40:04+00:00\";s:14:\"date_published\";s:25:\"2024-03-11T16:49:53+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:10;a:7:{s:2:\"id\";s:7:\"3408836\";s:5:\"title\";s:28:\"Drupal 10.2 is now available\";s:12:\"content_html\";s:378:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/10.2.0\">second feature release of Drupal 10</a> improves content modeling, block management, menu and taxonomy organization, and permission administration. New options to sanitize file names make it possible to clean up the names of uploaded files, and media item revisions now have a dedicated user interface.</p>\n\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-2-0\";s:13:\"date_modified\";s:25:\"2024-01-25T18:24:28+00:00\";s:14:\"date_published\";s:25:\"2023-12-15T18:27:47+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:11;a:7:{s:2:\"id\";s:7:\"3403229\";s:5:\"title\";s:75:\"Drupal 10 will be supported until the release of Drupal 12 in mid-late 2026\";s:12:\"content_html\";s:190:\"<p>Announcing a new major release schedule with long term support for Drupal 10 until mid-late 2026. Drupal 11 will be released in 2024 and work on the dedicated branch starts this week.</p>\";s:3:\"url\";s:103:\"https://www.drupal.org/blog/drupal-10-will-be-supported-until-the-release-of-drupal-12-in-mid-late-2026\";s:13:\"date_modified\";s:25:\"2024-01-25T18:31:05+00:00\";s:14:\"date_published\";s:25:\"2023-11-22T07:13:55+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:13;a:7:{s:2:\"id\";s:7:\"3368367\";s:5:\"title\";s:28:\"Drupal 10.1 is now available\";s:12:\"content_html\";s:257:\"<p>This first feature release of Drupal 10 is packed with amazing improvements! It makes customizing the look of your site easier, adds support for decoupled navigation, improves content modeling and editing, block management, performance and many more.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-1-0\";s:13:\"date_modified\";s:25:\"2023-10-30T16:22:24+00:00\";s:14:\"date_published\";s:25:\"2023-06-22T09:11:30+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:14;a:7:{s:2:\"id\";s:7:\"3347976\";s:5:\"title\";s:37:\"Contribute to Drupal and the Open Web\";s:12:\"content_html\";s:146:\"<p>Drupal is an open source project. But what does that mean? How can you as a site-owner participate in the project of building a better web?</p>\";s:3:\"url\";s:85:\"https://www.drupal.org/about/announcements/blog/contribute-to-drupal-and-the-open-web\";s:13:\"date_modified\";s:25:\"2023-03-14T19:43:12+00:00\";s:14:\"date_published\";s:25:\"2023-03-14T19:39:44+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:15;a:7:{s:2:\"id\";s:7:\"3343486\";s:5:\"title\";s:43:\"What to expect from the Announcements feed?\";s:12:\"content_html\";s:197:\"<p>Drupal is introducing a new project Announcements feature so that you can see news and updates about the Drupal project and community directly in your Drupal dashboard. Learn what to expect.</p>\";s:3:\"url\";s:90:\"https://www.drupal.org/about/announcements/blog/what-to-expect-from-the-announcements-feed\";s:13:\"date_modified\";s:25:\"2023-02-21T19:45:53+00:00\";s:14:\"date_published\";s:25:\"2023-02-21T19:45:53+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:16;a:7:{s:2:\"id\";s:7:\"3327047\";s:5:\"title\";s:26:\"Drupal 10.0.0 is available\";s:12:\"content_html\";s:296:\"<p>Thanks to 2129 contributors from 616 organizations resolving 4083 issues in the past two and a half years, Drupal 10.0.0 is available today! This new version sets Drupal up for continued stability and security for the longer term. All new features will be added to Drupal 10 going forward.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-0-0\";s:13:\"date_modified\";s:25:\"2023-10-30T16:21:38+00:00\";s:14:\"date_published\";s:25:\"2022-12-15T17:43:23+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}}',1744018374),('system','advisories_response',_binary 'a:0:{}',1743953574),('update','update_project_data',_binary 'a:33:{s:6:\"drupal\";a:14:{s:4:\"name\";s:6:\"drupal\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Announcements\";s:7:\"version\";s:6:\"11.1.5\";s:7:\"package\";s:4:\"Core\";s:7:\"project\";s:6:\"drupal\";s:16:\"_info_file_ctime\";i:1743933783;s:9:\"datestamp\";i:0;}s:9:\"datestamp\";i:0;s:8:\"includes\";a:45:{s:18:\"announcements_feed\";s:13:\"Announcements\";s:14:\"automated_cron\";s:14:\"Automated Cron\";s:8:\"big_pipe\";s:7:\"BigPipe\";s:5:\"block\";s:5:\"Block\";s:13:\"block_content\";s:13:\"Block Content\";s:10:\"breakpoint\";s:10:\"Breakpoint\";s:9:\"ckeditor5\";s:10:\"CKEditor 5\";s:7:\"comment\";s:7:\"Comment\";s:6:\"config\";s:21:\"Configuration Manager\";s:18:\"config_translation\";s:25:\"Configuration Translation\";s:7:\"contact\";s:7:\"Contact\";s:10:\"contextual\";s:16:\"Contextual Links\";s:8:\"datetime\";s:8:\"Datetime\";s:5:\"dblog\";s:16:\"Database Logging\";s:18:\"dynamic_page_cache\";s:27:\"Internal Dynamic Page Cache\";s:6:\"editor\";s:11:\"Text Editor\";s:5:\"field\";s:5:\"Field\";s:8:\"field_ui\";s:8:\"Field UI\";s:4:\"file\";s:4:\"File\";s:6:\"filter\";s:6:\"Filter\";s:4:\"help\";s:4:\"Help\";s:7:\"history\";s:7:\"History\";s:5:\"image\";s:5:\"Image\";s:7:\"jsonapi\";s:8:\"JSON:API\";s:8:\"language\";s:8:\"Language\";s:4:\"link\";s:4:\"Link\";s:6:\"locale\";s:21:\"Interface Translation\";s:17:\"menu_link_content\";s:17:\"Custom Menu Links\";s:7:\"menu_ui\";s:7:\"Menu UI\";s:4:\"node\";s:4:\"Node\";s:7:\"options\";s:7:\"Options\";s:10:\"page_cache\";s:19:\"Internal Page Cache\";s:4:\"path\";s:4:\"Path\";s:10:\"path_alias\";s:10:\"Path alias\";s:4:\"rest\";s:20:\"RESTful Web Services\";s:13:\"serialization\";s:13:\"Serialization\";s:8:\"shortcut\";s:8:\"Shortcut\";s:6:\"system\";s:6:\"System\";s:8:\"taxonomy\";s:8:\"Taxonomy\";s:4:\"text\";s:4:\"Text\";s:7:\"toolbar\";s:7:\"Toolbar\";s:6:\"update\";s:14:\"Update Manager\";s:4:\"user\";s:4:\"User\";s:5:\"views\";s:5:\"Views\";s:8:\"views_ui\";s:8:\"Views UI\";}s:12:\"project_type\";s:4:\"core\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:6:\"11.1.5\";s:14:\"existing_major\";s:2:\"11\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:11:\"Drupal core\";s:4:\"link\";s:37:\"https://www.drupal.org/project/drupal\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:11:\"anchor_link\";a:14:{s:4:\"name\";s:11:\"anchor_link\";s:4:\"info\";a:6:{s:4:\"name\";s:20:\"CKEditor Anchor Link\";s:7:\"package\";s:8:\"CKEditor\";s:7:\"version\";s:11:\"3.0.0-beta1\";s:7:\"project\";s:11:\"anchor_link\";s:9:\"datestamp\";i:1718825064;s:16:\"_info_file_ctime\";i:1743933648;}s:9:\"datestamp\";i:1718825064;s:8:\"includes\";a:1:{s:11:\"anchor_link\";s:20:\"CKEditor Anchor Link\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:11:\"3.0.0-beta1\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:20:\"CKEditor Anchor Link\";s:4:\"link\";s:42:\"https://www.drupal.org/project/anchor_link\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:21:\"ckeditor5_plugin_pack\";a:14:{s:4:\"name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.3.1\";s:7:\"project\";s:21:\"ckeditor5_plugin_pack\";s:9:\"datestamp\";i:1742472945;s:16:\"_info_file_ctime\";i:1743933784;}s:9:\"datestamp\";i:1742472945;s:8:\"includes\";a:11:{s:21:\"ckeditor5_plugin_pack\";s:22:\"CKEditor 5 Plugin Pack\";s:32:\"ckeditor5_plugin_pack_auto_image\";s:21:\"CKEditor 5 Auto Image\";s:30:\"ckeditor5_plugin_pack_bookmark\";s:20:\"CKEditor 5 Bookmarks\";s:38:\"ckeditor5_plugin_pack_find_and_replace\";s:27:\"CKEditor 5 Find And Replace\";s:26:\"ckeditor5_plugin_pack_font\";s:23:\"CKEditor 5 Font Plugins\";s:31:\"ckeditor5_plugin_pack_highlight\";s:20:\"CKEditor 5 Highlight\";s:34:\"ckeditor5_plugin_pack_indent_block\";s:28:\"CKEditor 5 Block Indentation\";s:32:\"ckeditor5_plugin_pack_page_break\";s:21:\"CKEditor 5 Page Break\";s:32:\"ckeditor5_plugin_pack_select_all\";s:21:\"CKEditor 5 Select All\";s:31:\"ckeditor5_plugin_pack_templates\";s:20:\"CKEditor 5 Templates\";s:41:\"ckeditor5_plugin_pack_text_transformation\";s:30:\"CKEditor 5 Text Transformation\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.3.1\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:22:\"CKEditor 5 Plugin Pack\";s:4:\"link\";s:52:\"https://www.drupal.org/project/ckeditor5_plugin_pack\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:26:\"ckeditor5_premium_features\";a:14:{s:4:\"name\";s:26:\"ckeditor5_premium_features\";s:4:\"info\";a:6:{s:4:\"name\";s:27:\"CKEditor 5 Full-screen Mode\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.4.1\";s:7:\"project\";s:26:\"ckeditor5_premium_features\";s:9:\"datestamp\";i:1742472692;s:16:\"_info_file_ctime\";i:1743933784;}s:9:\"datestamp\";i:1742472692;s:8:\"includes\";a:1:{s:37:\"ckeditor5_premium_features_fullscreen\";s:27:\"CKEditor 5 Full-screen Mode\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.4.1\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:27:\"CKEditor 5 Premium Features\";s:4:\"link\";s:57:\"https://www.drupal.org/project/ckeditor5_premium_features\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:13:\"config_ignore\";a:14:{s:4:\"name\";s:13:\"config_ignore\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Config Ignore\";s:7:\"package\";s:6:\"Config\";s:7:\"version\";s:7:\"8.x-3.3\";s:7:\"project\";s:13:\"config_ignore\";s:9:\"datestamp\";i:1713299497;s:16:\"_info_file_ctime\";i:1743933651;}s:9:\"datestamp\";i:1713299497;s:8:\"includes\";a:1:{s:13:\"config_ignore\";s:13:\"Config Ignore\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-3.3\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:13:\"Config Ignore\";s:4:\"link\";s:44:\"https://www.drupal.org/project/config_ignore\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:12:\"config_split\";a:14:{s:4:\"name\";s:12:\"config_split\";s:4:\"info\";a:6:{s:4:\"name\";s:12:\"Config Split\";s:7:\"package\";s:6:\"Config\";s:7:\"version\";s:5:\"2.0.2\";s:7:\"project\";s:12:\"config_split\";s:9:\"datestamp\";i:1739356082;s:16:\"_info_file_ctime\";i:1743933651;}s:9:\"datestamp\";i:1739356082;s:8:\"includes\";a:1:{s:12:\"config_split\";s:12:\"Config Split\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.0.2\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:19:\"Configuration Split\";s:4:\"link\";s:43:\"https://www.drupal.org/project/config_split\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:4:\"diff\";a:14:{s:4:\"name\";s:4:\"diff\";s:4:\"info\";a:6:{s:4:\"name\";s:4:\"Diff\";s:7:\"version\";s:7:\"8.x-1.8\";s:7:\"project\";s:4:\"diff\";s:9:\"datestamp\";i:1727849726;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1727849726;s:8:\"includes\";a:1:{s:4:\"diff\";s:4:\"Diff\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-1.8\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:4:\"Diff\";s:4:\"link\";s:35:\"https://www.drupal.org/project/diff\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:11:\"field_group\";a:14:{s:4:\"name\";s:11:\"field_group\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Field Group\";s:7:\"package\";s:6:\"Fields\";s:7:\"version\";s:7:\"8.x-3.6\";s:7:\"project\";s:11:\"field_group\";s:9:\"datestamp\";i:1722672513;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1722672513;s:8:\"includes\";a:1:{s:11:\"field_group\";s:11:\"Field Group\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-3.6\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:11:\"Field Group\";s:4:\"link\";s:42:\"https://www.drupal.org/project/field_group\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:11:\"gin_toolbar\";a:14:{s:4:\"name\";s:11:\"gin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Gin Toolbar\";s:7:\"version\";s:5:\"2.0.0\";s:7:\"project\";s:11:\"gin_toolbar\";s:9:\"datestamp\";i:1734698923;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1734698923;s:8:\"includes\";a:1:{s:11:\"gin_toolbar\";s:11:\"Gin Toolbar\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.0.0\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:11:\"Gin Toolbar\";s:4:\"link\";s:42:\"https://www.drupal.org/project/gin_toolbar\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:9:\"glightbox\";a:14:{s:4:\"name\";s:9:\"glightbox\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"GLightbox\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:6:\"1.0.14\";s:7:\"project\";s:9:\"glightbox\";s:9:\"datestamp\";i:1741428235;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1741428235;s:8:\"includes\";a:2:{s:9:\"glightbox\";s:9:\"GLightbox\";s:16:\"glightbox_inline\";s:16:\"GLightbox Inline\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:6:\"1.0.14\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:9:\"GLightbox\";s:4:\"link\";s:40:\"https://www.drupal.org/project/glightbox\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:16:\"hotkeys_for_save\";a:14:{s:4:\"name\";s:16:\"hotkeys_for_save\";s:4:\"info\";a:6:{s:4:\"name\";s:16:\"Hotkeys for Save\";s:7:\"package\";s:16:\"Hotkeys for Save\";s:7:\"version\";s:5:\"2.0.1\";s:7:\"project\";s:16:\"hotkeys_for_save\";s:9:\"datestamp\";i:1699460197;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1699460197;s:8:\"includes\";a:1:{s:16:\"hotkeys_for_save\";s:16:\"Hotkeys for Save\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.0.1\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:16:\"Hotkeys for Save\";s:4:\"link\";s:47:\"https://www.drupal.org/project/hotkeys_for_save\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:14:\"jsonapi_extras\";a:14:{s:4:\"name\";s:14:\"jsonapi_extras\";s:4:\"info\";a:6:{s:4:\"name\";s:15:\"JSON:API Extras\";s:7:\"package\";s:12:\"Web services\";s:7:\"version\";s:8:\"8.x-3.26\";s:7:\"project\";s:14:\"jsonapi_extras\";s:9:\"datestamp\";i:1727787966;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1727787966;s:8:\"includes\";a:2:{s:14:\"jsonapi_extras\";s:15:\"JSON:API Extras\";s:16:\"jsonapi_defaults\";s:17:\"JSON:API Defaults\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:8:\"8.x-3.26\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:15:\"JSON:API Extras\";s:4:\"link\";s:45:\"https://www.drupal.org/project/jsonapi_extras\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:18:\"jsonapi_menu_items\";a:14:{s:4:\"name\";s:18:\"jsonapi_menu_items\";s:4:\"info\";a:6:{s:4:\"name\";s:19:\"JSON:API Menu items\";s:7:\"version\";s:5:\"1.2.6\";s:7:\"project\";s:18:\"jsonapi_menu_items\";s:9:\"datestamp\";i:1722543503;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1722543503;s:8:\"includes\";a:1:{s:18:\"jsonapi_menu_items\";s:19:\"JSON:API Menu items\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.2.6\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:19:\"JSON:API Menu Items\";s:4:\"link\";s:49:\"https://www.drupal.org/project/jsonapi_menu_items\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:17:\"jsonapi_resources\";a:14:{s:4:\"name\";s:17:\"jsonapi_resources\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"JSON:API Resources\";s:7:\"version\";s:7:\"8.x-1.2\";s:7:\"project\";s:17:\"jsonapi_resources\";s:9:\"datestamp\";i:1719872298;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1719872298;s:8:\"includes\";a:1:{s:17:\"jsonapi_resources\";s:18:\"JSON:API Resources\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-1.2\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:18:\"JSON:API Resources\";s:4:\"link\";s:48:\"https://www.drupal.org/project/jsonapi_resources\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:22:\"jsonapi_response_alter\";a:14:{s:4:\"name\";s:22:\"jsonapi_response_alter\";s:4:\"info\";a:6:{s:4:\"name\";s:23:\"JSON:API Response Alter\";s:7:\"package\";s:6:\"Custom\";s:7:\"version\";s:5:\"2.0.1\";s:7:\"project\";s:22:\"jsonapi_response_alter\";s:9:\"datestamp\";i:1718696572;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1718696572;s:8:\"includes\";a:1:{s:22:\"jsonapi_response_alter\";s:23:\"JSON:API Response Alter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.0.1\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:23:\"JSON:API Response Alter\";s:4:\"link\";s:53:\"https://www.drupal.org/project/jsonapi_response_alter\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:13:\"jsonapi_views\";a:14:{s:4:\"name\";s:13:\"jsonapi_views\";s:4:\"info\";a:6:{s:4:\"name\";s:14:\"JSON:API Views\";s:7:\"version\";s:7:\"8.x-1.1\";s:7:\"project\";s:13:\"jsonapi_views\";s:9:\"datestamp\";i:1675998789;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1675998789;s:8:\"includes\";a:1:{s:13:\"jsonapi_views\";s:14:\"JSON:API Views\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-1.1\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:14:\"JSON:API Views\";s:4:\"link\";s:44:\"https://www.drupal.org/project/jsonapi_views\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:15:\"link_attributes\";a:14:{s:4:\"name\";s:15:\"link_attributes\";s:4:\"info\";a:6:{s:4:\"name\";s:15:\"Link attributes\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:15:\"link_attributes\";s:9:\"datestamp\";i:1721366574;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1721366574;s:8:\"includes\";a:3:{s:15:\"link_attributes\";s:15:\"Link attributes\";s:33:\"link_attributes_menu_link_content\";s:46:\"Link attributes: Menu Link Content integration\";s:17:\"linkit_attributes\";s:17:\"Linkit attributes\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.1.1\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:22:\"Link Attributes widget\";s:4:\"link\";s:46:\"https://www.drupal.org/project/link_attributes\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:6:\"linkit\";a:14:{s:4:\"name\";s:6:\"linkit\";s:4:\"info\";a:6:{s:4:\"name\";s:6:\"Linkit\";s:7:\"package\";s:14:\"User interface\";s:7:\"version\";s:5:\"7.0.3\";s:7:\"project\";s:6:\"linkit\";s:9:\"datestamp\";i:1738264706;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1738264706;s:8:\"includes\";a:1:{s:6:\"linkit\";s:6:\"Linkit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"7.0.3\";s:14:\"existing_major\";s:1:\"7\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:6:\"Linkit\";s:4:\"link\";s:37:\"https://www.drupal.org/project/linkit\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:18:\"media_library_edit\";a:14:{s:4:\"name\";s:18:\"media_library_edit\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"Media Library Edit\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"3.0.4\";s:7:\"project\";s:18:\"media_library_edit\";s:9:\"datestamp\";i:1724357847;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1724357847;s:8:\"includes\";a:1:{s:18:\"media_library_edit\";s:18:\"Media Library Edit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"3.0.4\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:18:\"Media Library Edit\";s:4:\"link\";s:49:\"https://www.drupal.org/project/media_library_edit\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:16:\"menu_item_extras\";a:14:{s:4:\"name\";s:16:\"menu_item_extras\";s:4:\"info\";a:6:{s:4:\"name\";s:16:\"Menu Item Extras\";s:7:\"package\";s:4:\"Menu\";s:7:\"version\";s:5:\"3.1.0\";s:7:\"project\";s:16:\"menu_item_extras\";s:9:\"datestamp\";i:1725022063;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1725022063;s:8:\"includes\";a:1:{s:16:\"menu_item_extras\";s:16:\"Menu Item Extras\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"3.1.0\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:16:\"Menu Item Extras\";s:4:\"link\";s:47:\"https://www.drupal.org/project/menu_item_extras\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:7:\"metatag\";a:14:{s:4:\"name\";s:7:\"metatag\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"Metatag\";s:7:\"package\";s:3:\"SEO\";s:7:\"version\";s:5:\"2.1.0\";s:7:\"project\";s:7:\"metatag\";s:9:\"datestamp\";i:1731004045;s:16:\"_info_file_ctime\";i:1743933654;}s:9:\"datestamp\";i:1731004045;s:8:\"includes\";a:1:{s:7:\"metatag\";s:7:\"Metatag\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.1.0\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:7:\"Metatag\";s:4:\"link\";s:38:\"https://www.drupal.org/project/metatag\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:8:\"pathauto\";a:14:{s:4:\"name\";s:8:\"pathauto\";s:4:\"info\";a:6:{s:4:\"name\";s:8:\"Pathauto\";s:7:\"version\";s:8:\"8.x-1.13\";s:7:\"project\";s:8:\"pathauto\";s:9:\"datestamp\";i:1722507674;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1722507674;s:8:\"includes\";a:1:{s:8:\"pathauto\";s:8:\"Pathauto\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:8:\"8.x-1.13\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:8:\"Pathauto\";s:4:\"link\";s:39:\"https://www.drupal.org/project/pathauto\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:11:\"rabbit_hole\";a:14:{s:4:\"name\";s:11:\"rabbit_hole\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Rabbit Hole nodes\";s:7:\"version\";s:7:\"8.x-1.0\";s:7:\"project\";s:11:\"rabbit_hole\";s:9:\"datestamp\";i:1721413115;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1721413115;s:8:\"includes\";a:3:{s:7:\"rh_node\";s:17:\"Rabbit Hole nodes\";s:11:\"rh_taxonomy\";s:20:\"Rabbit Hole taxonomy\";s:11:\"rabbit_hole\";s:11:\"Rabbit Hole\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:7:\"8.x-1.0\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:11:\"Rabbit Hole\";s:4:\"link\";s:42:\"https://www.drupal.org/project/rabbit_hole\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:8:\"redirect\";a:14:{s:4:\"name\";s:8:\"redirect\";s:4:\"info\";a:6:{s:4:\"name\";s:8:\"Redirect\";s:7:\"version\";s:8:\"8.x-1.11\";s:7:\"project\";s:8:\"redirect\";s:9:\"datestamp\";i:1737382888;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1737382888;s:8:\"includes\";a:1:{s:8:\"redirect\";s:8:\"Redirect\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:8:\"8.x-1.11\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:8:\"Redirect\";s:4:\"link\";s:39:\"https://www.drupal.org/project/redirect\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:18:\"rest_absolute_urls\";a:14:{s:4:\"name\";s:18:\"rest_absolute_urls\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"REST Absolute URLs\";s:7:\"version\";s:5:\"2.0.0\";s:7:\"project\";s:18:\"rest_absolute_urls\";s:9:\"datestamp\";i:1725017289;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933859;}s:9:\"datestamp\";i:1725017289;s:8:\"includes\";a:1:{s:18:\"rest_absolute_urls\";s:18:\"REST Absolute URLs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"2.0.0\";s:14:\"existing_major\";s:1:\"2\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:18:\"REST Absolute URLs\";s:4:\"link\";s:49:\"https://www.drupal.org/project/rest_absolute_urls\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:6:\"restui\";a:14:{s:4:\"name\";s:6:\"restui\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"REST UI\";s:7:\"package\";s:12:\"Web services\";s:7:\"version\";s:8:\"8.x-1.22\";s:7:\"project\";s:6:\"restui\";s:9:\"datestamp\";i:1721134192;s:16:\"_info_file_ctime\";i:1743933840;}s:9:\"datestamp\";i:1721134192;s:8:\"includes\";a:1:{s:6:\"restui\";s:7:\"REST UI\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:8:\"8.x-1.22\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:7:\"REST UI\";s:4:\"link\";s:37:\"https://www.drupal.org/project/restui\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:14:\"simple_sitemap\";a:14:{s:4:\"name\";s:14:\"simple_sitemap\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"Simple XML Sitemap\";s:7:\"package\";s:3:\"SEO\";s:7:\"version\";s:5:\"4.2.2\";s:7:\"project\";s:14:\"simple_sitemap\";s:9:\"datestamp\";i:1732485887;s:16:\"_info_file_ctime\";i:1743933657;}s:9:\"datestamp\";i:1732485887;s:8:\"includes\";a:1:{s:14:\"simple_sitemap\";s:18:\"Simple XML Sitemap\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"4.2.2\";s:14:\"existing_major\";s:1:\"4\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:18:\"Simple XML sitemap\";s:4:\"link\";s:45:\"https://www.drupal.org/project/simple_sitemap\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:9:\"svg_image\";a:14:{s:4:\"name\";s:9:\"svg_image\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"SVG image\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"3.2.1\";s:7:\"project\";s:9:\"svg_image\";s:9:\"datestamp\";i:1736865069;s:16:\"_info_file_ctime\";i:1743933658;}s:9:\"datestamp\";i:1736865069;s:8:\"includes\";a:1:{s:9:\"svg_image\";s:9:\"SVG image\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"3.2.1\";s:14:\"existing_major\";s:1:\"3\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:9:\"Svg Image\";s:4:\"link\";s:40:\"https://www.drupal.org/project/svg_image\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:5:\"token\";a:14:{s:4:\"name\";s:5:\"token\";s:4:\"info\";a:6:{s:4:\"name\";s:5:\"Token\";s:7:\"version\";s:8:\"8.x-1.15\";s:7:\"project\";s:5:\"token\";s:9:\"datestamp\";i:1722206215;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933658;}s:9:\"datestamp\";i:1722206215;s:8:\"includes\";a:1:{s:5:\"token\";s:5:\"Token\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:8:\"8.x-1.15\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:5:\"Token\";s:4:\"link\";s:36:\"https://www.drupal.org/project/token\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:7:\"webform\";a:14:{s:4:\"name\";s:7:\"webform\";s:4:\"info\";a:6:{s:4:\"name\";s:14:\"Webform Access\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:11:\"6.3.0-beta2\";s:7:\"project\";s:7:\"webform\";s:9:\"datestamp\";i:1742581873;s:16:\"_info_file_ctime\";i:1743933787;}s:9:\"datestamp\";i:1742581873;s:8:\"includes\";a:8:{s:14:\"webform_access\";s:14:\"Webform Access\";s:18:\"webform_attachment\";s:18:\"Webform Attachment\";s:12:\"webform_node\";s:12:\"Webform Node\";s:21:\"webform_options_limit\";s:21:\"Webform Options Limit\";s:14:\"webform_schema\";s:14:\"Webform Schema\";s:32:\"webform_submission_export_import\";s:32:\"Webform Submission Export/Import\";s:10:\"webform_ui\";s:10:\"Webform UI\";s:7:\"webform\";s:7:\"Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:11:\"6.3.0-beta2\";s:14:\"existing_major\";s:1:\"6\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:7:\"Webform\";s:4:\"link\";s:38:\"https://www.drupal.org/project/webform\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:12:\"webform_rest\";a:14:{s:4:\"name\";s:12:\"webform_rest\";s:4:\"info\";a:6:{s:4:\"name\";s:12:\"Webform REST\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:5:\"4.2.0\";s:7:\"project\";s:12:\"webform_rest\";s:9:\"datestamp\";i:1736288233;s:16:\"_info_file_ctime\";i:1743933666;}s:9:\"datestamp\";i:1736288233;s:8:\"includes\";a:1:{s:12:\"webform_rest\";s:12:\"Webform REST\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"4.2.0\";s:14:\"existing_major\";s:1:\"4\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:12:\"Webform REST\";s:4:\"link\";s:43:\"https://www.drupal.org/project/webform_rest\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:17:\"fast_distribution\";a:14:{s:4:\"name\";s:17:\"fast_distribution\";s:4:\"info\";a:6:{s:4:\"name\";s:4:\"Fast\";s:7:\"version\";s:5:\"1.0.1\";s:7:\"project\";s:17:\"fast_distribution\";s:9:\"datestamp\";i:1729499894;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933884;}s:9:\"datestamp\";i:1729499894;s:8:\"includes\";a:1:{s:4:\"fast\";s:4:\"Fast\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"1.0.1\";s:14:\"existing_major\";s:1:\"1\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:17:\"Fast Distribution\";s:4:\"link\";s:48:\"https://www.drupal.org/project/fast_distribution\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}s:3:\"gin\";a:14:{s:4:\"name\";s:3:\"gin\";s:4:\"info\";a:5:{s:4:\"name\";s:3:\"Gin\";s:7:\"version\";s:5:\"4.0.6\";s:7:\"project\";s:3:\"gin\";s:9:\"datestamp\";i:1740738975;s:16:\"_info_file_ctime\";i:1743933667;}s:9:\"datestamp\";i:1740738975;s:8:\"includes\";a:1:{s:3:\"gin\";s:3:\"Gin\";}s:12:\"project_type\";s:5:\"theme\";s:14:\"project_status\";b:1;s:16:\"existing_version\";s:5:\"4.0.6\";s:14:\"existing_major\";s:1:\"4\";s:12:\"install_type\";s:8:\"official\";s:5:\"title\";s:15:\"Gin Admin Theme\";s:4:\"link\";s:34:\"https://www.drupal.org/project/gin\";s:6:\"status\";i:-4;s:6:\"reason\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"No available update data\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"fetch_status\";i:-4;}}',1743940379),('update','update_project_projects',_binary 'a:33:{s:6:\"drupal\";a:6:{s:4:\"name\";s:6:\"drupal\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Announcements\";s:7:\"version\";s:6:\"11.1.5\";s:7:\"package\";s:4:\"Core\";s:7:\"project\";s:6:\"drupal\";s:16:\"_info_file_ctime\";i:1743933783;s:9:\"datestamp\";i:0;}s:9:\"datestamp\";i:0;s:8:\"includes\";a:45:{s:18:\"announcements_feed\";s:13:\"Announcements\";s:14:\"automated_cron\";s:14:\"Automated Cron\";s:8:\"big_pipe\";s:7:\"BigPipe\";s:5:\"block\";s:5:\"Block\";s:13:\"block_content\";s:13:\"Block Content\";s:10:\"breakpoint\";s:10:\"Breakpoint\";s:9:\"ckeditor5\";s:10:\"CKEditor 5\";s:7:\"comment\";s:7:\"Comment\";s:6:\"config\";s:21:\"Configuration Manager\";s:18:\"config_translation\";s:25:\"Configuration Translation\";s:7:\"contact\";s:7:\"Contact\";s:10:\"contextual\";s:16:\"Contextual Links\";s:8:\"datetime\";s:8:\"Datetime\";s:5:\"dblog\";s:16:\"Database Logging\";s:18:\"dynamic_page_cache\";s:27:\"Internal Dynamic Page Cache\";s:6:\"editor\";s:11:\"Text Editor\";s:5:\"field\";s:5:\"Field\";s:8:\"field_ui\";s:8:\"Field UI\";s:4:\"file\";s:4:\"File\";s:6:\"filter\";s:6:\"Filter\";s:4:\"help\";s:4:\"Help\";s:7:\"history\";s:7:\"History\";s:5:\"image\";s:5:\"Image\";s:7:\"jsonapi\";s:8:\"JSON:API\";s:8:\"language\";s:8:\"Language\";s:4:\"link\";s:4:\"Link\";s:6:\"locale\";s:21:\"Interface Translation\";s:17:\"menu_link_content\";s:17:\"Custom Menu Links\";s:7:\"menu_ui\";s:7:\"Menu UI\";s:4:\"node\";s:4:\"Node\";s:7:\"options\";s:7:\"Options\";s:10:\"page_cache\";s:19:\"Internal Page Cache\";s:4:\"path\";s:4:\"Path\";s:10:\"path_alias\";s:10:\"Path alias\";s:4:\"rest\";s:20:\"RESTful Web Services\";s:13:\"serialization\";s:13:\"Serialization\";s:8:\"shortcut\";s:8:\"Shortcut\";s:6:\"system\";s:6:\"System\";s:8:\"taxonomy\";s:8:\"Taxonomy\";s:4:\"text\";s:4:\"Text\";s:7:\"toolbar\";s:7:\"Toolbar\";s:6:\"update\";s:14:\"Update Manager\";s:4:\"user\";s:4:\"User\";s:5:\"views\";s:5:\"Views\";s:8:\"views_ui\";s:8:\"Views UI\";}s:12:\"project_type\";s:4:\"core\";s:14:\"project_status\";b:1;}s:11:\"anchor_link\";a:6:{s:4:\"name\";s:11:\"anchor_link\";s:4:\"info\";a:6:{s:4:\"name\";s:20:\"CKEditor Anchor Link\";s:7:\"package\";s:8:\"CKEditor\";s:7:\"version\";s:11:\"3.0.0-beta1\";s:7:\"project\";s:11:\"anchor_link\";s:9:\"datestamp\";i:1718825064;s:16:\"_info_file_ctime\";i:1743933648;}s:9:\"datestamp\";i:1718825064;s:8:\"includes\";a:1:{s:11:\"anchor_link\";s:20:\"CKEditor Anchor Link\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:21:\"ckeditor5_plugin_pack\";a:6:{s:4:\"name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.3.1\";s:7:\"project\";s:21:\"ckeditor5_plugin_pack\";s:9:\"datestamp\";i:1742472945;s:16:\"_info_file_ctime\";i:1743933784;}s:9:\"datestamp\";i:1742472945;s:8:\"includes\";a:11:{s:21:\"ckeditor5_plugin_pack\";s:22:\"CKEditor 5 Plugin Pack\";s:32:\"ckeditor5_plugin_pack_auto_image\";s:21:\"CKEditor 5 Auto Image\";s:30:\"ckeditor5_plugin_pack_bookmark\";s:20:\"CKEditor 5 Bookmarks\";s:38:\"ckeditor5_plugin_pack_find_and_replace\";s:27:\"CKEditor 5 Find And Replace\";s:26:\"ckeditor5_plugin_pack_font\";s:23:\"CKEditor 5 Font Plugins\";s:31:\"ckeditor5_plugin_pack_highlight\";s:20:\"CKEditor 5 Highlight\";s:34:\"ckeditor5_plugin_pack_indent_block\";s:28:\"CKEditor 5 Block Indentation\";s:32:\"ckeditor5_plugin_pack_page_break\";s:21:\"CKEditor 5 Page Break\";s:32:\"ckeditor5_plugin_pack_select_all\";s:21:\"CKEditor 5 Select All\";s:31:\"ckeditor5_plugin_pack_templates\";s:20:\"CKEditor 5 Templates\";s:41:\"ckeditor5_plugin_pack_text_transformation\";s:30:\"CKEditor 5 Text Transformation\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:26:\"ckeditor5_premium_features\";a:6:{s:4:\"name\";s:26:\"ckeditor5_premium_features\";s:4:\"info\";a:6:{s:4:\"name\";s:27:\"CKEditor 5 Full-screen Mode\";s:7:\"package\";s:22:\"CKEditor 5 Plugin Pack\";s:7:\"version\";s:5:\"1.4.1\";s:7:\"project\";s:26:\"ckeditor5_premium_features\";s:9:\"datestamp\";i:1742472692;s:16:\"_info_file_ctime\";i:1743933784;}s:9:\"datestamp\";i:1742472692;s:8:\"includes\";a:1:{s:37:\"ckeditor5_premium_features_fullscreen\";s:27:\"CKEditor 5 Full-screen Mode\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:13:\"config_ignore\";a:6:{s:4:\"name\";s:13:\"config_ignore\";s:4:\"info\";a:6:{s:4:\"name\";s:13:\"Config Ignore\";s:7:\"package\";s:6:\"Config\";s:7:\"version\";s:7:\"8.x-3.3\";s:7:\"project\";s:13:\"config_ignore\";s:9:\"datestamp\";i:1713299497;s:16:\"_info_file_ctime\";i:1743933651;}s:9:\"datestamp\";i:1713299497;s:8:\"includes\";a:1:{s:13:\"config_ignore\";s:13:\"Config Ignore\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:12:\"config_split\";a:6:{s:4:\"name\";s:12:\"config_split\";s:4:\"info\";a:6:{s:4:\"name\";s:12:\"Config Split\";s:7:\"package\";s:6:\"Config\";s:7:\"version\";s:5:\"2.0.2\";s:7:\"project\";s:12:\"config_split\";s:9:\"datestamp\";i:1739356082;s:16:\"_info_file_ctime\";i:1743933651;}s:9:\"datestamp\";i:1739356082;s:8:\"includes\";a:1:{s:12:\"config_split\";s:12:\"Config Split\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:4:\"diff\";a:6:{s:4:\"name\";s:4:\"diff\";s:4:\"info\";a:6:{s:4:\"name\";s:4:\"Diff\";s:7:\"version\";s:7:\"8.x-1.8\";s:7:\"project\";s:4:\"diff\";s:9:\"datestamp\";i:1727849726;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1727849726;s:8:\"includes\";a:1:{s:4:\"diff\";s:4:\"Diff\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"field_group\";a:6:{s:4:\"name\";s:11:\"field_group\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Field Group\";s:7:\"package\";s:6:\"Fields\";s:7:\"version\";s:7:\"8.x-3.6\";s:7:\"project\";s:11:\"field_group\";s:9:\"datestamp\";i:1722672513;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1722672513;s:8:\"includes\";a:1:{s:11:\"field_group\";s:11:\"Field Group\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"gin_toolbar\";a:6:{s:4:\"name\";s:11:\"gin_toolbar\";s:4:\"info\";a:6:{s:4:\"name\";s:11:\"Gin Toolbar\";s:7:\"version\";s:5:\"2.0.0\";s:7:\"project\";s:11:\"gin_toolbar\";s:9:\"datestamp\";i:1734698923;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1734698923;s:8:\"includes\";a:1:{s:11:\"gin_toolbar\";s:11:\"Gin Toolbar\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"glightbox\";a:6:{s:4:\"name\";s:9:\"glightbox\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"GLightbox\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:6:\"1.0.14\";s:7:\"project\";s:9:\"glightbox\";s:9:\"datestamp\";i:1741428235;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1741428235;s:8:\"includes\";a:2:{s:9:\"glightbox\";s:9:\"GLightbox\";s:16:\"glightbox_inline\";s:16:\"GLightbox Inline\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:16:\"hotkeys_for_save\";a:6:{s:4:\"name\";s:16:\"hotkeys_for_save\";s:4:\"info\";a:6:{s:4:\"name\";s:16:\"Hotkeys for Save\";s:7:\"package\";s:16:\"Hotkeys for Save\";s:7:\"version\";s:5:\"2.0.1\";s:7:\"project\";s:16:\"hotkeys_for_save\";s:9:\"datestamp\";i:1699460197;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1699460197;s:8:\"includes\";a:1:{s:16:\"hotkeys_for_save\";s:16:\"Hotkeys for Save\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:14:\"jsonapi_extras\";a:6:{s:4:\"name\";s:14:\"jsonapi_extras\";s:4:\"info\";a:6:{s:4:\"name\";s:15:\"JSON:API Extras\";s:7:\"package\";s:12:\"Web services\";s:7:\"version\";s:8:\"8.x-3.26\";s:7:\"project\";s:14:\"jsonapi_extras\";s:9:\"datestamp\";i:1727787966;s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1727787966;s:8:\"includes\";a:2:{s:14:\"jsonapi_extras\";s:15:\"JSON:API Extras\";s:16:\"jsonapi_defaults\";s:17:\"JSON:API Defaults\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:18:\"jsonapi_menu_items\";a:6:{s:4:\"name\";s:18:\"jsonapi_menu_items\";s:4:\"info\";a:6:{s:4:\"name\";s:19:\"JSON:API Menu items\";s:7:\"version\";s:5:\"1.2.6\";s:7:\"project\";s:18:\"jsonapi_menu_items\";s:9:\"datestamp\";i:1722543503;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1722543503;s:8:\"includes\";a:1:{s:18:\"jsonapi_menu_items\";s:19:\"JSON:API Menu items\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:17:\"jsonapi_resources\";a:6:{s:4:\"name\";s:17:\"jsonapi_resources\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"JSON:API Resources\";s:7:\"version\";s:7:\"8.x-1.2\";s:7:\"project\";s:17:\"jsonapi_resources\";s:9:\"datestamp\";i:1719872298;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933652;}s:9:\"datestamp\";i:1719872298;s:8:\"includes\";a:1:{s:17:\"jsonapi_resources\";s:18:\"JSON:API Resources\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:22:\"jsonapi_response_alter\";a:6:{s:4:\"name\";s:22:\"jsonapi_response_alter\";s:4:\"info\";a:6:{s:4:\"name\";s:23:\"JSON:API Response Alter\";s:7:\"package\";s:6:\"Custom\";s:7:\"version\";s:5:\"2.0.1\";s:7:\"project\";s:22:\"jsonapi_response_alter\";s:9:\"datestamp\";i:1718696572;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1718696572;s:8:\"includes\";a:1:{s:22:\"jsonapi_response_alter\";s:23:\"JSON:API Response Alter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:13:\"jsonapi_views\";a:6:{s:4:\"name\";s:13:\"jsonapi_views\";s:4:\"info\";a:6:{s:4:\"name\";s:14:\"JSON:API Views\";s:7:\"version\";s:7:\"8.x-1.1\";s:7:\"project\";s:13:\"jsonapi_views\";s:9:\"datestamp\";i:1675998789;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1675998789;s:8:\"includes\";a:1:{s:13:\"jsonapi_views\";s:14:\"JSON:API Views\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:15:\"link_attributes\";a:6:{s:4:\"name\";s:15:\"link_attributes\";s:4:\"info\";a:6:{s:4:\"name\";s:15:\"Link attributes\";s:7:\"version\";s:5:\"2.1.1\";s:7:\"project\";s:15:\"link_attributes\";s:9:\"datestamp\";i:1721366574;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1721366574;s:8:\"includes\";a:3:{s:15:\"link_attributes\";s:15:\"Link attributes\";s:33:\"link_attributes_menu_link_content\";s:46:\"Link attributes: Menu Link Content integration\";s:17:\"linkit_attributes\";s:17:\"Linkit attributes\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:6:\"linkit\";a:6:{s:4:\"name\";s:6:\"linkit\";s:4:\"info\";a:6:{s:4:\"name\";s:6:\"Linkit\";s:7:\"package\";s:14:\"User interface\";s:7:\"version\";s:5:\"7.0.3\";s:7:\"project\";s:6:\"linkit\";s:9:\"datestamp\";i:1738264706;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1738264706;s:8:\"includes\";a:1:{s:6:\"linkit\";s:6:\"Linkit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:18:\"media_library_edit\";a:6:{s:4:\"name\";s:18:\"media_library_edit\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"Media Library Edit\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"3.0.4\";s:7:\"project\";s:18:\"media_library_edit\";s:9:\"datestamp\";i:1724357847;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1724357847;s:8:\"includes\";a:1:{s:18:\"media_library_edit\";s:18:\"Media Library Edit\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:16:\"menu_item_extras\";a:6:{s:4:\"name\";s:16:\"menu_item_extras\";s:4:\"info\";a:6:{s:4:\"name\";s:16:\"Menu Item Extras\";s:7:\"package\";s:4:\"Menu\";s:7:\"version\";s:5:\"3.1.0\";s:7:\"project\";s:16:\"menu_item_extras\";s:9:\"datestamp\";i:1725022063;s:16:\"_info_file_ctime\";i:1743933653;}s:9:\"datestamp\";i:1725022063;s:8:\"includes\";a:1:{s:16:\"menu_item_extras\";s:16:\"Menu Item Extras\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:7:\"metatag\";a:6:{s:4:\"name\";s:7:\"metatag\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"Metatag\";s:7:\"package\";s:3:\"SEO\";s:7:\"version\";s:5:\"2.1.0\";s:7:\"project\";s:7:\"metatag\";s:9:\"datestamp\";i:1731004045;s:16:\"_info_file_ctime\";i:1743933654;}s:9:\"datestamp\";i:1731004045;s:8:\"includes\";a:1:{s:7:\"metatag\";s:7:\"Metatag\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:8:\"pathauto\";a:6:{s:4:\"name\";s:8:\"pathauto\";s:4:\"info\";a:6:{s:4:\"name\";s:8:\"Pathauto\";s:7:\"version\";s:8:\"8.x-1.13\";s:7:\"project\";s:8:\"pathauto\";s:9:\"datestamp\";i:1722507674;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1722507674;s:8:\"includes\";a:1:{s:8:\"pathauto\";s:8:\"Pathauto\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:11:\"rabbit_hole\";a:6:{s:4:\"name\";s:11:\"rabbit_hole\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Rabbit Hole nodes\";s:7:\"version\";s:7:\"8.x-1.0\";s:7:\"project\";s:11:\"rabbit_hole\";s:9:\"datestamp\";i:1721413115;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1721413115;s:8:\"includes\";a:3:{s:7:\"rh_node\";s:17:\"Rabbit Hole nodes\";s:11:\"rh_taxonomy\";s:20:\"Rabbit Hole taxonomy\";s:11:\"rabbit_hole\";s:11:\"Rabbit Hole\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:8:\"redirect\";a:6:{s:4:\"name\";s:8:\"redirect\";s:4:\"info\";a:6:{s:4:\"name\";s:8:\"Redirect\";s:7:\"version\";s:8:\"8.x-1.11\";s:7:\"project\";s:8:\"redirect\";s:9:\"datestamp\";i:1737382888;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933656;}s:9:\"datestamp\";i:1737382888;s:8:\"includes\";a:1:{s:8:\"redirect\";s:8:\"Redirect\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:18:\"rest_absolute_urls\";a:6:{s:4:\"name\";s:18:\"rest_absolute_urls\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"REST Absolute URLs\";s:7:\"version\";s:5:\"2.0.0\";s:7:\"project\";s:18:\"rest_absolute_urls\";s:9:\"datestamp\";i:1725017289;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933859;}s:9:\"datestamp\";i:1725017289;s:8:\"includes\";a:1:{s:18:\"rest_absolute_urls\";s:18:\"REST Absolute URLs\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:6:\"restui\";a:6:{s:4:\"name\";s:6:\"restui\";s:4:\"info\";a:6:{s:4:\"name\";s:7:\"REST UI\";s:7:\"package\";s:12:\"Web services\";s:7:\"version\";s:8:\"8.x-1.22\";s:7:\"project\";s:6:\"restui\";s:9:\"datestamp\";i:1721134192;s:16:\"_info_file_ctime\";i:1743933840;}s:9:\"datestamp\";i:1721134192;s:8:\"includes\";a:1:{s:6:\"restui\";s:7:\"REST UI\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:14:\"simple_sitemap\";a:6:{s:4:\"name\";s:14:\"simple_sitemap\";s:4:\"info\";a:6:{s:4:\"name\";s:18:\"Simple XML Sitemap\";s:7:\"package\";s:3:\"SEO\";s:7:\"version\";s:5:\"4.2.2\";s:7:\"project\";s:14:\"simple_sitemap\";s:9:\"datestamp\";i:1732485887;s:16:\"_info_file_ctime\";i:1743933657;}s:9:\"datestamp\";i:1732485887;s:8:\"includes\";a:1:{s:14:\"simple_sitemap\";s:18:\"Simple XML Sitemap\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:9:\"svg_image\";a:6:{s:4:\"name\";s:9:\"svg_image\";s:4:\"info\";a:6:{s:4:\"name\";s:9:\"SVG image\";s:7:\"package\";s:5:\"Media\";s:7:\"version\";s:5:\"3.2.1\";s:7:\"project\";s:9:\"svg_image\";s:9:\"datestamp\";i:1736865069;s:16:\"_info_file_ctime\";i:1743933658;}s:9:\"datestamp\";i:1736865069;s:8:\"includes\";a:1:{s:9:\"svg_image\";s:9:\"SVG image\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:5:\"token\";a:6:{s:4:\"name\";s:5:\"token\";s:4:\"info\";a:6:{s:4:\"name\";s:5:\"Token\";s:7:\"version\";s:8:\"8.x-1.15\";s:7:\"project\";s:5:\"token\";s:9:\"datestamp\";i:1722206215;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933658;}s:9:\"datestamp\";i:1722206215;s:8:\"includes\";a:1:{s:5:\"token\";s:5:\"Token\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:7:\"webform\";a:6:{s:4:\"name\";s:7:\"webform\";s:4:\"info\";a:6:{s:4:\"name\";s:14:\"Webform Access\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:11:\"6.3.0-beta2\";s:7:\"project\";s:7:\"webform\";s:9:\"datestamp\";i:1742581873;s:16:\"_info_file_ctime\";i:1743933787;}s:9:\"datestamp\";i:1742581873;s:8:\"includes\";a:8:{s:14:\"webform_access\";s:14:\"Webform Access\";s:18:\"webform_attachment\";s:18:\"Webform Attachment\";s:12:\"webform_node\";s:12:\"Webform Node\";s:21:\"webform_options_limit\";s:21:\"Webform Options Limit\";s:14:\"webform_schema\";s:14:\"Webform Schema\";s:32:\"webform_submission_export_import\";s:32:\"Webform Submission Export/Import\";s:10:\"webform_ui\";s:10:\"Webform UI\";s:7:\"webform\";s:7:\"Webform\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:12:\"webform_rest\";a:6:{s:4:\"name\";s:12:\"webform_rest\";s:4:\"info\";a:6:{s:4:\"name\";s:12:\"Webform REST\";s:7:\"package\";s:7:\"Webform\";s:7:\"version\";s:5:\"4.2.0\";s:7:\"project\";s:12:\"webform_rest\";s:9:\"datestamp\";i:1736288233;s:16:\"_info_file_ctime\";i:1743933666;}s:9:\"datestamp\";i:1736288233;s:8:\"includes\";a:1:{s:12:\"webform_rest\";s:12:\"Webform REST\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:17:\"fast_distribution\";a:6:{s:4:\"name\";s:17:\"fast_distribution\";s:4:\"info\";a:6:{s:4:\"name\";s:4:\"Fast\";s:7:\"version\";s:5:\"1.0.1\";s:7:\"project\";s:17:\"fast_distribution\";s:9:\"datestamp\";i:1729499894;s:7:\"package\";s:5:\"Other\";s:16:\"_info_file_ctime\";i:1743933884;}s:9:\"datestamp\";i:1729499894;s:8:\"includes\";a:1:{s:4:\"fast\";s:4:\"Fast\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}s:3:\"gin\";a:6:{s:4:\"name\";s:3:\"gin\";s:4:\"info\";a:5:{s:4:\"name\";s:3:\"Gin\";s:7:\"version\";s:5:\"4.0.6\";s:7:\"project\";s:3:\"gin\";s:9:\"datestamp\";i:1740738975;s:16:\"_info_file_ctime\";i:1743933667;}s:9:\"datestamp\";i:1740738975;s:8:\"includes\";a:1:{s:3:\"gin\";s:3:\"Gin\";}s:12:\"project_type\";s:5:\"theme\";s:14:\"project_status\";b:1;}}',1743940379),('update_available_releases','anchor_link',_binary 'a:10:{s:5:\"title\";s:20:\"CKEditor Anchor Link\";s:10:\"short_name\";s:11:\"anchor_link\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:18:\"3.0.,8.x-1.,8.x-2.\";s:18:\"composer_namespace\";s:18:\"drupal/anchor_link\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/anchor_link\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:28:{s:11:\"3.0.0-beta1\";a:11:{s:4:\"name\";s:23:\"anchor_link 3.0.0-beta1\";s:7:\"version\";s:11:\"3.0.0-beta1\";s:3:\"tag\";s:11:\"3.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/anchor_link/releases/3.0.0-beta1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/anchor_link-3.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1718825062\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:12:\"3.0.0-alpha2\";a:11:{s:4:\"name\";s:24:\"anchor_link 3.0.0-alpha2\";s:7:\"version\";s:12:\"3.0.0-alpha2\";s:3:\"tag\";s:12:\"3.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/anchor_link/releases/3.0.0-alpha2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/anchor_link-3.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1706674658\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:12:\"3.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"anchor_link 3.0.0-alpha1\";s:7:\"version\";s:12:\"3.0.0-alpha1\";s:3:\"tag\";s:12:\"3.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/anchor_link/releases/3.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/anchor_link-3.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1701378503\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:7:\"8.x-2.7\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-2.7\";s:7:\"version\";s:7:\"8.x-2.7\";s:3:\"tag\";s:7:\"8.x-2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.7\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.7.tar.gz\";s:4:\"date\";s:10:\"1718824697\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.6\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-2.6\";s:7:\"version\";s:7:\"8.x-2.6\";s:3:\"tag\";s:7:\"8.x-2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.6.tar.gz\";s:4:\"date\";s:10:\"1674766001\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1612887560\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1582628297\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1582550636\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1582204151\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1582022429\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1581868147\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-2.0-alpha2\";a:11:{s:4:\"name\";s:26:\"anchor_link 8.x-2.0-alpha2\";s:7:\"version\";s:14:\"8.x-2.0-alpha2\";s:3:\"tag\";s:14:\"8.x-2.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1530956624\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha1\";a:11:{s:4:\"name\";s:26:\"anchor_link 8.x-2.0-alpha1\";s:7:\"version\";s:14:\"8.x-2.0-alpha1\";s:3:\"tag\";s:14:\"8.x-2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1523112784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:20:\"anchor_link 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.11\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1718824822\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:20:\"anchor_link 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.10\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1673536301\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.9\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1643826959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.8\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1643805382\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.7\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1581868106\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1509961084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1497280742\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1496054883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1480862283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1476280139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"anchor_link 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1475773439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:26:\"anchor_link 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1468336389\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"3.0.x-dev\";a:11:{s:4:\"name\";s:21:\"anchor_link 3.0.x-dev\";s:7:\"version\";s:9:\"3.0.x-dev\";s:3:\"tag\";s:5:\"3.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/anchor_link/releases/3.0.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/anchor_link-3.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1718824087\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:23:\"anchor_link 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/anchor_link/releases/8.x-2.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1718824320\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"anchor_link 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/anchor_link/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/anchor_link-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1718824221\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','ckeditor5_plugin_pack',_binary 'a:10:{s:5:\"title\";s:22:\"CKEditor 5 Plugin Pack\";s:10:\"short_name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.3.\";s:18:\"composer_namespace\";s:28:\"drupal/ckeditor5_plugin_pack\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:52:\"https://www.drupal.org/project/ckeditor5_plugin_pack\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:10:{s:5:\"1.3.1\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.3.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1742472943\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.3.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1738746736\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.4\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.4\";s:7:\"version\";s:5:\"1.2.4\";s:3:\"tag\";s:5:\"1.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.4\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.4.tar.gz\";s:4:\"date\";s:10:\"1734514948\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.3\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1731594715\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1727947517\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1723548212\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1722415813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.1.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1718271916\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.0.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1714466054\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.0.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1713945391\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','ckeditor5_premium_features',_binary 'a:10:{s:5:\"title\";s:27:\"CKEditor 5 Premium Features\";s:10:\"short_name\";s:26:\"ckeditor5_premium_features\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"1.3.,1.4.\";s:18:\"composer_namespace\";s:33:\"drupal/ckeditor5_premium_features\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/ckeditor5_premium_features\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:26:{s:5:\"1.4.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.4.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1742472690\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.0 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.4.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1738759217\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.0 || ^11\";}s:5:\"1.3.5\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.5\";s:7:\"version\";s:5:\"1.3.5\";s:3:\"tag\";s:5:\"1.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.5.tar.gz\";s:4:\"date\";s:10:\"1734513727\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.4\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.4\";s:7:\"version\";s:5:\"1.3.4\";s:3:\"tag\";s:5:\"1.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.4.tar.gz\";s:4:\"date\";s:10:\"1733150653\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.3\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.3\";s:7:\"version\";s:5:\"1.3.3\";s:3:\"tag\";s:5:\"1.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.3.tar.gz\";s:4:\"date\";s:10:\"1731586774\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.2\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.2\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1727958023\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1723546977\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1722416832\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.9\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.9\";s:7:\"version\";s:5:\"1.2.9\";s:3:\"tag\";s:5:\"1.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.9\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.9.tar.gz\";s:4:\"date\";s:10:\"1718272066\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.8\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.8\";s:7:\"version\";s:5:\"1.2.8\";s:3:\"tag\";s:5:\"1.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.8\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.8.tar.gz\";s:4:\"date\";s:10:\"1713960338\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.7\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.7\";s:7:\"version\";s:5:\"1.2.7\";s:3:\"tag\";s:5:\"1.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.7\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.7.tar.gz\";s:4:\"date\";s:10:\"1713946256\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}s:5:\"1.2.6\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.6\";s:7:\"version\";s:5:\"1.2.6\";s:3:\"tag\";s:5:\"1.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.6\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.6.tar.gz\";s:4:\"date\";s:10:\"1709550478\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.5\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.5\";s:7:\"version\";s:5:\"1.2.5\";s:3:\"tag\";s:5:\"1.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.5.tar.gz\";s:4:\"date\";s:10:\"1706087373\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.4\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.4\";s:7:\"version\";s:5:\"1.2.4\";s:3:\"tag\";s:5:\"1.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.4.tar.gz\";s:4:\"date\";s:10:\"1702994815\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1699963145\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.2\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1693384282\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1688647071\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1687776512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.1.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.1.1\";s:7:\"version\";s:5:\"1.1.1\";s:3:\"tag\";s:5:\"1.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.1.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.1.1.tar.gz\";s:4:\"date\";s:10:\"1684309128\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.1.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1683814836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1681894913\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1677662363\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:9:\"1.0.0-rc2\";a:11:{s:4:\"name\";s:36:\"ckeditor5_premium_features 1.0.0-rc2\";s:7:\"version\";s:9:\"1.0.0-rc2\";s:3:\"tag\";s:9:\"1.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-rc2\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1671113465\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:9:\"1.0.0-rc1\";a:11:{s:4:\"name\";s:36:\"ckeditor5_premium_features 1.0.0-rc1\";s:7:\"version\";s:9:\"1.0.0-rc1\";s:3:\"tag\";s:9:\"1.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-rc1\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1667227760\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"1.0.0-beta2\";a:11:{s:4:\"name\";s:38:\"ckeditor5_premium_features 1.0.0-beta2\";s:7:\"version\";s:11:\"1.0.0-beta2\";s:3:\"tag\";s:11:\"1.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-beta2\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1663854316\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:38:\"ckeditor5_premium_features 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-beta1\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663684376\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','config_ignore',_binary 'a:10:{s:5:\"title\";s:13:\"Config Ignore\";s:10:\"short_name\";s:13:\"config_ignore\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-3.\";s:18:\"composer_namespace\";s:20:\"drupal/config_ignore\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/config_ignore\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:25:{s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1713299496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:24:\"^8.8 || ^9 || ^10 || ^11\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1705226226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1699302168\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1698624094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1697716408\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:13:\"8.x-3.0-beta2\";a:11:{s:4:\"name\";s:27:\"config_ignore 8.x-3.0-beta2\";s:7:\"version\";s:13:\"8.x-3.0-beta2\";s:3:\"tag\";s:13:\"8.x-3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.0-beta2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1676045569\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:27:\"config_ignore 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1627977337\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1676045435\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1608306489\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-2.3-rc1\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-2.3-rc1\";s:7:\"version\";s:11:\"8.x-2.3-rc1\";s:3:\"tag\";s:11:\"8.x-2.3-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.3-rc1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.3-rc1.tar.gz\";s:4:\"date\";s:10:\"1607033836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1576528386\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1507706044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1494323585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc2\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-2.0-rc2\";s:7:\"version\";s:11:\"8.x-2.0-rc2\";s:3:\"tag\";s:11:\"8.x-2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.0-rc2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1493231943\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1490346183\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1487336284\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1485770283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1485251884\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1484669883\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1481797383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1480522084\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1480363684\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713937215\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:24:\"^8.8 || ^9 || ^10 || ^11\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1662296469\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1493230443\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','config_split',_binary 'a:10:{s:5:\"title\";s:19:\"Configuration Split\";s:10:\"short_name\";s:12:\"config_split\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"2.0.,8.x-1.\";s:18:\"composer_namespace\";s:19:\"drupal/config_split\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:43:\"https://www.drupal.org/project/config_split\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:37:{s:5:\"2.0.2\";a:11:{s:4:\"name\";s:18:\"config_split 2.0.2\";s:7:\"version\";s:5:\"2.0.2\";s:3:\"tag\";s:5:\"2.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/config_split/releases/2.0.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/config_split-2.0.2.tar.gz\";s:4:\"date\";s:10:\"1739356079\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:24:\"^8.8 || ^9 || ^10 || ^11\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:18:\"config_split 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/config_split/releases/2.0.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/config_split-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1711022056\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:24:\"^8.8 || ^9 || ^10 || ^11\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:18:\"config_split 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/config_split/releases/2.0.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/config_split-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1699259254\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:9:\"2.0.0-rc5\";a:11:{s:4:\"name\";s:22:\"config_split 2.0.0-rc5\";s:7:\"version\";s:9:\"2.0.0-rc5\";s:3:\"tag\";s:9:\"2.0.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/config_split/releases/2.0.0-rc5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1698624439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:9:\"2.0.0-rc4\";a:11:{s:4:\"name\";s:22:\"config_split 2.0.0-rc4\";s:7:\"version\";s:9:\"2.0.0-rc4\";s:3:\"tag\";s:9:\"2.0.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/config_split/releases/2.0.0-rc4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1662235380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:9:\"2.0.0-rc3\";a:11:{s:4:\"name\";s:22:\"config_split 2.0.0-rc3\";s:7:\"version\";s:9:\"2.0.0-rc3\";s:3:\"tag\";s:9:\"2.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/config_split/releases/2.0.0-rc3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1656976745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:9:\"2.0.0-rc2\";a:11:{s:4:\"name\";s:22:\"config_split 2.0.0-rc2\";s:7:\"version\";s:9:\"2.0.0-rc2\";s:3:\"tag\";s:9:\"2.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/config_split/releases/2.0.0-rc2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1656976495\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:9:\"2.0.0-rc1\";a:11:{s:4:\"name\";s:22:\"config_split 2.0.0-rc1\";s:7:\"version\";s:9:\"2.0.0-rc1\";s:3:\"tag\";s:9:\"2.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/config_split/releases/2.0.0-rc1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1650976427\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"2.0.0-beta5\";a:11:{s:4:\"name\";s:24:\"config_split 2.0.0-beta5\";s:7:\"version\";s:11:\"2.0.0-beta5\";s:3:\"tag\";s:11:\"2.0.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/2.0.0-beta5\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1637101204\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"2.0.0-beta4\";a:11:{s:4:\"name\";s:24:\"config_split 2.0.0-beta4\";s:7:\"version\";s:11:\"2.0.0-beta4\";s:3:\"tag\";s:11:\"2.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/2.0.0-beta4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1631393371\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"2.0.0-beta3\";a:11:{s:4:\"name\";s:24:\"config_split 2.0.0-beta3\";s:7:\"version\";s:11:\"2.0.0-beta3\";s:3:\"tag\";s:11:\"2.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/2.0.0-beta3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1631372296\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"2.0.0-beta2\";a:11:{s:4:\"name\";s:24:\"config_split 2.0.0-beta2\";s:7:\"version\";s:11:\"2.0.0-beta2\";s:3:\"tag\";s:11:\"2.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/2.0.0-beta2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1605524409\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"2.0.0-beta1\";a:11:{s:4:\"name\";s:24:\"config_split 2.0.0-beta1\";s:7:\"version\";s:11:\"2.0.0-beta1\";s:3:\"tag\";s:11:\"2.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/2.0.0-beta1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-2.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1604945670\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:21:\"config_split 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_split/releases/8.x-1.10\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1739356047\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.9\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1656976376\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.8\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1649337368\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1603782947\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"8.x-1.7-rc1\";a:11:{s:4:\"name\";s:24:\"config_split 8.x-1.7-rc1\";s:7:\"version\";s:11:\"8.x-1.7-rc1\";s:3:\"tag\";s:11:\"8.x-1.7-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/8.x-1.7-rc1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.7-rc1.tar.gz\";s:4:\"date\";s:10:\"1603782443\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1600935570\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1599549544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"8.x-1.5-rc4\";a:11:{s:4:\"name\";s:24:\"config_split 8.x-1.5-rc4\";s:7:\"version\";s:11:\"8.x-1.5-rc4\";s:3:\"tag\";s:11:\"8.x-1.5-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/8.x-1.5-rc4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.5-rc4.tar.gz\";s:4:\"date\";s:10:\"1598364582\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"8.x-1.5-rc3\";a:11:{s:4:\"name\";s:24:\"config_split 8.x-1.5-rc3\";s:7:\"version\";s:11:\"8.x-1.5-rc3\";s:3:\"tag\";s:11:\"8.x-1.5-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/8.x-1.5-rc3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.5-rc3.tar.gz\";s:4:\"date\";s:10:\"1591798688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.5-rc2\";a:11:{s:4:\"name\";s:24:\"config_split 8.x-1.5-rc2\";s:7:\"version\";s:11:\"8.x-1.5-rc2\";s:3:\"tag\";s:11:\"8.x-1.5-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/8.x-1.5-rc2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.5-rc2.tar.gz\";s:4:\"date\";s:10:\"1591625860\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.5-rc1\";a:11:{s:4:\"name\";s:24:\"config_split 8.x-1.5-rc1\";s:7:\"version\";s:11:\"8.x-1.5-rc1\";s:3:\"tag\";s:11:\"8.x-1.5-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/8.x-1.5-rc1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.5-rc1.tar.gz\";s:4:\"date\";s:10:\"1588277563\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1537971780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1511810585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1506875344\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1503561844\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:20:\"config_split 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/config_split/releases/8.x-1.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1503305044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta6\";a:11:{s:4:\"name\";s:26:\"config_split 8.x-1.0-beta6\";s:7:\"version\";s:13:\"8.x-1.0-beta6\";s:3:\"tag\";s:13:\"8.x-1.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/config_split/releases/8.x-1.0-beta6\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1496912342\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:26:\"config_split 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/config_split/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1494175684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:26:\"config_split 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/config_split/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1489417685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:26:\"config_split 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/config_split/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1489063982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:26:\"config_split 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/config_split/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1486720683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:26:\"config_split 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/config_split/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1480263780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:22:\"config_split 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/config_split/releases/2.0.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/config_split-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1739355889\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:24:\"^8.8 || ^9 || ^10 || ^11\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:24:\"config_split 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/config_split/releases/8.x-1.x-dev\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/config_split-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1739355956\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','diff',_binary 'a:10:{s:5:\"title\";s:4:\"Diff\";s:10:\"short_name\";s:4:\"diff\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"2.0.,8.x-1.\";s:18:\"composer_namespace\";s:11:\"drupal/diff\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:35:\"https://www.drupal.org/project/diff\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:23:{s:11:\"2.0.0-beta3\";a:11:{s:4:\"name\";s:16:\"diff 2.0.0-beta3\";s:7:\"version\";s:11:\"2.0.0-beta3\";s:3:\"tag\";s:11:\"2.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/diff/releases/2.0.0-beta3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/diff-2.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1727849859\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";}s:11:\"2.0.0-beta2\";a:11:{s:4:\"name\";s:16:\"diff 2.0.0-beta2\";s:7:\"version\";s:11:\"2.0.0-beta2\";s:3:\"tag\";s:11:\"2.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/diff/releases/2.0.0-beta2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/diff-2.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1720739026\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";}s:11:\"2.0.0-beta1\";a:11:{s:4:\"name\";s:16:\"diff 2.0.0-beta1\";s:7:\"version\";s:11:\"2.0.0-beta1\";s:3:\"tag\";s:11:\"2.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/diff/releases/2.0.0-beta1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/diff-2.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1719185162\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1727849719\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1718073570\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1718073506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1718059992\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1717130431\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1712883857\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1712878881\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1665437355\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:12:\"diff 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/8.x-1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1578322688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:16:\"diff 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/diff/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1530178424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:16:\"diff 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/diff/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1484566683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:18:\"diff 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/diff/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1476455639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:18:\"diff 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/diff/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1474122839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:19:\"diff 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/diff/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1473849898\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:19:\"diff 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/diff/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1471295939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:19:\"diff 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/diff/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1468625339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:19:\"diff 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/diff/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1457387742\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:19:\"diff 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/diff/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/diff-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1457387742\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:12:\"diff 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/diff/releases/2.x-dev\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/diff-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735764959\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:16:\"diff 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/diff/releases/8.x-1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/diff-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1736720228\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','drupal',_binary 'a:10:{s:5:\"title\";s:11:\"Drupal core\";s:10:\"short_name\";s:6:\"drupal\";s:4:\"type\";s:12:\"project_core\";s:18:\"supported_branches\";s:29:\"10.3.,10.4.,10.5.,11.0.,11.1.\";s:18:\"composer_namespace\";s:11:\"drupal/core\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:37:\"https://www.drupal.org/project/drupal\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:459:{s:6:\"11.1.6\";a:10:{s:4:\"name\";s:13:\"drupal 11.1.6\";s:7:\"version\";s:6:\"11.1.6\";s:3:\"tag\";s:6:\"11.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.1.6.tar.gz\";s:4:\"date\";s:10:\"1743628262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.1.5\";a:10:{s:4:\"name\";s:13:\"drupal 11.1.5\";s:7:\"version\";s:6:\"11.1.5\";s:3:\"tag\";s:6:\"11.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.1.5.tar.gz\";s:4:\"date\";s:10:\"1742407823\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.1.4\";a:10:{s:4:\"name\";s:13:\"drupal 11.1.4\";s:7:\"version\";s:6:\"11.1.4\";s:3:\"tag\";s:6:\"11.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.1.4.tar.gz\";s:4:\"date\";s:10:\"1741210524\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.1.3\";a:10:{s:4:\"name\";s:13:\"drupal 11.1.3\";s:7:\"version\";s:6:\"11.1.3\";s:3:\"tag\";s:6:\"11.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.1.3.tar.gz\";s:4:\"date\";s:10:\"1739986133\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.1.2\";a:10:{s:4:\"name\";s:13:\"drupal 11.1.2\";s:7:\"version\";s:6:\"11.1.2\";s:3:\"tag\";s:6:\"11.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.1.2.tar.gz\";s:4:\"date\";s:10:\"1738796542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.1.1\";a:10:{s:4:\"name\";s:13:\"drupal 11.1.1\";s:7:\"version\";s:6:\"11.1.1\";s:3:\"tag\";s:6:\"11.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.1.1.tar.gz\";s:4:\"date\";s:10:\"1736204811\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.1.0\";a:10:{s:4:\"name\";s:13:\"drupal 11.1.0\";s:7:\"version\";s:6:\"11.1.0\";s:3:\"tag\";s:6:\"11.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.1.0.tar.gz\";s:4:\"date\";s:10:\"1734369672\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"11.1.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 11.1.0-rc1\";s:7:\"version\";s:10:\"11.1.0-rc1\";s:3:\"tag\";s:10:\"11.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.1.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1733153182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"11.1.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 11.1.0-beta1\";s:7:\"version\";s:12:\"11.1.0-beta1\";s:3:\"tag\";s:12:\"11.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/11.1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-11.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1731695942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:7:\"11.0.13\";a:10:{s:4:\"name\";s:14:\"drupal 11.0.13\";s:7:\"version\";s:7:\"11.0.13\";s:3:\"tag\";s:7:\"11.0.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/11.0.13\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-11.0.13.tar.gz\";s:4:\"date\";s:10:\"1742408477\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"11.0.12\";a:10:{s:4:\"name\";s:14:\"drupal 11.0.12\";s:7:\"version\";s:7:\"11.0.12\";s:3:\"tag\";s:7:\"11.0.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/11.0.12\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-11.0.12.tar.gz\";s:4:\"date\";s:10:\"1739988102\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"11.0.11\";a:10:{s:4:\"name\";s:14:\"drupal 11.0.11\";s:7:\"version\";s:7:\"11.0.11\";s:3:\"tag\";s:7:\"11.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/11.0.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-11.0.11.tar.gz\";s:4:\"date\";s:10:\"1738797159\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"11.0.10\";a:10:{s:4:\"name\";s:14:\"drupal 11.0.10\";s:7:\"version\";s:7:\"11.0.10\";s:3:\"tag\";s:7:\"11.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/11.0.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-11.0.10.tar.gz\";s:4:\"date\";s:10:\"1736206526\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.9\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.9\";s:7:\"version\";s:6:\"11.0.9\";s:3:\"tag\";s:6:\"11.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.9.tar.gz\";s:4:\"date\";s:10:\"1732283629\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.8\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.8\";s:7:\"version\";s:6:\"11.0.8\";s:3:\"tag\";s:6:\"11.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.8.tar.gz\";s:4:\"date\";s:10:\"1732132096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.7\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.7\";s:7:\"version\";s:6:\"11.0.7\";s:3:\"tag\";s:6:\"11.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.7.tar.gz\";s:4:\"date\";s:10:\"1731407794\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.6\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.6\";s:7:\"version\";s:6:\"11.0.6\";s:3:\"tag\";s:6:\"11.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.6.tar.gz\";s:4:\"date\";s:10:\"1730969764\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.5\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.5\";s:7:\"version\";s:6:\"11.0.5\";s:3:\"tag\";s:6:\"11.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.5.tar.gz\";s:4:\"date\";s:10:\"1727946737\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.4\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.4\";s:7:\"version\";s:6:\"11.0.4\";s:3:\"tag\";s:6:\"11.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.4.tar.gz\";s:4:\"date\";s:10:\"1726136390\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.3\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.3\";s:7:\"version\";s:6:\"11.0.3\";s:3:\"tag\";s:6:\"11.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.3.tar.gz\";s:4:\"date\";s:10:\"1726074557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.2\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.2\";s:7:\"version\";s:6:\"11.0.2\";s:3:\"tag\";s:6:\"11.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.2.tar.gz\";s:4:\"date\";s:10:\"1725526703\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.1\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.1\";s:7:\"version\";s:6:\"11.0.1\";s:3:\"tag\";s:6:\"11.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.1.tar.gz\";s:4:\"date\";s:10:\"1723108396\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.0\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.0\";s:7:\"version\";s:6:\"11.0.0\";s:3:\"tag\";s:6:\"11.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.0.tar.gz\";s:4:\"date\";s:10:\"1722578454\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"11.0.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 11.0.0-rc1\";s:7:\"version\";s:10:\"11.0.0-rc1\";s:3:\"tag\";s:10:\"11.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1720736512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"11.0.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 11.0.0-beta1\";s:7:\"version\";s:12:\"11.0.0-beta1\";s:3:\"tag\";s:12:\"11.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/11.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1715953266\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"11.0.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 11.0.0-alpha1\";s:7:\"version\";s:13:\"11.0.0-alpha1\";s:3:\"tag\";s:13:\"11.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/11.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1714797816\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"10.4.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.4.6\";s:7:\"version\";s:6:\"10.4.6\";s:3:\"tag\";s:6:\"10.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.4.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.4.6.tar.gz\";s:4:\"date\";s:10:\"1743628915\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.4.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.4.5\";s:7:\"version\";s:6:\"10.4.5\";s:3:\"tag\";s:6:\"10.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.4.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.4.5.tar.gz\";s:4:\"date\";s:10:\"1742409107\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.4.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.4.4\";s:7:\"version\";s:6:\"10.4.4\";s:3:\"tag\";s:6:\"10.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.4.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.4.4.tar.gz\";s:4:\"date\";s:10:\"1741211791\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.4.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.4.3\";s:7:\"version\";s:6:\"10.4.3\";s:3:\"tag\";s:6:\"10.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.4.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.4.3.tar.gz\";s:4:\"date\";s:10:\"1739987505\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.4.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.4.2\";s:7:\"version\";s:6:\"10.4.2\";s:3:\"tag\";s:6:\"10.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.4.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.4.2.tar.gz\";s:4:\"date\";s:10:\"1738798328\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.4.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.4.1\";s:7:\"version\";s:6:\"10.4.1\";s:3:\"tag\";s:6:\"10.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.4.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.4.1.tar.gz\";s:4:\"date\";s:10:\"1736207882\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.4.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.4.0\";s:7:\"version\";s:6:\"10.4.0\";s:3:\"tag\";s:6:\"10.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.4.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.4.0.tar.gz\";s:4:\"date\";s:10:\"1734475162\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.4.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.4.0-rc1\";s:7:\"version\";s:10:\"10.4.0-rc1\";s:3:\"tag\";s:10:\"10.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.4.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1733155673\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.4.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.4.0-beta1\";s:7:\"version\";s:12:\"10.4.0-beta1\";s:3:\"tag\";s:12:\"10.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.4.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1731947109\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:7:\"10.3.14\";a:10:{s:4:\"name\";s:14:\"drupal 10.3.14\";s:7:\"version\";s:7:\"10.3.14\";s:3:\"tag\";s:7:\"10.3.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.3.14\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.3.14.tar.gz\";s:4:\"date\";s:10:\"1742410042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.3.13\";a:10:{s:4:\"name\";s:14:\"drupal 10.3.13\";s:7:\"version\";s:7:\"10.3.13\";s:3:\"tag\";s:7:\"10.3.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.3.13\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.3.13.tar.gz\";s:4:\"date\";s:10:\"1739986815\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.3.12\";a:10:{s:4:\"name\";s:14:\"drupal 10.3.12\";s:7:\"version\";s:7:\"10.3.12\";s:3:\"tag\";s:7:\"10.3.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.3.12\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.3.12.tar.gz\";s:4:\"date\";s:10:\"1738798951\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.3.11\";a:10:{s:4:\"name\";s:14:\"drupal 10.3.11\";s:7:\"version\";s:7:\"10.3.11\";s:3:\"tag\";s:7:\"10.3.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.3.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.3.11.tar.gz\";s:4:\"date\";s:10:\"1736208549\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.3.10\";a:10:{s:4:\"name\";s:14:\"drupal 10.3.10\";s:7:\"version\";s:7:\"10.3.10\";s:3:\"tag\";s:7:\"10.3.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.3.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.3.10.tar.gz\";s:4:\"date\";s:10:\"1732284381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.9\";s:7:\"version\";s:6:\"10.3.9\";s:3:\"tag\";s:6:\"10.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.9.tar.gz\";s:4:\"date\";s:10:\"1732132747\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.8\";s:7:\"version\";s:6:\"10.3.8\";s:3:\"tag\";s:6:\"10.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.8.tar.gz\";s:4:\"date\";s:10:\"1731407050\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.7\";s:7:\"version\";s:6:\"10.3.7\";s:3:\"tag\";s:6:\"10.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.7.tar.gz\";s:4:\"date\";s:10:\"1730969060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.6\";s:7:\"version\";s:6:\"10.3.6\";s:3:\"tag\";s:6:\"10.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.6.tar.gz\";s:4:\"date\";s:10:\"1727948888\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.5\";s:7:\"version\";s:6:\"10.3.5\";s:3:\"tag\";s:6:\"10.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.5.tar.gz\";s:4:\"date\";s:10:\"1726134993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.4\";s:7:\"version\";s:6:\"10.3.4\";s:3:\"tag\";s:6:\"10.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.4.tar.gz\";s:4:\"date\";s:10:\"1726072510\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.3\";s:7:\"version\";s:6:\"10.3.3\";s:3:\"tag\";s:6:\"10.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.3.tar.gz\";s:4:\"date\";s:10:\"1725528161\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.2\";s:7:\"version\";s:6:\"10.3.2\";s:3:\"tag\";s:6:\"10.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.2.tar.gz\";s:4:\"date\";s:10:\"1723109810\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.1\";s:7:\"version\";s:6:\"10.3.1\";s:3:\"tag\";s:6:\"10.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.1.tar.gz\";s:4:\"date\";s:10:\"1720094095\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.0\";s:7:\"version\";s:6:\"10.3.0\";s:3:\"tag\";s:6:\"10.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.0.tar.gz\";s:4:\"date\";s:10:\"1718911125\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.3.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.3.0-rc1\";s:7:\"version\";s:10:\"10.3.0-rc1\";s:3:\"tag\";s:10:\"10.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.3.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1717621189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.3.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.3.0-beta1\";s:7:\"version\";s:12:\"10.3.0-beta1\";s:3:\"tag\";s:12:\"10.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.3.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1715953149\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:7:\"10.2.12\";a:10:{s:4:\"name\";s:14:\"drupal 10.2.12\";s:7:\"version\";s:7:\"10.2.12\";s:3:\"tag\";s:7:\"10.2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.2.12\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.2.12.tar.gz\";s:4:\"date\";s:10:\"1732281201\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.2.11\";a:10:{s:4:\"name\";s:14:\"drupal 10.2.11\";s:7:\"version\";s:7:\"10.2.11\";s:3:\"tag\";s:7:\"10.2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.2.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.2.11.tar.gz\";s:4:\"date\";s:10:\"1732133662\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.2.10\";a:10:{s:4:\"name\";s:14:\"drupal 10.2.10\";s:7:\"version\";s:7:\"10.2.10\";s:3:\"tag\";s:7:\"10.2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.2.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.2.10.tar.gz\";s:4:\"date\";s:10:\"1729096989\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.9\";s:7:\"version\";s:6:\"10.2.9\";s:3:\"tag\";s:6:\"10.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.9.tar.gz\";s:4:\"date\";s:10:\"1728387439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.8\";s:7:\"version\";s:6:\"10.2.8\";s:3:\"tag\";s:6:\"10.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.8.tar.gz\";s:4:\"date\";s:10:\"1726073816\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.7\";s:7:\"version\";s:6:\"10.2.7\";s:3:\"tag\";s:6:\"10.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.7.tar.gz\";s:4:\"date\";s:10:\"1717660024\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.6\";s:7:\"version\";s:6:\"10.2.6\";s:3:\"tag\";s:6:\"10.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.6.tar.gz\";s:4:\"date\";s:10:\"1714597701\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.5\";s:7:\"version\";s:6:\"10.2.5\";s:3:\"tag\";s:6:\"10.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.5.tar.gz\";s:4:\"date\";s:10:\"1712130945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.4\";s:7:\"version\";s:6:\"10.2.4\";s:3:\"tag\";s:6:\"10.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.4.tar.gz\";s:4:\"date\";s:10:\"1709715366\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.3\";s:7:\"version\";s:6:\"10.2.3\";s:3:\"tag\";s:6:\"10.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.3.tar.gz\";s:4:\"date\";s:10:\"1707347611\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.2\";s:7:\"version\";s:6:\"10.2.2\";s:3:\"tag\";s:6:\"10.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.2.tar.gz\";s:4:\"date\";s:10:\"1705511786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.1\";s:7:\"version\";s:6:\"10.2.1\";s:3:\"tag\";s:6:\"10.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.1.tar.gz\";s:4:\"date\";s:10:\"1704448164\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.0\";s:7:\"version\";s:6:\"10.2.0\";s:3:\"tag\";s:6:\"10.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.0.tar.gz\";s:4:\"date\";s:10:\"1702681674\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.2.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.2.0-rc1\";s:7:\"version\";s:10:\"10.2.0-rc1\";s:3:\"tag\";s:10:\"10.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.2.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1701450971\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.2.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.2.0-beta1\";s:7:\"version\";s:12:\"10.2.0-beta1\";s:3:\"tag\";s:12:\"10.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.2.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1700578716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.2.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.2.0-alpha1\";s:7:\"version\";s:13:\"10.2.0-alpha1\";s:3:\"tag\";s:13:\"10.2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.2.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1699048959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"10.1.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.8\";s:7:\"version\";s:6:\"10.1.8\";s:3:\"tag\";s:6:\"10.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.8.tar.gz\";s:4:\"date\";s:10:\"1705512711\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.7\";s:7:\"version\";s:6:\"10.1.7\";s:3:\"tag\";s:6:\"10.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.7.tar.gz\";s:4:\"date\";s:10:\"1701857745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.6\";s:7:\"version\";s:6:\"10.1.6\";s:3:\"tag\";s:6:\"10.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.6.tar.gz\";s:4:\"date\";s:10:\"1698841286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.5\";s:7:\"version\";s:6:\"10.1.5\";s:3:\"tag\";s:6:\"10.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.5.tar.gz\";s:4:\"date\";s:10:\"1696456362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.4\";s:7:\"version\";s:6:\"10.1.4\";s:3:\"tag\";s:6:\"10.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.4.tar.gz\";s:4:\"date\";s:10:\"1695227262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.3\";s:7:\"version\";s:6:\"10.1.3\";s:3:\"tag\";s:6:\"10.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.3.tar.gz\";s:4:\"date\";s:10:\"1694101052\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.2\";s:7:\"version\";s:6:\"10.1.2\";s:3:\"tag\";s:6:\"10.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.2.tar.gz\";s:4:\"date\";s:10:\"1690972078\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.1\";s:7:\"version\";s:6:\"10.1.1\";s:3:\"tag\";s:6:\"10.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.1.tar.gz\";s:4:\"date\";s:10:\"1688632960\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.0\";s:7:\"version\";s:6:\"10.1.0\";s:3:\"tag\";s:6:\"10.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.0.tar.gz\";s:4:\"date\";s:10:\"1687424272\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.1.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.1.0-rc1\";s:7:\"version\";s:10:\"10.1.0-rc1\";s:3:\"tag\";s:10:\"10.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.1.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1686244833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.1.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.1.0-beta1\";s:7:\"version\";s:12:\"10.1.0-beta1\";s:3:\"tag\";s:12:\"10.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1684130534\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.1.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.1.0-alpha1\";s:7:\"version\";s:13:\"10.1.0-alpha1\";s:3:\"tag\";s:13:\"10.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.1.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1682694475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:7:\"10.0.11\";a:10:{s:4:\"name\";s:14:\"drupal 10.0.11\";s:7:\"version\";s:7:\"10.0.11\";s:3:\"tag\";s:7:\"10.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.0.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.0.11.tar.gz\";s:4:\"date\";s:10:\"1695228927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.0.10\";a:10:{s:4:\"name\";s:14:\"drupal 10.0.10\";s:7:\"version\";s:7:\"10.0.10\";s:3:\"tag\";s:7:\"10.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.0.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.0.10.tar.gz\";s:4:\"date\";s:10:\"1688549719\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.9\";s:7:\"version\";s:6:\"10.0.9\";s:3:\"tag\";s:6:\"10.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.9.tar.gz\";s:4:\"date\";s:10:\"1683108606\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.8\";s:7:\"version\";s:6:\"10.0.8\";s:3:\"tag\";s:6:\"10.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.8.tar.gz\";s:4:\"date\";s:10:\"1681921539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.7\";s:7:\"version\";s:6:\"10.0.7\";s:3:\"tag\";s:6:\"10.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.7.tar.gz\";s:4:\"date\";s:10:\"1679678060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.6\";s:7:\"version\";s:6:\"10.0.6\";s:3:\"tag\";s:6:\"10.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.6.tar.gz\";s:4:\"date\";s:10:\"1679664982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.5\";s:7:\"version\";s:6:\"10.0.5\";s:3:\"tag\";s:6:\"10.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.5.tar.gz\";s:4:\"date\";s:10:\"1678901067\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.4\";s:7:\"version\";s:6:\"10.0.4\";s:3:\"tag\";s:6:\"10.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.4.tar.gz\";s:4:\"date\";s:10:\"1677681486\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.3\";s:7:\"version\";s:6:\"10.0.3\";s:3:\"tag\";s:6:\"10.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.3.tar.gz\";s:4:\"date\";s:10:\"1675276709\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.2\";s:7:\"version\";s:6:\"10.0.2\";s:3:\"tag\";s:6:\"10.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.2.tar.gz\";s:4:\"date\";s:10:\"1674065542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.1\";s:7:\"version\";s:6:\"10.0.1\";s:3:\"tag\";s:6:\"10.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.1.tar.gz\";s:4:\"date\";s:10:\"1672847780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.0\";s:7:\"version\";s:6:\"10.0.0\";s:3:\"tag\";s:6:\"10.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.0.tar.gz\";s:4:\"date\";s:10:\"1671125939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.0.0-rc3\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc3\";s:7:\"version\";s:10:\"10.0.0-rc3\";s:3:\"tag\";s:10:\"10.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1670591784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:10:\"10.0.0-rc2\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc2\";s:7:\"version\";s:10:\"10.0.0-rc2\";s:3:\"tag\";s:10:\"10.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1670320927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:10:\"10.0.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc1\";s:7:\"version\";s:10:\"10.0.0-rc1\";s:3:\"tag\";s:10:\"10.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1668612993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.0.0-beta2\";a:10:{s:4:\"name\";s:19:\"drupal 10.0.0-beta2\";s:7:\"version\";s:12:\"10.0.0-beta2\";s:3:\"tag\";s:12:\"10.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.0.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1664462663\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"10.0.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.0.0-beta1\";s:7:\"version\";s:12:\"10.0.0-beta1\";s:3:\"tag\";s:12:\"10.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663358020\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha7\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha7\";s:7:\"version\";s:13:\"10.0.0-alpha7\";s:3:\"tag\";s:13:\"10.0.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1659633851\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha6\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha6\";s:7:\"version\";s:13:\"10.0.0-alpha6\";s:3:\"tag\";s:13:\"10.0.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1657218740\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha5\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha5\";s:7:\"version\";s:13:\"10.0.0-alpha5\";s:3:\"tag\";s:13:\"10.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1654722993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha4\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha4\";s:7:\"version\";s:13:\"10.0.0-alpha4\";s:3:\"tag\";s:13:\"10.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1651875601\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha3\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha3\";s:7:\"version\";s:13:\"10.0.0-alpha3\";s:3:\"tag\";s:13:\"10.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1649887793\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha2\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha2\";s:7:\"version\";s:13:\"10.0.0-alpha2\";s:3:\"tag\";s:13:\"10.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1645204305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha1\";s:7:\"version\";s:13:\"10.0.0-alpha1\";s:3:\"tag\";s:13:\"10.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1643404041\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.5.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.5.11\";s:7:\"version\";s:6:\"9.5.11\";s:3:\"tag\";s:6:\"9.5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.5.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.5.11.tar.gz\";s:4:\"date\";s:10:\"1695228016\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.5.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.5.10\";s:7:\"version\";s:6:\"9.5.10\";s:3:\"tag\";s:6:\"9.5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.5.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.5.10.tar.gz\";s:4:\"date\";s:10:\"1688550984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.9\";s:7:\"version\";s:5:\"9.5.9\";s:3:\"tag\";s:5:\"9.5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.9.tar.gz\";s:4:\"date\";s:10:\"1683121532\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.8\";s:7:\"version\";s:5:\"9.5.8\";s:3:\"tag\";s:5:\"9.5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.8.tar.gz\";s:4:\"date\";s:10:\"1681922649\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.7\";s:7:\"version\";s:5:\"9.5.7\";s:3:\"tag\";s:5:\"9.5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.7.tar.gz\";s:4:\"date\";s:10:\"1679677448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.6\";s:7:\"version\";s:5:\"9.5.6\";s:3:\"tag\";s:5:\"9.5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.6.tar.gz\";s:4:\"date\";s:10:\"1679664389\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.5\";s:7:\"version\";s:5:\"9.5.5\";s:3:\"tag\";s:5:\"9.5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.5.tar.gz\";s:4:\"date\";s:10:\"1678902101\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.4\";s:7:\"version\";s:5:\"9.5.4\";s:3:\"tag\";s:5:\"9.5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.4.tar.gz\";s:4:\"date\";s:10:\"1677680813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.3\";s:7:\"version\";s:5:\"9.5.3\";s:3:\"tag\";s:5:\"9.5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.3.tar.gz\";s:4:\"date\";s:10:\"1675281829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.2\";s:7:\"version\";s:5:\"9.5.2\";s:3:\"tag\";s:5:\"9.5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.2.tar.gz\";s:4:\"date\";s:10:\"1674066112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.1\";s:7:\"version\";s:5:\"9.5.1\";s:3:\"tag\";s:5:\"9.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.1.tar.gz\";s:4:\"date\";s:10:\"1672849046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.0\";s:7:\"version\";s:5:\"9.5.0\";s:3:\"tag\";s:5:\"9.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.0.tar.gz\";s:4:\"date\";s:10:\"1671115839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.5.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.0-rc2\";s:7:\"version\";s:9:\"9.5.0-rc2\";s:3:\"tag\";s:9:\"9.5.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1670593040\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.5.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.0-rc1\";s:7:\"version\";s:9:\"9.5.0-rc1\";s:3:\"tag\";s:9:\"9.5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1668611189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.5.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.5.0-beta2\";s:7:\"version\";s:11:\"9.5.0-beta2\";s:3:\"tag\";s:11:\"9.5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.5.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1664463958\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.5.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.5.0-beta1\";s:7:\"version\";s:11:\"9.5.0-beta1\";s:3:\"tag\";s:11:\"9.5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.5.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663358587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"9.4.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.15\";s:7:\"version\";s:6:\"9.4.15\";s:3:\"tag\";s:6:\"9.4.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.15.tar.gz\";s:4:\"date\";s:10:\"1683122076\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.14\";s:7:\"version\";s:6:\"9.4.14\";s:3:\"tag\";s:6:\"9.4.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.14.tar.gz\";s:4:\"date\";s:10:\"1681922120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.13\";s:7:\"version\";s:6:\"9.4.13\";s:3:\"tag\";s:6:\"9.4.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.13.tar.gz\";s:4:\"date\";s:10:\"1679665413\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.12\";s:7:\"version\";s:6:\"9.4.12\";s:3:\"tag\";s:6:\"9.4.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.12.tar.gz\";s:4:\"date\";s:10:\"1678901516\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.11\";s:7:\"version\";s:6:\"9.4.11\";s:3:\"tag\";s:6:\"9.4.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.11.tar.gz\";s:4:\"date\";s:10:\"1675282255\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.10\";s:7:\"version\";s:6:\"9.4.10\";s:3:\"tag\";s:6:\"9.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.10.tar.gz\";s:4:\"date\";s:10:\"1674066615\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.9\";s:7:\"version\";s:5:\"9.4.9\";s:3:\"tag\";s:5:\"9.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.9.tar.gz\";s:4:\"date\";s:10:\"1670421053\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.8\";s:7:\"version\";s:5:\"9.4.8\";s:3:\"tag\";s:5:\"9.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.8.tar.gz\";s:4:\"date\";s:10:\"1665072393\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.7\";s:7:\"version\";s:5:\"9.4.7\";s:3:\"tag\";s:5:\"9.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.7.tar.gz\";s:4:\"date\";s:10:\"1664383239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.6\";s:7:\"version\";s:5:\"9.4.6\";s:3:\"tag\";s:5:\"9.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.6.tar.gz\";s:4:\"date\";s:10:\"1663681319\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.5\";s:7:\"version\";s:5:\"9.4.5\";s:3:\"tag\";s:5:\"9.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.5.tar.gz\";s:4:\"date\";s:10:\"1659545453\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.4\";s:7:\"version\";s:5:\"9.4.4\";s:3:\"tag\";s:5:\"9.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.4.tar.gz\";s:4:\"date\";s:10:\"1659037490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.3\";s:7:\"version\";s:5:\"9.4.3\";s:3:\"tag\";s:5:\"9.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.3.tar.gz\";s:4:\"date\";s:10:\"1658333415\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.2\";s:7:\"version\";s:5:\"9.4.2\";s:3:\"tag\";s:5:\"9.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.2.tar.gz\";s:4:\"date\";s:10:\"1657157309\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.1\";s:7:\"version\";s:5:\"9.4.1\";s:3:\"tag\";s:5:\"9.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.1.tar.gz\";s:4:\"date\";s:10:\"1655845511\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.0\";s:7:\"version\";s:5:\"9.4.0\";s:3:\"tag\";s:5:\"9.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.0.tar.gz\";s:4:\"date\";s:10:\"1655311138\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.4.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.0-rc2\";s:7:\"version\";s:9:\"9.4.0-rc2\";s:3:\"tag\";s:9:\"9.4.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1654890055\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.4.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.0-rc1\";s:7:\"version\";s:9:\"9.4.0-rc1\";s:3:\"tag\";s:9:\"9.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1654740019\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.4.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.4.0-beta1\";s:7:\"version\";s:11:\"9.4.0-beta1\";s:3:\"tag\";s:11:\"9.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.4.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1653938214\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.4.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.4.0-alpha1\";s:7:\"version\";s:12:\"9.4.0-alpha1\";s:3:\"tag\";s:12:\"9.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.4.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1651875606\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.3.22\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.22\";s:7:\"version\";s:6:\"9.3.22\";s:3:\"tag\";s:6:\"9.3.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.22\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.22.tar.gz\";s:4:\"date\";s:10:\"1664382666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.21\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.21\";s:7:\"version\";s:6:\"9.3.21\";s:3:\"tag\";s:6:\"9.3.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.21\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.21.tar.gz\";s:4:\"date\";s:10:\"1659544886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.20\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.20\";s:7:\"version\";s:6:\"9.3.20\";s:3:\"tag\";s:6:\"9.3.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.20.tar.gz\";s:4:\"date\";s:10:\"1659037977\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.19\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.19\";s:7:\"version\";s:6:\"9.3.19\";s:3:\"tag\";s:6:\"9.3.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.19.tar.gz\";s:4:\"date\";s:10:\"1658333887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.18\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.18\";s:7:\"version\";s:6:\"9.3.18\";s:3:\"tag\";s:6:\"9.3.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.18.tar.gz\";s:4:\"date\";s:10:\"1657238772\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.17\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.17\";s:7:\"version\";s:6:\"9.3.17\";s:3:\"tag\";s:6:\"9.3.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.17.tar.gz\";s:4:\"date\";s:10:\"1655846622\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.16\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.16\";s:7:\"version\";s:6:\"9.3.16\";s:3:\"tag\";s:6:\"9.3.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.16.tar.gz\";s:4:\"date\";s:10:\"1654888736\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.15\";s:7:\"version\";s:6:\"9.3.15\";s:3:\"tag\";s:6:\"9.3.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.15.tar.gz\";s:4:\"date\";s:10:\"1654098765\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.14\";s:7:\"version\";s:6:\"9.3.14\";s:3:\"tag\";s:6:\"9.3.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.14.tar.gz\";s:4:\"date\";s:10:\"1653506291\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.13\";s:7:\"version\";s:6:\"9.3.13\";s:3:\"tag\";s:6:\"9.3.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.13.tar.gz\";s:4:\"date\";s:10:\"1652261874\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.12\";s:7:\"version\";s:6:\"9.3.12\";s:3:\"tag\";s:6:\"9.3.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.12.tar.gz\";s:4:\"date\";s:10:\"1650467536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.11\";s:7:\"version\";s:6:\"9.3.11\";s:3:\"tag\";s:6:\"9.3.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.11.tar.gz\";s:4:\"date\";s:10:\"1649897391\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.10\";s:7:\"version\";s:6:\"9.3.10\";s:3:\"tag\";s:6:\"9.3.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.10.tar.gz\";s:4:\"date\";s:10:\"1649890098\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.9\";s:7:\"version\";s:5:\"9.3.9\";s:3:\"tag\";s:5:\"9.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.9.tar.gz\";s:4:\"date\";s:10:\"1647899360\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.8\";s:7:\"version\";s:5:\"9.3.8\";s:3:\"tag\";s:5:\"9.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.8.tar.gz\";s:4:\"date\";s:10:\"1647446914\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.7\";s:7:\"version\";s:5:\"9.3.7\";s:3:\"tag\";s:5:\"9.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.7.tar.gz\";s:4:\"date\";s:10:\"1646300599\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.6\";s:7:\"version\";s:5:\"9.3.6\";s:3:\"tag\";s:5:\"9.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.6.tar.gz\";s:4:\"date\";s:10:\"1645029460\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.5\";s:7:\"version\";s:5:\"9.3.5\";s:3:\"tag\";s:5:\"9.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.5.tar.gz\";s:4:\"date\";s:10:\"1644011676\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.4\";s:7:\"version\";s:5:\"9.3.4\";s:3:\"tag\";s:5:\"9.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.4.tar.gz\";s:4:\"date\";s:10:\"1643832805\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.3\";s:7:\"version\";s:5:\"9.3.3\";s:3:\"tag\";s:5:\"9.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.3.tar.gz\";s:4:\"date\";s:10:\"1642607769\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.2\";s:7:\"version\";s:5:\"9.3.2\";s:3:\"tag\";s:5:\"9.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.2.tar.gz\";s:4:\"date\";s:10:\"1641351799\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.1\";s:7:\"version\";s:5:\"9.3.1\";s:3:\"tag\";s:5:\"9.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.1.tar.gz\";s:4:\"date\";s:10:\"1641342679\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.0\";s:7:\"version\";s:5:\"9.3.0\";s:3:\"tag\";s:5:\"9.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.0.tar.gz\";s:4:\"date\";s:10:\"1639051276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.3.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.3.0-rc1\";s:7:\"version\";s:9:\"9.3.0-rc1\";s:3:\"tag\";s:9:\"9.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.3.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1637959424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta3\";s:7:\"version\";s:11:\"9.3.0-beta3\";s:3:\"tag\";s:11:\"9.3.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1637764182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta2\";s:7:\"version\";s:11:\"9.3.0-beta2\";s:3:\"tag\";s:11:\"9.3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1637196496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta1\";s:7:\"version\";s:11:\"9.3.0-beta1\";s:3:\"tag\";s:11:\"9.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1636746050\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.3.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.3.0-alpha1\";s:7:\"version\";s:12:\"9.3.0-alpha1\";s:3:\"tag\";s:12:\"9.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.3.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1635510285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.2.21\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.21\";s:7:\"version\";s:6:\"9.2.21\";s:3:\"tag\";s:6:\"9.2.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.21\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.21.tar.gz\";s:4:\"date\";s:10:\"1654889475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.20\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.20\";s:7:\"version\";s:6:\"9.2.20\";s:3:\"tag\";s:6:\"9.2.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.20.tar.gz\";s:4:\"date\";s:10:\"1653507225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.19\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.19\";s:7:\"version\";s:6:\"9.2.19\";s:3:\"tag\";s:6:\"9.2.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.19.tar.gz\";s:4:\"date\";s:10:\"1652306637\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.18\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.18\";s:7:\"version\";s:6:\"9.2.18\";s:3:\"tag\";s:6:\"9.2.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.18.tar.gz\";s:4:\"date\";s:10:\"1650466972\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.17\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.17\";s:7:\"version\";s:6:\"9.2.17\";s:3:\"tag\";s:6:\"9.2.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.17.tar.gz\";s:4:\"date\";s:10:\"1649898006\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.16\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.16\";s:7:\"version\";s:6:\"9.2.16\";s:3:\"tag\";s:6:\"9.2.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.16.tar.gz\";s:4:\"date\";s:10:\"1647898826\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.15\";s:7:\"version\";s:6:\"9.2.15\";s:3:\"tag\";s:6:\"9.2.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.15.tar.gz\";s:4:\"date\";s:10:\"1647447411\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.14\";s:7:\"version\";s:6:\"9.2.14\";s:3:\"tag\";s:6:\"9.2.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.14.tar.gz\";s:4:\"date\";s:10:\"1647027629\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.13\";s:7:\"version\";s:6:\"9.2.13\";s:3:\"tag\";s:6:\"9.2.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.13.tar.gz\";s:4:\"date\";s:10:\"1645029955\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.12\";s:7:\"version\";s:6:\"9.2.12\";s:3:\"tag\";s:6:\"9.2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.12.tar.gz\";s:4:\"date\";s:10:\"1644012448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.11\";s:7:\"version\";s:6:\"9.2.11\";s:3:\"tag\";s:6:\"9.2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.11.tar.gz\";s:4:\"date\";s:10:\"1642608353\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.10\";s:7:\"version\";s:6:\"9.2.10\";s:3:\"tag\";s:6:\"9.2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.10.tar.gz\";s:4:\"date\";s:10:\"1637765544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.9\";s:7:\"version\";s:5:\"9.2.9\";s:3:\"tag\";s:5:\"9.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.9.tar.gz\";s:4:\"date\";s:10:\"1637184936\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.8\";s:7:\"version\";s:5:\"9.2.8\";s:3:\"tag\";s:5:\"9.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.8.tar.gz\";s:4:\"date\";s:10:\"1635961216\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.7\";s:7:\"version\";s:5:\"9.2.7\";s:3:\"tag\";s:5:\"9.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.7.tar.gz\";s:4:\"date\";s:10:\"1633544267\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.6\";s:7:\"version\";s:5:\"9.2.6\";s:3:\"tag\";s:5:\"9.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.6.tar.gz\";s:4:\"date\";s:10:\"1631721555\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.5\";s:7:\"version\";s:5:\"9.2.5\";s:3:\"tag\";s:5:\"9.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.5.tar.gz\";s:4:\"date\";s:10:\"1630534729\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.4\";s:7:\"version\";s:5:\"9.2.4\";s:3:\"tag\";s:5:\"9.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.4.tar.gz\";s:4:\"date\";s:10:\"1628791178\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.3\";s:7:\"version\";s:5:\"9.2.3\";s:3:\"tag\";s:5:\"9.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.3.tar.gz\";s:4:\"date\";s:10:\"1627997922\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.2\";s:7:\"version\";s:5:\"9.2.2\";s:3:\"tag\";s:5:\"9.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.2.tar.gz\";s:4:\"date\";s:10:\"1626882385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.1\";s:7:\"version\";s:5:\"9.2.1\";s:3:\"tag\";s:5:\"9.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.1.tar.gz\";s:4:\"date\";s:10:\"1625664286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.0\";s:7:\"version\";s:5:\"9.2.0\";s:3:\"tag\";s:5:\"9.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.0.tar.gz\";s:4:\"date\";s:10:\"1623847798\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.2.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.2.0-rc1\";s:7:\"version\";s:9:\"9.2.0-rc1\";s:3:\"tag\";s:9:\"9.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.2.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1623080867\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta3\";s:7:\"version\";s:11:\"9.2.0-beta3\";s:3:\"tag\";s:11:\"9.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1622207568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta2\";s:7:\"version\";s:11:\"9.2.0-beta2\";s:3:\"tag\";s:11:\"9.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1622068611\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta1\";s:7:\"version\";s:11:\"9.2.0-beta1\";s:3:\"tag\";s:11:\"9.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1621506248\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.2.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.2.0-alpha1\";s:7:\"version\";s:12:\"9.2.0-alpha1\";s:3:\"tag\";s:12:\"9.2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.2.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1620291652\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.1.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.15\";s:7:\"version\";s:6:\"9.1.15\";s:3:\"tag\";s:6:\"9.1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.15.tar.gz\";s:4:\"date\";s:10:\"1637766681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.14\";s:7:\"version\";s:6:\"9.1.14\";s:3:\"tag\";s:6:\"9.1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.14.tar.gz\";s:4:\"date\";s:10:\"1637185450\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.13\";s:7:\"version\";s:6:\"9.1.13\";s:3:\"tag\";s:6:\"9.1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.13.tar.gz\";s:4:\"date\";s:10:\"1631722011\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.12\";s:7:\"version\";s:6:\"9.1.12\";s:3:\"tag\";s:6:\"9.1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.12.tar.gz\";s:4:\"date\";s:10:\"1628791786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.11\";s:7:\"version\";s:6:\"9.1.11\";s:3:\"tag\";s:6:\"9.1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.11.tar.gz\";s:4:\"date\";s:10:\"1626882849\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.10\";s:7:\"version\";s:6:\"9.1.10\";s:3:\"tag\";s:6:\"9.1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.10.tar.gz\";s:4:\"date\";s:10:\"1622828120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.9\";s:7:\"version\";s:5:\"9.1.9\";s:3:\"tag\";s:5:\"9.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.9.tar.gz\";s:4:\"date\";s:10:\"1622056478\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.8\";s:7:\"version\";s:5:\"9.1.8\";s:3:\"tag\";s:5:\"9.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.8.tar.gz\";s:4:\"date\";s:10:\"1620214182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.7\";s:7:\"version\";s:5:\"9.1.7\";s:3:\"tag\";s:5:\"9.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.7.tar.gz\";s:4:\"date\";s:10:\"1619022156\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.6\";s:7:\"version\";s:5:\"9.1.6\";s:3:\"tag\";s:5:\"9.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.6.tar.gz\";s:4:\"date\";s:10:\"1617795446\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.5\";s:7:\"version\";s:5:\"9.1.5\";s:3:\"tag\";s:5:\"9.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.5.tar.gz\";s:4:\"date\";s:10:\"1614869503\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.4\";s:7:\"version\";s:5:\"9.1.4\";s:3:\"tag\";s:5:\"9.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.4.tar.gz\";s:4:\"date\";s:10:\"1612380948\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.3\";s:7:\"version\";s:5:\"9.1.3\";s:3:\"tag\";s:5:\"9.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.3.tar.gz\";s:4:\"date\";s:10:\"1611161215\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.2\";s:7:\"version\";s:5:\"9.1.2\";s:3:\"tag\";s:5:\"9.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.2.tar.gz\";s:4:\"date\";s:10:\"1609984407\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.1\";s:7:\"version\";s:5:\"9.1.1\";s:3:\"tag\";s:5:\"9.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.1.tar.gz\";s:4:\"date\";s:10:\"1609979034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.0\";s:7:\"version\";s:5:\"9.1.0\";s:3:\"tag\";s:5:\"9.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.0.tar.gz\";s:4:\"date\";s:10:\"1606933254\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.1.0-rc3\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc3\";s:7:\"version\";s:9:\"9.1.0-rc3\";s:3:\"tag\";s:9:\"9.1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1606357271\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.1.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc2\";s:7:\"version\";s:9:\"9.1.0-rc2\";s:3:\"tag\";s:9:\"9.1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1606332982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.1.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc1\";s:7:\"version\";s:9:\"9.1.0-rc1\";s:3:\"tag\";s:9:\"9.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1605722782\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.1.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.1.0-beta1\";s:7:\"version\";s:11:\"9.1.0-beta1\";s:3:\"tag\";s:11:\"9.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1604672644\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.1.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.1.0-alpha1\";s:7:\"version\";s:12:\"9.1.0-alpha1\";s:3:\"tag\";s:12:\"9.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.1.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1603466665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.0.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.14\";s:7:\"version\";s:6:\"9.0.14\";s:3:\"tag\";s:6:\"9.0.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.14.tar.gz\";s:4:\"date\";s:10:\"1622055778\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.13\";s:7:\"version\";s:6:\"9.0.13\";s:3:\"tag\";s:6:\"9.0.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.13.tar.gz\";s:4:\"date\";s:10:\"1620218506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.12\";s:7:\"version\";s:6:\"9.0.12\";s:3:\"tag\";s:6:\"9.0.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.12.tar.gz\";s:4:\"date\";s:10:\"1619020951\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.11\";s:7:\"version\";s:6:\"9.0.11\";s:3:\"tag\";s:6:\"9.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.11.tar.gz\";s:4:\"date\";s:10:\"1611161749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.10\";s:7:\"version\";s:6:\"9.0.10\";s:3:\"tag\";s:6:\"9.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.10.tar.gz\";s:4:\"date\";s:10:\"1607029536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.9\";s:7:\"version\";s:5:\"9.0.9\";s:3:\"tag\";s:5:\"9.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.9.tar.gz\";s:4:\"date\";s:10:\"1606359757\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.8\";s:7:\"version\";s:5:\"9.0.8\";s:3:\"tag\";s:5:\"9.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.8.tar.gz\";s:4:\"date\";s:10:\"1605720638\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.7\";s:7:\"version\";s:5:\"9.0.7\";s:3:\"tag\";s:5:\"9.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.7.tar.gz\";s:4:\"date\";s:10:\"1602100055\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.6\";s:7:\"version\";s:5:\"9.0.6\";s:3:\"tag\";s:5:\"9.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.6.tar.gz\";s:4:\"date\";s:10:\"1600275813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.5\";s:7:\"version\";s:5:\"9.0.5\";s:3:\"tag\";s:5:\"9.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.5.tar.gz\";s:4:\"date\";s:10:\"1599167739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.4\";s:7:\"version\";s:5:\"9.0.4\";s:3:\"tag\";s:5:\"9.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.4.tar.gz\";s:4:\"date\";s:10:\"1599046734\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.3\";s:7:\"version\";s:5:\"9.0.3\";s:3:\"tag\";s:5:\"9.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.3.tar.gz\";s:4:\"date\";s:10:\"1596664575\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.2\";s:7:\"version\";s:5:\"9.0.2\";s:3:\"tag\";s:5:\"9.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.2.tar.gz\";s:4:\"date\";s:10:\"1594237418\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.1\";s:7:\"version\";s:5:\"9.0.1\";s:3:\"tag\";s:5:\"9.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.1.tar.gz\";s:4:\"date\";s:10:\"1592417721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.0\";s:7:\"version\";s:5:\"9.0.0\";s:3:\"tag\";s:5:\"9.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.0.tar.gz\";s:4:\"date\";s:10:\"1591221685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.0.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.0.0-rc1\";s:7:\"version\";s:9:\"9.0.0-rc1\";s:3:\"tag\";s:9:\"9.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1590187579\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta3\";s:7:\"version\";s:11:\"9.0.0-beta3\";s:3:\"tag\";s:11:\"9.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1589587936\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta2\";s:7:\"version\";s:11:\"9.0.0-beta2\";s:3:\"tag\";s:11:\"9.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1585597395\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta1\";s:7:\"version\";s:11:\"9.0.0-beta1\";s:3:\"tag\";s:11:\"9.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1584734060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.0.0-alpha2\";a:10:{s:4:\"name\";s:19:\"drupal 9.0.0-alpha2\";s:7:\"version\";s:12:\"9.0.0-alpha2\";s:3:\"tag\";s:12:\"9.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.0.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1583349043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:12:\"9.0.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.0.0-alpha1\";s:7:\"version\";s:12:\"9.0.0-alpha1\";s:3:\"tag\";s:12:\"9.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.0.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1581447927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.9.20\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.20\";s:7:\"version\";s:6:\"8.9.20\";s:3:\"tag\";s:6:\"8.9.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.20.tar.gz\";s:4:\"date\";s:10:\"1637185966\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.19\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.19\";s:7:\"version\";s:6:\"8.9.19\";s:3:\"tag\";s:6:\"8.9.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.19.tar.gz\";s:4:\"date\";s:10:\"1631722431\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.18\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.18\";s:7:\"version\";s:6:\"8.9.18\";s:3:\"tag\";s:6:\"8.9.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.18.tar.gz\";s:4:\"date\";s:10:\"1628792296\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.17\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.17\";s:7:\"version\";s:6:\"8.9.17\";s:3:\"tag\";s:6:\"8.9.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.17.tar.gz\";s:4:\"date\";s:10:\"1626883324\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.16\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.16\";s:7:\"version\";s:6:\"8.9.16\";s:3:\"tag\";s:6:\"8.9.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.16.tar.gz\";s:4:\"date\";s:10:\"1622058087\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.15\";s:7:\"version\";s:6:\"8.9.15\";s:3:\"tag\";s:6:\"8.9.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.15.tar.gz\";s:4:\"date\";s:10:\"1620216983\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.14\";s:7:\"version\";s:6:\"8.9.14\";s:3:\"tag\";s:6:\"8.9.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.14.tar.gz\";s:4:\"date\";s:10:\"1619021518\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.13\";s:7:\"version\";s:6:\"8.9.13\";s:3:\"tag\";s:6:\"8.9.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.13.tar.gz\";s:4:\"date\";s:10:\"1611162272\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.12\";s:7:\"version\";s:6:\"8.9.12\";s:3:\"tag\";s:6:\"8.9.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.12.tar.gz\";s:4:\"date\";s:10:\"1609977009\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.11\";s:7:\"version\";s:6:\"8.9.11\";s:3:\"tag\";s:6:\"8.9.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.11.tar.gz\";s:4:\"date\";s:10:\"1607030087\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.10\";s:7:\"version\";s:6:\"8.9.10\";s:3:\"tag\";s:6:\"8.9.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.10.tar.gz\";s:4:\"date\";s:10:\"1606360301\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.9\";s:7:\"version\";s:5:\"8.9.9\";s:3:\"tag\";s:5:\"8.9.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.9.tar.gz\";s:4:\"date\";s:10:\"1605721120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.8\";s:7:\"version\";s:5:\"8.9.8\";s:3:\"tag\";s:5:\"8.9.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.8.tar.gz\";s:4:\"date\";s:10:\"1604595269\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.7\";s:7:\"version\";s:5:\"8.9.7\";s:3:\"tag\";s:5:\"8.9.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.7.tar.gz\";s:4:\"date\";s:10:\"1602100507\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.6\";s:7:\"version\";s:5:\"8.9.6\";s:3:\"tag\";s:5:\"8.9.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.6.tar.gz\";s:4:\"date\";s:10:\"1600276267\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.5\";s:7:\"version\";s:5:\"8.9.5\";s:3:\"tag\";s:5:\"8.9.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.5.tar.gz\";s:4:\"date\";s:10:\"1599168205\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.4\";s:7:\"version\";s:5:\"8.9.4\";s:3:\"tag\";s:5:\"8.9.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.4.tar.gz\";s:4:\"date\";s:10:\"1599047691\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.3\";s:7:\"version\";s:5:\"8.9.3\";s:3:\"tag\";s:5:\"8.9.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.3.tar.gz\";s:4:\"date\";s:10:\"1596665051\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.2\";s:7:\"version\";s:5:\"8.9.2\";s:3:\"tag\";s:5:\"8.9.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.2.tar.gz\";s:4:\"date\";s:10:\"1594237961\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.1\";s:7:\"version\";s:5:\"8.9.1\";s:3:\"tag\";s:5:\"8.9.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.1.tar.gz\";s:4:\"date\";s:10:\"1592418237\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.0\";s:7:\"version\";s:5:\"8.9.0\";s:3:\"tag\";s:5:\"8.9.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.0.tar.gz\";s:4:\"date\";s:10:\"1591204117\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.9.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.9.0-rc1\";s:7:\"version\";s:9:\"8.9.0-rc1\";s:3:\"tag\";s:9:\"8.9.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.9.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1590189096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta3\";s:7:\"version\";s:11:\"8.9.0-beta3\";s:3:\"tag\";s:11:\"8.9.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1589746375\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta2\";s:7:\"version\";s:11:\"8.9.0-beta2\";s:3:\"tag\";s:11:\"8.9.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1585863226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta1\";s:7:\"version\";s:11:\"8.9.0-beta1\";s:3:\"tag\";s:11:\"8.9.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1585263710\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"8.8.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.12\";s:7:\"version\";s:6:\"8.8.12\";s:3:\"tag\";s:6:\"8.8.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.12.tar.gz\";s:4:\"date\";s:10:\"1606360866\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.8.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.11\";s:7:\"version\";s:6:\"8.8.11\";s:3:\"tag\";s:6:\"8.8.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.11.tar.gz\";s:4:\"date\";s:10:\"1605721628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.8.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.10\";s:7:\"version\";s:6:\"8.8.10\";s:3:\"tag\";s:6:\"8.8.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.10.tar.gz\";s:4:\"date\";s:10:\"1600276704\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.9\";s:7:\"version\";s:5:\"8.8.9\";s:3:\"tag\";s:5:\"8.8.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.9.tar.gz\";s:4:\"date\";s:10:\"1599168716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.8\";s:7:\"version\";s:5:\"8.8.8\";s:3:\"tag\";s:5:\"8.8.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.8.tar.gz\";s:4:\"date\";s:10:\"1592418750\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.7\";s:7:\"version\";s:5:\"8.8.7\";s:3:\"tag\";s:5:\"8.8.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.7.tar.gz\";s:4:\"date\";s:10:\"1591203837\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.6\";s:7:\"version\";s:5:\"8.8.6\";s:3:\"tag\";s:5:\"8.8.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.6.tar.gz\";s:4:\"date\";s:10:\"1589989060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.5\";s:7:\"version\";s:5:\"8.8.5\";s:3:\"tag\";s:5:\"8.8.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.5.tar.gz\";s:4:\"date\";s:10:\"1585861530\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.4\";s:7:\"version\";s:5:\"8.8.4\";s:3:\"tag\";s:5:\"8.8.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.4.tar.gz\";s:4:\"date\";s:10:\"1584560524\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.3\";s:7:\"version\";s:5:\"8.8.3\";s:3:\"tag\";s:5:\"8.8.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.3.tar.gz\";s:4:\"date\";s:10:\"1583347094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.2\";s:7:\"version\";s:5:\"8.8.2\";s:3:\"tag\";s:5:\"8.8.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.2.tar.gz\";s:4:\"date\";s:10:\"1580598849\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.1\";s:7:\"version\";s:5:\"8.8.1\";s:3:\"tag\";s:5:\"8.8.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.1.tar.gz\";s:4:\"date\";s:10:\"1576695785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.0\";s:7:\"version\";s:5:\"8.8.0\";s:3:\"tag\";s:5:\"8.8.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.0.tar.gz\";s:4:\"date\";s:10:\"1575450481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.8.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.8.0-rc1\";s:7:\"version\";s:9:\"8.8.0-rc1\";s:3:\"tag\";s:9:\"8.8.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.8.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1574462580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.8.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.8.0-beta1\";s:7:\"version\";s:11:\"8.8.0-beta1\";s:3:\"tag\";s:11:\"8.8.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.8.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1573256280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.8.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.8.0-alpha1\";s:7:\"version\";s:12:\"8.8.0-alpha1\";s:3:\"tag\";s:12:\"8.8.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.8.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571355784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.7.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.14\";s:7:\"version\";s:6:\"8.7.14\";s:3:\"tag\";s:6:\"8.7.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.14.tar.gz\";s:4:\"date\";s:10:\"1589988665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.13\";s:7:\"version\";s:6:\"8.7.13\";s:3:\"tag\";s:6:\"8.7.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.13.tar.gz\";s:4:\"date\";s:10:\"1585861883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.12\";s:7:\"version\";s:6:\"8.7.12\";s:3:\"tag\";s:6:\"8.7.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.12.tar.gz\";s:4:\"date\";s:10:\"1584552250\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.11\";s:7:\"version\";s:6:\"8.7.11\";s:3:\"tag\";s:6:\"8.7.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.11.tar.gz\";s:4:\"date\";s:10:\"1576695785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.10\";s:7:\"version\";s:6:\"8.7.10\";s:3:\"tag\";s:6:\"8.7.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.10.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.9\";s:7:\"version\";s:5:\"8.7.9\";s:3:\"tag\";s:5:\"8.7.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.9.tar.gz\";s:4:\"date\";s:10:\"1573063387\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.8\";s:7:\"version\";s:5:\"8.7.8\";s:3:\"tag\";s:5:\"8.7.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.8.tar.gz\";s:4:\"date\";s:10:\"1570044484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.7\";s:7:\"version\";s:5:\"8.7.7\";s:3:\"tag\";s:5:\"8.7.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.7.tar.gz\";s:4:\"date\";s:10:\"1567593185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.6\";s:7:\"version\";s:5:\"8.7.6\";s:3:\"tag\";s:5:\"8.7.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.6.tar.gz\";s:4:\"date\";s:10:\"1565206385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.5\";s:7:\"version\";s:5:\"8.7.5\";s:3:\"tag\";s:5:\"8.7.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.5.tar.gz\";s:4:\"date\";s:10:\"1563380885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.4\";s:7:\"version\";s:5:\"8.7.4\";s:3:\"tag\";s:5:\"8.7.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.4.tar.gz\";s:4:\"date\";s:10:\"1562225587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.3\";s:7:\"version\";s:5:\"8.7.3\";s:3:\"tag\";s:5:\"8.7.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.3.tar.gz\";s:4:\"date\";s:10:\"1559762581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.2\";s:7:\"version\";s:5:\"8.7.2\";s:3:\"tag\";s:5:\"8.7.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.2.tar.gz\";s:4:\"date\";s:10:\"1558597086\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.1\";s:7:\"version\";s:5:\"8.7.1\";s:3:\"tag\";s:5:\"8.7.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.1.tar.gz\";s:4:\"date\";s:10:\"1557335588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.0\";s:7:\"version\";s:5:\"8.7.0\";s:3:\"tag\";s:5:\"8.7.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.0.tar.gz\";s:4:\"date\";s:10:\"1556737085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.7.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.7.0-rc1\";s:7:\"version\";s:9:\"8.7.0-rc1\";s:3:\"tag\";s:9:\"8.7.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.7.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1555603385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.7.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.7.0-beta2\";s:7:\"version\";s:11:\"8.7.0-beta2\";s:3:\"tag\";s:11:\"8.7.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.7.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1554684784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.7.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.7.0-beta1\";s:7:\"version\";s:11:\"8.7.0-beta1\";s:3:\"tag\";s:11:\"8.7.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.7.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1553881681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.7.0-alpha2\";a:10:{s:4:\"name\";s:19:\"drupal 8.7.0-alpha2\";s:7:\"version\";s:12:\"8.7.0-alpha2\";s:3:\"tag\";s:12:\"8.7.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.7.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1553106180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:12:\"8.7.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.7.0-alpha1\";s:7:\"version\";s:12:\"8.7.0-alpha1\";s:3:\"tag\";s:12:\"8.7.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.7.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1552602484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.6.18\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.18\";s:7:\"version\";s:6:\"8.6.18\";s:3:\"tag\";s:6:\"8.6.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.18.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.17\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.17\";s:7:\"version\";s:6:\"8.6.17\";s:3:\"tag\";s:6:\"8.6.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.17.tar.gz\";s:4:\"date\";s:10:\"1560756785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.16\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.16\";s:7:\"version\";s:6:\"8.6.16\";s:3:\"tag\";s:6:\"8.6.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.16.tar.gz\";s:4:\"date\";s:10:\"1557335588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.15\";s:7:\"version\";s:6:\"8.6.15\";s:3:\"tag\";s:6:\"8.6.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.15.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.14\";s:7:\"version\";s:6:\"8.6.14\";s:3:\"tag\";s:6:\"8.6.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.14.tar.gz\";s:4:\"date\";s:10:\"1554688384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.13\";s:7:\"version\";s:6:\"8.6.13\";s:3:\"tag\";s:6:\"8.6.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.13.tar.gz\";s:4:\"date\";s:10:\"1553099584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.12\";s:7:\"version\";s:6:\"8.6.12\";s:3:\"tag\";s:6:\"8.6.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.12.tar.gz\";s:4:\"date\";s:10:\"1552601584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.11\";s:7:\"version\";s:6:\"8.6.11\";s:3:\"tag\";s:6:\"8.6.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.11.tar.gz\";s:4:\"date\";s:10:\"1552511584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.10\";s:7:\"version\";s:6:\"8.6.10\";s:3:\"tag\";s:6:\"8.6.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.10.tar.gz\";s:4:\"date\";s:10:\"1550691784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.9\";s:7:\"version\";s:5:\"8.6.9\";s:3:\"tag\";s:5:\"8.6.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.9.tar.gz\";s:4:\"date\";s:10:\"1549628580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.8\";s:7:\"version\";s:5:\"8.6.8\";s:3:\"tag\";s:5:\"8.6.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.8.tar.gz\";s:4:\"date\";s:10:\"1549466580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.7\";s:7:\"version\";s:5:\"8.6.7\";s:3:\"tag\";s:5:\"8.6.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.7.tar.gz\";s:4:\"date\";s:10:\"1547682180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.6\";s:7:\"version\";s:5:\"8.6.6\";s:3:\"tag\";s:5:\"8.6.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.6.tar.gz\";s:4:\"date\";s:10:\"1547663557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.5\";s:7:\"version\";s:5:\"8.6.5\";s:3:\"tag\";s:5:\"8.6.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.5.tar.gz\";s:4:\"date\";s:10:\"1546467485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.4\";s:7:\"version\";s:5:\"8.6.4\";s:3:\"tag\";s:5:\"8.6.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.4.tar.gz\";s:4:\"date\";s:10:\"1544011681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.3\";s:7:\"version\";s:5:\"8.6.3\";s:3:\"tag\";s:5:\"8.6.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.3.tar.gz\";s:4:\"date\";s:10:\"1541602684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.2\";s:7:\"version\";s:5:\"8.6.2\";s:3:\"tag\";s:5:\"8.6.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.2.tar.gz\";s:4:\"date\";s:10:\"1539816180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.1\";s:7:\"version\";s:5:\"8.6.1\";s:3:\"tag\";s:5:\"8.6.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.1.tar.gz\";s:4:\"date\";s:10:\"1536585780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.0\";s:7:\"version\";s:5:\"8.6.0\";s:3:\"tag\";s:5:\"8.6.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.0.tar.gz\";s:4:\"date\";s:10:\"1536186480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.6.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.6.0-rc1\";s:7:\"version\";s:9:\"8.6.0-rc1\";s:3:\"tag\";s:9:\"8.6.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.6.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1534532580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.6.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.6.0-beta2\";s:7:\"version\";s:11:\"8.6.0-beta2\";s:3:\"tag\";s:11:\"8.6.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.6.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1533298080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.6.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.6.0-beta1\";s:7:\"version\";s:11:\"8.6.0-beta1\";s:3:\"tag\";s:11:\"8.6.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.6.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1533270485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.6.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.6.0-alpha1\";s:7:\"version\";s:12:\"8.6.0-alpha1\";s:3:\"tag\";s:12:\"8.6.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.6.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1532033881\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.5.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.15\";s:7:\"version\";s:6:\"8.5.15\";s:3:\"tag\";s:6:\"8.5.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.15.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.14\";s:7:\"version\";s:6:\"8.5.14\";s:3:\"tag\";s:6:\"8.5.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.14.tar.gz\";s:4:\"date\";s:10:\"1553099584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.13\";s:7:\"version\";s:6:\"8.5.13\";s:3:\"tag\";s:6:\"8.5.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.13.tar.gz\";s:4:\"date\";s:10:\"1552601584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.12\";s:7:\"version\";s:6:\"8.5.12\";s:3:\"tag\";s:6:\"8.5.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.12.tar.gz\";s:4:\"date\";s:10:\"1552511584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.11\";s:7:\"version\";s:6:\"8.5.11\";s:3:\"tag\";s:6:\"8.5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.11.tar.gz\";s:4:\"date\";s:10:\"1550691784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.10\";s:7:\"version\";s:6:\"8.5.10\";s:3:\"tag\";s:6:\"8.5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.10.tar.gz\";s:4:\"date\";s:10:\"1547682180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.9\";s:7:\"version\";s:5:\"8.5.9\";s:3:\"tag\";s:5:\"8.5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.9.tar.gz\";s:4:\"date\";s:10:\"1547663557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.8\";s:7:\"version\";s:5:\"8.5.8\";s:3:\"tag\";s:5:\"8.5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.8.tar.gz\";s:4:\"date\";s:10:\"1539816180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.7\";s:7:\"version\";s:5:\"8.5.7\";s:3:\"tag\";s:5:\"8.5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.7.tar.gz\";s:4:\"date\";s:10:\"1536187080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.6\";s:7:\"version\";s:5:\"8.5.6\";s:3:\"tag\";s:5:\"8.5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.6.tar.gz\";s:4:\"date\";s:10:\"1533156780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.5\";s:7:\"version\";s:5:\"8.5.5\";s:3:\"tag\";s:5:\"8.5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.5.tar.gz\";s:4:\"date\";s:10:\"1530738820\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.4\";s:7:\"version\";s:5:\"8.5.4\";s:3:\"tag\";s:5:\"8.5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.4.tar.gz\";s:4:\"date\";s:10:\"1528319584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.3\";s:7:\"version\";s:5:\"8.5.3\";s:3:\"tag\";s:5:\"8.5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.3.tar.gz\";s:4:\"date\";s:10:\"1524672780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.2\";s:7:\"version\";s:5:\"8.5.2\";s:3:\"tag\";s:5:\"8.5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.2.tar.gz\";s:4:\"date\";s:10:\"1524073147\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.1\";s:7:\"version\";s:5:\"8.5.1\";s:3:\"tag\";s:5:\"8.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.1.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.0\";s:7:\"version\";s:5:\"8.5.0\";s:3:\"tag\";s:5:\"8.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.0.tar.gz\";s:4:\"date\";s:10:\"1520457780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.5.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.5.0-rc1\";s:7:\"version\";s:9:\"8.5.0-rc1\";s:3:\"tag\";s:9:\"8.5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.5.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1519234680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";i:2;s:9:\"Bug fixes\";i:3;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.5.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.5.0-beta1\";s:7:\"version\";s:11:\"8.5.0-beta1\";s:3:\"tag\";s:11:\"8.5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.5.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1518211380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.5.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.5.0-alpha1\";s:7:\"version\";s:12:\"8.5.0-alpha1\";s:3:\"tag\";s:12:\"8.5.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.5.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1516320484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.4.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.8\";s:7:\"version\";s:5:\"8.4.8\";s:3:\"tag\";s:5:\"8.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.8.tar.gz\";s:4:\"date\";s:10:\"1524672780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.7\";s:7:\"version\";s:5:\"8.4.7\";s:3:\"tag\";s:5:\"8.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.7.tar.gz\";s:4:\"date\";s:10:\"1524073147\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.6\";s:7:\"version\";s:5:\"8.4.6\";s:3:\"tag\";s:5:\"8.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.6.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.5\";s:7:\"version\";s:5:\"8.4.5\";s:3:\"tag\";s:5:\"8.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.5.tar.gz\";s:4:\"date\";s:10:\"1519234680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.4\";s:7:\"version\";s:5:\"8.4.4\";s:3:\"tag\";s:5:\"8.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.4.tar.gz\";s:4:\"date\";s:10:\"1515021185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.3\";s:7:\"version\";s:5:\"8.4.3\";s:3:\"tag\";s:5:\"8.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.3.tar.gz\";s:4:\"date\";s:10:\"1512600784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.2\";s:7:\"version\";s:5:\"8.4.2\";s:3:\"tag\";s:5:\"8.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.2.tar.gz\";s:4:\"date\";s:10:\"1509719885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.1\";s:7:\"version\";s:5:\"8.4.1\";s:3:\"tag\";s:5:\"8.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.1.tar.gz\";s:4:\"date\";s:10:\"1509562384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.0\";s:7:\"version\";s:5:\"8.4.0\";s:3:\"tag\";s:5:\"8.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.0.tar.gz\";s:4:\"date\";s:10:\"1507146244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.4.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.0-rc2\";s:7:\"version\";s:9:\"8.4.0-rc2\";s:3:\"tag\";s:9:\"8.4.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1505911444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.4.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.0-rc1\";s:7:\"version\";s:9:\"8.4.0-rc1\";s:3:\"tag\";s:9:\"8.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1504733043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.4.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.4.0-beta1\";s:7:\"version\";s:11:\"8.4.0-beta1\";s:3:\"tag\";s:11:\"8.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.4.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1502992144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.4.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.4.0-alpha1\";s:7:\"version\";s:12:\"8.4.0-alpha1\";s:3:\"tag\";s:12:\"8.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.4.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1501790944\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.3.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.9\";s:7:\"version\";s:5:\"8.3.9\";s:3:\"tag\";s:5:\"8.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.9.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.8\";s:7:\"version\";s:5:\"8.3.8\";s:3:\"tag\";s:5:\"8.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.8.tar.gz\";s:4:\"date\";s:10:\"1520881985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";i:2;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.7\";s:7:\"version\";s:5:\"8.3.7\";s:3:\"tag\";s:5:\"8.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.7.tar.gz\";s:4:\"date\";s:10:\"1502903903\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.6\";s:7:\"version\";s:5:\"8.3.6\";s:3:\"tag\";s:5:\"8.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.6.tar.gz\";s:4:\"date\";s:10:\"1501688043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.5\";s:7:\"version\";s:5:\"8.3.5\";s:3:\"tag\";s:5:\"8.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.5.tar.gz\";s:4:\"date\";s:10:\"1499274843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.4\";s:7:\"version\";s:5:\"8.3.4\";s:3:\"tag\";s:5:\"8.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.4.tar.gz\";s:4:\"date\";s:10:\"1498069442\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.3\";s:7:\"version\";s:5:\"8.3.3\";s:3:\"tag\";s:5:\"8.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.3.tar.gz\";s:4:\"date\";s:10:\"1496858041\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.2\";s:7:\"version\";s:5:\"8.3.2\";s:3:\"tag\";s:5:\"8.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.2.tar.gz\";s:4:\"date\";s:10:\"1493834585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.1\";s:7:\"version\";s:5:\"8.3.1\";s:3:\"tag\";s:5:\"8.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.1.tar.gz\";s:4:\"date\";s:10:\"1492622946\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.0\";s:7:\"version\";s:5:\"8.3.0\";s:3:\"tag\";s:5:\"8.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.0.tar.gz\";s:4:\"date\";s:10:\"1491439084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.3.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.0-rc2\";s:7:\"version\";s:9:\"8.3.0-rc2\";s:3:\"tag\";s:9:\"8.3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1489613583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.3.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.0-rc1\";s:7:\"version\";s:9:\"8.3.0-rc1\";s:3:\"tag\";s:9:\"8.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1488383284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.3.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.3.0-beta1\";s:7:\"version\";s:11:\"8.3.0-beta1\";s:3:\"tag\";s:11:\"8.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.3.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1487175783\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.3.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.3.0-alpha1\";s:7:\"version\";s:12:\"8.3.0-alpha1\";s:3:\"tag\";s:12:\"8.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.3.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1485968583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.2.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.8\";s:7:\"version\";s:5:\"8.2.8\";s:3:\"tag\";s:5:\"8.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.8.tar.gz\";s:4:\"date\";s:10:\"1492622852\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.7\";s:7:\"version\";s:5:\"8.2.7\";s:3:\"tag\";s:5:\"8.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.7.tar.gz\";s:4:\"date\";s:10:\"1489609638\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.6\";s:7:\"version\";s:5:\"8.2.6\";s:3:\"tag\";s:5:\"8.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.6.tar.gz\";s:4:\"date\";s:10:\"1485975485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.5\";s:7:\"version\";s:5:\"8.2.5\";s:3:\"tag\";s:5:\"8.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.5.tar.gz\";s:4:\"date\";s:10:\"1483529942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.4\";s:7:\"version\";s:5:\"8.2.4\";s:3:\"tag\";s:5:\"8.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.4.tar.gz\";s:4:\"date\";s:10:\"1481136784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.3\";s:7:\"version\";s:5:\"8.2.3\";s:3:\"tag\";s:5:\"8.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.3.tar.gz\";s:4:\"date\";s:10:\"1479322439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.2\";s:7:\"version\";s:5:\"8.2.2\";s:3:\"tag\";s:5:\"8.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.2.tar.gz\";s:4:\"date\";s:10:\"1478106542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.1\";s:7:\"version\";s:5:\"8.2.1\";s:3:\"tag\";s:5:\"8.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.1.tar.gz\";s:4:\"date\";s:10:\"1476181439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.0\";s:7:\"version\";s:5:\"8.2.0\";s:3:\"tag\";s:5:\"8.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.0.tar.gz\";s:4:\"date\";s:10:\"1475660639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.2.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.0-rc2\";s:7:\"version\";s:9:\"8.2.0-rc2\";s:3:\"tag\";s:9:\"8.2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1474484358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.2.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.0-rc1\";s:7:\"version\";s:9:\"8.2.0-rc1\";s:3:\"tag\";s:9:\"8.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1473285089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta3\";s:7:\"version\";s:11:\"8.2.0-beta3\";s:3:\"tag\";s:11:\"8.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1472222475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta2\";s:7:\"version\";s:11:\"8.2.0-beta2\";s:3:\"tag\";s:11:\"8.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1471710839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta1\";s:7:\"version\";s:11:\"8.2.0-beta1\";s:3:\"tag\";s:11:\"8.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1470230639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"8.1.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.1.10\";s:7:\"version\";s:6:\"8.1.10\";s:3:\"tag\";s:6:\"8.1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.1.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.1.10.tar.gz\";s:4:\"date\";s:10:\"1474478939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.9\";s:7:\"version\";s:5:\"8.1.9\";s:3:\"tag\";s:5:\"8.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.9.tar.gz\";s:4:\"date\";s:10:\"1473276313\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.8\";s:7:\"version\";s:5:\"8.1.8\";s:3:\"tag\";s:5:\"8.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.8.tar.gz\";s:4:\"date\";s:10:\"1470233647\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.7\";s:7:\"version\";s:5:\"8.1.7\";s:3:\"tag\";s:5:\"8.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.7.tar.gz\";s:4:\"date\";s:10:\"1468855358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.6\";s:7:\"version\";s:5:\"8.1.6\";s:3:\"tag\";s:5:\"8.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.6.tar.gz\";s:4:\"date\";s:10:\"1468242539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.5\";s:7:\"version\";s:5:\"8.1.5\";s:3:\"tag\";s:5:\"8.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.5.tar.gz\";s:4:\"date\";s:10:\"1467884639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.4\";s:7:\"version\";s:5:\"8.1.4\";s:3:\"tag\";s:5:\"8.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.4.tar.gz\";s:4:\"date\";s:10:\"1467810839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.3\";s:7:\"version\";s:5:\"8.1.3\";s:3:\"tag\";s:5:\"8.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.3.tar.gz\";s:4:\"date\";s:10:\"1466021480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.2\";s:7:\"version\";s:5:\"8.1.2\";s:3:\"tag\";s:5:\"8.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.2.tar.gz\";s:4:\"date\";s:10:\"1464824339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.1\";s:7:\"version\";s:5:\"8.1.1\";s:3:\"tag\";s:5:\"8.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.1.tar.gz\";s:4:\"date\";s:10:\"1462361039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.0\";s:7:\"version\";s:5:\"8.1.0\";s:3:\"tag\";s:5:\"8.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.0.tar.gz\";s:4:\"date\";s:10:\"1461118190\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.1.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.1.0-rc1\";s:7:\"version\";s:9:\"8.1.0-rc1\";s:3:\"tag\";s:9:\"8.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1459976639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.1.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.1.0-beta2\";s:7:\"version\";s:11:\"8.1.0-beta2\";s:3:\"tag\";s:11:\"8.1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.1.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1458699840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.1.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.1.0-beta1\";s:7:\"version\";s:11:\"8.1.0-beta1\";s:3:\"tag\";s:11:\"8.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1456975758\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:5:\"8.0.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.6\";s:7:\"version\";s:5:\"8.0.6\";s:3:\"tag\";s:5:\"8.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.6.tar.gz\";s:4:\"date\";s:10:\"1459900439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.5\";s:7:\"version\";s:5:\"8.0.5\";s:3:\"tag\";s:5:\"8.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.5.tar.gz\";s:4:\"date\";s:10:\"1456914839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.4\";s:7:\"version\";s:5:\"8.0.4\";s:3:\"tag\";s:5:\"8.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.4.tar.gz\";s:4:\"date\";s:10:\"1456341749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.3\";s:7:\"version\";s:5:\"8.0.3\";s:3:\"tag\";s:5:\"8.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.3.tar.gz\";s:4:\"date\";s:10:\"1454489043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.2\";s:7:\"version\";s:5:\"8.0.2\";s:3:\"tag\";s:5:\"8.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.2.tar.gz\";s:4:\"date\";s:10:\"1452119939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.1\";s:7:\"version\";s:5:\"8.0.1\";s:3:\"tag\";s:5:\"8.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.1.tar.gz\";s:4:\"date\";s:10:\"1449066839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.0\";s:7:\"version\";s:5:\"8.0.0\";s:3:\"tag\";s:5:\"8.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.0.tar.gz\";s:4:\"date\";s:10:\"1447941840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.0.0-rc4\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc4\";s:7:\"version\";s:9:\"8.0.0-rc4\";s:3:\"tag\";s:9:\"8.0.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447413840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc3\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc3\";s:7:\"version\";s:9:\"8.0.0-rc3\";s:3:\"tag\";s:9:\"8.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1446633239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc2\";s:7:\"version\";s:9:\"8.0.0-rc2\";s:3:\"tag\";s:9:\"8.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1445468639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc1\";s:7:\"version\";s:9:\"8.0.0-rc1\";s:3:\"tag\";s:9:\"8.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1444253039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta16\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta16\";s:7:\"version\";s:12:\"8.0.0-beta16\";s:3:\"tag\";s:12:\"8.0.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1443746640\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta15\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta15\";s:7:\"version\";s:12:\"8.0.0-beta15\";s:3:\"tag\";s:12:\"8.0.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1441357140\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta14\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta14\";s:7:\"version\";s:12:\"8.0.0-beta14\";s:3:\"tag\";s:12:\"8.0.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1438593539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta13\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta13\";s:7:\"version\";s:12:\"8.0.0-beta13\";s:3:\"tag\";s:12:\"8.0.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1438194539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta12\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta12\";s:7:\"version\";s:12:\"8.0.0-beta12\";s:3:\"tag\";s:12:\"8.0.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1435601583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta11\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta11\";s:7:\"version\";s:12:\"8.0.0-beta11\";s:3:\"tag\";s:12:\"8.0.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1432758481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta10\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta10\";s:7:\"version\";s:12:\"8.0.0-beta10\";s:3:\"tag\";s:12:\"8.0.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1430314681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta9\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta9\";s:7:\"version\";s:11:\"8.0.0-beta9\";s:3:\"tag\";s:11:\"8.0.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1427299981\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta7\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta7\";s:7:\"version\";s:11:\"8.0.0-beta7\";s:3:\"tag\";s:11:\"8.0.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1424875381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta6\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta6\";s:7:\"version\";s:11:\"8.0.0-beta6\";s:3:\"tag\";s:11:\"8.0.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1422443800\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta4\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta4\";s:7:\"version\";s:11:\"8.0.0-beta4\";s:3:\"tag\";s:11:\"8.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1418825280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta3\";s:7:\"version\";s:11:\"8.0.0-beta3\";s:3:\"tag\";s:11:\"8.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1415797380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta2\";s:7:\"version\";s:11:\"8.0.0-beta2\";s:3:\"tag\";s:11:\"8.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1413394161\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta1\";s:7:\"version\";s:11:\"8.0.0-beta1\";s:3:\"tag\";s:11:\"8.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1412147030\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"8.0.0-alpha15\";a:10:{s:4:\"name\";s:20:\"drupal 8.0.0-alpha15\";s:7:\"version\";s:13:\"8.0.0-alpha15\";s:3:\"tag\";s:13:\"8.0.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/8.0.0-alpha15\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1411139628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"8.0.0-alpha14\";a:10:{s:4:\"name\";s:20:\"drupal 8.0.0-alpha14\";s:7:\"version\";s:13:\"8.0.0-alpha14\";s:3:\"tag\";s:13:\"8.0.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/8.0.0-alpha14\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1407344628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha13\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha13\";s:7:\"version\";s:11:\"8.0-alpha13\";s:3:\"tag\";s:11:\"8.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha13\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1404296627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha12\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha12\";s:7:\"version\";s:11:\"8.0-alpha12\";s:3:\"tag\";s:11:\"8.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha12\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1401293627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha11\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha11\";s:7:\"version\";s:11:\"8.0-alpha11\";s:3:\"tag\";s:11:\"8.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha11\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1398249227\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha10\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha10\";s:7:\"version\";s:11:\"8.0-alpha10\";s:3:\"tag\";s:11:\"8.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha10\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1395231556\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha9\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha9\";s:7:\"version\";s:10:\"8.0-alpha9\";s:3:\"tag\";s:10:\"8.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha9\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1392806005\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha8\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha8\";s:7:\"version\";s:10:\"8.0-alpha8\";s:3:\"tag\";s:10:\"8.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha8\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1390393105\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha7\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha7\";s:7:\"version\";s:10:\"8.0-alpha7\";s:3:\"tag\";s:10:\"8.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1387399705\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha6\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha6\";s:7:\"version\";s:10:\"8.0-alpha6\";s:3:\"tag\";s:10:\"8.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1385153305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha5\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha5\";s:7:\"version\";s:10:\"8.0-alpha5\";s:3:\"tag\";s:10:\"8.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1384850305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha4\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha4\";s:7:\"version\";s:10:\"8.0-alpha4\";s:3:\"tag\";s:10:\"8.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1382092313\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:12:\"New features\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha3\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha3\";s:7:\"version\";s:10:\"8.0-alpha3\";s:3:\"tag\";s:10:\"8.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1378303307\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:12:\"New features\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha2\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha2\";s:7:\"version\";s:10:\"8.0-alpha2\";s:3:\"tag\";s:10:\"8.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1372069563\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"11.1.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 11.1.x-dev\";s:7:\"version\";s:10:\"11.1.x-dev\";s:3:\"tag\";s:6:\"11.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743768287\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"11.0.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 11.0.x-dev\";s:7:\"version\";s:10:\"11.0.x-dev\";s:3:\"tag\";s:6:\"11.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743629939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:8:\"11.x-dev\";a:10:{s:4:\"name\";s:15:\"drupal 11.x-dev\";s:7:\"version\";s:8:\"11.x-dev\";s:3:\"tag\";s:4:\"11.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/drupal/releases/11.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/drupal-11.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743775197\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:10:\"10.5.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.5.x-dev\";s:7:\"version\";s:10:\"10.5.x-dev\";s:3:\"tag\";s:6:\"10.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.5.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743767885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.4.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.4.x-dev\";s:7:\"version\";s:10:\"10.4.x-dev\";s:3:\"tag\";s:6:\"10.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.4.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743768714\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.3.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.3.x-dev\";s:7:\"version\";s:10:\"10.3.x-dev\";s:3:\"tag\";s:6:\"10.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1738800218\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.2.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.2.x-dev\";s:7:\"version\";s:10:\"10.2.x-dev\";s:3:\"tag\";s:6:\"10.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.2.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1732287023\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.1.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.1.x-dev\";s:7:\"version\";s:10:\"10.1.x-dev\";s:3:\"tag\";s:6:\"10.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713001795\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.0.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.x-dev\";s:7:\"version\";s:10:\"10.0.x-dev\";s:3:\"tag\";s:6:\"10.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1696930730\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"9.5.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.x-dev\";s:7:\"version\";s:9:\"9.5.x-dev\";s:3:\"tag\";s:5:\"9.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1701801362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.4.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.x-dev\";s:7:\"version\";s:9:\"9.4.x-dev\";s:3:\"tag\";s:5:\"9.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1683123227\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.3.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.3.x-dev\";s:7:\"version\";s:9:\"9.3.x-dev\";s:3:\"tag\";s:5:\"9.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.3.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1664385919\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"9.2.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.2.x-dev\";s:7:\"version\";s:9:\"9.2.x-dev\";s:3:\"tag\";s:5:\"9.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.2.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1654891907\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.1.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.x-dev\";s:7:\"version\";s:9:\"9.1.x-dev\";s:3:\"tag\";s:5:\"9.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1637766277\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.0.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.0.x-dev\";s:7:\"version\";s:9:\"9.0.x-dev\";s:3:\"tag\";s:5:\"9.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1622063424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.9.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.9.x-dev\";s:7:\"version\";s:9:\"8.9.x-dev\";s:3:\"tag\";s:5:\"8.9.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.9.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.9.x-dev.tar.gz\";s:4:\"date\";s:10:\"1637188625\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.8.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.8.x-dev\";s:7:\"version\";s:9:\"8.8.x-dev\";s:3:\"tag\";s:5:\"8.8.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.8.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.8.x-dev.tar.gz\";s:4:\"date\";s:10:\"1606364994\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.7.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.7.x-dev\";s:7:\"version\";s:9:\"8.7.x-dev\";s:3:\"tag\";s:5:\"8.7.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.7.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.7.x-dev.tar.gz\";s:4:\"date\";s:10:\"1589987612\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.6.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.6.x-dev\";s:7:\"version\";s:9:\"8.6.x-dev\";s:3:\"tag\";s:5:\"8.6.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.6.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.6.x-dev.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.5.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.5.x-dev\";s:7:\"version\";s:9:\"8.5.x-dev\";s:3:\"tag\";s:5:\"8.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.5.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.4.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.x-dev\";s:7:\"version\";s:9:\"8.4.x-dev\";s:3:\"tag\";s:5:\"8.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1533047880\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.3.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.x-dev\";s:7:\"version\";s:9:\"8.3.x-dev\";s:3:\"tag\";s:5:\"8.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.2.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.x-dev\";s:7:\"version\";s:9:\"8.2.x-dev\";s:3:\"tag\";s:5:\"8.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1492624982\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.1.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.1.x-dev\";s:7:\"version\";s:9:\"8.1.x-dev\";s:3:\"tag\";s:5:\"8.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1474478393\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.0.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.x-dev\";s:7:\"version\";s:9:\"8.0.x-dev\";s:3:\"tag\";s:5:\"8.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1459900439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}}s:10:\"last_fetch\";i:1743932015;}',1744018415),('update_available_releases','fast_distribution',_binary 'a:9:{s:5:\"title\";s:17:\"Fast Distribution\";s:10:\"short_name\";s:17:\"fast_distribution\";s:4:\"type\";s:20:\"project_distribution\";s:18:\"supported_branches\";s:4:\"1.0.\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/fast_distribution\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:4:{s:5:\"1.0.1\";a:10:{s:4:\"name\";s:23:\"fast_distribution 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/fast_distribution/releases/1.0.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/fast_distribution-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1729499892\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:5:\"terms\";a:0:{}}s:5:\"1.0.0\";a:10:{s:4:\"name\";s:23:\"fast_distribution 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/fast_distribution/releases/1.0.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/fast_distribution-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1729147157\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:5:\"terms\";a:0:{}}s:12:\"1.0.0-alpha1\";a:10:{s:4:\"name\";s:30:\"fast_distribution 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/fast_distribution/releases/1.0.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/fast_distribution-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1723406511\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"1.0.x-dev\";a:10:{s:4:\"name\";s:27:\"fast_distribution 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/fast_distribution/releases/1.0.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/fast_distribution-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1729499739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932020;}',1744018420),('update_available_releases','field_group',_binary 'a:10:{s:5:\"title\";s:11:\"Field Group\";s:10:\"short_name\";s:11:\"field_group\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"4.0.,8.x-3.\";s:18:\"composer_namespace\";s:18:\"drupal/field_group\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/field_group\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:19:{s:12:\"4.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"field_group 4.0.0-alpha1\";s:7:\"version\";s:12:\"4.0.0-alpha1\";s:3:\"tag\";s:12:\"4.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/field_group/releases/4.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/field_group-4.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1725952813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:7:\"8.x-3.6\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1722672510\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-3.5\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.5\";s:7:\"version\";s:7:\"8.x-3.5\";s:3:\"tag\";s:7:\"8.x-3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.5.tar.gz\";s:4:\"date\";s:10:\"1722630494\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-3.4\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.4\";s:7:\"version\";s:7:\"8.x-3.4\";s:3:\"tag\";s:7:\"8.x-3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.4.tar.gz\";s:4:\"date\";s:10:\"1667241979\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1663516404\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1628513585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1591772567\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1580250787\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1574200085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1558647185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:25:\"field_group 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1510352284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1510352885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1480365484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1480288380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1449771240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1447385940\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"4.x-dev\";a:11:{s:4:\"name\";s:19:\"field_group 4.x-dev\";s:7:\"version\";s:7:\"4.x-dev\";s:3:\"tag\";s:3:\"4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1739471423\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1739379201\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1570214888\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','gin',_binary 'a:10:{s:5:\"title\";s:15:\"Gin Admin Theme\";s:10:\"short_name\";s:3:\"gin\";s:4:\"type\";s:13:\"project_theme\";s:18:\"supported_branches\";s:11:\"4.0.,8.x-3.\";s:18:\"composer_namespace\";s:10:\"drupal/gin\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:34:\"https://www.drupal.org/project/gin\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:97:{s:5:\"4.0.6\";a:11:{s:4:\"name\";s:9:\"gin 4.0.6\";s:7:\"version\";s:5:\"4.0.6\";s:3:\"tag\";s:5:\"4.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.6\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.6.tar.gz\";s:4:\"date\";s:10:\"1740738970\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"4.0.5\";a:11:{s:4:\"name\";s:9:\"gin 4.0.5\";s:7:\"version\";s:5:\"4.0.5\";s:3:\"tag\";s:5:\"4.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.5\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.5.tar.gz\";s:4:\"date\";s:10:\"1739910568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"4.0.4\";a:11:{s:4:\"name\";s:9:\"gin 4.0.4\";s:7:\"version\";s:5:\"4.0.4\";s:3:\"tag\";s:5:\"4.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.4\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.4.tar.gz\";s:4:\"date\";s:10:\"1739529351\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"4.0.3\";a:11:{s:4:\"name\";s:9:\"gin 4.0.3\";s:7:\"version\";s:5:\"4.0.3\";s:3:\"tag\";s:5:\"4.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.3\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.3.tar.gz\";s:4:\"date\";s:10:\"1739275576\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"4.0.2\";a:11:{s:4:\"name\";s:9:\"gin 4.0.2\";s:7:\"version\";s:5:\"4.0.2\";s:3:\"tag\";s:5:\"4.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.2\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.2.tar.gz\";s:4:\"date\";s:10:\"1735404747\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"4.0.1\";a:11:{s:4:\"name\";s:9:\"gin 4.0.1\";s:7:\"version\";s:5:\"4.0.1\";s:3:\"tag\";s:5:\"4.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.1\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.1.tar.gz\";s:4:\"date\";s:10:\"1735326747\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"4.0.0\";a:11:{s:4:\"name\";s:9:\"gin 4.0.0\";s:7:\"version\";s:5:\"4.0.0\";s:3:\"tag\";s:5:\"4.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:49:\"https://www.drupal.org/project/gin/releases/4.0.0\";s:13:\"download_link\";s:54:\"https://ftp.drupal.org/files/projects/gin-4.0.0.tar.gz\";s:4:\"date\";s:10:\"1734696940\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:11:\"gin 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:51:\"https://www.drupal.org/project/gin/releases/8.x-3.0\";s:13:\"download_link\";s:56:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1734696845\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc16\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc16\";s:7:\"version\";s:12:\"8.x-3.0-rc16\";s:3:\"tag\";s:12:\"8.x-3.0-rc16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc16\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc16.tar.gz\";s:4:\"date\";s:10:\"1734527306\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc15\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc15\";s:7:\"version\";s:12:\"8.x-3.0-rc15\";s:3:\"tag\";s:12:\"8.x-3.0-rc15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc15\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc15.tar.gz\";s:4:\"date\";s:10:\"1733734246\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc14\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc14\";s:7:\"version\";s:12:\"8.x-3.0-rc14\";s:3:\"tag\";s:12:\"8.x-3.0-rc14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc14\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc14.tar.gz\";s:4:\"date\";s:10:\"1731015952\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc13\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc13\";s:7:\"version\";s:12:\"8.x-3.0-rc13\";s:3:\"tag\";s:12:\"8.x-3.0-rc13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc13.tar.gz\";s:4:\"date\";s:10:\"1720416342\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc12\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc12\";s:7:\"version\";s:12:\"8.x-3.0-rc12\";s:3:\"tag\";s:12:\"8.x-3.0-rc12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc12.tar.gz\";s:4:\"date\";s:10:\"1719568767\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc11\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc11\";s:7:\"version\";s:12:\"8.x-3.0-rc11\";s:3:\"tag\";s:12:\"8.x-3.0-rc11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc11.tar.gz\";s:4:\"date\";s:10:\"1718351205\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc10\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc10\";s:7:\"version\";s:12:\"8.x-3.0-rc10\";s:3:\"tag\";s:12:\"8.x-3.0-rc10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc10.tar.gz\";s:4:\"date\";s:10:\"1712686345\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc9\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc9\";s:7:\"version\";s:11:\"8.x-3.0-rc9\";s:3:\"tag\";s:11:\"8.x-3.0-rc9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc9.tar.gz\";s:4:\"date\";s:10:\"1706705034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc8\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc8\";s:7:\"version\";s:11:\"8.x-3.0-rc8\";s:3:\"tag\";s:11:\"8.x-3.0-rc8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc8.tar.gz\";s:4:\"date\";s:10:\"1702729136\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc7\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc7\";s:7:\"version\";s:11:\"8.x-3.0-rc7\";s:3:\"tag\";s:11:\"8.x-3.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1697193234\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc6\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc6\";s:7:\"version\";s:11:\"8.x-3.0-rc6\";s:3:\"tag\";s:11:\"8.x-3.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1693299666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc5\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc5\";s:7:\"version\";s:11:\"8.x-3.0-rc5\";s:3:\"tag\";s:11:\"8.x-3.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1689504430\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc4\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc4\";s:7:\"version\";s:11:\"8.x-3.0-rc4\";s:3:\"tag\";s:11:\"8.x-3.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1688474317\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc3\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc3\";s:7:\"version\";s:11:\"8.x-3.0-rc3\";s:3:\"tag\";s:11:\"8.x-3.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1682979025\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1678627668\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1669666691\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta5\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta5\";s:7:\"version\";s:13:\"8.x-3.0-beta5\";s:3:\"tag\";s:13:\"8.x-3.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1656068146\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta4\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta4\";s:7:\"version\";s:13:\"8.x-3.0-beta4\";s:3:\"tag\";s:13:\"8.x-3.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1656062400\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta3\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta3\";s:7:\"version\";s:13:\"8.x-3.0-beta3\";s:3:\"tag\";s:13:\"8.x-3.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1653469869\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta2\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta2\";s:7:\"version\";s:13:\"8.x-3.0-beta2\";s:3:\"tag\";s:13:\"8.x-3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1649709347\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1646929485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:15:\"8.x-3.0-alpha37\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha37\";s:7:\"version\";s:15:\"8.x-3.0-alpha37\";s:3:\"tag\";s:15:\"8.x-3.0-alpha37\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha37\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha37.tar.gz\";s:4:\"date\";s:10:\"1632767973\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:15:\"8.x-3.0-alpha36\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha36\";s:7:\"version\";s:15:\"8.x-3.0-alpha36\";s:3:\"tag\";s:15:\"8.x-3.0-alpha36\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha36\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha36.tar.gz\";s:4:\"date\";s:10:\"1625232222\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha35\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha35\";s:7:\"version\";s:15:\"8.x-3.0-alpha35\";s:3:\"tag\";s:15:\"8.x-3.0-alpha35\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha35\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha35.tar.gz\";s:4:\"date\";s:10:\"1622412154\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha34\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha34\";s:7:\"version\";s:15:\"8.x-3.0-alpha34\";s:3:\"tag\";s:15:\"8.x-3.0-alpha34\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha34\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha34.tar.gz\";s:4:\"date\";s:10:\"1620394439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha33\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha33\";s:7:\"version\";s:15:\"8.x-3.0-alpha33\";s:3:\"tag\";s:15:\"8.x-3.0-alpha33\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha33\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha33.tar.gz\";s:4:\"date\";s:10:\"1611172829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha32\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha32\";s:7:\"version\";s:15:\"8.x-3.0-alpha32\";s:3:\"tag\";s:15:\"8.x-3.0-alpha32\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha32\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha32.tar.gz\";s:4:\"date\";s:10:\"1607370374\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha31\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha31\";s:7:\"version\";s:15:\"8.x-3.0-alpha31\";s:3:\"tag\";s:15:\"8.x-3.0-alpha31\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha31\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha31.tar.gz\";s:4:\"date\";s:10:\"1606944288\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha30\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha30\";s:7:\"version\";s:15:\"8.x-3.0-alpha30\";s:3:\"tag\";s:15:\"8.x-3.0-alpha30\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha30\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha30.tar.gz\";s:4:\"date\";s:10:\"1605395013\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha29\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha29\";s:7:\"version\";s:15:\"8.x-3.0-alpha29\";s:3:\"tag\";s:15:\"8.x-3.0-alpha29\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha29\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha29.tar.gz\";s:4:\"date\";s:10:\"1605375202\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha28\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha28\";s:7:\"version\";s:15:\"8.x-3.0-alpha28\";s:3:\"tag\";s:15:\"8.x-3.0-alpha28\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha28\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha28.tar.gz\";s:4:\"date\";s:10:\"1604868112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha27\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha27\";s:7:\"version\";s:15:\"8.x-3.0-alpha27\";s:3:\"tag\";s:15:\"8.x-3.0-alpha27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha27\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha27.tar.gz\";s:4:\"date\";s:10:\"1601291419\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha26\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha26\";s:7:\"version\";s:15:\"8.x-3.0-alpha26\";s:3:\"tag\";s:15:\"8.x-3.0-alpha26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha26\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha26.tar.gz\";s:4:\"date\";s:10:\"1598863786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha25\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha25\";s:7:\"version\";s:15:\"8.x-3.0-alpha25\";s:3:\"tag\";s:15:\"8.x-3.0-alpha25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha25\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha25.tar.gz\";s:4:\"date\";s:10:\"1597406186\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha24\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha24\";s:7:\"version\";s:15:\"8.x-3.0-alpha24\";s:3:\"tag\";s:15:\"8.x-3.0-alpha24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha24\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha24.tar.gz\";s:4:\"date\";s:10:\"1595854343\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha23\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha23\";s:7:\"version\";s:15:\"8.x-3.0-alpha23\";s:3:\"tag\";s:15:\"8.x-3.0-alpha23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha23\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha23.tar.gz\";s:4:\"date\";s:10:\"1594643695\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha22\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha22\";s:7:\"version\";s:15:\"8.x-3.0-alpha22\";s:3:\"tag\";s:15:\"8.x-3.0-alpha22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha22\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha22.tar.gz\";s:4:\"date\";s:10:\"1593766525\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha21\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha21\";s:7:\"version\";s:15:\"8.x-3.0-alpha21\";s:3:\"tag\";s:15:\"8.x-3.0-alpha21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha21\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha21.tar.gz\";s:4:\"date\";s:10:\"1593461879\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha20\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha20\";s:7:\"version\";s:15:\"8.x-3.0-alpha20\";s:3:\"tag\";s:15:\"8.x-3.0-alpha20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha20\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha20.tar.gz\";s:4:\"date\";s:10:\"1592855613\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha19\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha19\";s:7:\"version\";s:15:\"8.x-3.0-alpha19\";s:3:\"tag\";s:15:\"8.x-3.0-alpha19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha19\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha19.tar.gz\";s:4:\"date\";s:10:\"1592580886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha18\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha18\";s:7:\"version\";s:15:\"8.x-3.0-alpha18\";s:3:\"tag\";s:15:\"8.x-3.0-alpha18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha18\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha18.tar.gz\";s:4:\"date\";s:10:\"1592169349\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha17\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha17\";s:7:\"version\";s:15:\"8.x-3.0-alpha17\";s:3:\"tag\";s:15:\"8.x-3.0-alpha17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha17\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha17.tar.gz\";s:4:\"date\";s:10:\"1591349946\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:15:\"8.x-3.0-alpha16\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha16\";s:7:\"version\";s:15:\"8.x-3.0-alpha16\";s:3:\"tag\";s:15:\"8.x-3.0-alpha16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha16.tar.gz\";s:4:\"date\";s:10:\"1591188802\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha15\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha15\";s:7:\"version\";s:15:\"8.x-3.0-alpha15\";s:3:\"tag\";s:15:\"8.x-3.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1591026800\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha14\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha14\";s:7:\"version\";s:15:\"8.x-3.0-alpha14\";s:3:\"tag\";s:15:\"8.x-3.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1590401622\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha13\";s:7:\"version\";s:15:\"8.x-3.0-alpha13\";s:3:\"tag\";s:15:\"8.x-3.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1590058790\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha12\";s:7:\"version\";s:15:\"8.x-3.0-alpha12\";s:3:\"tag\";s:15:\"8.x-3.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1588701093\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha11\";s:7:\"version\";s:15:\"8.x-3.0-alpha11\";s:3:\"tag\";s:15:\"8.x-3.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1588112180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha10\";s:7:\"version\";s:15:\"8.x-3.0-alpha10\";s:3:\"tag\";s:15:\"8.x-3.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1588110279\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha9\";s:7:\"version\";s:14:\"8.x-3.0-alpha9\";s:3:\"tag\";s:14:\"8.x-3.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1587598687\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha8\";s:7:\"version\";s:14:\"8.x-3.0-alpha8\";s:3:\"tag\";s:14:\"8.x-3.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1587403171\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha7\";s:7:\"version\";s:14:\"8.x-3.0-alpha7\";s:3:\"tag\";s:14:\"8.x-3.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1586889051\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha6\";s:7:\"version\";s:14:\"8.x-3.0-alpha6\";s:3:\"tag\";s:14:\"8.x-3.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1585911008\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha5\";s:7:\"version\";s:14:\"8.x-3.0-alpha5\";s:3:\"tag\";s:14:\"8.x-3.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1585758919\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha4\";s:7:\"version\";s:14:\"8.x-3.0-alpha4\";s:3:\"tag\";s:14:\"8.x-3.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1585218206\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha3\";s:7:\"version\";s:14:\"8.x-3.0-alpha3\";s:3:\"tag\";s:14:\"8.x-3.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1585056344\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha2\";s:7:\"version\";s:14:\"8.x-3.0-alpha2\";s:3:\"tag\";s:14:\"8.x-3.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1584823830\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha1\";s:7:\"version\";s:14:\"8.x-3.0-alpha1\";s:3:\"tag\";s:14:\"8.x-3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1584713675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha13\";s:7:\"version\";s:15:\"8.x-2.0-alpha13\";s:3:\"tag\";s:15:\"8.x-2.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1582141618\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha12\";s:7:\"version\";s:15:\"8.x-2.0-alpha12\";s:3:\"tag\";s:15:\"8.x-2.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1581799850\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha11\";s:7:\"version\";s:15:\"8.x-2.0-alpha11\";s:3:\"tag\";s:15:\"8.x-2.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1581784971\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:15:\"8.x-2.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha10\";s:7:\"version\";s:15:\"8.x-2.0-alpha10\";s:3:\"tag\";s:15:\"8.x-2.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1581670919\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha9\";s:7:\"version\";s:14:\"8.x-2.0-alpha9\";s:3:\"tag\";s:14:\"8.x-2.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1580894379\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha8\";s:7:\"version\";s:14:\"8.x-2.0-alpha8\";s:3:\"tag\";s:14:\"8.x-2.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1580892462\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha7\";s:7:\"version\";s:14:\"8.x-2.0-alpha7\";s:3:\"tag\";s:14:\"8.x-2.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1580374257\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha6\";s:7:\"version\";s:14:\"8.x-2.0-alpha6\";s:3:\"tag\";s:14:\"8.x-2.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha5\";s:7:\"version\";s:14:\"8.x-2.0-alpha5\";s:3:\"tag\";s:14:\"8.x-2.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1579908781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha4\";s:7:\"version\";s:14:\"8.x-2.0-alpha4\";s:3:\"tag\";s:14:\"8.x-2.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1578573789\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha3\";s:7:\"version\";s:14:\"8.x-2.0-alpha3\";s:3:\"tag\";s:14:\"8.x-2.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1576589285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-2.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha2\";s:7:\"version\";s:14:\"8.x-2.0-alpha2\";s:3:\"tag\";s:14:\"8.x-2.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1575496380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-2.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha1\";s:7:\"version\";s:14:\"8.x-2.0-alpha1\";s:3:\"tag\";s:14:\"8.x-2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1575493680\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";s:5:\"terms\";a:0:{}}s:15:\"8.x-1.0-alpha14\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha14\";s:7:\"version\";s:15:\"8.x-1.0-alpha14\";s:3:\"tag\";s:15:\"8.x-1.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1582141601\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha13\";s:7:\"version\";s:15:\"8.x-1.0-alpha13\";s:3:\"tag\";s:15:\"8.x-1.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1581799836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha12\";s:7:\"version\";s:15:\"8.x-1.0-alpha12\";s:3:\"tag\";s:15:\"8.x-1.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1581784989\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";s:5:\"terms\";a:0:{}}s:15:\"8.x-1.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha11\";s:7:\"version\";s:15:\"8.x-1.0-alpha11\";s:3:\"tag\";s:15:\"8.x-1.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1581670945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha10\";s:7:\"version\";s:15:\"8.x-1.0-alpha10\";s:3:\"tag\";s:15:\"8.x-1.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1580894364\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha9\";s:7:\"version\";s:14:\"8.x-1.0-alpha9\";s:3:\"tag\";s:14:\"8.x-1.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1580892445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1578905887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1578573789\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1576589285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1572892684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1572358984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1572007384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1570199287\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"4.0.x-dev\";a:11:{s:4:\"name\";s:13:\"gin 4.0.x-dev\";s:7:\"version\";s:9:\"4.0.x-dev\";s:3:\"tag\";s:5:\"4.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/gin/releases/4.0.x-dev\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/gin-4.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1740737299\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1739521990\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-2.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1582387423\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-1.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1582387472\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}}s:10:\"last_fetch\";i:1743932020;}',1744018420),('update_available_releases','gin_toolbar',_binary 'a:10:{s:5:\"title\";s:11:\"Gin Toolbar\";s:10:\"short_name\";s:11:\"gin_toolbar\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"2.0.,8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/gin_toolbar\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/gin_toolbar\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:38:{s:5:\"2.0.0\";a:11:{s:4:\"name\";s:17:\"gin_toolbar 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin_toolbar/releases/2.0.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin_toolbar-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1734698921\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"gin_toolbar 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1734698810\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc8\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc8\";s:7:\"version\";s:11:\"8.x-1.0-rc8\";s:3:\"tag\";s:11:\"8.x-1.0-rc8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc8\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc8.tar.gz\";s:4:\"date\";s:10:\"1734527411\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc7\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc7\";s:7:\"version\";s:11:\"8.x-1.0-rc7\";s:3:\"tag\";s:11:\"8.x-1.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc7\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1733734483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1718368950\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1702727588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1697192878\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1688477489\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1688474912\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1669666835\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta22\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta22\";s:7:\"version\";s:14:\"8.x-1.0-beta22\";s:3:\"tag\";s:14:\"8.x-1.0-beta22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta22\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta22.tar.gz\";s:4:\"date\";s:10:\"1649709351\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta21\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta21\";s:7:\"version\";s:14:\"8.x-1.0-beta21\";s:3:\"tag\";s:14:\"8.x-1.0-beta21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta21\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta21.tar.gz\";s:4:\"date\";s:10:\"1646929714\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta20\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta20\";s:7:\"version\";s:14:\"8.x-1.0-beta20\";s:3:\"tag\";s:14:\"8.x-1.0-beta20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta20\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta20.tar.gz\";s:4:\"date\";s:10:\"1635149590\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta19\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta19\";s:7:\"version\";s:14:\"8.x-1.0-beta19\";s:3:\"tag\";s:14:\"8.x-1.0-beta19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta19\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta19.tar.gz\";s:4:\"date\";s:10:\"1626682027\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta18\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta18\";s:7:\"version\";s:14:\"8.x-1.0-beta18\";s:3:\"tag\";s:14:\"8.x-1.0-beta18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta18\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta18.tar.gz\";s:4:\"date\";s:10:\"1625232247\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta17\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta17\";s:7:\"version\";s:14:\"8.x-1.0-beta17\";s:3:\"tag\";s:14:\"8.x-1.0-beta17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta17\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta17.tar.gz\";s:4:\"date\";s:10:\"1622635843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta16\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta16\";s:7:\"version\";s:14:\"8.x-1.0-beta16\";s:3:\"tag\";s:14:\"8.x-1.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta16\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1622620508\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta15\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta15\";s:7:\"version\";s:14:\"8.x-1.0-beta15\";s:3:\"tag\";s:14:\"8.x-1.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta15\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1620393971\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta14\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta14\";s:7:\"version\";s:14:\"8.x-1.0-beta14\";s:3:\"tag\";s:14:\"8.x-1.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta14\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1607370428\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta13\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta13\";s:7:\"version\";s:14:\"8.x-1.0-beta13\";s:3:\"tag\";s:14:\"8.x-1.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta13\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1604868424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta12\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta12\";s:7:\"version\";s:14:\"8.x-1.0-beta12\";s:3:\"tag\";s:14:\"8.x-1.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta12\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1597406475\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-beta11\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta11\";s:7:\"version\";s:14:\"8.x-1.0-beta11\";s:3:\"tag\";s:14:\"8.x-1.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta11\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1594643490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta10\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta10\";s:7:\"version\";s:14:\"8.x-1.0-beta10\";s:3:\"tag\";s:14:\"8.x-1.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta10\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1593766660\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta9\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta9\";s:7:\"version\";s:13:\"8.x-1.0-beta9\";s:3:\"tag\";s:13:\"8.x-1.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta9\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1593462042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta8\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta8\";s:7:\"version\";s:13:\"8.x-1.0-beta8\";s:3:\"tag\";s:13:\"8.x-1.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta8\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1592855833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta7\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta7\";s:7:\"version\";s:13:\"8.x-1.0-beta7\";s:3:\"tag\";s:13:\"8.x-1.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta7\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1591349902\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta6\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta6\";s:7:\"version\";s:13:\"8.x-1.0-beta6\";s:3:\"tag\";s:13:\"8.x-1.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta6\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1590401639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1588460020\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1588342225\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1587403136\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1584829276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1584713311\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1581785004\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1579960985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1579958885\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:21:\"gin_toolbar 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/gin_toolbar/releases/2.0.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/gin_toolbar-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1735327030\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734511651\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','glightbox',_binary 'a:10:{s:5:\"title\";s:9:\"GLightbox\";s:10:\"short_name\";s:9:\"glightbox\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.0.\";s:18:\"composer_namespace\";s:16:\"drupal/glightbox\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:18:{s:6:\"1.0.15\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.15\";s:7:\"version\";s:6:\"1.0.15\";s:3:\"tag\";s:6:\"1.0.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.15\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.15.tar.gz\";s:4:\"date\";s:10:\"1743701759\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.0.14\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.14\";s:7:\"version\";s:6:\"1.0.14\";s:3:\"tag\";s:6:\"1.0.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.14\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.14.tar.gz\";s:4:\"date\";s:10:\"1741428233\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.0.13\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.13\";s:7:\"version\";s:6:\"1.0.13\";s:3:\"tag\";s:6:\"1.0.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.13.tar.gz\";s:4:\"date\";s:10:\"1734093961\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.0.12\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.12\";s:7:\"version\";s:6:\"1.0.12\";s:3:\"tag\";s:6:\"1.0.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.12.tar.gz\";s:4:\"date\";s:10:\"1731583765\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.0.11\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.11\";s:7:\"version\";s:6:\"1.0.11\";s:3:\"tag\";s:6:\"1.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.11.tar.gz\";s:4:\"date\";s:10:\"1730572135\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.0.10\";a:11:{s:4:\"name\";s:16:\"glightbox 1.0.10\";s:7:\"version\";s:6:\"1.0.10\";s:3:\"tag\";s:6:\"1.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/glightbox/releases/1.0.10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/glightbox-1.0.10.tar.gz\";s:4:\"date\";s:10:\"1730571218\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.9\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.9\";s:7:\"version\";s:5:\"1.0.9\";s:3:\"tag\";s:5:\"1.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.9.tar.gz\";s:4:\"date\";s:10:\"1727939818\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.8\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.8\";s:7:\"version\";s:5:\"1.0.8\";s:3:\"tag\";s:5:\"1.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.8.tar.gz\";s:4:\"date\";s:10:\"1726929656\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.7\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.7\";s:7:\"version\";s:5:\"1.0.7\";s:3:\"tag\";s:5:\"1.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.7.tar.gz\";s:4:\"date\";s:10:\"1713942568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.6\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.6\";s:7:\"version\";s:5:\"1.0.6\";s:3:\"tag\";s:5:\"1.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.6.tar.gz\";s:4:\"date\";s:10:\"1712003661\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.5\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.5\";s:7:\"version\";s:5:\"1.0.5\";s:3:\"tag\";s:5:\"1.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.5.tar.gz\";s:4:\"date\";s:10:\"1712002850\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.4\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.4\";s:7:\"version\";s:5:\"1.0.4\";s:3:\"tag\";s:5:\"1.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.4.tar.gz\";s:4:\"date\";s:10:\"1704707152\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1697006475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1690874897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1670673111\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:21:\"glightbox 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/glightbox/releases/1.0.0-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1669550449\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:22:\"glightbox 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/glightbox/releases/1.0.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1669124562\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:19:\"glightbox 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/glightbox/releases/1.0.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/glightbox-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743701663\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932016;}',1744018416),('update_available_releases','hotkeys_for_save',_binary 'a:10:{s:5:\"title\";s:16:\"Hotkeys for Save\";s:10:\"short_name\";s:16:\"hotkeys_for_save\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"2.0.\";s:18:\"composer_namespace\";s:23:\"drupal/hotkeys_for_save\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/hotkeys_for_save\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"2.0.1\";a:11:{s:4:\"name\";s:22:\"hotkeys_for_save 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/hotkeys_for_save/releases/2.0.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/hotkeys_for_save-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1699460196\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\">=8\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:22:\"hotkeys_for_save 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/hotkeys_for_save/releases/2.0.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/hotkeys_for_save-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1672265488\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:24:\"hotkeys_for_save 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/hotkeys_for_save/releases/8.x-1.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/hotkeys_for_save-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1590164406\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:24:\"hotkeys_for_save 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/hotkeys_for_save/releases/8.x-1.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/hotkeys_for_save-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1526348884\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:26:\"hotkeys_for_save 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/hotkeys_for_save/releases/2.0.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/hotkeys_for_save-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1699524941\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\">=8\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:28:\"hotkeys_for_save 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/hotkeys_for_save/releases/8.x-1.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/hotkeys_for_save-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1590164007\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932017;}',1744018417),('update_available_releases','jsonapi_extras',_binary 'a:10:{s:5:\"title\";s:15:\"JSON:API Extras\";s:10:\"short_name\";s:14:\"jsonapi_extras\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-3.\";s:18:\"composer_namespace\";s:21:\"drupal/jsonapi_extras\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/jsonapi_extras\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:67:{s:8:\"8.x-3.26\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.26\";s:7:\"version\";s:8:\"8.x-3.26\";s:3:\"tag\";s:8:\"8.x-3.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.26\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.26.tar.gz\";s:4:\"date\";s:10:\"1727787963\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:14:\"8.x-3.26-beta1\";a:11:{s:4:\"name\";s:29:\"jsonapi_extras 8.x-3.26-beta1\";s:7:\"version\";s:14:\"8.x-3.26-beta1\";s:3:\"tag\";s:14:\"8.x-3.26-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.26-beta1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.26-beta1.tar.gz\";s:4:\"date\";s:10:\"1719473945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:8:\"8.x-3.25\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.25\";s:7:\"version\";s:8:\"8.x-3.25\";s:3:\"tag\";s:8:\"8.x-3.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.25\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.25.tar.gz\";s:4:\"date\";s:10:\"1717340217\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:14:\"8.x-3.25-beta2\";a:11:{s:4:\"name\";s:29:\"jsonapi_extras 8.x-3.25-beta2\";s:7:\"version\";s:14:\"8.x-3.25-beta2\";s:3:\"tag\";s:14:\"8.x-3.25-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.25-beta2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.25-beta2.tar.gz\";s:4:\"date\";s:10:\"1716575200\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:14:\"8.x-3.25-beta1\";a:11:{s:4:\"name\";s:29:\"jsonapi_extras 8.x-3.25-beta1\";s:7:\"version\";s:14:\"8.x-3.25-beta1\";s:3:\"tag\";s:14:\"8.x-3.25-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.25-beta1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.25-beta1.tar.gz\";s:4:\"date\";s:10:\"1716560689\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-3.24\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.24\";s:7:\"version\";s:8:\"8.x-3.24\";s:3:\"tag\";s:8:\"8.x-3.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.24\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.24.tar.gz\";s:4:\"date\";s:10:\"1694442796\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:14:\"8.x-3.24-beta1\";a:11:{s:4:\"name\";s:29:\"jsonapi_extras 8.x-3.24-beta1\";s:7:\"version\";s:14:\"8.x-3.24-beta1\";s:3:\"tag\";s:14:\"8.x-3.24-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.24-beta1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.24-beta1.tar.gz\";s:4:\"date\";s:10:\"1694015619\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-3.23\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.23\";s:7:\"version\";s:8:\"8.x-3.23\";s:3:\"tag\";s:8:\"8.x-3.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.23\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.23.tar.gz\";s:4:\"date\";s:10:\"1669374477\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-3.22\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.22\";s:7:\"version\";s:8:\"8.x-3.22\";s:3:\"tag\";s:8:\"8.x-3.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.22\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.22.tar.gz\";s:4:\"date\";s:10:\"1668758150\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:8:\"8.x-3.21\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.21\";s:7:\"version\";s:8:\"8.x-3.21\";s:3:\"tag\";s:8:\"8.x-3.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.21\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.21.tar.gz\";s:4:\"date\";s:10:\"1659004732\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-3.20\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.20\";s:7:\"version\";s:8:\"8.x-3.20\";s:3:\"tag\";s:8:\"8.x-3.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.20\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.20.tar.gz\";s:4:\"date\";s:10:\"1639580049\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-3.19\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.19\";s:7:\"version\";s:8:\"8.x-3.19\";s:3:\"tag\";s:8:\"8.x-3.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.19\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.19.tar.gz\";s:4:\"date\";s:10:\"1625144988\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-3.18\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.18\";s:7:\"version\";s:8:\"8.x-3.18\";s:3:\"tag\";s:8:\"8.x-3.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.18\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.18.tar.gz\";s:4:\"date\";s:10:\"1623673079\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-3.17\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.17\";s:7:\"version\";s:8:\"8.x-3.17\";s:3:\"tag\";s:8:\"8.x-3.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.17\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.17.tar.gz\";s:4:\"date\";s:10:\"1613848645\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-3.16\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.16\";s:7:\"version\";s:8:\"8.x-3.16\";s:3:\"tag\";s:8:\"8.x-3.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.16\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.16.tar.gz\";s:4:\"date\";s:10:\"1599132031\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-3.15\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.15\";s:7:\"version\";s:8:\"8.x-3.15\";s:3:\"tag\";s:8:\"8.x-3.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.15\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.15.tar.gz\";s:4:\"date\";s:10:\"1594927280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-3.14\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.14\";s:7:\"version\";s:8:\"8.x-3.14\";s:3:\"tag\";s:8:\"8.x-3.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.14\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.14.tar.gz\";s:4:\"date\";s:10:\"1585437198\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-3.13\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.13\";s:7:\"version\";s:8:\"8.x-3.13\";s:3:\"tag\";s:8:\"8.x-3.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.13\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.13.tar.gz\";s:4:\"date\";s:10:\"1576303987\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-3.12\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.12\";s:7:\"version\";s:8:\"8.x-3.12\";s:3:\"tag\";s:8:\"8.x-3.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.12\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.12.tar.gz\";s:4:\"date\";s:10:\"1568182084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-3.11\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.11\";s:7:\"version\";s:8:\"8.x-3.11\";s:3:\"tag\";s:8:\"8.x-3.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.11\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.11.tar.gz\";s:4:\"date\";s:10:\"1568149685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-3.10\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-3.10\";s:7:\"version\";s:8:\"8.x-3.10\";s:3:\"tag\";s:8:\"8.x-3.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.10\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.10.tar.gz\";s:4:\"date\";s:10:\"1566052685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.9\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.9\";s:7:\"version\";s:7:\"8.x-3.9\";s:3:\"tag\";s:7:\"8.x-3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.9\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.9.tar.gz\";s:4:\"date\";s:10:\"1565730484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.8\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.8\";s:7:\"version\";s:7:\"8.x-3.8\";s:3:\"tag\";s:7:\"8.x-3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.8.tar.gz\";s:4:\"date\";s:10:\"1560872886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.7\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.7\";s:7:\"version\";s:7:\"8.x-3.7\";s:3:\"tag\";s:7:\"8.x-3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.7.tar.gz\";s:4:\"date\";s:10:\"1558388885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.6\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1556431984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.5\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.5\";s:7:\"version\";s:7:\"8.x-3.5\";s:3:\"tag\";s:7:\"8.x-3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.5.tar.gz\";s:4:\"date\";s:10:\"1553751485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.4\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.4\";s:7:\"version\";s:7:\"8.x-3.4\";s:3:\"tag\";s:7:\"8.x-3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.4.tar.gz\";s:4:\"date\";s:10:\"1550505485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1548088380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1546039681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1545520980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1544218380\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.0-rc4\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-3.0-rc4\";s:7:\"version\";s:11:\"8.x-3.0-rc4\";s:3:\"tag\";s:11:\"8.x-3.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.0-rc4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1544217780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc3\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-3.0-rc3\";s:7:\"version\";s:11:\"8.x-3.0-rc3\";s:3:\"tag\";s:11:\"8.x-3.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.0-rc3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1543960980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1543537081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1543533481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-2.15\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-2.15\";s:7:\"version\";s:8:\"8.x-2.15\";s:3:\"tag\";s:8:\"8.x-2.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.15\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.15.tar.gz\";s:4:\"date\";s:10:\"1545810180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-2.14\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-2.14\";s:7:\"version\";s:8:\"8.x-2.14\";s:3:\"tag\";s:8:\"8.x-2.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.14\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.14.tar.gz\";s:4:\"date\";s:10:\"1544132580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-2.13\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-2.13\";s:7:\"version\";s:8:\"8.x-2.13\";s:3:\"tag\";s:8:\"8.x-2.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.13\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.13.tar.gz\";s:4:\"date\";s:10:\"1543960980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-2.12\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-2.12\";s:7:\"version\";s:8:\"8.x-2.12\";s:3:\"tag\";s:8:\"8.x-2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.12\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.12.tar.gz\";s:4:\"date\";s:10:\"1543616280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-2.11\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-2.11\";s:7:\"version\";s:8:\"8.x-2.11\";s:3:\"tag\";s:8:\"8.x-2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.11\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.11.tar.gz\";s:4:\"date\";s:10:\"1542151980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-2.10\";a:11:{s:4:\"name\";s:23:\"jsonapi_extras 8.x-2.10\";s:7:\"version\";s:8:\"8.x-2.10\";s:3:\"tag\";s:8:\"8.x-2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.10\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.10.tar.gz\";s:4:\"date\";s:10:\"1539794280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.9\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.9\";s:7:\"version\";s:7:\"8.x-2.9\";s:3:\"tag\";s:7:\"8.x-2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.9\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.9.tar.gz\";s:4:\"date\";s:10:\"1535790180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.8\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.8\";s:7:\"version\";s:7:\"8.x-2.8\";s:3:\"tag\";s:7:\"8.x-2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.8.tar.gz\";s:4:\"date\";s:10:\"1535351285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.7\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.7\";s:7:\"version\";s:7:\"8.x-2.7\";s:3:\"tag\";s:7:\"8.x-2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.7.tar.gz\";s:4:\"date\";s:10:\"1535349181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.6\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.6\";s:7:\"version\";s:7:\"8.x-2.6\";s:3:\"tag\";s:7:\"8.x-2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.6.tar.gz\";s:4:\"date\";s:10:\"1535295184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1533103380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1533102484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1531668525\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1530338020\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1525411687\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:22:\"jsonapi_extras 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1524931084\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.0-rc3\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-2.0-rc3\";s:7:\"version\";s:11:\"8.x-2.0-rc3\";s:3:\"tag\";s:11:\"8.x-2.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.0-rc3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1524930184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc2\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-2.0-rc2\";s:7:\"version\";s:11:\"8.x-2.0-rc2\";s:3:\"tag\";s:11:\"8.x-2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.0-rc2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1524209880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc1\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-2.0-rc1\";s:7:\"version\";s:11:\"8.x-2.0-rc1\";s:3:\"tag\";s:11:\"8.x-2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.0-rc1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1521442084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc7\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-1.0-rc7\";s:7:\"version\";s:11:\"8.x-1.0-rc7\";s:3:\"tag\";s:11:\"8.x-1.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-rc7\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1520153584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1520147884\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1519402080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1519396085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1519388584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1519342984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1514674084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:28:\"jsonapi_extras 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1514496184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:28:\"jsonapi_extras 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1507731243\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:28:\"jsonapi_extras 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1506315244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-3.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1733551686\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-2.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1545808380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:26:\"jsonapi_extras 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jsonapi_extras/releases/8.x-1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jsonapi_extras-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1522561385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}}s:10:\"last_fetch\";i:1743932017;}',1744018417),('update_available_releases','jsonapi_menu_items',_binary 'a:10:{s:5:\"title\";s:19:\"JSON:API Menu Items\";s:10:\"short_name\";s:18:\"jsonapi_menu_items\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.2.\";s:18:\"composer_namespace\";s:25:\"drupal/jsonapi_menu_items\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:49:\"https://www.drupal.org/project/jsonapi_menu_items\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:14:{s:5:\"1.2.6\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.2.6\";s:7:\"version\";s:5:\"1.2.6\";s:3:\"tag\";s:5:\"1.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.2.6\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.2.6.tar.gz\";s:4:\"date\";s:10:\"1722543501\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.2.5\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.2.5\";s:7:\"version\";s:5:\"1.2.5\";s:3:\"tag\";s:5:\"1.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.2.5\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.2.5.tar.gz\";s:4:\"date\";s:10:\"1714592115\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"1.2.4\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.2.4\";s:7:\"version\";s:5:\"1.2.4\";s:3:\"tag\";s:5:\"1.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.2.4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.2.4.tar.gz\";s:4:\"date\";s:10:\"1670542784\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.2.3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1657144496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.2.2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1721340205\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.2.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1619993273\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.2.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1618724745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"1.1.1\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.1.1\";s:7:\"version\";s:5:\"1.1.1\";s:3:\"tag\";s:5:\"1.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.1.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.1.1.tar.gz\";s:4:\"date\";s:10:\"1611263486\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.1.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1600354715\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.0.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1599791545\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:24:\"jsonapi_menu_items 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.0.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1599199632\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"1.2.x-dev\";a:11:{s:4:\"name\";s:28:\"jsonapi_menu_items 1.2.x-dev\";s:7:\"version\";s:9:\"1.2.x-dev\";s:3:\"tag\";s:5:\"1.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.2.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721339952\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.1.x-dev\";a:11:{s:4:\"name\";s:28:\"jsonapi_menu_items 1.1.x-dev\";s:7:\"version\";s:9:\"1.1.x-dev\";s:3:\"tag\";s:5:\"1.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.1.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1618616699\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:28:\"jsonapi_menu_items 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_menu_items/releases/1.0.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_menu_items-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1600354504\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932017;}',1744018417),('update_available_releases','jsonapi_resources',_binary 'a:10:{s:5:\"title\";s:18:\"JSON:API Resources\";s:10:\"short_name\";s:17:\"jsonapi_resources\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:24:\"drupal/jsonapi_resources\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/jsonapi_resources\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:25:\"jsonapi_resources 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1719872296\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.1 || ^10 || ^11\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:25:\"jsonapi_resources 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1719351148\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.1 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:25:\"jsonapi_resources 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1714670127\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.1 || ^10\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:31:\"jsonapi_resources 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1668787739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:31:\"jsonapi_resources 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1608428207\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:31:\"jsonapi_resources 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1578690483\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:31:\"jsonapi_resources 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1574789880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:31:\"jsonapi_resources 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1573085585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:29:\"jsonapi_resources 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/jsonapi_resources/releases/8.x-1.x-dev\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/jsonapi_resources-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1719871852\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.1 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932017;}',1744018417),('update_available_releases','jsonapi_response_alter',_binary 'a:10:{s:5:\"title\";s:23:\"JSON:API Response Alter\";s:10:\"short_name\";s:22:\"jsonapi_response_alter\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"1.2.,2.0.\";s:18:\"composer_namespace\";s:29:\"drupal/jsonapi_response_alter\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:53:\"https://www.drupal.org/project/jsonapi_response_alter\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:5:{s:5:\"2.0.1\";a:11:{s:4:\"name\";s:28:\"jsonapi_response_alter 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_response_alter/releases/2.0.1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_response_alter-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1718696571\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:54:\"Project has not opted into security advisory coverage!\";s:18:\"core_compatibility\";s:12:\"^10.1 || ^11\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:28:\"jsonapi_response_alter 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_response_alter/releases/2.0.0\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_response_alter-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1718284988\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:54:\"Project has not opted into security advisory coverage!\";s:18:\"core_compatibility\";s:12:\"^10.1 || ^11\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:28:\"jsonapi_response_alter 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_response_alter/releases/1.2.0\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_response_alter-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1697111887\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:54:\"Project has not opted into security advisory coverage!\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:28:\"jsonapi_response_alter 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_response_alter/releases/1.1.0\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_response_alter-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1684498292\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:54:\"Project has not opted into security advisory coverage!\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:28:\"jsonapi_response_alter 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/jsonapi_response_alter/releases/1.0.0\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/jsonapi_response_alter-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1624979787\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:54:\"Project has not opted into security advisory coverage!\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932017;}',1744018417),('update_available_releases','jsonapi_views',_binary 'a:10:{s:5:\"title\";s:14:\"JSON:API Views\";s:10:\"short_name\";s:13:\"jsonapi_views\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:20:\"drupal/jsonapi_views\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/jsonapi_views\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:21:\"jsonapi_views 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/jsonapi_views/releases/8.x-1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/jsonapi_views-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1675998787\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\">=8.8\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:21:\"jsonapi_views 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/jsonapi_views/releases/8.x-1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/jsonapi_views-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1633070688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:27:\"jsonapi_views 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jsonapi_views/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jsonapi_views-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1623905514\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:27:\"jsonapi_views 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jsonapi_views/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jsonapi_views-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1616619144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:27:\"jsonapi_views 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jsonapi_views/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jsonapi_views-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1612768893\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:25:\"jsonapi_views 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jsonapi_views/releases/8.x-1.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jsonapi_views-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1675998618\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\">=8.8\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932017;}',1744018417),('update_available_releases','linkit',_binary 'a:10:{s:5:\"title\";s:6:\"Linkit\";s:10:\"short_name\";s:6:\"linkit\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:14:\"6.0.,6.1.,7.0.\";s:18:\"composer_namespace\";s:13:\"drupal/linkit\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:37:\"https://www.drupal.org/project/linkit\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:48:{s:5:\"7.0.3\";a:11:{s:4:\"name\";s:12:\"linkit 7.0.3\";s:7:\"version\";s:5:\"7.0.3\";s:3:\"tag\";s:5:\"7.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/7.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-7.0.3.tar.gz\";s:4:\"date\";s:10:\"1738264704\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";}s:5:\"7.0.2\";a:11:{s:4:\"name\";s:12:\"linkit 7.0.2\";s:7:\"version\";s:5:\"7.0.2\";s:3:\"tag\";s:5:\"7.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/7.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-7.0.2.tar.gz\";s:4:\"date\";s:10:\"1734967499\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";s:5:\"terms\";a:0:{}}s:5:\"7.0.1\";a:11:{s:4:\"name\";s:12:\"linkit 7.0.1\";s:7:\"version\";s:5:\"7.0.1\";s:3:\"tag\";s:5:\"7.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/7.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-7.0.1.tar.gz\";s:4:\"date\";s:10:\"1734561089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";}s:5:\"7.0.0\";a:11:{s:4:\"name\";s:12:\"linkit 7.0.0\";s:7:\"version\";s:5:\"7.0.0\";s:3:\"tag\";s:5:\"7.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/7.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-7.0.0.tar.gz\";s:4:\"date\";s:10:\"1733919071\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";s:5:\"terms\";a:0:{}}s:12:\"7.0.0-alpha2\";a:11:{s:4:\"name\";s:19:\"linkit 7.0.0-alpha2\";s:7:\"version\";s:12:\"7.0.0-alpha2\";s:3:\"tag\";s:12:\"7.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/linkit/releases/7.0.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/linkit-7.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1728680089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";}s:12:\"7.0.0-alpha1\";a:11:{s:4:\"name\";s:19:\"linkit 7.0.0-alpha1\";s:7:\"version\";s:12:\"7.0.0-alpha1\";s:3:\"tag\";s:12:\"7.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/linkit/releases/7.0.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/linkit-7.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1715887209\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";s:5:\"terms\";a:0:{}}s:5:\"6.1.6\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.6\";s:7:\"version\";s:5:\"6.1.6\";s:3:\"tag\";s:5:\"6.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.6.tar.gz\";s:4:\"date\";s:10:\"1729189029\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.5\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.5\";s:7:\"version\";s:5:\"6.1.5\";s:3:\"tag\";s:5:\"6.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.5.tar.gz\";s:4:\"date\";s:10:\"1728680387\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.4\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.4\";s:7:\"version\";s:5:\"6.1.4\";s:3:\"tag\";s:5:\"6.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.4.tar.gz\";s:4:\"date\";s:10:\"1715203830\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.3\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.3\";s:7:\"version\";s:5:\"6.1.3\";s:3:\"tag\";s:5:\"6.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.3.tar.gz\";s:4:\"date\";s:10:\"1710519126\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.2\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.2\";s:7:\"version\";s:5:\"6.1.2\";s:3:\"tag\";s:5:\"6.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.2.tar.gz\";s:4:\"date\";s:10:\"1696865454\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.1\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.1\";s:7:\"version\";s:5:\"6.1.1\";s:3:\"tag\";s:5:\"6.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.1.tar.gz\";s:4:\"date\";s:10:\"1696099840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.0\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.0\";s:7:\"version\";s:5:\"6.1.0\";s:3:\"tag\";s:5:\"6.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.0.tar.gz\";s:4:\"date\";s:10:\"1688747800\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:9:\"6.1.0-rc2\";a:11:{s:4:\"name\";s:16:\"linkit 6.1.0-rc2\";s:7:\"version\";s:9:\"6.1.0-rc2\";s:3:\"tag\";s:9:\"6.1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.1.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1688055727\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:9:\"6.1.0-rc1\";a:11:{s:4:\"name\";s:16:\"linkit 6.1.0-rc1\";s:7:\"version\";s:9:\"6.1.0-rc1\";s:3:\"tag\";s:9:\"6.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1681070586\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.0.2\";a:11:{s:4:\"name\";s:12:\"linkit 6.0.2\";s:7:\"version\";s:5:\"6.0.2\";s:3:\"tag\";s:5:\"6.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.0.2.tar.gz\";s:4:\"date\";s:10:\"1696865395\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";}s:5:\"6.0.1\";a:11:{s:4:\"name\";s:12:\"linkit 6.0.1\";s:7:\"version\";s:5:\"6.0.1\";s:3:\"tag\";s:5:\"6.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.0.1.tar.gz\";s:4:\"date\";s:10:\"1696099905\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";}s:5:\"6.0.0\";a:11:{s:4:\"name\";s:12:\"linkit 6.0.0\";s:7:\"version\";s:5:\"6.0.0\";s:3:\"tag\";s:5:\"6.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.0.0.tar.gz\";s:4:\"date\";s:10:\"1688748025\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";s:5:\"terms\";a:0:{}}s:9:\"6.0.0-rc2\";a:11:{s:4:\"name\";s:16:\"linkit 6.0.0-rc2\";s:7:\"version\";s:9:\"6.0.0-rc2\";s:3:\"tag\";s:9:\"6.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.0.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1688055675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";}s:9:\"6.0.0-rc1\";a:11:{s:4:\"name\";s:16:\"linkit 6.0.0-rc1\";s:7:\"version\";s:9:\"6.0.0-rc1\";s:3:\"tag\";s:9:\"6.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1681070405\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";}s:11:\"6.0.0-beta4\";a:11:{s:4:\"name\";s:18:\"linkit 6.0.0-beta4\";s:7:\"version\";s:11:\"6.0.0-beta4\";s:3:\"tag\";s:11:\"6.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/6.0.0-beta4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1678030708\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.0.0-beta3\";a:11:{s:4:\"name\";s:18:\"linkit 6.0.0-beta3\";s:7:\"version\";s:11:\"6.0.0-beta3\";s:3:\"tag\";s:11:\"6.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/6.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1632848771\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta2\";a:11:{s:4:\"name\";s:18:\"linkit 6.0.0-beta2\";s:7:\"version\";s:11:\"6.0.0-beta2\";s:3:\"tag\";s:11:\"6.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/6.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1608957496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta1\";a:11:{s:4:\"name\";s:18:\"linkit 6.0.0-beta1\";s:7:\"version\";s:11:\"6.0.0-beta1\";s:3:\"tag\";s:11:\"6.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/6.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1591971462\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.0-beta13\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-beta13\";s:7:\"version\";s:14:\"8.x-5.0-beta13\";s:3:\"tag\";s:14:\"8.x-5.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta13\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1632848792\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.0-beta12\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-beta12\";s:7:\"version\";s:14:\"8.x-5.0-beta12\";s:3:\"tag\";s:14:\"8.x-5.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta12\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1608957625\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.0-beta11\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-beta11\";s:7:\"version\";s:14:\"8.x-5.0-beta11\";s:3:\"tag\";s:14:\"8.x-5.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta11\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1591971693\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.0-beta10\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-beta10\";s:7:\"version\";s:14:\"8.x-5.0-beta10\";s:3:\"tag\";s:14:\"8.x-5.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta10\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1573783085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta9\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta9\";s:7:\"version\";s:13:\"8.x-5.0-beta9\";s:3:\"tag\";s:13:\"8.x-5.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta9\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1562194985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta8\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta8\";s:7:\"version\";s:13:\"8.x-5.0-beta8\";s:3:\"tag\";s:13:\"8.x-5.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta8\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1545966784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta7\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta7\";s:7:\"version\";s:13:\"8.x-5.0-beta7\";s:3:\"tag\";s:13:\"8.x-5.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1520552585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta6\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta6\";s:7:\"version\";s:13:\"8.x-5.0-beta6\";s:3:\"tag\";s:13:\"8.x-5.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1505341745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta5\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta5\";s:7:\"version\";s:13:\"8.x-5.0-beta5\";s:3:\"tag\";s:13:\"8.x-5.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1490224383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta4\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta4\";s:7:\"version\";s:13:\"8.x-5.0-beta4\";s:3:\"tag\";s:13:\"8.x-5.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1483883642\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta3\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta3\";s:7:\"version\";s:13:\"8.x-5.0-beta3\";s:3:\"tag\";s:13:\"8.x-5.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1474147139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta2\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta2\";s:7:\"version\";s:13:\"8.x-5.0-beta2\";s:3:\"tag\";s:13:\"8.x-5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1468708139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta1\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta1\";s:7:\"version\";s:13:\"8.x-5.0-beta1\";s:3:\"tag\";s:13:\"8.x-5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1468032240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-alpha1\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-alpha1\";s:7:\"version\";s:14:\"8.x-5.0-alpha1\";s:3:\"tag\";s:14:\"8.x-5.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1462227194\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.4\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.4\";s:7:\"version\";s:7:\"8.x-4.4\";s:3:\"tag\";s:7:\"8.x-4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.4.tar.gz\";s:4:\"date\";s:10:\"1632848667\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.3\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.3\";s:7:\"version\";s:7:\"8.x-4.3\";s:3:\"tag\";s:7:\"8.x-4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.3.tar.gz\";s:4:\"date\";s:10:\"1490127184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.2\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.2\";s:7:\"version\";s:7:\"8.x-4.2\";s:3:\"tag\";s:7:\"8.x-4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.2.tar.gz\";s:4:\"date\";s:10:\"1483883342\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.1\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.1\";s:7:\"version\";s:7:\"8.x-4.1\";s:3:\"tag\";s:7:\"8.x-4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.1.tar.gz\";s:4:\"date\";s:10:\"1455051539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.0\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.0\";s:7:\"version\";s:7:\"8.x-4.0\";s:3:\"tag\";s:7:\"8.x-4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.0.tar.gz\";s:4:\"date\";s:10:\"1452407039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"7.x-dev\";a:11:{s:4:\"name\";s:14:\"linkit 7.x-dev\";s:7:\"version\";s:7:\"7.x-dev\";s:3:\"tag\";s:3:\"7.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/7.x-dev\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-7.x-dev.tar.gz\";s:4:\"date\";s:10:\"1737127452\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";s:5:\"terms\";a:0:{}}s:9:\"6.1.x-dev\";a:11:{s:4:\"name\";s:16:\"linkit 6.1.x-dev\";s:7:\"version\";s:9:\"6.1.x-dev\";s:3:\"tag\";s:5:\"6.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1730848273\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:9:\"6.0.x-dev\";a:11:{s:4:\"name\";s:16:\"linkit 6.0.x-dev\";s:7:\"version\";s:9:\"6.0.x-dev\";s:3:\"tag\";s:5:\"6.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1696865222\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";s:5:\"terms\";a:0:{}}s:11:\"8.x-5.x-dev\";a:11:{s:4:\"name\";s:18:\"linkit 8.x-5.x-dev\";s:7:\"version\";s:11:\"8.x-5.x-dev\";s:3:\"tag\";s:7:\"8.x-5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/8.x-5.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1651431912\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-4.x-dev\";a:11:{s:4:\"name\";s:18:\"linkit 8.x-4.x-dev\";s:7:\"version\";s:11:\"8.x-4.x-dev\";s:3:\"tag\";s:7:\"8.x-4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/8.x-4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1632848383\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932017;}',1744018417),('update_available_releases','link_attributes',_binary 'a:10:{s:5:\"title\";s:22:\"Link Attributes widget\";s:10:\"short_name\";s:15:\"link_attributes\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"2.1.\";s:18:\"composer_namespace\";s:22:\"drupal/link_attributes\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:46:\"https://www.drupal.org/project/link_attributes\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:25:{s:5:\"2.1.1\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1721366572\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:5:\"2.1.0\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1690356668\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.2\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.2\";s:7:\"version\";s:5:\"2.0.2\";s:3:\"tag\";s:5:\"2.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.2.tar.gz\";s:4:\"date\";s:10:\"1689299675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1689118258\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1687393829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.14\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1687393687\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.13\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1677018560\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.12\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1668801560\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.11\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1598323550\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.10\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1580259496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.9\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1564012686\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.8\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1560473286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.7\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1559689681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1554334381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1537173781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1537148883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1526769180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1514787185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1500846243\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1481849583\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1479245341\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1467697426\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1467697426\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:23:\"link_attributes 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/2.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721366461\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:27:\"link_attributes 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1685694375\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932017;}',1744018417),('update_available_releases','media_library_edit',_binary 'a:10:{s:5:\"title\";s:18:\"Media Library Edit\";s:10:\"short_name\";s:18:\"media_library_edit\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"3.0.\";s:18:\"composer_namespace\";s:25:\"drupal/media_library_edit\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:49:\"https://www.drupal.org/project/media_library_edit\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:15:{s:5:\"3.0.4\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.4\";s:7:\"version\";s:5:\"3.0.4\";s:3:\"tag\";s:5:\"3.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.4.tar.gz\";s:4:\"date\";s:10:\"1724357846\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"3.0.3\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.3\";s:7:\"version\";s:5:\"3.0.3\";s:3:\"tag\";s:5:\"3.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.3.tar.gz\";s:4:\"date\";s:10:\"1706394959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.0.2\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1671913381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.0.1\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.1\";s:7:\"version\";s:5:\"3.0.1\";s:3:\"tag\";s:5:\"3.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.1.tar.gz\";s:4:\"date\";s:10:\"1667499767\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1667489719\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1653483531\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1638192802\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1634818379\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1607795681\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1607795644\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:33:\"media_library_edit 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1591618255\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:33:\"media_library_edit 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1573913585\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:9:\"3.0.x-dev\";a:11:{s:4:\"name\";s:28:\"media_library_edit 3.0.x-dev\";s:7:\"version\";s:9:\"3.0.x-dev\";s:3:\"tag\";s:5:\"3.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/media_library_edit/releases/3.0.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1738676498\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:30:\"media_library_edit 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1741276841\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:30:\"media_library_edit 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1593086545\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932018;}',1744018418),('update_available_releases','menu_item_extras',_binary 'a:10:{s:5:\"title\";s:16:\"Menu Item Extras\";s:10:\"short_name\";s:16:\"menu_item_extras\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:16:\"3.0.,3.1.,8.x-2.\";s:18:\"composer_namespace\";s:23:\"drupal/menu_item_extras\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/menu_item_extras\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:38:{s:5:\"3.1.0\";a:11:{s:4:\"name\";s:22:\"menu_item_extras 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/menu_item_extras/releases/3.1.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/menu_item_extras-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1725022060\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"3.0.2\";a:11:{s:4:\"name\";s:22:\"menu_item_extras 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/menu_item_extras/releases/3.0.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/menu_item_extras-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1685006492\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:22:\"menu_item_extras 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/menu_item_extras/releases/3.0.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/menu_item_extras-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1685006192\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:8:\"8.x-2.19\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.19\";s:7:\"version\";s:8:\"8.x-2.19\";s:3:\"tag\";s:8:\"8.x-2.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.19\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.19.tar.gz\";s:4:\"date\";s:10:\"1671971153\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:8:\"8.x-2.18\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.18\";s:7:\"version\";s:8:\"8.x-2.18\";s:3:\"tag\";s:8:\"8.x-2.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.18\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.18.tar.gz\";s:4:\"date\";s:10:\"1671633517\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:8:\"8.x-2.17\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.17\";s:7:\"version\";s:8:\"8.x-2.17\";s:3:\"tag\";s:8:\"8.x-2.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.17\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.17.tar.gz\";s:4:\"date\";s:10:\"1655020997\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-2.16\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.16\";s:7:\"version\";s:8:\"8.x-2.16\";s:3:\"tag\";s:8:\"8.x-2.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.16\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.16.tar.gz\";s:4:\"date\";s:10:\"1629830739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-2.15\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.15\";s:7:\"version\";s:8:\"8.x-2.15\";s:3:\"tag\";s:8:\"8.x-2.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.15\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.15.tar.gz\";s:4:\"date\";s:10:\"1620413731\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-2.14\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.14\";s:7:\"version\";s:8:\"8.x-2.14\";s:3:\"tag\";s:8:\"8.x-2.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.14\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.14.tar.gz\";s:4:\"date\";s:10:\"1614617022\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-2.13\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.13\";s:7:\"version\";s:8:\"8.x-2.13\";s:3:\"tag\";s:8:\"8.x-2.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.13\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.13.tar.gz\";s:4:\"date\";s:10:\"1606037924\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-2.12\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.12\";s:7:\"version\";s:8:\"8.x-2.12\";s:3:\"tag\";s:8:\"8.x-2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.12\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.12.tar.gz\";s:4:\"date\";s:10:\"1600958987\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-2.11\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.11\";s:7:\"version\";s:8:\"8.x-2.11\";s:3:\"tag\";s:8:\"8.x-2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.11\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.11.tar.gz\";s:4:\"date\";s:10:\"1585397140\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-2.10\";a:11:{s:4:\"name\";s:25:\"menu_item_extras 8.x-2.10\";s:7:\"version\";s:8:\"8.x-2.10\";s:3:\"tag\";s:8:\"8.x-2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.10\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.10.tar.gz\";s:4:\"date\";s:10:\"1578834483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.9\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.9\";s:7:\"version\";s:7:\"8.x-2.9\";s:3:\"tag\";s:7:\"8.x-2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.9\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.9.tar.gz\";s:4:\"date\";s:10:\"1575835084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.8\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.8\";s:7:\"version\";s:7:\"8.x-2.8\";s:3:\"tag\";s:7:\"8.x-2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.8\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.8.tar.gz\";s:4:\"date\";s:10:\"1572279487\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.7\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.7\";s:7:\"version\";s:7:\"8.x-2.7\";s:3:\"tag\";s:7:\"8.x-2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.7\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.7.tar.gz\";s:4:\"date\";s:10:\"1566238385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.6\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.6\";s:7:\"version\";s:7:\"8.x-2.6\";s:3:\"tag\";s:7:\"8.x-2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.6\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.6.tar.gz\";s:4:\"date\";s:10:\"1559810889\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.5\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1558448581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1547131380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1532680681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1522691284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1518776880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1517414880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc2\";a:11:{s:4:\"name\";s:28:\"menu_item_extras 8.x-2.0-rc2\";s:7:\"version\";s:11:\"8.x-2.0-rc2\";s:3:\"tag\";s:11:\"8.x-2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.0-rc2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1514190487\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc1\";a:11:{s:4:\"name\";s:28:\"menu_item_extras 8.x-2.0-rc1\";s:7:\"version\";s:11:\"8.x-2.0-rc1\";s:3:\"tag\";s:11:\"8.x-2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.0-rc1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1511278985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta3\";a:11:{s:4:\"name\";s:30:\"menu_item_extras 8.x-2.0-beta3\";s:7:\"version\";s:13:\"8.x-2.0-beta3\";s:3:\"tag\";s:13:\"8.x-2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.0-beta3\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1508493244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta2\";a:11:{s:4:\"name\";s:30:\"menu_item_extras 8.x-2.0-beta2\";s:7:\"version\";s:13:\"8.x-2.0-beta2\";s:3:\"tag\";s:13:\"8.x-2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.0-beta2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1507621145\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:30:\"menu_item_extras 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1507385944\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha2\";a:11:{s:4:\"name\";s:31:\"menu_item_extras 8.x-2.0-alpha2\";s:7:\"version\";s:14:\"8.x-2.0-alpha2\";s:3:\"tag\";s:14:\"8.x-2.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.0-alpha2\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1505977144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha1\";a:11:{s:4:\"name\";s:31:\"menu_item_extras 8.x-2.0-alpha1\";s:7:\"version\";s:14:\"8.x-2.0-alpha1\";s:3:\"tag\";s:14:\"8.x-2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.0-alpha1\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1503330843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-1.3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1503071044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-1.2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1502887143\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-1.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1500309843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:24:\"menu_item_extras 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-1.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1500102542\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:9:\"3.1.x-dev\";a:11:{s:4:\"name\";s:26:\"menu_item_extras 3.1.x-dev\";s:7:\"version\";s:9:\"3.1.x-dev\";s:3:\"tag\";s:5:\"3.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/menu_item_extras/releases/3.1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/menu_item_extras-3.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1725021835\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"3.0.x-dev\";a:11:{s:4:\"name\";s:26:\"menu_item_extras 3.0.x-dev\";s:7:\"version\";s:9:\"3.0.x-dev\";s:3:\"tag\";s:5:\"3.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/menu_item_extras/releases/3.0.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/menu_item_extras-3.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1708872146\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:28:\"menu_item_extras 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-2.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1676244951\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:28:\"menu_item_extras 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/menu_item_extras/releases/8.x-1.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/menu_item_extras-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1503047044\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932018;}',1744018418),('update_available_releases','metatag',_binary 'a:10:{s:5:\"title\";s:7:\"Metatag\";s:10:\"short_name\";s:7:\"metatag\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:14:\"drupal/metatag\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:38:\"https://www.drupal.org/project/metatag\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:49:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:13:\"metatag 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/metatag/releases/2.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/metatag-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1731004042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";}s:5:\"2.0.3\";a:11:{s:4:\"name\";s:13:\"metatag 2.0.3\";s:7:\"version\";s:5:\"2.0.3\";s:3:\"tag\";s:5:\"2.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/metatag/releases/2.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/metatag-2.0.3.tar.gz\";s:4:\"date\";s:10:\"1731003620\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";}s:5:\"2.0.2\";a:11:{s:4:\"name\";s:13:\"metatag 2.0.2\";s:7:\"version\";s:5:\"2.0.2\";s:3:\"tag\";s:5:\"2.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/metatag/releases/2.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/metatag-2.0.2.tar.gz\";s:4:\"date\";s:10:\"1722869772\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:13:\"metatag 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/metatag/releases/2.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/metatag-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1722843615\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:13:\"metatag 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/metatag/releases/2.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/metatag-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1687856982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"2.0.0-rc2\";a:11:{s:4:\"name\";s:17:\"metatag 2.0.0-rc2\";s:7:\"version\";s:9:\"2.0.0-rc2\";s:3:\"tag\";s:9:\"2.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/metatag/releases/2.0.0-rc2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/metatag-2.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1685470335\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"2.0.0-rc1\";a:11:{s:4:\"name\";s:17:\"metatag 2.0.0-rc1\";s:7:\"version\";s:9:\"2.0.0-rc1\";s:3:\"tag\";s:9:\"2.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/metatag/releases/2.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/metatag-2.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1685126939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:8:\"8.x-1.26\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.26\";s:7:\"version\";s:8:\"8.x-1.26\";s:3:\"tag\";s:8:\"8.x-1.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.26\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.26.tar.gz\";s:4:\"date\";s:10:\"1687856123\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.25\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.25\";s:7:\"version\";s:8:\"8.x-1.25\";s:3:\"tag\";s:8:\"8.x-1.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.25\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.25.tar.gz\";s:4:\"date\";s:10:\"1685541226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.24\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.24\";s:7:\"version\";s:8:\"8.x-1.24\";s:3:\"tag\";s:8:\"8.x-1.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.24\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.24.tar.gz\";s:4:\"date\";s:10:\"1685125893\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.23\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.23\";s:7:\"version\";s:8:\"8.x-1.23\";s:3:\"tag\";s:8:\"8.x-1.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.23\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.23.tar.gz\";s:4:\"date\";s:10:\"1683896256\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.22\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.22\";s:7:\"version\";s:8:\"8.x-1.22\";s:3:\"tag\";s:8:\"8.x-1.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.22\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.22.tar.gz\";s:4:\"date\";s:10:\"1664472818\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.21\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.21\";s:7:\"version\";s:8:\"8.x-1.21\";s:3:\"tag\";s:8:\"8.x-1.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.21\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.21.tar.gz\";s:4:\"date\";s:10:\"1657971667\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.20\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.20\";s:7:\"version\";s:8:\"8.x-1.20\";s:3:\"tag\";s:8:\"8.x-1.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.20\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.20.tar.gz\";s:4:\"date\";s:10:\"1657649277\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.19\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.19\";s:7:\"version\";s:8:\"8.x-1.19\";s:3:\"tag\";s:8:\"8.x-1.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.19\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.19.tar.gz\";s:4:\"date\";s:10:\"1641496014\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.18\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.18\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1640098931\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.17\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1640019321\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.16\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1615820867\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.15\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1607188979\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.14\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1597183852\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1587476385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1585576513\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1576870683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1567099985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1563985988\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1550683382\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1535726393\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1534867985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1522344484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1513888384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1506714244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1501553646\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1496286243\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1485901983\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-beta12\";a:11:{s:4:\"name\";s:22:\"metatag 8.x-1.0-beta12\";s:7:\"version\";s:14:\"8.x-1.0-beta12\";s:3:\"tag\";s:14:\"8.x-1.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta12\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1483477143\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-beta11\";a:11:{s:4:\"name\";s:22:\"metatag 8.x-1.0-beta11\";s:7:\"version\";s:14:\"8.x-1.0-beta11\";s:3:\"tag\";s:14:\"8.x-1.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta11\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1477928941\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-beta10\";a:11:{s:4:\"name\";s:22:\"metatag 8.x-1.0-beta10\";s:7:\"version\";s:14:\"8.x-1.0-beta10\";s:3:\"tag\";s:14:\"8.x-1.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta10\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1471888739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta9\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta9\";s:7:\"version\";s:13:\"8.x-1.0-beta9\";s:3:\"tag\";s:13:\"8.x-1.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta9\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1464897839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta8\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta8\";s:7:\"version\";s:13:\"8.x-1.0-beta8\";s:3:\"tag\";s:13:\"8.x-1.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta8\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1463224445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta7\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta7\";s:7:\"version\";s:13:\"8.x-1.0-beta7\";s:3:\"tag\";s:13:\"8.x-1.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta7\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1459708139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta6\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta6\";s:7:\"version\";s:13:\"8.x-1.0-beta6\";s:3:\"tag\";s:13:\"8.x-1.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1459610941\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1457723339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1454780939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1449616139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1448302443\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1447944840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"2.1.x-dev\";a:11:{s:4:\"name\";s:17:\"metatag 2.1.x-dev\";s:7:\"version\";s:9:\"2.1.x-dev\";s:3:\"tag\";s:5:\"2.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/metatag/releases/2.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/metatag-2.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1731003901\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:17:\"metatag 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/metatag/releases/2.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/metatag-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1731003552\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:19:\"metatag 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/metatag/releases/8.x-1.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722272637\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932018;}',1744018418),('update_available_releases','pathauto',_binary 'a:10:{s:5:\"title\";s:8:\"Pathauto\";s:10:\"short_name\";s:8:\"pathauto\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:15:\"drupal/pathauto\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/pathauto\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:23:{s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:17:\"pathauto 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/pathauto/releases/8.x-1.13\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1722507672\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:17:\"pathauto 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/pathauto/releases/8.x-1.12\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1696776683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:17:\"pathauto 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/pathauto/releases/8.x-1.11\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1659472548\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:17:\"pathauto 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/pathauto/releases/8.x-1.10\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1650806739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.9\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1644822949\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.8\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1588103046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.7\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1587898105\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.6\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1575467285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.6-beta1\";a:11:{s:4:\"name\";s:22:\"pathauto 8.x-1.6-beta1\";s:7:\"version\";s:13:\"8.x-1.6-beta1\";s:3:\"tag\";s:13:\"8.x-1.6-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/pathauto/releases/8.x-1.6-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.6-beta1.tar.gz\";s:4:\"date\";s:10:\"1573505285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.6-alpha1\";a:11:{s:4:\"name\";s:23:\"pathauto 8.x-1.6-alpha1\";s:7:\"version\";s:14:\"8.x-1.6-alpha1\";s:3:\"tag\";s:14:\"8.x-1.6-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/pathauto/releases/8.x-1.6-alpha1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.6-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571587984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.5\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1570828084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1554239887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1536407884\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1524421084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1520092685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1493468044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:20:\"pathauto 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1485702484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:22:\"pathauto 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1484781483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:22:\"pathauto 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1474313339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:23:\"pathauto 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1461007694\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:23:\"pathauto 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1456529339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:23:\"pathauto 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1453413539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:20:\"pathauto 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/pathauto/releases/8.x-1.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722507274\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932018;}',1744018418),('update_available_releases','rabbit_hole',_binary 'a:10:{s:5:\"title\";s:11:\"Rabbit Hole\";s:10:\"short_name\";s:11:\"rabbit_hole\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"2.0.,8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/rabbit_hole\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/rabbit_hole\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:21:{s:11:\"2.0.0-beta1\";a:11:{s:4:\"name\";s:23:\"rabbit_hole 2.0.0-beta1\";s:7:\"version\";s:11:\"2.0.0-beta1\";s:3:\"tag\";s:11:\"2.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/rabbit_hole/releases/2.0.0-beta1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/rabbit_hole-2.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1736896334\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:12:\"2.0.0-alpha5\";a:11:{s:4:\"name\";s:24:\"rabbit_hole 2.0.0-alpha5\";s:7:\"version\";s:12:\"2.0.0-alpha5\";s:3:\"tag\";s:12:\"2.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/rabbit_hole/releases/2.0.0-alpha5\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/rabbit_hole-2.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1691228234\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:12:\"2.0.0-alpha4\";a:11:{s:4:\"name\";s:24:\"rabbit_hole 2.0.0-alpha4\";s:7:\"version\";s:12:\"2.0.0-alpha4\";s:3:\"tag\";s:12:\"2.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/rabbit_hole/releases/2.0.0-alpha4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/rabbit_hole-2.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1689688828\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:12:\"2.0.0-alpha3\";a:11:{s:4:\"name\";s:24:\"rabbit_hole 2.0.0-alpha3\";s:7:\"version\";s:12:\"2.0.0-alpha3\";s:3:\"tag\";s:12:\"2.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/rabbit_hole/releases/2.0.0-alpha3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/rabbit_hole-2.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1688847249\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:12:\"2.0.0-alpha2\";a:11:{s:4:\"name\";s:24:\"rabbit_hole 2.0.0-alpha2\";s:7:\"version\";s:12:\"2.0.0-alpha2\";s:3:\"tag\";s:12:\"2.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/rabbit_hole/releases/2.0.0-alpha2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/rabbit_hole-2.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1687957454\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:12:\"2.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"rabbit_hole 2.0.0-alpha1\";s:7:\"version\";s:12:\"2.0.0-alpha1\";s:3:\"tag\";s:12:\"2.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/rabbit_hole/releases/2.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/rabbit_hole-2.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1687771797\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"rabbit_hole 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1721413113\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:14:\"8.x-1.0-beta11\";a:11:{s:4:\"name\";s:26:\"rabbit_hole 8.x-1.0-beta11\";s:7:\"version\";s:14:\"8.x-1.0-beta11\";s:3:\"tag\";s:14:\"8.x-1.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta11\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1670668459\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta10\";a:11:{s:4:\"name\";s:26:\"rabbit_hole 8.x-1.0-beta10\";s:7:\"version\";s:14:\"8.x-1.0-beta10\";s:3:\"tag\";s:14:\"8.x-1.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta10\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1610813035\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta9\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta9\";s:7:\"version\";s:13:\"8.x-1.0-beta9\";s:3:\"tag\";s:13:\"8.x-1.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta9\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1607021826\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta8\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta8\";s:7:\"version\";s:13:\"8.x-1.0-beta8\";s:3:\"tag\";s:13:\"8.x-1.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta8\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1606119907\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta7\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta7\";s:7:\"version\";s:13:\"8.x-1.0-beta7\";s:3:\"tag\";s:13:\"8.x-1.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta7\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1591667436\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta6\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta6\";s:7:\"version\";s:13:\"8.x-1.0-beta6\";s:3:\"tag\";s:13:\"8.x-1.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta6\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1556921886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1550891284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1506790444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1491779583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1486311483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:25:\"rabbit_hole 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1480471987\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:21:\"rabbit_hole 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/rabbit_hole/releases/2.0.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/rabbit_hole-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1736895375\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:19:\"rabbit_hole 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/rabbit_hole/releases/2.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/rabbit_hole-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1658497537\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"rabbit_hole 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/rabbit_hole/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/rabbit_hole-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1726704719\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932018;}',1744018418),('update_available_releases','redirect',_binary 'a:10:{s:5:\"title\";s:8:\"Redirect\";s:10:\"short_name\";s:8:\"redirect\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:15:\"drupal/redirect\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/redirect\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:19:{s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:17:\"redirect 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/redirect/releases/8.x-1.11\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1737382886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:17:\"redirect 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/redirect/releases/8.x-1.10\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1723277641\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.9\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1693393506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.8\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1661806955\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.7\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1639380488\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.6\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1589312204\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.5\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1576656784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1561757585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1539682684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1525419785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1520897880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1513767485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:22:\"redirect 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1501443542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1492182542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1487092684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1486078383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1481901483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1460041522\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:20:\"redirect 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/redirect/releases/8.x-1.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1736290352\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932018;}',1744018418),('update_available_releases','restui',_binary 'a:10:{s:5:\"title\";s:7:\"REST UI\";s:10:\"short_name\";s:6:\"restui\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:13:\"drupal/restui\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:37:\"https://www.drupal.org/project/restui\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:24:{s:8:\"8.x-1.22\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.22\";s:7:\"version\";s:8:\"8.x-1.22\";s:3:\"tag\";s:8:\"8.x-1.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.22\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.22.tar.gz\";s:4:\"date\";s:10:\"1721134189\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.21\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.21\";s:7:\"version\";s:8:\"8.x-1.21\";s:3:\"tag\";s:8:\"8.x-1.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.21\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.21.tar.gz\";s:4:\"date\";s:10:\"1659086914\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.7.7 || ^9 || ^10\";}s:8:\"8.x-1.20\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.20\";s:7:\"version\";s:8:\"8.x-1.20\";s:3:\"tag\";s:8:\"8.x-1.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.20\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.20.tar.gz\";s:4:\"date\";s:10:\"1616839543\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.19\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.19\";s:7:\"version\";s:8:\"8.x-1.19\";s:3:\"tag\";s:8:\"8.x-1.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.19\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.19.tar.gz\";s:4:\"date\";s:10:\"1606482499\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.18\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.18\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1586170645\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.17\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1557845581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.16\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1541330284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.15\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1496919842\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.14\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1493396643\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.13\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1478790974\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.12\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1476692639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.11\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1448976839\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:15:\"restui 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/restui/releases/8.x-1.10\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/restui-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1443268739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.9\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1421504281\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.8\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1398635327\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.7\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1395923643\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.6\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1389475404\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.5\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1387793305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1387150104\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1379507260\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1378074342\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1377727313\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:14:\"restui 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/restui/releases/8.x-1.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/restui-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1377188810\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:18:\"restui 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/restui/releases/8.x-1.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/restui-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721130858\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932019;}',1744018419),('update_available_releases','rest_absolute_urls',_binary 'a:10:{s:5:\"title\";s:18:\"REST Absolute URLs\";s:10:\"short_name\";s:18:\"rest_absolute_urls\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"2.0.\";s:18:\"composer_namespace\";s:25:\"drupal/rest_absolute_urls\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:49:\"https://www.drupal.org/project/rest_absolute_urls\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:4:{s:5:\"2.0.0\";a:11:{s:4:\"name\";s:24:\"rest_absolute_urls 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/rest_absolute_urls/releases/2.0.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/rest_absolute_urls-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1725017287\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:32:\"rest_absolute_urls 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/rest_absolute_urls/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/rest_absolute_urls-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1708683127\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:32:\"rest_absolute_urls 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/rest_absolute_urls/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/rest_absolute_urls-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1612876958\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:32:\"rest_absolute_urls 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/rest_absolute_urls/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/rest_absolute_urls-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1502800443\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932018;}',1744018418),('update_available_releases','simple_sitemap',_binary 'a:10:{s:5:\"title\";s:18:\"Simple XML sitemap\";s:10:\"short_name\";s:14:\"simple_sitemap\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"4.2.\";s:18:\"composer_namespace\";s:21:\"drupal/simple_sitemap\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/simple_sitemap\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:62:{s:5:\"4.2.2\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.2.2\";s:7:\"version\";s:5:\"4.2.2\";s:3:\"tag\";s:5:\"4.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.2.2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.2.2.tar.gz\";s:4:\"date\";s:10:\"1732485885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";}s:5:\"4.2.1\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.2.1\";s:7:\"version\";s:5:\"4.2.1\";s:3:\"tag\";s:5:\"4.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.2.1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.2.1.tar.gz\";s:4:\"date\";s:10:\"1723801798\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";}s:5:\"4.1.9\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.9\";s:7:\"version\";s:5:\"4.1.9\";s:3:\"tag\";s:5:\"4.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.9\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.9.tar.gz\";s:4:\"date\";s:10:\"1712441537\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.1.8\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.8\";s:7:\"version\";s:5:\"4.1.8\";s:3:\"tag\";s:5:\"4.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.8\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.8.tar.gz\";s:4:\"date\";s:10:\"1702898353\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.1.7\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.7\";s:7:\"version\";s:5:\"4.1.7\";s:3:\"tag\";s:5:\"4.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.7.tar.gz\";s:4:\"date\";s:10:\"1698936269\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.1.6\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.6\";s:7:\"version\";s:5:\"4.1.6\";s:3:\"tag\";s:5:\"4.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.6.tar.gz\";s:4:\"date\";s:10:\"1686288643\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.1.5\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.5\";s:7:\"version\";s:5:\"4.1.5\";s:3:\"tag\";s:5:\"4.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.5.tar.gz\";s:4:\"date\";s:10:\"1686252274\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.1.4\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.4\";s:7:\"version\";s:5:\"4.1.4\";s:3:\"tag\";s:5:\"4.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.4.tar.gz\";s:4:\"date\";s:10:\"1674226567\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.1.3\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.3\";s:7:\"version\";s:5:\"4.1.3\";s:3:\"tag\";s:5:\"4.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.3.tar.gz\";s:4:\"date\";s:10:\"1665533576\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.1.2\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.2\";s:7:\"version\";s:5:\"4.1.2\";s:3:\"tag\";s:5:\"4.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.2.tar.gz\";s:4:\"date\";s:10:\"1655334532\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.1.1\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.1\";s:7:\"version\";s:5:\"4.1.1\";s:3:\"tag\";s:5:\"4.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.1.tar.gz\";s:4:\"date\";s:10:\"1644365752\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:5:\"4.1.0\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.1.0\";s:7:\"version\";s:5:\"4.1.0\";s:3:\"tag\";s:5:\"4.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.1.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.1.0.tar.gz\";s:4:\"date\";s:10:\"1644326226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:5:\"4.0.1\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.0.1\";s:7:\"version\";s:5:\"4.0.1\";s:3:\"tag\";s:5:\"4.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.0.1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.0.1.tar.gz\";s:4:\"date\";s:10:\"1640700058\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:5:\"4.0.0\";a:11:{s:4:\"name\";s:20:\"simple_sitemap 4.0.0\";s:7:\"version\";s:5:\"4.0.0\";s:3:\"tag\";s:5:\"4.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/simple_sitemap/releases/4.0.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.0.0.tar.gz\";s:4:\"date\";s:10:\"1636933564\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:9:\"4.0.0-rc1\";a:11:{s:4:\"name\";s:24:\"simple_sitemap 4.0.0-rc1\";s:7:\"version\";s:9:\"4.0.0-rc1\";s:3:\"tag\";s:9:\"4.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/simple_sitemap/releases/4.0.0-rc1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1634992325\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:12:\"4.0.0-alpha3\";a:11:{s:4:\"name\";s:27:\"simple_sitemap 4.0.0-alpha3\";s:7:\"version\";s:12:\"4.0.0-alpha3\";s:3:\"tag\";s:12:\"4.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/simple_sitemap/releases/4.0.0-alpha3\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1634342992\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:12:\"4.0.0-alpha2\";a:11:{s:4:\"name\";s:27:\"simple_sitemap 4.0.0-alpha2\";s:7:\"version\";s:12:\"4.0.0-alpha2\";s:3:\"tag\";s:12:\"4.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/simple_sitemap/releases/4.0.0-alpha2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1626796251\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:12:\"4.0.0-alpha1\";a:11:{s:4:\"name\";s:27:\"simple_sitemap 4.0.0-alpha1\";s:7:\"version\";s:12:\"4.0.0-alpha1\";s:3:\"tag\";s:12:\"4.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/simple_sitemap/releases/4.0.0-alpha1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1625063106\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-3.11\";a:11:{s:4:\"name\";s:23:\"simple_sitemap 8.x-3.11\";s:7:\"version\";s:8:\"8.x-3.11\";s:3:\"tag\";s:8:\"8.x-3.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.11\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.11.tar.gz\";s:4:\"date\";s:10:\"1634343986\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-3.10\";a:11:{s:4:\"name\";s:23:\"simple_sitemap 8.x-3.10\";s:7:\"version\";s:8:\"8.x-3.10\";s:3:\"tag\";s:8:\"8.x-3.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.10\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.10.tar.gz\";s:4:\"date\";s:10:\"1617833756\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-3.9\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.9\";s:7:\"version\";s:7:\"8.x-3.9\";s:3:\"tag\";s:7:\"8.x-3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.9\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.9.tar.gz\";s:4:\"date\";s:10:\"1614984547\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-3.8\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.8\";s:7:\"version\";s:7:\"8.x-3.8\";s:3:\"tag\";s:7:\"8.x-3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.8.tar.gz\";s:4:\"date\";s:10:\"1605141357\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-3.7\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.7\";s:7:\"version\";s:7:\"8.x-3.7\";s:3:\"tag\";s:7:\"8.x-3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.7.tar.gz\";s:4:\"date\";s:10:\"1592298874\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-3.6\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1586468194\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-3.5\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.5\";s:7:\"version\";s:7:\"8.x-3.5\";s:3:\"tag\";s:7:\"8.x-3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.5.tar.gz\";s:4:\"date\";s:10:\"1576429387\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-3.4\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.4\";s:7:\"version\";s:7:\"8.x-3.4\";s:3:\"tag\";s:7:\"8.x-3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.4.tar.gz\";s:4:\"date\";s:10:\"1570445886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1563488885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1559004185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1552141685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1544174880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc4\";a:11:{s:4:\"name\";s:26:\"simple_sitemap 8.x-3.0-rc4\";s:7:\"version\";s:11:\"8.x-3.0-rc4\";s:3:\"tag\";s:11:\"8.x-3.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.0-rc4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1543633381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc3\";a:11:{s:4:\"name\";s:26:\"simple_sitemap 8.x-3.0-rc3\";s:7:\"version\";s:11:\"8.x-3.0-rc3\";s:3:\"tag\";s:11:\"8.x-3.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.0-rc3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1543326780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:26:\"simple_sitemap 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1542631980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:26:\"simple_sitemap 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1542505084\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:8:\"8.x-2.12\";a:11:{s:4:\"name\";s:23:\"simple_sitemap 8.x-2.12\";s:7:\"version\";s:8:\"8.x-2.12\";s:3:\"tag\";s:8:\"8.x-2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.12\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.12.tar.gz\";s:4:\"date\";s:10:\"1523202480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-2.11\";a:11:{s:4:\"name\";s:23:\"simple_sitemap 8.x-2.11\";s:7:\"version\";s:8:\"8.x-2.11\";s:3:\"tag\";s:8:\"8.x-2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.11\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.11.tar.gz\";s:4:\"date\";s:10:\"1513114985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-2.10\";a:11:{s:4:\"name\";s:23:\"simple_sitemap 8.x-2.10\";s:7:\"version\";s:8:\"8.x-2.10\";s:3:\"tag\";s:8:\"8.x-2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.10\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.10.tar.gz\";s:4:\"date\";s:10:\"1506357544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.9\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.9\";s:7:\"version\";s:7:\"8.x-2.9\";s:3:\"tag\";s:7:\"8.x-2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.9\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.9.tar.gz\";s:4:\"date\";s:10:\"1490775483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.8\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.8\";s:7:\"version\";s:7:\"8.x-2.8\";s:3:\"tag\";s:7:\"8.x-2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.8.tar.gz\";s:4:\"date\";s:10:\"1482783482\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.7\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.7\";s:7:\"version\";s:7:\"8.x-2.7\";s:3:\"tag\";s:7:\"8.x-2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.7.tar.gz\";s:4:\"date\";s:10:\"1478810042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.6\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.6\";s:7:\"version\";s:7:\"8.x-2.6\";s:3:\"tag\";s:7:\"8.x-2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.6.tar.gz\";s:4:\"date\";s:10:\"1471954139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1465427039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1474285739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1464269943\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1459197239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1456591439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:23:\"simple_sitemap 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.11\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1455214439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:23:\"simple_sitemap 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.10\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1474285739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.9\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1474285739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1454217240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1453164240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1452561240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1452357539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1474285739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1451828039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1446835439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1446827039\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1474285739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"4.x-dev\";a:11:{s:4:\"name\";s:22:\"simple_sitemap 4.x-dev\";s:7:\"version\";s:7:\"4.x-dev\";s:3:\"tag\";s:3:\"4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/simple_sitemap/releases/4.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/simple_sitemap-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743505575\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:26:\"simple_sitemap 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-3.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1644917966\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:26:\"simple_sitemap 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-2.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1528184884\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:26:\"simple_sitemap 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/simple_sitemap/releases/8.x-1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/simple_sitemap-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1457130540\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932019;}',1744018419),('update_available_releases','svg_image',_binary 'a:10:{s:5:\"title\";s:9:\"Svg Image\";s:10:\"short_name\";s:9:\"svg_image\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"3.0.,3.2.\";s:18:\"composer_namespace\";s:16:\"drupal/svg_image\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/svg_image\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:25:{s:5:\"3.2.1\";a:11:{s:4:\"name\";s:15:\"svg_image 3.2.1\";s:7:\"version\";s:5:\"3.2.1\";s:3:\"tag\";s:5:\"3.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/svg_image/releases/3.2.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/svg_image-3.2.1.tar.gz\";s:4:\"date\";s:10:\"1736865067\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:5:\"3.2.0\";a:11:{s:4:\"name\";s:15:\"svg_image 3.2.0\";s:7:\"version\";s:5:\"3.2.0\";s:3:\"tag\";s:5:\"3.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/svg_image/releases/3.2.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/svg_image-3.2.0.tar.gz\";s:4:\"date\";s:10:\"1733298091\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:5:\"3.1.0\";a:11:{s:4:\"name\";s:15:\"svg_image 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/svg_image/releases/3.1.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/svg_image-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1727351323\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:5:\"3.0.2\";a:11:{s:4:\"name\";s:15:\"svg_image 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/svg_image/releases/3.0.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/svg_image-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1698471266\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"3.0.1\";a:11:{s:4:\"name\";s:15:\"svg_image 3.0.1\";s:7:\"version\";s:5:\"3.0.1\";s:3:\"tag\";s:5:\"3.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/svg_image/releases/3.0.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/svg_image-3.0.1.tar.gz\";s:4:\"date\";s:10:\"1676292042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.16\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1647314248\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.15\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1629259130\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.14\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1591251834\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.13\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1585379082\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.12\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1585212808\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.11\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1585194882\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.10\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1585150271\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.9\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1548492180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.8\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1516678385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1508989144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1508940244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1508939044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1508930344\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1505705046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1503124445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1497798542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1497798242\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:17:\"svg_image 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734534945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:17:\"svg_image 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/2.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1628735183\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:21:\"svg_image 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/svg_image/releases/8.x-1.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1698470956\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}}s:10:\"last_fetch\";i:1743932019;}',1744018419),('update_available_releases','token',_binary 'a:10:{s:5:\"title\";s:5:\"Token\";s:10:\"short_name\";s:5:\"token\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:12:\"drupal/token\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:36:\"https://www.drupal.org/project/token\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:22:{s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.15\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1722206211\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.14\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1713009399\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.13\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1697885927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.12\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1688015262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1659471813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1638619775\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1608284866\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1607552423\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1587893588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1577708583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1537557481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1536408480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1527232684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1527112080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1513810384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1493466843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:17:\"token 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/token/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1483290542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:19:\"token 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/token/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1474367039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:19:\"token 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/token/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1470864453\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:20:\"token 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/token/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1453363739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:20:\"token 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/token/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1450961339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:17:\"token 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/token/releases/8.x-1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/token-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1734904588\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932019;}',1744018419),('update_available_releases','webform',_binary 'a:10:{s:5:\"title\";s:7:\"Webform\";s:10:\"short_name\";s:7:\"webform\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"6.2.,6.3.\";s:18:\"composer_namespace\";s:14:\"drupal/webform\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:38:\"https://www.drupal.org/project/webform\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:202:{s:11:\"6.3.0-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.3.0-beta2\";s:7:\"version\";s:11:\"6.3.0-beta2\";s:3:\"tag\";s:11:\"6.3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.3.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1742581864\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:14:\"^10.3 || ^11.0\";}s:11:\"6.3.0-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.3.0-beta1\";s:7:\"version\";s:11:\"6.3.0-beta1\";s:3:\"tag\";s:11:\"6.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.3.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1736275819\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:14:\"^10.3 || ^11.0\";}s:12:\"6.3.0-alpha3\";a:11:{s:4:\"name\";s:20:\"webform 6.3.0-alpha3\";s:7:\"version\";s:12:\"6.3.0-alpha3\";s:3:\"tag\";s:12:\"6.3.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.3.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.3.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1733851306\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:14:\"^10.3 || ^11.0\";}s:12:\"6.3.0-alpha2\";a:11:{s:4:\"name\";s:20:\"webform 6.3.0-alpha2\";s:7:\"version\";s:12:\"6.3.0-alpha2\";s:3:\"tag\";s:12:\"6.3.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.3.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.3.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1732628316\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:14:\"^10.3 || ^11.0\";}s:12:\"6.3.0-alpha1\";a:11:{s:4:\"name\";s:20:\"webform 6.3.0-alpha1\";s:7:\"version\";s:12:\"6.3.0-alpha1\";s:3:\"tag\";s:12:\"6.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.3.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1732305102\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:14:\"^10.3 || ^11.0\";}s:5:\"6.2.9\";a:11:{s:4:\"name\";s:13:\"webform 6.2.9\";s:7:\"version\";s:5:\"6.2.9\";s:3:\"tag\";s:5:\"6.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.9.tar.gz\";s:4:\"date\";s:10:\"1733851063\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.2\";}s:5:\"6.2.8\";a:11:{s:4:\"name\";s:13:\"webform 6.2.8\";s:7:\"version\";s:5:\"6.2.8\";s:3:\"tag\";s:5:\"6.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.8.tar.gz\";s:4:\"date\";s:10:\"1732627900\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.2\";}s:5:\"6.2.7\";a:11:{s:4:\"name\";s:13:\"webform 6.2.7\";s:7:\"version\";s:5:\"6.2.7\";s:3:\"tag\";s:5:\"6.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.7.tar.gz\";s:4:\"date\";s:10:\"1721425228\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.2.6\";a:11:{s:4:\"name\";s:13:\"webform 6.2.6\";s:7:\"version\";s:5:\"6.2.6\";s:3:\"tag\";s:5:\"6.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.6.tar.gz\";s:4:\"date\";s:10:\"1721424721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"6.2.5\";a:11:{s:4:\"name\";s:13:\"webform 6.2.5\";s:7:\"version\";s:5:\"6.2.5\";s:3:\"tag\";s:5:\"6.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.5.tar.gz\";s:4:\"date\";s:10:\"1721065379\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.2.4\";a:11:{s:4:\"name\";s:13:\"webform 6.2.4\";s:7:\"version\";s:5:\"6.2.4\";s:3:\"tag\";s:5:\"6.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.4.tar.gz\";s:4:\"date\";s:10:\"1721054262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:9:\"6.2.4-rc1\";a:11:{s:4:\"name\";s:17:\"webform 6.2.4-rc1\";s:7:\"version\";s:9:\"6.2.4-rc1\";s:3:\"tag\";s:9:\"6.2.4-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.4-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.4-rc1.tar.gz\";s:4:\"date\";s:10:\"1719495514\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.2.3\";a:11:{s:4:\"name\";s:13:\"webform 6.2.3\";s:7:\"version\";s:5:\"6.2.3\";s:3:\"tag\";s:5:\"6.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.3.tar.gz\";s:4:\"date\";s:10:\"1719330022\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"6.2.2\";a:11:{s:4:\"name\";s:13:\"webform 6.2.2\";s:7:\"version\";s:5:\"6.2.2\";s:3:\"tag\";s:5:\"6.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.2.tar.gz\";s:4:\"date\";s:10:\"1701948363\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"6.2.1\";a:11:{s:4:\"name\";s:13:\"webform 6.2.1\";s:7:\"version\";s:5:\"6.2.1\";s:3:\"tag\";s:5:\"6.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.1.tar.gz\";s:4:\"date\";s:10:\"1701862848\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"6.2.0\";a:11:{s:4:\"name\";s:13:\"webform 6.2.0\";s:7:\"version\";s:5:\"6.2.0\";s:3:\"tag\";s:5:\"6.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.0.tar.gz\";s:4:\"date\";s:10:\"1698674300\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"6.2.0-rc4\";a:11:{s:4:\"name\";s:17:\"webform 6.2.0-rc4\";s:7:\"version\";s:9:\"6.2.0-rc4\";s:3:\"tag\";s:9:\"6.2.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.0-rc4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1698417151\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"6.2.0-rc3\";a:11:{s:4:\"name\";s:17:\"webform 6.2.0-rc3\";s:7:\"version\";s:9:\"6.2.0-rc3\";s:3:\"tag\";s:9:\"6.2.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.0-rc3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1698075159\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"6.2.0-rc2\";a:11:{s:4:\"name\";s:17:\"webform 6.2.0-rc2\";s:7:\"version\";s:9:\"6.2.0-rc2\";s:3:\"tag\";s:9:\"6.2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.0-rc2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1697463934\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"6.2.0-rc1\";a:11:{s:4:\"name\";s:17:\"webform 6.2.0-rc1\";s:7:\"version\";s:9:\"6.2.0-rc1\";s:3:\"tag\";s:9:\"6.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1696976940\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.2.0-beta7\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta7\";s:7:\"version\";s:11:\"6.2.0-beta7\";s:3:\"tag\";s:11:\"6.2.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta7\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1696543693\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.2.0-beta6\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta6\";s:7:\"version\";s:11:\"6.2.0-beta6\";s:3:\"tag\";s:11:\"6.2.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1686598812\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.2.0-beta5\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta5\";s:7:\"version\";s:11:\"6.2.0-beta5\";s:3:\"tag\";s:11:\"6.2.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1673535773\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.2.0-beta4\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta4\";s:7:\"version\";s:11:\"6.2.0-beta4\";s:3:\"tag\";s:11:\"6.2.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1672758935\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"6.2.0-beta3\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta3\";s:7:\"version\";s:11:\"6.2.0-beta3\";s:3:\"tag\";s:11:\"6.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1663937872\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^9.4\";}s:11:\"6.2.0-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta2\";s:7:\"version\";s:11:\"6.2.0-beta2\";s:3:\"tag\";s:11:\"6.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1644940970\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:11:\"6.2.0-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta1\";s:7:\"version\";s:11:\"6.2.0-beta1\";s:3:\"tag\";s:11:\"6.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1640795829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:5:\"6.1.8\";a:11:{s:4:\"name\";s:13:\"webform 6.1.8\";s:7:\"version\";s:5:\"6.1.8\";s:3:\"tag\";s:5:\"6.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.8.tar.gz\";s:4:\"date\";s:10:\"1698673929\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.3\";}s:5:\"6.1.7\";a:11:{s:4:\"name\";s:13:\"webform 6.1.7\";s:7:\"version\";s:5:\"6.1.7\";s:3:\"tag\";s:5:\"6.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.7.tar.gz\";s:4:\"date\";s:10:\"1696976671\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.3\";}s:5:\"6.1.6\";a:11:{s:4:\"name\";s:13:\"webform 6.1.6\";s:7:\"version\";s:5:\"6.1.6\";s:3:\"tag\";s:5:\"6.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.6.tar.gz\";s:4:\"date\";s:10:\"1696543413\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.3\";}s:5:\"6.1.5\";a:11:{s:4:\"name\";s:13:\"webform 6.1.5\";s:7:\"version\";s:5:\"6.1.5\";s:3:\"tag\";s:5:\"6.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.5.tar.gz\";s:4:\"date\";s:10:\"1686599078\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.3\";}s:5:\"6.1.4\";a:11:{s:4:\"name\";s:13:\"webform 6.1.4\";s:7:\"version\";s:5:\"6.1.4\";s:3:\"tag\";s:5:\"6.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.4.tar.gz\";s:4:\"date\";s:10:\"1673535467\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.1.4-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.1.4-beta2\";s:7:\"version\";s:11:\"6.1.4-beta2\";s:3:\"tag\";s:11:\"6.1.4-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.4-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.4-beta2.tar.gz\";s:4:\"date\";s:10:\"1672758568\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"6.1.4-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.1.4-beta1\";s:7:\"version\";s:11:\"6.1.4-beta1\";s:3:\"tag\";s:11:\"6.1.4-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.4-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.4-beta1.tar.gz\";s:4:\"date\";s:10:\"1663937578\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.1.3\";a:11:{s:4:\"name\";s:13:\"webform 6.1.3\";s:7:\"version\";s:5:\"6.1.3\";s:3:\"tag\";s:5:\"6.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.3.tar.gz\";s:4:\"date\";s:10:\"1644940723\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.1.3-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.1.3-beta1\";s:7:\"version\";s:11:\"6.1.3-beta1\";s:3:\"tag\";s:11:\"6.1.3-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.3-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.3-beta1.tar.gz\";s:4:\"date\";s:10:\"1640795631\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.1.2\";a:11:{s:4:\"name\";s:13:\"webform 6.1.2\";s:7:\"version\";s:5:\"6.1.2\";s:3:\"tag\";s:5:\"6.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.2.tar.gz\";s:4:\"date\";s:10:\"1638917151\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.1.1\";a:11:{s:4:\"name\";s:13:\"webform 6.1.1\";s:7:\"version\";s:5:\"6.1.1\";s:3:\"tag\";s:5:\"6.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.1.tar.gz\";s:4:\"date\";s:10:\"1638398898\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.1.0\";a:11:{s:4:\"name\";s:13:\"webform 6.1.0\";s:7:\"version\";s:5:\"6.1.0\";s:3:\"tag\";s:5:\"6.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.0.tar.gz\";s:4:\"date\";s:10:\"1635676666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.1.0-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.1.0-beta2\";s:7:\"version\";s:11:\"6.1.0-beta2\";s:3:\"tag\";s:11:\"6.1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1629904016\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.1.0-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.1.0-beta1\";s:7:\"version\";s:11:\"6.1.0-beta1\";s:3:\"tag\";s:11:\"6.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1626269425\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.8\";a:11:{s:4:\"name\";s:13:\"webform 6.0.8\";s:7:\"version\";s:5:\"6.0.8\";s:3:\"tag\";s:5:\"6.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.8.tar.gz\";s:4:\"date\";s:10:\"1673535119\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.7\";a:11:{s:4:\"name\";s:13:\"webform 6.0.7\";s:7:\"version\";s:5:\"6.0.7\";s:3:\"tag\";s:5:\"6.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.7.tar.gz\";s:4:\"date\";s:10:\"1644940479\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.6\";a:11:{s:4:\"name\";s:13:\"webform 6.0.6\";s:7:\"version\";s:5:\"6.0.6\";s:3:\"tag\";s:5:\"6.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.6.tar.gz\";s:4:\"date\";s:10:\"1638916646\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.5\";a:11:{s:4:\"name\";s:13:\"webform 6.0.5\";s:7:\"version\";s:5:\"6.0.5\";s:3:\"tag\";s:5:\"6.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.5.tar.gz\";s:4:\"date\";s:10:\"1629903941\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.4\";a:11:{s:4:\"name\";s:13:\"webform 6.0.4\";s:7:\"version\";s:5:\"6.0.4\";s:3:\"tag\";s:5:\"6.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.4.tar.gz\";s:4:\"date\";s:10:\"1624461046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.3\";a:11:{s:4:\"name\";s:13:\"webform 6.0.3\";s:7:\"version\";s:5:\"6.0.3\";s:3:\"tag\";s:5:\"6.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.3.tar.gz\";s:4:\"date\";s:10:\"1620250254\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.2\";a:11:{s:4:\"name\";s:13:\"webform 6.0.2\";s:7:\"version\";s:5:\"6.0.2\";s:3:\"tag\";s:5:\"6.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.2.tar.gz\";s:4:\"date\";s:10:\"1614711149\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.1\";a:11:{s:4:\"name\";s:13:\"webform 6.0.1\";s:7:\"version\";s:5:\"6.0.1\";s:3:\"tag\";s:5:\"6.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.1.tar.gz\";s:4:\"date\";s:10:\"1612453373\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.0\";a:11:{s:4:\"name\";s:13:\"webform 6.0.0\";s:7:\"version\";s:5:\"6.0.0\";s:3:\"tag\";s:5:\"6.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.0.tar.gz\";s:4:\"date\";s:10:\"1608855845\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta3\";a:11:{s:4:\"name\";s:19:\"webform 6.0.0-beta3\";s:7:\"version\";s:11:\"6.0.0-beta3\";s:3:\"tag\";s:11:\"6.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.0.0-beta3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1608425493\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.0.0-beta2\";s:7:\"version\";s:11:\"6.0.0-beta2\";s:3:\"tag\";s:11:\"6.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.0.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1606687841\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.0.0-beta1\";s:7:\"version\";s:11:\"6.0.0-beta1\";s:3:\"tag\";s:11:\"6.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1606179568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha21\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha21\";s:7:\"version\";s:13:\"6.0.0-alpha21\";s:3:\"tag\";s:13:\"6.0.0-alpha21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha21\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha21.tar.gz\";s:4:\"date\";s:10:\"1604531929\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha20\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha20\";s:7:\"version\";s:13:\"6.0.0-alpha20\";s:3:\"tag\";s:13:\"6.0.0-alpha20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha20\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha20.tar.gz\";s:4:\"date\";s:10:\"1601919730\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha19\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha19\";s:7:\"version\";s:13:\"6.0.0-alpha19\";s:3:\"tag\";s:13:\"6.0.0-alpha19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha19\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha19.tar.gz\";s:4:\"date\";s:10:\"1601647879\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha18\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha18\";s:7:\"version\";s:13:\"6.0.0-alpha18\";s:3:\"tag\";s:13:\"6.0.0-alpha18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha18\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha18.tar.gz\";s:4:\"date\";s:10:\"1601385862\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha17\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha17\";s:7:\"version\";s:13:\"6.0.0-alpha17\";s:3:\"tag\";s:13:\"6.0.0-alpha17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha17\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha17.tar.gz\";s:4:\"date\";s:10:\"1600376449\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha16\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha16\";s:7:\"version\";s:13:\"6.0.0-alpha16\";s:3:\"tag\";s:13:\"6.0.0-alpha16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha16\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha16.tar.gz\";s:4:\"date\";s:10:\"1599851828\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha15\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha15\";s:7:\"version\";s:13:\"6.0.0-alpha15\";s:3:\"tag\";s:13:\"6.0.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha15\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1599240333\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha14\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha14\";s:7:\"version\";s:13:\"6.0.0-alpha14\";s:3:\"tag\";s:13:\"6.0.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha14\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1597828848\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha13\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha13\";s:7:\"version\";s:13:\"6.0.0-alpha13\";s:3:\"tag\";s:13:\"6.0.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha13\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1597166474\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha12\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha12\";s:7:\"version\";s:13:\"6.0.0-alpha12\";s:3:\"tag\";s:13:\"6.0.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha12\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1595283358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha11\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha11\";s:7:\"version\";s:13:\"6.0.0-alpha11\";s:3:\"tag\";s:13:\"6.0.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha11\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1594713947\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha10\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha10\";s:7:\"version\";s:13:\"6.0.0-alpha10\";s:3:\"tag\";s:13:\"6.0.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha10\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1594241841\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha9\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha9\";s:7:\"version\";s:12:\"6.0.0-alpha9\";s:3:\"tag\";s:12:\"6.0.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha9\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1593681225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha8\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha8\";s:7:\"version\";s:12:\"6.0.0-alpha8\";s:3:\"tag\";s:12:\"6.0.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha8\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1593034684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha7\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha7\";s:7:\"version\";s:12:\"6.0.0-alpha7\";s:3:\"tag\";s:12:\"6.0.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1592841350\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha6\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha6\";s:7:\"version\";s:12:\"6.0.0-alpha6\";s:3:\"tag\";s:12:\"6.0.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1592616296\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha5\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha5\";s:7:\"version\";s:12:\"6.0.0-alpha5\";s:3:\"tag\";s:12:\"6.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1592495851\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha4\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha4\";s:7:\"version\";s:12:\"6.0.0-alpha4\";s:3:\"tag\";s:12:\"6.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1591273787\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha3\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha3\";s:7:\"version\";s:12:\"6.0.0-alpha3\";s:3:\"tag\";s:12:\"6.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1591199141\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha2\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha2\";s:7:\"version\";s:12:\"6.0.0-alpha2\";s:3:\"tag\";s:12:\"6.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1590971769\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"6.0.0-alpha1\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha1\";s:7:\"version\";s:12:\"6.0.0-alpha1\";s:3:\"tag\";s:12:\"6.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1590950600\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-5.31\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.31\";s:7:\"version\";s:8:\"8.x-5.31\";s:3:\"tag\";s:8:\"8.x-5.31\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.31\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.31.tar.gz\";s:4:\"date\";s:10:\"1638915771\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.30\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.30\";s:7:\"version\";s:8:\"8.x-5.30\";s:3:\"tag\";s:8:\"8.x-5.30\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.30\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.30.tar.gz\";s:4:\"date\";s:10:\"1638915163\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.29\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.29\";s:7:\"version\";s:8:\"8.x-5.29\";s:3:\"tag\";s:8:\"8.x-5.29\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.29\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.29.tar.gz\";s:4:\"date\";s:10:\"1635676451\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.28\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.28\";s:7:\"version\";s:8:\"8.x-5.28\";s:3:\"tag\";s:8:\"8.x-5.28\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.28\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.28.tar.gz\";s:4:\"date\";s:10:\"1629903873\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.28-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.28-beta1\";s:7:\"version\";s:14:\"8.x-5.28-beta1\";s:3:\"tag\";s:14:\"8.x-5.28-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.28-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.28-beta1.tar.gz\";s:4:\"date\";s:10:\"1626269167\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.27\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.27\";s:7:\"version\";s:8:\"8.x-5.27\";s:3:\"tag\";s:8:\"8.x-5.27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.27\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.27.tar.gz\";s:4:\"date\";s:10:\"1624460854\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.26\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.26\";s:7:\"version\";s:8:\"8.x-5.26\";s:3:\"tag\";s:8:\"8.x-5.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.26\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.26.tar.gz\";s:4:\"date\";s:10:\"1620250064\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.25\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.25\";s:7:\"version\";s:8:\"8.x-5.25\";s:3:\"tag\";s:8:\"8.x-5.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.25\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.25.tar.gz\";s:4:\"date\";s:10:\"1614711099\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.24\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.24\";s:7:\"version\";s:8:\"8.x-5.24\";s:3:\"tag\";s:8:\"8.x-5.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.24\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.24.tar.gz\";s:4:\"date\";s:10:\"1612453175\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.23\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.23\";s:7:\"version\";s:8:\"8.x-5.23\";s:3:\"tag\";s:8:\"8.x-5.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.23\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23.tar.gz\";s:4:\"date\";s:10:\"1608855643\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.23-beta4\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.23-beta4\";s:7:\"version\";s:14:\"8.x-5.23-beta4\";s:3:\"tag\";s:14:\"8.x-5.23-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.23-beta4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23-beta4.tar.gz\";s:4:\"date\";s:10:\"1608425252\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.23-beta3\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.23-beta3\";s:7:\"version\";s:14:\"8.x-5.23-beta3\";s:3:\"tag\";s:14:\"8.x-5.23-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.23-beta3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23-beta3.tar.gz\";s:4:\"date\";s:10:\"1606687658\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.23-beta2\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.23-beta2\";s:7:\"version\";s:14:\"8.x-5.23-beta2\";s:3:\"tag\";s:14:\"8.x-5.23-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.23-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23-beta2.tar.gz\";s:4:\"date\";s:10:\"1606179294\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.23-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.23-beta1\";s:7:\"version\";s:14:\"8.x-5.23-beta1\";s:3:\"tag\";s:14:\"8.x-5.23-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.23-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23-beta1.tar.gz\";s:4:\"date\";s:10:\"1604531721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.22\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.22\";s:7:\"version\";s:8:\"8.x-5.22\";s:3:\"tag\";s:8:\"8.x-5.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.22\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.22.tar.gz\";s:4:\"date\";s:10:\"1601919522\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.21\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.21\";s:7:\"version\";s:8:\"8.x-5.21\";s:3:\"tag\";s:8:\"8.x-5.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.21\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.21.tar.gz\";s:4:\"date\";s:10:\"1601385690\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.20\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.20\";s:7:\"version\";s:8:\"8.x-5.20\";s:3:\"tag\";s:8:\"8.x-5.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.20\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20.tar.gz\";s:4:\"date\";s:10:\"1599851752\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta6\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta6\";s:7:\"version\";s:14:\"8.x-5.20-beta6\";s:3:\"tag\";s:14:\"8.x-5.20-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta6.tar.gz\";s:4:\"date\";s:10:\"1599240197\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta5\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta5\";s:7:\"version\";s:14:\"8.x-5.20-beta5\";s:3:\"tag\";s:14:\"8.x-5.20-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta5.tar.gz\";s:4:\"date\";s:10:\"1597828670\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta4\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta4\";s:7:\"version\";s:14:\"8.x-5.20-beta4\";s:3:\"tag\";s:14:\"8.x-5.20-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta4.tar.gz\";s:4:\"date\";s:10:\"1597166399\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta3\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta3\";s:7:\"version\";s:14:\"8.x-5.20-beta3\";s:3:\"tag\";s:14:\"8.x-5.20-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta3.tar.gz\";s:4:\"date\";s:10:\"1595283192\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta2\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta2\";s:7:\"version\";s:14:\"8.x-5.20-beta2\";s:3:\"tag\";s:14:\"8.x-5.20-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta2.tar.gz\";s:4:\"date\";s:10:\"1594713787\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta1\";s:7:\"version\";s:14:\"8.x-5.20-beta1\";s:3:\"tag\";s:14:\"8.x-5.20-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta1.tar.gz\";s:4:\"date\";s:10:\"1594241756\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.19\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.19\";s:7:\"version\";s:8:\"8.x-5.19\";s:3:\"tag\";s:8:\"8.x-5.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.19\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.19.tar.gz\";s:4:\"date\";s:10:\"1593681136\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.18\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.18\";s:7:\"version\";s:8:\"8.x-5.18\";s:3:\"tag\";s:8:\"8.x-5.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.18\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.18.tar.gz\";s:4:\"date\";s:10:\"1593034084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.17\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.17\";s:7:\"version\";s:8:\"8.x-5.17\";s:3:\"tag\";s:8:\"8.x-5.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.17\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.17.tar.gz\";s:4:\"date\";s:10:\"1592841189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.17-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.17-beta1\";s:7:\"version\";s:14:\"8.x-5.17-beta1\";s:3:\"tag\";s:14:\"8.x-5.17-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.17-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.17-beta1.tar.gz\";s:4:\"date\";s:10:\"1592495751\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.16\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.16\";s:7:\"version\";s:8:\"8.x-5.16\";s:3:\"tag\";s:8:\"8.x-5.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.16\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.16.tar.gz\";s:4:\"date\";s:10:\"1591198998\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.15\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.15\";s:7:\"version\";s:8:\"8.x-5.15\";s:3:\"tag\";s:8:\"8.x-5.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.15\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.15.tar.gz\";s:4:\"date\";s:10:\"1590971702\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:8:\"8.x-5.14\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.14\";s:7:\"version\";s:8:\"8.x-5.14\";s:3:\"tag\";s:8:\"8.x-5.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.14\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.14.tar.gz\";s:4:\"date\";s:10:\"1590950034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:14:\"8.x-5.14-beta2\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.14-beta2\";s:7:\"version\";s:14:\"8.x-5.14-beta2\";s:3:\"tag\";s:14:\"8.x-5.14-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.14-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.14-beta2.tar.gz\";s:4:\"date\";s:10:\"1590499309\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.14-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.14-beta1\";s:7:\"version\";s:14:\"8.x-5.14-beta1\";s:3:\"tag\";s:14:\"8.x-5.14-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.14-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.14-beta1.tar.gz\";s:4:\"date\";s:10:\"1590275692\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-5.13\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.13\";s:7:\"version\";s:8:\"8.x-5.13\";s:3:\"tag\";s:8:\"8.x-5.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.13.tar.gz\";s:4:\"date\";s:10:\"1589661354\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-5.12\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.12\";s:7:\"version\";s:8:\"8.x-5.12\";s:3:\"tag\";s:8:\"8.x-5.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.12.tar.gz\";s:4:\"date\";s:10:\"1589372278\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-5.11\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.11\";s:7:\"version\";s:8:\"8.x-5.11\";s:3:\"tag\";s:8:\"8.x-5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.11.tar.gz\";s:4:\"date\";s:10:\"1588690387\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-5.10\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.10\";s:7:\"version\";s:8:\"8.x-5.10\";s:3:\"tag\";s:8:\"8.x-5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.10.tar.gz\";s:4:\"date\";s:10:\"1588090448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-5.9\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.9\";s:7:\"version\";s:7:\"8.x-5.9\";s:3:\"tag\";s:7:\"8.x-5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.9.tar.gz\";s:4:\"date\";s:10:\"1584560013\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:13:\"8.x-5.9-beta2\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.9-beta2\";s:7:\"version\";s:13:\"8.x-5.9-beta2\";s:3:\"tag\";s:13:\"8.x-5.9-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.9-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.9-beta2.tar.gz\";s:4:\"date\";s:10:\"1582899185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:13:\"8.x-5.9-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.9-beta1\";s:7:\"version\";s:13:\"8.x-5.9-beta1\";s:3:\"tag\";s:13:\"8.x-5.9-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.9-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.9-beta1.tar.gz\";s:4:\"date\";s:10:\"1581626310\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-5.8\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.8\";s:7:\"version\";s:7:\"8.x-5.8\";s:3:\"tag\";s:7:\"8.x-5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.8.tar.gz\";s:4:\"date\";s:10:\"1579637587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:7:\"8.x-5.7\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.7\";s:7:\"version\";s:7:\"8.x-5.7\";s:3:\"tag\";s:7:\"8.x-5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.7.tar.gz\";s:4:\"date\";s:10:\"1579208583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:13:\"8.x-5.7-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.7-beta1\";s:7:\"version\";s:13:\"8.x-5.7-beta1\";s:3:\"tag\";s:13:\"8.x-5.7-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.7-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.7-beta1.tar.gz\";s:4:\"date\";s:10:\"1578341283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^8\";}s:7:\"8.x-5.6\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.6\";s:7:\"version\";s:7:\"8.x-5.6\";s:3:\"tag\";s:7:\"8.x-5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.6.tar.gz\";s:4:\"date\";s:10:\"1575331086\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.6-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.6-beta1\";s:7:\"version\";s:13:\"8.x-5.6-beta1\";s:3:\"tag\";s:13:\"8.x-5.6-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.6-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.6-beta1.tar.gz\";s:4:\"date\";s:10:\"1574077985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.5\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.5\";s:7:\"version\";s:7:\"8.x-5.5\";s:3:\"tag\";s:7:\"8.x-5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5.tar.gz\";s:4:\"date\";s:10:\"1572377284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.5-rc2\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.5-rc2\";s:7:\"version\";s:11:\"8.x-5.5-rc2\";s:3:\"tag\";s:11:\"8.x-5.5-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.5-rc2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5-rc2.tar.gz\";s:4:\"date\";s:10:\"1570176784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.5-rc1\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.5-rc1\";s:7:\"version\";s:11:\"8.x-5.5-rc1\";s:3:\"tag\";s:11:\"8.x-5.5-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.5-rc1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5-rc1.tar.gz\";s:4:\"date\";s:10:\"1569445386\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.5-beta2\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.5-beta2\";s:7:\"version\";s:13:\"8.x-5.5-beta2\";s:3:\"tag\";s:13:\"8.x-5.5-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.5-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5-beta2.tar.gz\";s:4:\"date\";s:10:\"1568992985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.5-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.5-beta1\";s:7:\"version\";s:13:\"8.x-5.5-beta1\";s:3:\"tag\";s:13:\"8.x-5.5-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.5-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5-beta1.tar.gz\";s:4:\"date\";s:10:\"1567698485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.4\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.4\";s:7:\"version\";s:7:\"8.x-5.4\";s:3:\"tag\";s:7:\"8.x-5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.4.tar.gz\";s:4:\"date\";s:10:\"1566209286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.4-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.4-beta1\";s:7:\"version\";s:13:\"8.x-5.4-beta1\";s:3:\"tag\";s:13:\"8.x-5.4-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.4-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.4-beta1.tar.gz\";s:4:\"date\";s:10:\"1565332985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.3\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.3\";s:7:\"version\";s:7:\"8.x-5.3\";s:3:\"tag\";s:7:\"8.x-5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3.tar.gz\";s:4:\"date\";s:10:\"1563460085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.3-rc3\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.3-rc3\";s:7:\"version\";s:11:\"8.x-5.3-rc3\";s:3:\"tag\";s:11:\"8.x-5.3-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.3-rc3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-rc3.tar.gz\";s:4:\"date\";s:10:\"1562013184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.3-rc2\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.3-rc2\";s:7:\"version\";s:11:\"8.x-5.3-rc2\";s:3:\"tag\";s:11:\"8.x-5.3-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.3-rc2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-rc2.tar.gz\";s:4:\"date\";s:10:\"1561474385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.3-rc1\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.3-rc1\";s:7:\"version\";s:11:\"8.x-5.3-rc1\";s:3:\"tag\";s:11:\"8.x-5.3-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.3-rc1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-rc1.tar.gz\";s:4:\"date\";s:10:\"1559676185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.3-beta3\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.3-beta3\";s:7:\"version\";s:13:\"8.x-5.3-beta3\";s:3:\"tag\";s:13:\"8.x-5.3-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.3-beta3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-beta3.tar.gz\";s:4:\"date\";s:10:\"1558032481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.3-beta2\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.3-beta2\";s:7:\"version\";s:13:\"8.x-5.3-beta2\";s:3:\"tag\";s:13:\"8.x-5.3-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.3-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-beta2.tar.gz\";s:4:\"date\";s:10:\"1557417193\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.3-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.3-beta1\";s:7:\"version\";s:13:\"8.x-5.3-beta1\";s:3:\"tag\";s:13:\"8.x-5.3-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.3-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-beta1.tar.gz\";s:4:\"date\";s:10:\"1556736481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.2\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.2\";s:7:\"version\";s:7:\"8.x-5.2\";s:3:\"tag\";s:7:\"8.x-5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2.tar.gz\";s:4:\"date\";s:10:\"1553768585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.2-rc3\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.2-rc3\";s:7:\"version\";s:11:\"8.x-5.2-rc3\";s:3:\"tag\";s:11:\"8.x-5.2-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.2-rc3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2-rc3.tar.gz\";s:4:\"date\";s:10:\"1552733285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.2-rc2\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.2-rc2\";s:7:\"version\";s:11:\"8.x-5.2-rc2\";s:3:\"tag\";s:11:\"8.x-5.2-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.2-rc2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2-rc2.tar.gz\";s:4:\"date\";s:10:\"1551880385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.2-rc1\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.2-rc1\";s:7:\"version\";s:11:\"8.x-5.2-rc1\";s:3:\"tag\";s:11:\"8.x-5.2-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.2-rc1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2-rc1.tar.gz\";s:4:\"date\";s:10:\"1551829980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.2-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.2-beta1\";s:7:\"version\";s:13:\"8.x-5.2-beta1\";s:3:\"tag\";s:13:\"8.x-5.2-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.2-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2-beta1.tar.gz\";s:4:\"date\";s:10:\"1548435780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.1\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.1\";s:7:\"version\";s:7:\"8.x-5.1\";s:3:\"tag\";s:7:\"8.x-5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.1.tar.gz\";s:4:\"date\";s:10:\"1546458480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.0\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.0\";s:7:\"version\";s:7:\"8.x-5.0\";s:3:\"tag\";s:7:\"8.x-5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0.tar.gz\";s:4:\"date\";s:10:\"1545656285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc31\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc31\";s:7:\"version\";s:12:\"8.x-5.0-rc31\";s:3:\"tag\";s:12:\"8.x-5.0-rc31\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc31\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc31.tar.gz\";s:4:\"date\";s:10:\"1545138180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc30\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc30\";s:7:\"version\";s:12:\"8.x-5.0-rc30\";s:3:\"tag\";s:12:\"8.x-5.0-rc30\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc30\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc30.tar.gz\";s:4:\"date\";s:10:\"1544990880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc29\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc29\";s:7:\"version\";s:12:\"8.x-5.0-rc29\";s:3:\"tag\";s:12:\"8.x-5.0-rc29\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc29\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc29.tar.gz\";s:4:\"date\";s:10:\"1544223180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc28\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc28\";s:7:\"version\";s:12:\"8.x-5.0-rc28\";s:3:\"tag\";s:12:\"8.x-5.0-rc28\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc28\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc28.tar.gz\";s:4:\"date\";s:10:\"1544218081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc27\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc27\";s:7:\"version\";s:12:\"8.x-5.0-rc27\";s:3:\"tag\";s:12:\"8.x-5.0-rc27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc27\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc27.tar.gz\";s:4:\"date\";s:10:\"1543520280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc26\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc26\";s:7:\"version\";s:12:\"8.x-5.0-rc26\";s:3:\"tag\";s:12:\"8.x-5.0-rc26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc26\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc26.tar.gz\";s:4:\"date\";s:10:\"1541466481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc25\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc25\";s:7:\"version\";s:12:\"8.x-5.0-rc25\";s:3:\"tag\";s:12:\"8.x-5.0-rc25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc25\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc25.tar.gz\";s:4:\"date\";s:10:\"1541452980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc24\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc24\";s:7:\"version\";s:12:\"8.x-5.0-rc24\";s:3:\"tag\";s:12:\"8.x-5.0-rc24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc24\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc24.tar.gz\";s:4:\"date\";s:10:\"1540255380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc23\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc23\";s:7:\"version\";s:12:\"8.x-5.0-rc23\";s:3:\"tag\";s:12:\"8.x-5.0-rc23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc23\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc23.tar.gz\";s:4:\"date\";s:10:\"1540052580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc22\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc22\";s:7:\"version\";s:12:\"8.x-5.0-rc22\";s:3:\"tag\";s:12:\"8.x-5.0-rc22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc22\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc22.tar.gz\";s:4:\"date\";s:10:\"1538482685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc21\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc21\";s:7:\"version\";s:12:\"8.x-5.0-rc21\";s:3:\"tag\";s:12:\"8.x-5.0-rc21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc21\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc21.tar.gz\";s:4:\"date\";s:10:\"1536405484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc20\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc20\";s:7:\"version\";s:12:\"8.x-5.0-rc20\";s:3:\"tag\";s:12:\"8.x-5.0-rc20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc20\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc20.tar.gz\";s:4:\"date\";s:10:\"1536336480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc19\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc19\";s:7:\"version\";s:12:\"8.x-5.0-rc19\";s:3:\"tag\";s:12:\"8.x-5.0-rc19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc19\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc19.tar.gz\";s:4:\"date\";s:10:\"1536257580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc18\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc18\";s:7:\"version\";s:12:\"8.x-5.0-rc18\";s:3:\"tag\";s:12:\"8.x-5.0-rc18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc18\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc18.tar.gz\";s:4:\"date\";s:10:\"1533682980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc17\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc17\";s:7:\"version\";s:12:\"8.x-5.0-rc17\";s:3:\"tag\";s:12:\"8.x-5.0-rc17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc17\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc17.tar.gz\";s:4:\"date\";s:10:\"1533563280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc16\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc16\";s:7:\"version\";s:12:\"8.x-5.0-rc16\";s:3:\"tag\";s:12:\"8.x-5.0-rc16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc16\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc16.tar.gz\";s:4:\"date\";s:10:\"1530298420\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc15\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc15\";s:7:\"version\";s:12:\"8.x-5.0-rc15\";s:3:\"tag\";s:12:\"8.x-5.0-rc15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc15\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc15.tar.gz\";s:4:\"date\";s:10:\"1528795685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc14\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc14\";s:7:\"version\";s:12:\"8.x-5.0-rc14\";s:3:\"tag\";s:12:\"8.x-5.0-rc14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc14\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc14.tar.gz\";s:4:\"date\";s:10:\"1528277284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc13\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc13\";s:7:\"version\";s:12:\"8.x-5.0-rc13\";s:3:\"tag\";s:12:\"8.x-5.0-rc13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc13\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc13.tar.gz\";s:4:\"date\";s:10:\"1528137480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc12\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc12\";s:7:\"version\";s:12:\"8.x-5.0-rc12\";s:3:\"tag\";s:12:\"8.x-5.0-rc12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc12\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc12.tar.gz\";s:4:\"date\";s:10:\"1524706684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc11\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc11\";s:7:\"version\";s:12:\"8.x-5.0-rc11\";s:3:\"tag\";s:12:\"8.x-5.0-rc11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc11\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc11.tar.gz\";s:4:\"date\";s:10:\"1524229380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc10\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc10\";s:7:\"version\";s:12:\"8.x-5.0-rc10\";s:3:\"tag\";s:12:\"8.x-5.0-rc10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc10\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc10.tar.gz\";s:4:\"date\";s:10:\"1523291284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc9\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc9\";s:7:\"version\";s:11:\"8.x-5.0-rc9\";s:3:\"tag\";s:11:\"8.x-5.0-rc9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc9\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc9.tar.gz\";s:4:\"date\";s:10:\"1523115484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc8\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc8\";s:7:\"version\";s:11:\"8.x-5.0-rc8\";s:3:\"tag\";s:11:\"8.x-5.0-rc8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc8\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc8.tar.gz\";s:4:\"date\";s:10:\"1522698184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc7\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc7\";s:7:\"version\";s:11:\"8.x-5.0-rc7\";s:3:\"tag\";s:11:\"8.x-5.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc7\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1521829380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc6\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc6\";s:7:\"version\";s:11:\"8.x-5.0-rc6\";s:3:\"tag\";s:11:\"8.x-5.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1521230880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc5\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc5\";s:7:\"version\";s:11:\"8.x-5.0-rc5\";s:3:\"tag\";s:11:\"8.x-5.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1521041284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc4\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc4\";s:7:\"version\";s:11:\"8.x-5.0-rc4\";s:3:\"tag\";s:11:\"8.x-5.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1520964784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc3\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc3\";s:7:\"version\";s:11:\"8.x-5.0-rc3\";s:3:\"tag\";s:11:\"8.x-5.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1517746080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc2\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc2\";s:7:\"version\";s:11:\"8.x-5.0-rc2\";s:3:\"tag\";s:11:\"8.x-5.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1517359384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc1\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc1\";s:7:\"version\";s:11:\"8.x-5.0-rc1\";s:3:\"tag\";s:11:\"8.x-5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1514196484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta25\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta25\";s:7:\"version\";s:14:\"8.x-5.0-beta25\";s:3:\"tag\";s:14:\"8.x-5.0-beta25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta25\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta25.tar.gz\";s:4:\"date\";s:10:\"1513003985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta24\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta24\";s:7:\"version\";s:14:\"8.x-5.0-beta24\";s:3:\"tag\";s:14:\"8.x-5.0-beta24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta24\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta24.tar.gz\";s:4:\"date\";s:10:\"1510867685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta23\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta23\";s:7:\"version\";s:14:\"8.x-5.0-beta23\";s:3:\"tag\";s:14:\"8.x-5.0-beta23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta23\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta23.tar.gz\";s:4:\"date\";s:10:\"1509673984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta22\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta22\";s:7:\"version\";s:14:\"8.x-5.0-beta22\";s:3:\"tag\";s:14:\"8.x-5.0-beta22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta22\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta22.tar.gz\";s:4:\"date\";s:10:\"1509576185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta21\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta21\";s:7:\"version\";s:14:\"8.x-5.0-beta21\";s:3:\"tag\";s:14:\"8.x-5.0-beta21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta21\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta21.tar.gz\";s:4:\"date\";s:10:\"1509363484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta20\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta20\";s:7:\"version\";s:14:\"8.x-5.0-beta20\";s:3:\"tag\";s:14:\"8.x-5.0-beta20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta20\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta20.tar.gz\";s:4:\"date\";s:10:\"1509357785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta19\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta19\";s:7:\"version\";s:14:\"8.x-5.0-beta19\";s:3:\"tag\";s:14:\"8.x-5.0-beta19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta19\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta19.tar.gz\";s:4:\"date\";s:10:\"1506634743\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta18\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta18\";s:7:\"version\";s:14:\"8.x-5.0-beta18\";s:3:\"tag\";s:14:\"8.x-5.0-beta18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta18\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta18.tar.gz\";s:4:\"date\";s:10:\"1505244243\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta17\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta17\";s:7:\"version\";s:14:\"8.x-5.0-beta17\";s:3:\"tag\";s:14:\"8.x-5.0-beta17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta17\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta17.tar.gz\";s:4:\"date\";s:10:\"1505089745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta16\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta16\";s:7:\"version\";s:14:\"8.x-5.0-beta16\";s:3:\"tag\";s:14:\"8.x-5.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta16\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1502154844\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta15\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta15\";s:7:\"version\";s:14:\"8.x-5.0-beta15\";s:3:\"tag\";s:14:\"8.x-5.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta15\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1498873444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta14\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta14\";s:7:\"version\";s:14:\"8.x-5.0-beta14\";s:3:\"tag\";s:14:\"8.x-5.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta14\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1498698843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta13\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta13\";s:7:\"version\";s:14:\"8.x-5.0-beta13\";s:3:\"tag\";s:14:\"8.x-5.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta13\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1496265842\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta12\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta12\";s:7:\"version\";s:14:\"8.x-5.0-beta12\";s:3:\"tag\";s:14:\"8.x-5.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta12\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1492798443\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta11\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta11\";s:7:\"version\";s:14:\"8.x-5.0-beta11\";s:3:\"tag\";s:14:\"8.x-5.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta11\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1491471183\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta10\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta10\";s:7:\"version\";s:14:\"8.x-5.0-beta10\";s:3:\"tag\";s:14:\"8.x-5.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta10\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1491362286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta9\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta9\";s:7:\"version\";s:13:\"8.x-5.0-beta9\";s:3:\"tag\";s:13:\"8.x-5.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta9\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1488753784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta8\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta8\";s:7:\"version\";s:13:\"8.x-5.0-beta8\";s:3:\"tag\";s:13:\"8.x-5.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta8\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1488739683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta7\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta7\";s:7:\"version\";s:13:\"8.x-5.0-beta7\";s:3:\"tag\";s:13:\"8.x-5.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta7\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1487143684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta6\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta6\";s:7:\"version\";s:13:\"8.x-5.0-beta6\";s:3:\"tag\";s:13:\"8.x-5.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1487025483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta5\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta5\";s:7:\"version\";s:13:\"8.x-5.0-beta5\";s:3:\"tag\";s:13:\"8.x-5.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1485776283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta4\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta4\";s:7:\"version\";s:13:\"8.x-5.0-beta4\";s:3:\"tag\";s:13:\"8.x-5.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1482752282\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta3\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta3\";s:7:\"version\";s:13:\"8.x-5.0-beta3\";s:3:\"tag\";s:13:\"8.x-5.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1482316383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta2\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta2\";s:7:\"version\";s:13:\"8.x-5.0-beta2\";s:3:\"tag\";s:13:\"8.x-5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1481192283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta1\";s:7:\"version\";s:13:\"8.x-5.0-beta1\";s:3:\"tag\";s:13:\"8.x-5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1481140089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"6.3.x-dev\";a:11:{s:4:\"name\";s:17:\"webform 6.3.x-dev\";s:7:\"version\";s:9:\"6.3.x-dev\";s:3:\"tag\";s:5:\"6.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743176885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:14:\"^10.3 || ^11.0\";}s:9:\"6.2.x-dev\";a:11:{s:4:\"name\";s:17:\"webform 6.2.x-dev\";s:7:\"version\";s:9:\"6.2.x-dev\";s:3:\"tag\";s:5:\"6.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743086166\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.2\";}s:9:\"6.1.x-dev\";a:11:{s:4:\"name\";s:17:\"webform 6.1.x-dev\";s:7:\"version\";s:9:\"6.1.x-dev\";s:3:\"tag\";s:5:\"6.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1698357330\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^9.3\";s:5:\"terms\";a:0:{}}s:9:\"6.0.x-dev\";a:11:{s:4:\"name\";s:17:\"webform 6.0.x-dev\";s:7:\"version\";s:9:\"6.0.x-dev\";s:3:\"tag\";s:5:\"6.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1644873671\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"6.x-dev\";a:11:{s:4:\"name\";s:15:\"webform 6.x-dev\";s:7:\"version\";s:7:\"6.x-dev\";s:3:\"tag\";s:3:\"6.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/6.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-6.x-dev.tar.gz\";s:4:\"date\";s:10:\"1743091777\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:14:\"^10.3 || ^11.0\";s:5:\"terms\";a:0:{}}s:11:\"8.x-5.x-dev\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.x-dev\";s:7:\"version\";s:11:\"8.x-5.x-dev\";s:3:\"tag\";s:7:\"8.x-5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1638915617\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";s:5:\"terms\";a:0:{}}s:11:\"8.x-4.x-dev\";a:10:{s:4:\"name\";s:19:\"webform 8.x-4.x-dev\";s:7:\"version\";s:11:\"8.x-4.x-dev\";s:3:\"tag\";s:7:\"8.x-4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1480317483\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932019;}',1744018419),('update_available_releases','webform_rest',_binary 'a:10:{s:5:\"title\";s:12:\"Webform REST\";s:10:\"short_name\";s:12:\"webform_rest\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"4.1.,4.2.\";s:18:\"composer_namespace\";s:19:\"drupal/webform_rest\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:43:\"https://www.drupal.org/project/webform_rest\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:16:{s:5:\"4.2.0\";a:11:{s:4:\"name\";s:18:\"webform_rest 4.2.0\";s:7:\"version\";s:5:\"4.2.0\";s:3:\"tag\";s:5:\"4.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/webform_rest/releases/4.2.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/webform_rest-4.2.0.tar.gz\";s:4:\"date\";s:10:\"1736288230\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"4.1.0\";a:11:{s:4:\"name\";s:18:\"webform_rest 4.1.0\";s:7:\"version\";s:5:\"4.1.0\";s:3:\"tag\";s:5:\"4.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/webform_rest/releases/4.1.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/webform_rest-4.1.0.tar.gz\";s:4:\"date\";s:10:\"1702831078\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.7.7 || ^9 || ^10\";}s:5:\"4.0.3\";a:11:{s:4:\"name\";s:18:\"webform_rest 4.0.3\";s:7:\"version\";s:5:\"4.0.3\";s:3:\"tag\";s:5:\"4.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/webform_rest/releases/4.0.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/webform_rest-4.0.3.tar.gz\";s:4:\"date\";s:10:\"1684134659\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.7.7 || ^9 || ^10\";}s:5:\"4.0.2\";a:11:{s:4:\"name\";s:18:\"webform_rest 4.0.2\";s:7:\"version\";s:5:\"4.0.2\";s:3:\"tag\";s:5:\"4.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/webform_rest/releases/4.0.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/webform_rest-4.0.2.tar.gz\";s:4:\"date\";s:10:\"1676586894\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.7.7 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"4.0.1\";a:11:{s:4:\"name\";s:18:\"webform_rest 4.0.1\";s:7:\"version\";s:5:\"4.0.1\";s:3:\"tag\";s:5:\"4.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/webform_rest/releases/4.0.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/webform_rest-4.0.1.tar.gz\";s:4:\"date\";s:10:\"1636116585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"4.0.0\";a:11:{s:4:\"name\";s:18:\"webform_rest 4.0.0\";s:7:\"version\";s:5:\"4.0.0\";s:3:\"tag\";s:5:\"4.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/webform_rest/releases/4.0.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/webform_rest-4.0.0.tar.gz\";s:4:\"date\";s:10:\"1614618512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"4.0.0-beta2\";a:11:{s:4:\"name\";s:24:\"webform_rest 4.0.0-beta2\";s:7:\"version\";s:11:\"4.0.0-beta2\";s:3:\"tag\";s:11:\"4.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/webform_rest/releases/4.0.0-beta2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/webform_rest-4.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1600634518\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"4.0.0-beta1\";a:11:{s:4:\"name\";s:24:\"webform_rest 4.0.0-beta1\";s:7:\"version\";s:11:\"4.0.0-beta1\";s:3:\"tag\";s:11:\"4.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/webform_rest/releases/4.0.0-beta1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/webform_rest-4.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1597674368\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta4\";a:11:{s:4:\"name\";s:26:\"webform_rest 8.x-2.0-beta4\";s:7:\"version\";s:13:\"8.x-2.0-beta4\";s:3:\"tag\";s:13:\"8.x-2.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/webform_rest/releases/8.x-2.0-beta4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/webform_rest-8.x-2.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1600634753\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-2.0-beta3\";a:11:{s:4:\"name\";s:26:\"webform_rest 8.x-2.0-beta3\";s:7:\"version\";s:13:\"8.x-2.0-beta3\";s:3:\"tag\";s:13:\"8.x-2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/webform_rest/releases/8.x-2.0-beta3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/webform_rest-8.x-2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1591175741\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta2\";a:11:{s:4:\"name\";s:26:\"webform_rest 8.x-2.0-beta2\";s:7:\"version\";s:13:\"8.x-2.0-beta2\";s:3:\"tag\";s:13:\"8.x-2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/webform_rest/releases/8.x-2.0-beta2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/webform_rest-8.x-2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1543288980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:26:\"webform_rest 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/webform_rest/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/webform_rest-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1537417681\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"4.x-dev\";a:11:{s:4:\"name\";s:20:\"webform_rest 4.x-dev\";s:7:\"version\";s:7:\"4.x-dev\";s:3:\"tag\";s:3:\"4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform_rest/releases/4.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform_rest-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1736466710\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:24:\"webform_rest 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/webform_rest/releases/8.x-3.x-dev\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/webform_rest-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1597673690\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:24:\"webform_rest 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/webform_rest/releases/8.x-2.x-dev\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/webform_rest-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1600634047\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:24:\"webform_rest 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/webform_rest/releases/8.x-1.x-dev\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/webform_rest-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1513548184\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1743932020;}',1744018420);
/*!40000 ALTER TABLE `key_value_expire` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `locale_file`
--

DROP TABLE IF EXISTS `locale_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `locale_file` (
  `project` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A unique short name to identify the project the file belongs to.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Language code of this translation. References "language".langcode.',
  `filename` varchar(255) NOT NULL DEFAULT '' COMMENT 'Filename of the imported file.',
  `version` varchar(128) NOT NULL DEFAULT '' COMMENT 'Version tag of the imported file.',
  `uri` varchar(255) NOT NULL DEFAULT '' COMMENT 'URI of the remote file, the resulting local file or the locally imported file.',
  `timestamp` bigint DEFAULT '0' COMMENT 'Unix timestamp of the imported file.',
  `last_checked` bigint DEFAULT '0' COMMENT 'Unix timestamp of the last time this translation was confirmed to be the most recent release available.',
  PRIMARY KEY (`project`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='File import status information for interface translation…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `locale_file`
--

LOCK TABLES `locale_file` WRITE;
/*!40000 ALTER TABLE `locale_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `locale_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `locales_location`
--

DROP TABLE IF EXISTS `locales_location`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `locales_location` (
  `lid` int NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier of this location.',
  `sid` int NOT NULL COMMENT 'Unique identifier of this string.',
  `type` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The location type (file, config, path, etc).',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'Type dependent location information (file name, path, etc).',
  `version` varchar(20) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'none' COMMENT 'Version of Drupal where the location was found.',
  PRIMARY KEY (`lid`),
  KEY `string_type` (`sid`,`type`),
  KEY `type_name` (`type`,`name`(191))
) ENGINE=InnoDB AUTO_INCREMENT=140 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Location information for source strings.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `locales_location`
--

LOCK TABLES `locales_location` WRITE;
/*!40000 ALTER TABLE `locales_location` DISABLE KEYS */;
INSERT INTO `locales_location` VALUES (1,1,'javascript','core/misc/announce.js','11.1.5'),(2,2,'javascript','core/misc/message.js','11.1.5'),(3,3,'javascript','core/misc/message.js','11.1.5'),(4,4,'javascript','core/misc/message.js','11.1.5'),(5,5,'javascript','themes/contrib/gin/dist/js/messages.js','11.1.5'),(6,6,'javascript','core/misc/ajax.js','11.1.5'),(7,7,'javascript','core/misc/ajax.js','11.1.5'),(8,8,'javascript','core/misc/ajax.js','11.1.5'),(9,9,'javascript','core/misc/ajax.js','11.1.5'),(10,10,'javascript','core/misc/ajax.js','11.1.5'),(11,11,'javascript','core/misc/ajax.js','11.1.5'),(12,12,'javascript','core/misc/ajax.js','11.1.5'),(13,13,'javascript','core/misc/ajax.js','11.1.5'),(14,14,'javascript','core/misc/ajax.js','11.1.5'),(15,15,'javascript','core/misc/ajax.js','11.1.5'),(16,16,'javascript','core/misc/ajax.js','11.1.5'),(17,17,'javascript','core/misc/ajax.js','11.1.5'),(18,18,'javascript','core/misc/ajax.js','11.1.5'),(19,19,'javascript','core/misc/ajax.js','11.1.5'),(20,20,'javascript','core/misc/ajax.js','11.1.5'),(21,21,'javascript','core/modules/contextual/js/contextual.js','11.1.5'),(22,22,'javascript','core/modules/contextual/js/contextual.js','11.1.5'),(23,23,'javascript','core/modules/contextual/js/views/AuralView.js','11.1.5'),(24,24,'javascript','core/modules/contextual/js/contextual.toolbar.js','11.1.5'),(25,25,'javascript','core/modules/contextual/js/contextual.toolbar.js','11.1.5'),(26,26,'javascript','core/modules/contextual/js/contextual.toolbar.js','11.1.5'),(27,27,'javascript','core/modules/contextual/js/toolbar/views/AuralView.js','11.1.5'),(28,28,'javascript','core/misc/tableresponsive.js','11.1.5'),(29,29,'javascript','core/misc/tableresponsive.js','11.1.5'),(30,30,'javascript','core/misc/tableresponsive.js','11.1.5'),(31,31,'javascript','themes/contrib/gin/js/navigation/navigation.js','11.1.5'),(32,32,'javascript','themes/contrib/gin/js/navigation/navigation.js','11.1.5'),(33,33,'javascript','themes/contrib/gin/js/navigation/navigation.js','11.1.5'),(34,34,'javascript','themes/contrib/gin/js/navigation/navigation.js','11.1.5'),(35,35,'javascript','core/modules/system/js/system.modules.js','11.1.5'),(36,33,'javascript','core/modules/toolbar/js/toolbar.menu.js','11.1.5'),(37,34,'javascript','core/modules/toolbar/js/toolbar.menu.js','11.1.5'),(38,36,'javascript','core/modules/toolbar/js/toolbar.menu.js','11.1.5'),(39,37,'javascript','core/modules/toolbar/js/toolbar.js','11.1.5'),(40,38,'javascript','core/modules/toolbar/js/toolbar.js','11.1.5'),(41,39,'javascript','core/modules/toolbar/js/models/ToolbarModel.js','11.1.5'),(42,40,'javascript','core/modules/toolbar/js/views/ToolbarAuralView.js','11.1.5'),(43,41,'javascript','core/modules/toolbar/js/views/ToolbarAuralView.js','11.1.5'),(44,42,'javascript','core/modules/toolbar/js/views/ToolbarAuralView.js','11.1.5'),(45,43,'javascript','core/modules/toolbar/js/views/ToolbarAuralView.js','11.1.5'),(46,44,'javascript','core/modules/toolbar/js/views/ToolbarAuralView.js','11.1.5'),(47,45,'javascript','core/misc/dropbutton/dropbutton.js','11.1.5'),(48,20,'javascript','themes/contrib/gin/js/overrides/tabledrag.js','11.1.5'),(49,46,'javascript','themes/contrib/gin/js/overrides/tabledrag.js','11.1.5'),(50,47,'javascript','themes/contrib/gin/js/overrides/tabledrag.js','11.1.5'),(51,48,'javascript','themes/contrib/gin/js/overrides/tabledrag.js','11.1.5'),(52,49,'javascript','themes/contrib/gin/js/overrides/tabledrag.js','11.1.5'),(53,50,'javascript','themes/contrib/gin/js/overrides/tabledrag.js','11.1.5'),(54,46,'javascript','core/themes/claro/js/tabledrag.js','11.1.5'),(55,49,'javascript','core/themes/claro/js/tabledrag.js','11.1.5'),(56,50,'javascript','core/themes/claro/js/tabledrag.js','11.1.5'),(57,47,'javascript','core/themes/claro/js/tabledrag.js','11.1.5'),(58,48,'javascript','core/themes/claro/js/tabledrag.js','11.1.5'),(59,51,'javascript','core/misc/vertical-tabs.js','11.1.5'),(60,52,'javascript','core/modules/filter/js/filter.admin.js','11.1.5'),(61,53,'javascript','core/modules/filter/js/filter.admin.js','11.1.5'),(62,54,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(63,55,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(64,56,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(65,57,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(66,58,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(67,59,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(68,60,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(69,61,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(70,62,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(71,63,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(72,64,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(73,65,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(74,66,'javascript','core/modules/ckeditor5/js/ckeditor5.admin.js','11.1.5'),(75,67,'javascript','core/modules/ckeditor5/js/ckeditor5.image.admin.js','11.1.5'),(76,68,'javascript','core/modules/ckeditor5/js/ckeditor5.image.admin.js','11.1.5'),(77,69,'javascript','core/modules/ckeditor5/js/ckeditor5.style.admin.js','11.1.5'),(78,70,'javascript','core/modules/ckeditor5/js/ckeditor5.style.admin.js','11.1.5'),(79,71,'javascript','core/misc/machine-name.js','11.1.5'),(80,72,'javascript','core/misc/machine-name.js','11.1.5'),(81,73,'javascript','core/modules/user/js/user.permissions.js','11.1.5'),(82,74,'javascript','core/modules/user/js/user.permissions.js','11.1.5'),(83,75,'javascript','core/modules/node/js/content_types.js','11.1.4'),(84,76,'javascript','core/modules/node/js/content_types.js','11.1.4'),(85,77,'javascript','core/modules/node/js/content_types.js','11.1.4'),(86,78,'javascript','modules/contrib/simple_sitemap/js/simple_sitemap.fieldsetSummaries.js','11.1.4'),(87,79,'javascript','modules/contrib/simple_sitemap/js/simple_sitemap.fieldsetSummaries.js','11.1.4'),(88,80,'javascript','modules/contrib/simple_sitemap/js/simple_sitemap.fieldsetSummaries.js','11.1.4'),(89,81,'javascript','modules/contrib/simple_sitemap/js/simple_sitemap.fieldsetSummaries.js','11.1.4'),(90,82,'javascript','modules/contrib/token/js/token.js','11.1.5'),(91,83,'javascript','modules/contrib/token/js/token.js','11.1.5'),(92,84,'javascript','core/themes/olivero/js/messages.js','11.1.5'),(93,85,'javascript','themes/contrib/gin/js/overrides/tableselect.js','11.1.5'),(94,86,'javascript','themes/contrib/gin/js/overrides/tableselect.js','11.1.5'),(95,87,'javascript','core/themes/claro/js/tableselect.js','11.1.5'),(96,88,'javascript','core/themes/claro/js/tableselect.js','11.1.5'),(97,89,'javascript','core/themes/claro/js/tableselect.js','11.1.5'),(98,90,'javascript','core/modules/editor/js/editor.js','11.1.5'),(99,91,'javascript','core/modules/editor/js/editor.js','11.1.5'),(100,92,'javascript','core/modules/editor/js/editor.js','11.1.5'),(101,93,'javascript','core/modules/editor/js/editor.js','11.1.5'),(102,94,'javascript','core/modules/ckeditor5/js/build/drupalImage.js','11.1.5'),(103,93,'javascript','core/modules/ckeditor5/js/build/drupalImage.js','11.1.5'),(104,95,'javascript','core/modules/ckeditor5/js/build/drupalImage.js','11.1.5'),(105,96,'javascript','core/modules/ckeditor5/js/build/drupalImage.js','11.1.5'),(106,97,'javascript','core/modules/ckeditor5/js/build/drupalImage.js','11.1.5'),(107,98,'javascript','core/modules/ckeditor5/js/build/drupalImage.js','11.1.5'),(108,99,'javascript','core/modules/file/js/file.js','11.1.4'),(109,100,'javascript','themes/contrib/gin/dist/js/sidebar.js','11.1.5'),(110,101,'javascript','themes/contrib/gin/dist/js/sidebar.js','11.1.5'),(111,102,'javascript','core/modules/menu_ui/js/menu_ui.js','11.1.5'),(112,103,'javascript','core/misc/entity-form.js','11.1.5'),(113,104,'javascript','core/misc/entity-form.js','11.1.5'),(114,105,'javascript','core/misc/entity-form.js','11.1.5'),(115,106,'javascript','core/misc/entity-form.js','11.1.5'),(116,107,'javascript','core/misc/entity-form.js','11.1.5'),(117,108,'javascript','core/misc/entity-form.js','11.1.5'),(118,109,'javascript','core/modules/node/js/node.js','11.1.5'),(119,110,'javascript','core/modules/node/js/node.js','11.1.5'),(120,111,'javascript','core/modules/node/js/node.js','11.1.5'),(121,112,'javascript','core/modules/node/js/node.js','11.1.5'),(122,113,'javascript','core/modules/path/js/path.js','11.1.5'),(123,114,'javascript','core/modules/path/js/path.js','11.1.5'),(124,115,'javascript','modules/contrib/pathauto/pathauto.js','11.1.5'),(125,113,'javascript','modules/contrib/pathauto/pathauto.js','11.1.5'),(126,114,'javascript','modules/contrib/pathauto/pathauto.js','11.1.5'),(127,116,'javascript','core/modules/text/js/text.js','11.1.5'),(128,117,'javascript','core/modules/text/js/text.js','11.1.5'),(129,118,'javascript','core/themes/olivero/js/comments.js','11.1.4'),(130,119,'javascript','modules/contrib/webform/js/webform.filter.js','11.1.5'),(131,120,'javascript','modules/contrib/webform/js/webform.filter.js','11.1.5'),(132,121,'javascript','modules/contrib/webform/js/webform.filter.js','11.1.5'),(133,122,'javascript','modules/contrib/webform/js/webform.filter.js','11.1.5'),(134,123,'javascript','modules/contrib/webform/js/webform.element.details.toggle.js','11.1.5'),(135,124,'javascript','modules/contrib/webform/js/webform.element.details.toggle.js','11.1.5'),(136,125,'javascript','modules/contrib/webform/js/webform.element.details.toggle.js','11.1.5'),(137,126,'javascript','modules/contrib/webform/js/webform.element.details.toggle.js','11.1.5'),(138,127,'javascript','modules/contrib/webform/js/webform.element.details.toggle.js','11.1.5'),(139,128,'javascript','modules/contrib/webform/modules/webform_ui/js/webform_ui.js','11.1.5');
/*!40000 ALTER TABLE `locales_location` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `locales_source`
--

DROP TABLE IF EXISTS `locales_source`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `locales_source` (
  `lid` int NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier of this string.',
  `source` blob NOT NULL COMMENT 'The original string in English.',
  `context` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The context this string applies to.',
  `version` varchar(20) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'none' COMMENT 'Version of Drupal where the string was last used (for locales optimization).',
  PRIMARY KEY (`lid`),
  KEY `source_context` (`source`(30),`context`)
) ENGINE=InnoDB AUTO_INCREMENT=129 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='List of English source strings.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `locales_source`
--

LOCK TABLES `locales_source` WRITE;
/*!40000 ALTER TABLE `locales_source` DISABLE KEYS */;
INSERT INTO `locales_source` VALUES (1,_binary '@count items added to @container','','11.1.5'),(2,_binary 'Status message','','11.1.5'),(3,_binary 'Error message','','11.1.5'),(4,_binary 'Warning message','','11.1.5'),(5,_binary 'Hide','','11.1.5'),(6,_binary 'An AJAX HTTP error occurred.','','11.1.5'),(7,_binary 'HTTP Result Code: !status','','11.1.5'),(8,_binary 'An AJAX HTTP request terminated abnormally.','','11.1.5'),(9,_binary 'Debugging information follows.','','11.1.5'),(10,_binary 'Path: !uri','','11.1.5'),(11,_binary 'StatusText: !statusText','','11.1.5'),(12,_binary 'ResponseText: !responseText','','11.1.5'),(13,_binary 'ReadyState: !readyState','','11.1.5'),(14,_binary 'CustomMessage: !customMessage','','11.1.5'),(15,_binary 'Oops, something went wrong. Check your browser\'s developer console for more details.','','11.1.5'),(16,_binary 'Processing...','','11.1.5'),(17,_binary 'The response failed verification so will not be processed.','','11.1.5'),(18,_binary 'The callback URL is not local and not trusted: !url','','11.1.5'),(19,_binary 'An error occurred during the execution of the Ajax response: !error','','11.1.5'),(20,_binary 'Changed','','11.1.5'),(21,_binary 'Open','','11.1.5'),(22,_binary 'Close','','11.1.5'),(23,_binary '@action @title configuration options','','11.1.5'),(24,_binary 'Tabbing is no longer constrained by the Contextual module.','','11.1.5'),(25,_binary 'Tabbing is constrained to a set of @contextualsCount and the edit mode toggle.','','11.1.5'),(26,_binary 'Press the esc key to exit.','','11.1.5'),(27,_binary '@count contextual link@count contextual links','','11.1.5'),(28,_binary 'Show all columns','','11.1.5'),(29,_binary 'Hide lower priority columns','','11.1.5'),(30,_binary 'Show table cells that were hidden to make the table fit within a small screen.','','11.1.5'),(31,_binary 'Collapse sidebar','','11.1.5'),(32,_binary 'Expand sidebar','','11.1.5'),(33,_binary 'Extend','','11.1.5'),(34,_binary 'Collapse','','11.1.5'),(35,_binary '1 module is available in the modified list.@count modules are available in the modified list.','','11.1.5'),(36,_binary '@label','','11.1.5'),(37,_binary 'Horizontal orientation','','11.1.5'),(38,_binary 'Vertical orientation','','11.1.5'),(39,_binary 'The toolbar cannot be set to a horizontal orientation when it is locked.','','11.1.5'),(40,_binary 'Tray orientation changed to @orientation.','','11.1.5'),(41,_binary 'closed','','11.1.5'),(42,_binary 'opened','','11.1.5'),(43,_binary 'Tray \"@tray\" @action.','','11.1.5'),(44,_binary 'Tray @action.','','11.1.5'),(45,_binary 'List additional actions','','11.1.5'),(46,_binary 'You have unsaved changes.','','11.1.5'),(47,_binary 'Hide row weights','','11.1.5'),(48,_binary 'Show row weights','','11.1.5'),(49,_binary 'Change order','','11.1.5'),(50,_binary 'Move in any direction','','11.1.5'),(51,_binary '(active tab)','','11.1.5'),(52,_binary 'Enabled','','11.1.5'),(53,_binary 'Disabled','','11.1.5'),(54,_binary 'The toolbar buttons that don\'t fit the user\'s browser window width will be grouped in a dropdown. If multiple toolbar rows are preferred, those can be configured by adding an explicit wrapping breakpoint wherever you want to start a new row.','','11.1.5'),(55,_binary 'You have configured a multi-row toolbar by using an explicit wrapping breakpoint. This may not work well in narrow browser windows. To use automatic grouping, remove any of these divider buttons.','','11.1.5'),(56,_binary 'Button @name has been copied to the active toolbar.','','11.1.5'),(57,_binary 'Button @name has been removed from the active toolbar.','','11.1.5'),(58,_binary 'Button @name has been moved to the active toolbar.','','11.1.5'),(59,_binary 'Divider','','11.1.5'),(60,_binary 'Wrapping','','11.1.5'),(61,_binary 'Press the down arrow key to use this divider in the active button list','','11.1.5'),(62,_binary 'Press the down arrow key to activate','','11.1.5'),(63,_binary 'Press the up arrow key to deactivate. Use the right and left arrow keys to move position','','11.1.5'),(64,_binary 'Available buttons','','11.1.5'),(65,_binary 'Button divider','','11.1.5'),(66,_binary 'Active toolbar','','11.1.5'),(67,_binary 'Images can only be uploaded.','','11.1.5'),(68,_binary 'Images can only be added by URL.','','11.1.5'),(69,_binary 'No styles configured','','11.1.5'),(70,_binary 'One style configured@count styles configured','','11.1.5'),(71,_binary 'Edit machine name','','11.1.5'),(72,_binary 'Edit','','11.1.5'),(73,_binary 'This permission is inherited from the authenticated user role.','','11.1.5'),(74,_binary '1 permission is available in the modified list.@count permissions are available in the modified list.','','11.1.5'),(75,_binary 'Requires a title','','11.1.4'),(76,_binary 'Not published','','11.1.4'),(77,_binary 'Don\'t display post information','','11.1.4'),(78,_binary 'IndexNow notification enabled','','11.1.4'),(79,_binary 'IndexNow notification disabled','','11.1.4'),(80,_binary 'Included in sitemaps: ','','11.1.4'),(81,_binary 'Excluded from all sitemaps','','11.1.4'),(82,_binary 'Insert this token into your form','','11.1.5'),(83,_binary 'First click a text field to insert your tokens into.','','11.1.5'),(84,_binary 'Close message','','11.1.5'),(85,_binary 'Select all rows in this table','','11.1.5'),(86,_binary 'Deselect all rows in this table','','11.1.5'),(87,_binary 'Bulk actions are now available. These actions will be applied to all selected items. This can be accessed via the \"Skip to bulk actions\" link that appears after every enabled checkbox. ','','11.1.5'),(88,_binary 'No items selected','','11.1.5'),(89,_binary '1 item selected@count items selected','','11.1.5'),(90,_binary 'Changing the text format to %text_format will permanently remove content that is not allowed in that text format.<br><br>Save your changes before switching the text format to avoid losing data.','','11.1.5'),(91,_binary 'Change text format?','','11.1.5'),(92,_binary 'Continue','','11.1.5'),(93,_binary 'Cancel','','11.1.5'),(94,_binary 'Save','','11.1.5'),(95,_binary 'Alternative text','','11.1.5'),(96,_binary 'Decorative image','','11.1.5'),(97,_binary 'Add missing alternative text','','11.1.5'),(98,_binary 'Change image alternative text','','11.1.5'),(99,_binary 'The selected file %filename cannot be uploaded. Only files with the following extensions are allowed: %extensions.','','11.1.4'),(100,_binary 'Hide sidebar panel','','11.1.5'),(101,_binary 'Show sidebar panel','','11.1.5'),(102,_binary 'Not in menu','','11.1.5'),(103,_binary 'New revision','','11.1.5'),(104,_binary 'No revision','','11.1.5'),(105,_binary 'Needs to be updated','','11.1.5'),(106,_binary 'Does not need to be updated','','11.1.5'),(107,_binary 'Flag other translations as outdated','','11.1.5'),(108,_binary 'Do not flag other translations as outdated','','11.1.5'),(109,_binary 'By @name on @date','','11.1.5'),(110,_binary 'By @name','','11.1.5'),(111,_binary 'Authored on @date','','11.1.5'),(112,_binary 'Not promoted','','11.1.5'),(113,_binary 'Alias: @alias','','11.1.5'),(114,_binary 'No alias','','11.1.5'),(115,_binary 'Automatic alias','','11.1.5'),(116,_binary 'Hide summary','','11.1.5'),(117,_binary 'Edit summary','','11.1.5'),(118,_binary 'Replies','','11.1.4'),(119,_binary 'item','','11.1.5'),(120,_binary 'items','','11.1.5'),(121,_binary '1 @item is available in the modified list.@total @items are available in the modified list.','','11.1.5'),(122,_binary '1 @item@total @items','','11.1.5'),(123,_binary 'Toggle details widget state.','','11.1.5'),(124,_binary 'Collapse all','','11.1.5'),(125,_binary 'Expand all','','11.1.5'),(126,_binary 'All details have been expanded.','','11.1.5'),(127,_binary 'All details have been collapsed.','','11.1.5'),(128,_binary 'Please avoid using the reserved word \'@key\' as the element\'s key.','','11.1.5');
/*!40000 ALTER TABLE `locales_source` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `locales_target`
--

DROP TABLE IF EXISTS `locales_target`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `locales_target` (
  `lid` int NOT NULL DEFAULT '0' COMMENT 'Source string ID. References "locales_source".lid.',
  `translation` blob NOT NULL COMMENT 'Translation string value in this language.',
  `language` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Language code. References "language".langcode.',
  `customized` int NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether the translation is custom to this site.',
  PRIMARY KEY (`language`,`lid`),
  KEY `lid` (`lid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores translated versions of strings.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `locales_target`
--

LOCK TABLES `locales_target` WRITE;
/*!40000 ALTER TABLE `locales_target` DISABLE KEYS */;
/*!40000 ALTER TABLE `locales_target` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content`
--

DROP TABLE IF EXISTS `menu_link_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`id`),
  UNIQUE KEY `menu_link_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `menu_link_content__revision_id` (`revision_id`),
  KEY `menu_link_content_field__bundle__target_id` (`bundle`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content`
--

LOCK TABLES `menu_link_content` WRITE;
/*!40000 ALTER TABLE `menu_link_content` DISABLE KEYS */;
INSERT INTO `menu_link_content` VALUES (1,1,'78af3662-8542-4dda-846c-f12fe6d1c234','en','main'),(2,2,'a98db427-0beb-4d41-bf82-0793d7159241','en','main');
/*!40000 ALTER TABLE `menu_link_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_data`
--

DROP TABLE IF EXISTS `menu_link_content_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `menu_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `rediscover` tinyint DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `expanded` tinyint DEFAULT NULL,
  `parent` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  `view_mode` varchar(255) DEFAULT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content__revision_id` (`revision_id`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30)),
  KEY `menu_link_content_field__bundle__target_id` (`bundle`),
  KEY `menu_link_content__enabled_bundle` (`enabled`,`bundle`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_data`
--

LOCK TABLES `menu_link_content_data` WRITE;
/*!40000 ALTER TABLE `menu_link_content_data` DISABLE KEYS */;
INSERT INTO `menu_link_content_data` VALUES (1,1,'en',1,'Articles',NULL,'main','internal:/articles','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1,-49,0,NULL,1742757017,1,1,'default','main'),(2,2,'en',1,'Contact Us',NULL,'main','internal:/form/contact','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1,-48,0,NULL,1742757017,1,1,'default','main');
/*!40000 ALTER TABLE `menu_link_content_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_field_revision`
--

DROP TABLE IF EXISTS `menu_link_content_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_field_revision`
--

LOCK TABLES `menu_link_content_field_revision` WRITE;
/*!40000 ALTER TABLE `menu_link_content_field_revision` DISABLE KEYS */;
INSERT INTO `menu_link_content_field_revision` VALUES (1,1,'en',1,'Articles',NULL,'internal:/articles','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1742757017,1,1),(2,2,'en',1,'Contact Us',NULL,'internal:/form/contact','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1742757017,1,1);
/*!40000 ALTER TABLE `menu_link_content_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_revision`
--

DROP TABLE IF EXISTS `menu_link_content_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `menu_link_content__id` (`id`),
  KEY `menu_link_content__ef029a1897` (`revision_user`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_revision`
--

LOCK TABLES `menu_link_content_revision` WRITE;
/*!40000 ALTER TABLE `menu_link_content_revision` DISABLE KEYS */;
INSERT INTO `menu_link_content_revision` VALUES (1,1,'en',NULL,1742746781,NULL,1),(2,2,'en',NULL,1742746853,NULL,1);
/*!40000 ALTER TABLE `menu_link_content_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_tree`
--

DROP TABLE IF EXISTS `menu_tree`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_tree` (
  `menu_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The menu name. All links with the same menu name (such as ''tools'') are part of the same menu.',
  `mlid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The menu link ID (mlid) is the integer primary key.',
  `id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'Unique machine name: the plugin ID.',
  `parent` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The plugin ID for the parent of this link.',
  `route_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The machine name of a defined Symfony Route this menu link represents.',
  `route_param_key` varchar(2048) DEFAULT NULL COMMENT 'An encoded string of route parameters for loading by route.',
  `route_parameters` longblob COMMENT 'Serialized array of route parameters of this menu link.',
  `url` varchar(2048) NOT NULL DEFAULT '' COMMENT 'The external path this link points to (when not using a route).',
  `title` longblob COMMENT 'The serialized title for the link. May be a TranslatableMarkup.',
  `description` longblob COMMENT 'The serialized description of this link - used for admin pages and title attribute. May be a TranslatableMarkup.',
  `class` text COMMENT 'The class for this link plugin.',
  `options` longblob COMMENT 'A serialized array of URL options, such as a query string or HTML attributes.',
  `provider` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'system' COMMENT 'The name of the module that generated this link.',
  `enabled` smallint NOT NULL DEFAULT '1' COMMENT 'A flag for whether the link should be rendered in menus. (0 = a disabled menu link that may be shown on admin screens, 1 = a normal, visible link)',
  `discovered` smallint NOT NULL DEFAULT '0' COMMENT 'A flag for whether the link was discovered, so can be purged on rebuild',
  `expanded` smallint NOT NULL DEFAULT '0' COMMENT 'Flag for whether this link should be rendered as expanded in menus - expanded links always have their child links displayed, instead of only when the link is in the active trail (1 = expanded, 0 = not expanded)',
  `weight` int NOT NULL DEFAULT '0' COMMENT 'Link weight among links in the same menu at the same depth.',
  `metadata` longblob COMMENT 'A serialized array of data that may be used by the plugin instance.',
  `has_children` smallint NOT NULL DEFAULT '0' COMMENT 'Flag indicating whether any enabled links have this link as a parent (1 = enabled children exist, 0 = no enabled children).',
  `depth` smallint NOT NULL DEFAULT '0' COMMENT 'The depth relative to the top level. A link with empty parent will have depth == 1.',
  `p1` int unsigned NOT NULL DEFAULT '0' COMMENT 'The first mlid in the materialized path. If N = depth, then pN must equal the mlid. If depth > 1 then p(N-1) must equal the parent link mlid. All pX where X > depth must equal zero. The columns p1 .. p9 are also called the parents.',
  `p2` int unsigned NOT NULL DEFAULT '0' COMMENT 'The second mlid in the materialized path. See p1.',
  `p3` int unsigned NOT NULL DEFAULT '0' COMMENT 'The third mlid in the materialized path. See p1.',
  `p4` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fourth mlid in the materialized path. See p1.',
  `p5` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fifth mlid in the materialized path. See p1.',
  `p6` int unsigned NOT NULL DEFAULT '0' COMMENT 'The sixth mlid in the materialized path. See p1.',
  `p7` int unsigned NOT NULL DEFAULT '0' COMMENT 'The seventh mlid in the materialized path. See p1.',
  `p8` int unsigned NOT NULL DEFAULT '0' COMMENT 'The eighth mlid in the materialized path. See p1.',
  `p9` int unsigned NOT NULL DEFAULT '0' COMMENT 'The ninth mlid in the materialized path. See p1.',
  `form_class` varchar(255) DEFAULT NULL COMMENT 'meh',
  PRIMARY KEY (`mlid`),
  UNIQUE KEY `id` (`id`),
  KEY `menu_parents` (`menu_name`,`p1`,`p2`,`p3`,`p4`,`p5`,`p6`,`p7`,`p8`,`p9`),
  KEY `menu_parent_expand_child` (`menu_name`,`expanded`,`has_children`,`parent`(16)),
  KEY `route_values` (`route_name`(32),`route_param_key`(16))
) ENGINE=InnoDB AUTO_INCREMENT=96 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Contains the menu tree hierarchy.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_tree`
--

LOCK TABLES `menu_tree` WRITE;
/*!40000 ALTER TABLE `menu_tree` DISABLE KEYS */;
INSERT INTO `menu_tree` VALUES ('footer',1,'contact.site_page','','contact.site_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Contact\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','contact',1,1,0,0,_binary 'a:0:{}',0,1,1,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('tools',2,'filter.tips_all','','filter.tips_all','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Compose tips\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','filter',0,1,0,0,_binary 'a:0:{}',0,1,2,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('tools',3,'node.add_page','','node.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','node',1,1,0,0,_binary 'a:0:{}',0,1,3,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',6,'system.admin','','system.admin','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Administration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,9,_binary 'a:0:{}',1,1,6,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',7,'announcements_feed.announcement','system.admin','announcements_feed.announcement','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Announcements\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Displays announcements from the Drupal community.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','announcements_feed',1,1,0,10,_binary 'a:0:{}',0,2,6,7,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',8,'help.main','system.admin','help.main','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Help\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Reference for usage, configuration, and modules.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','help',1,1,0,9,_binary 'a:0:{}',0,2,6,8,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',9,'system.admin_content','system.admin','system.admin_content','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Find and manage content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,2,6,9,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',10,'comment.admin','system.admin_content','comment.admin','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Comments\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"List and edit site comments and the comment approval queue.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','comment',1,1,0,0,_binary 'a:0:{}',0,3,6,9,10,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',11,'system.admin_structure','system.admin','system.admin_structure','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Structure\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Administer blocks, content types, menus, etc.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-8,_binary 'a:0:{}',1,2,6,11,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',12,'block.admin_display','system.admin_structure','block.admin_display','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Block layout\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:79:\"Configure what block content appears in your site\'s sidebars and other regions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','block',1,1,0,0,_binary 'a:0:{}',0,3,6,11,12,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',13,'entity.block_content_type.collection','system.admin_structure','entity.block_content_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Create and manage fields, forms, and display settings for your content blocks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','block_content',1,1,0,0,_binary 'a:0:{}',0,3,6,11,13,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',14,'entity.comment_type.collection','system.admin_structure','entity.comment_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Comment types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"Manage form and displays settings of comments.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','comment',1,1,0,0,_binary 'a:0:{}',0,3,6,11,14,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',15,'entity.contact_form.collection','system.admin_structure','entity.contact_form.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Create and manage contact forms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','contact',1,1,0,0,_binary 'a:0:{}',0,3,6,11,15,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',16,'field_ui.display_mode','system.admin_structure','field_ui.display_mode','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Display modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"Configure what displays are available for your content and forms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,11,16,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',17,'entity.entity_view_mode.collection','field_ui.display_mode','entity.entity_view_mode.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"View modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Manage custom view modes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',0,4,6,11,16,17,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',18,'entity.entity_form_mode.collection','field_ui.display_mode','entity.entity_form_mode.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Form modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Manage custom form modes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',0,4,6,11,16,18,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',19,'entity.menu.collection','system.admin_structure','entity.menu.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Manage menus and menu links.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','menu_ui',1,1,0,0,_binary 'a:0:{}',0,3,6,11,19,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',20,'entity.node_type.collection','system.admin_structure','entity.node_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"Create and manage fields, forms, and display settings for your content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','node',1,1,0,0,_binary 'a:0:{}',0,3,6,11,20,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',21,'entity.taxonomy_vocabulary.collection','system.admin_structure','entity.taxonomy_vocabulary.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Taxonomy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"Manage tagging, categorization, and classification of your content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','taxonomy',1,1,0,0,_binary 'a:0:{}',0,3,6,11,21,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',22,'entity.view.collection','system.admin_structure','entity.view.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"Manage customized lists of content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','views_ui',1,1,0,0,_binary 'a:0:{}',0,3,6,11,22,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',23,'system.themes_page','system.admin','system.themes_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Appearance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Select and configure themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-6,_binary 'a:0:{}',0,2,6,23,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',24,'system.modules_list','system.admin','system.modules_list','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Extend\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:53:\"Add and install modules to extend site functionality.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-2,_binary 'a:0:{}',0,2,6,24,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',25,'system.admin_config','system.admin','system.admin_config','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Administer settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',1,2,6,25,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',26,'system.admin_config_media','system.admin_config','system.admin_config_media','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,26,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',27,'entity.image_style.collection','system.admin_config_media','entity.image_style.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Configure styles that can be used for resizing or adjusting images on display.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','image',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,27,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',28,'system.file_system_settings','system.admin_config_media','system.file_system_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"File system\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"Configure the location of uploaded files and how they are accessed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,28,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',29,'system.image_toolkit_settings','system.admin_config_media','system.image_toolkit_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Image toolkit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:74:\"Choose which image toolkit to use if you have installed optional toolkits.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,20,_binary 'a:0:{}',0,4,6,25,26,29,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',30,'system.admin_config_services','system.admin_config','system.admin_config_services','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Web services\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',1,3,6,25,30,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',31,'system.rss_feeds_settings','system.admin_config_services','system.rss_feeds_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"RSS publishing\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:115:\"Configure the site description, the number of items per feed, and whether feeds should be titles/teasers/full-text.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',0,4,6,25,30,31,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',32,'system.linkset_settings','system.admin_config_services','system.linkset_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Menu Linkset Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Enable or disable the menu linkset endpoint\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,10,_binary 'a:0:{}',0,4,6,25,30,32,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',33,'system.admin_config_development','system.admin_config','system.admin_config_development','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Development\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Configure and use development tools.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,33,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',34,'config.sync','system.admin_config_development','config.sync','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Configuration synchronization\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Import and export your configuration.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','config',1,1,0,0,_binary 'a:0:{}',1,4,6,25,33,34,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',35,'system.site_maintenance_mode','system.admin_config_development','system.site_maintenance_mode','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Maintenance mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:62:\"Take the site offline for updates and other maintenance tasks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',0,4,6,25,33,35,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',36,'system.performance_settings','system.admin_config_development','system.performance_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Performance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Configure caching and bandwidth optimization.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,33,36,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',37,'system.development_settings','system.admin_config_development','system.development_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Development settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Configure theme development settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-19,_binary 'a:0:{}',0,4,6,25,33,37,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',38,'system.logging_settings','system.admin_config_development','system.logging_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Logging and errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:61:\"Configure the display of error messages and database logging.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',0,4,6,25,33,38,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',39,'system.admin_config_regional','system.admin_config','system.admin_config_regional','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Region and language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"Configure regional settings, localization, and translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-5,_binary 'a:0:{}',1,3,6,25,39,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',40,'system.regional_settings','system.admin_config_regional','system.regional_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Regional settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Configure the locale and timezone settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,39,40,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',41,'entity.date_format.collection','system.admin_config_regional','entity.date_format.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Date and time formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure how dates and times are displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-9,_binary 'a:0:{}',0,4,6,25,39,41,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',42,'system.admin_config_search','system.admin_config','system.admin_config_search','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Search and metadata\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:64:\"Configure site search, metadata, and search engine optimization.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,42,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',43,'entity.path_alias.collection','system.admin_config_search','entity.path_alias.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Add custom URLs to existing paths.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','path',1,1,0,-5,_binary 'a:0:{}',0,4,6,25,42,43,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',45,'system.admin_config_system','system.admin_config','system.admin_config_system','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"System\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Configure basic site settings, actions, and cron.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',1,3,6,25,45,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',46,'system.site_information_settings','system.admin_config_system','system.site_information_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Basic site settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"Change site name, email address, slogan, default front page, and error pages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,45,46,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',47,'system.cron_settings','system.admin_config_system','system.cron_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Cron\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Manage automatic site maintenance tasks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,20,_binary 'a:0:{}',0,4,6,25,45,47,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',48,'system.admin_config_ui','system.admin_config','system.admin_config_ui','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"User interface\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure the administrative user interface.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',1,3,6,25,48,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',49,'entity.shortcut_set.collection','system.admin_config_ui','entity.shortcut_set.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Shortcuts\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Add and modify shortcut sets.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','shortcut',1,1,0,0,_binary 'a:0:{}',0,4,6,25,48,49,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',50,'system.admin_config_workflow','system.admin_config','system.admin_config_workflow','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Workflow\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Manage the content workflow.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,5,_binary 'a:0:{}',0,3,6,25,50,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',51,'system.admin_config_content','system.admin_config','system.admin_config_content','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Content authoring\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Configure content formatting and authoring.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',1,3,6,25,51,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',52,'filter.admin_overview','system.admin_config_content','filter.admin_overview','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Text formats and editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Select and configure text editors, and how content is filtered when displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','filter',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,52,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',53,'user.admin_index','system.admin_config','user.admin_index','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"People\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Configure user accounts.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,-20,_binary 'a:0:{}',1,3,6,25,53,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',54,'entity.user.admin_form','user.admin_index','entity.user.admin_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Account settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:105:\"Configure default user account settings, including fields, registration requirements, and email messages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,-10,_binary 'a:0:{}',0,4,6,25,53,54,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',55,'system.admin_reports','system.admin','system.admin_reports','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Reports\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"View reports, updates, and errors.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,5,_binary 'a:0:{}',1,2,6,55,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',56,'dblog.overview','system.admin_reports','dblog.overview','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Recent log messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"View events that have recently been logged.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,-1,_binary 'a:0:{}',0,3,6,55,56,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',57,'dblog.page_not_found','system.admin_reports','dblog.page_not_found','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Top \'page not found\' errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"View \'page not found\' errors (404s).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,0,_binary 'a:0:{}',0,3,6,55,57,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',58,'dblog.access_denied','system.admin_reports','dblog.access_denied','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Top \'access denied\' errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"View \'access denied\' errors (403s).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,0,_binary 'a:0:{}',0,3,6,55,58,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',59,'entity.field_storage_config.collection','system.admin_reports','entity.field_storage_config.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Field list\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Overview of fields on all entity types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',0,3,6,55,59,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',60,'system.status','system.admin_reports','system.status','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Status report\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Get a status report about your site\'s operation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-60,_binary 'a:0:{}',0,3,6,55,60,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',61,'views_ui.reports_plugins','system.admin_reports','views_ui.reports_plugins','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Views plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Overview of plugins used in all views.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','views_ui',1,1,0,0,_binary 'a:0:{}',0,3,6,55,61,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',63,'entity.user.collection','system.admin','entity.user.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"People\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Manage user accounts, roles, and permissions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,4,_binary 'a:0:{}',0,2,6,63,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('account',64,'user.page','','user.page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"My account\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,-10,_binary 'a:0:{}',0,1,64,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('account',65,'user.logout','','','',_binary 'a:0:{}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\user\\Plugin\\Menu\\LoginLogoutMenuLink',_binary 'a:0:{}','user',1,1,0,10,_binary 'a:0:{}',0,1,65,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',66,'update.status','system.admin_reports','update.status','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Available updates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:82:\"Get a status report about available updates for your installed modules and themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','update',1,1,0,-50,_binary 'a:0:{}',0,3,6,55,66,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',67,'config_translation.mapper_list','system.admin_config_regional','config_translation.mapper_list','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Configuration translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Translate the configuration.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','config_translation',1,1,0,30,_binary 'a:0:{}',0,4,6,25,39,67,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',68,'entity.configurable_language.collection','system.admin_config_regional','entity.configurable_language.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Languages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:62:\"Configure languages for content, interface, and configuration.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','language',1,1,0,0,_binary 'a:0:{}',0,4,6,25,39,68,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',69,'language.content_settings_page','system.admin_config_regional','language.content_settings_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Content language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Configure language support for content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','language',1,1,0,10,_binary 'a:0:{}',0,4,6,25,39,69,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',70,'locale.translate_page','system.admin_config_regional','locale.translate_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"User interface translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:87:\"Configure the import of translation files, and add or customize interface translations.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','locale',1,1,0,15,_binary 'a:0:{}',0,4,6,25,39,70,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',71,'ckeditor5_plugin_pack.settings','system.admin_config_content','ckeditor5_plugin_pack.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"CKEditor 5 Plugin Pack\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure the CKEditor 5 Plugin Pack module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','ckeditor5_plugin_pack',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,71,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',72,'entity.ckeditor5_template.overview','system.admin_config_content','entity.ckeditor5_template.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"CKEditor 5 Content Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:89:\"The template feature allows you to insert predefined content structures into the document\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','ckeditor5_plugin_pack_templates',1,1,0,32,_binary 'a:0:{}',0,4,6,25,51,72,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',73,'locale.translate_status','system.admin_reports','locale.translate_status','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Available translation updates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:97:\"Get a status report about available interface translations for your installed modules and themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','locale',1,1,0,0,_binary 'a:0:{}',0,3,6,55,73,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',74,'config_ignore.settings','config.sync','config_ignore.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Ignore\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Configuration Ignore settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','config_ignore',1,1,0,3,_binary 'a:0:{}',0,5,6,25,33,34,74,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',75,'entity.linkit_profile.collection','system.admin_config_content','entity.linkit_profile.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Linkit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Manage Linkit profiles.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','linkit',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,75,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',76,'entity.metatag_defaults.collection','system.admin_config_search','entity.metatag_defaults.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Metatag\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Configure Metatag defaults.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','metatag',1,1,0,0,_binary 'a:0:{}',1,4,6,25,42,76,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',77,'metatag.settings','entity.metatag_defaults.collection','metatag.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Configure Metatag defaults.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','metatag',1,1,0,0,_binary 'a:0:{}',0,5,6,25,42,76,77,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',78,'metatag.reports_plugins','system.admin_reports','metatag.reports_plugins','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Metatag plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Overview of plugins used in metatag.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','metatag',1,1,0,0,_binary 'a:0:{}',0,3,6,55,78,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',79,'glightbox.admin_settings','system.admin_config_media','glightbox.admin_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"GLightbox settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Configure the GLightbox settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','glightbox',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,79,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',80,'redirect.list','system.admin_config_search','redirect.list','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"URL redirects\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Redirect users from one URL to another.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','redirect',1,1,0,0,_binary 'a:0:{}',1,4,6,25,42,80,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',81,'redirect.add','redirect.list','redirect.add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Add redirect\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','redirect',1,1,0,0,_binary 'a:0:{}',0,5,6,25,42,80,81,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',82,'redirect.settings','redirect.list','redirect.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Configure behavior for URL redirects.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','redirect',1,1,0,0,_binary 'a:0:{}',0,5,6,25,42,80,82,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',83,'simple_sitemap.sitemaps','system.admin_config_search','entity.simple_sitemap.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Simple XML Sitemap\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Configure, add content to and generate XML sitemaps.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','simple_sitemap',1,1,0,0,_binary 'a:0:{}',1,4,6,25,42,83,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',84,'simple_sitemap.status','simple_sitemap.sitemaps','entity.simple_sitemap.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Sitemaps\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','simple_sitemap',1,1,0,0,_binary 'a:0:{}',0,5,6,25,42,83,84,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',85,'simple_sitemap.inclusion','simple_sitemap.sitemaps','simple_sitemap.entities','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Inclusion\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','simple_sitemap',1,1,0,1,_binary 'a:0:{}',0,5,6,25,42,83,85,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',86,'entity.config_split.collection','system.admin_config_development','entity.config_split.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Configuration Split settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"List Configuration Split settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','config_split',1,1,0,0,_binary 'a:0:{}',0,4,6,25,33,86,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',87,'diff.settings','system.admin_config_content','diff.general_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Diff\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"Configure how entity fields are compared.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','diff',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,87,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',90,'entity.webform.collection','system.admin_structure','entity.webform.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Create webforms and manage submissions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,0,_binary 'a:0:{}',0,3,6,11,90,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',91,'webform.reports_plugins','system.admin_reports','webform.reports_plugins.elements','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"Overview of plugins used by the Webform module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','webform',1,1,0,0,_binary 'a:0:{}',0,3,6,55,91,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',92,'jsonapi.settings','system.admin_config_services','jsonapi.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"JSON:API\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:66:\"Configure whether to allow only read operations or all operations.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','jsonapi',1,1,0,0,_binary 'a:0:{}',0,4,6,25,30,92,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('main',93,'menu_link_content:78af3662-8542-4dda-846c-f12fe6d1c234','',NULL,'',_binary 'a:0:{}','base:articles',_binary 's:8:\"Articles\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:1:{s:10:\"attributes\";a:0:{}}','menu_link_content',1,1,0,-49,_binary 'a:1:{s:9:\"entity_id\";s:1:\"1\";}',0,1,93,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('main',94,'menu_link_content:a98db427-0beb-4d41-bf82-0793d7159241','','entity.webform.canonical','webform=contact',_binary 'a:1:{s:7:\"webform\";s:7:\"contact\";}','',_binary 's:10:\"Contact Us\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:0:{}s:5:\"query\";a:0:{}}','menu_link_content',1,1,0,-48,_binary 'a:1:{s:9:\"entity_id\";s:1:\"2\";}',0,1,94,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('admin',95,'restui.list','system.admin_config_services','restui.list','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"REST\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:31:\"Configure REST server settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','restui',1,1,0,0,_binary 'a:0:{}',0,4,6,25,30,95,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm');
/*!40000 ALTER TABLE `menu_tree` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node`
--

DROP TABLE IF EXISTS `node`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node` (
  `nid` int unsigned NOT NULL AUTO_INCREMENT,
  `vid` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`nid`),
  UNIQUE KEY `node_field__uuid__value` (`uuid`),
  UNIQUE KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node`
--

LOCK TABLES `node` WRITE;
/*!40000 ALTER TABLE `node` DISABLE KEYS */;
INSERT INTO `node` VALUES (1,6,'article','3bc20f97-5c68-4424-953a-17578646b409','en'),(2,5,'article','b26c80d2-155c-4c7e-9135-5a4011e2ae17','en'),(3,9,'article','510c7306-b0cb-4e73-bc15-ad74a7194f2c','en'),(4,14,'page','8b53db13-613e-45c4-80d7-dc81eba75f11','en');
/*!40000 ALTER TABLE `node` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__body`
--

DROP TABLE IF EXISTS `node__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__body`
--

LOCK TABLES `node__body` WRITE;
/*!40000 ALTER TABLE `node__body` DISABLE KEYS */;
INSERT INTO `node__body` VALUES ('article',0,1,6,'en',0,'<div><p>In today\'s fast-paced digital landscape, the need for efficient and scalable web solutions is paramount. One such solution that has gained significant traction is the JSON:API backend with a built-in Content Management System (CMS). This powerful combination offers a streamlined approach to managing and delivering content across various platforms.</p><h3 id=\"whatisjsonapi\">What is JSON:API?</h3><p>JSON:API is a specification for building APIs in JSON format. It standardizes how clients should request and modify data from a server, making it easier to develop and maintain APIs. By adhering to JSON:API standards, developers can ensure consistency, reduce the complexity of their code, and improve the overall performance of their applications.</p><h3 id=\"benefitsofjsonapibackend\">Benefits of JSON:API Backend</h3><ol><li>Consistency: JSON:API provides a uniform structure for API responses, which simplifies the development process and ensures that all endpoints behave predictably.</li><li>Efficiency: With JSON:API, data can be fetched and manipulated in a more efficient manner, reducing the amount of code needed and improving the speed of operations.</li><li>Scalability: JSON:API\'s standardized approach allows for easier scaling of applications, as new endpoints can be added without disrupting existing functionality.</li></ol><h3 id=\"integratingabuiltincms\">Integrating a Built-in CMS</h3><p>A built-in CMS enhances the capabilities of a JSON:API backend by providing a user-friendly interface for managing content. This integration allows non-technical users to create, edit, and publish content without needing to understand the underlying API structure.</p><h4 id=\"keyfeaturesofabuiltincms\">Key Features of a Built-in CMS</h4><ol><li>User-Friendly Interface: A CMS with an intuitive interface enables users to manage content effortlessly, reducing the need for extensive training.</li><li>Content Versioning: Built-in version control ensures that changes to content are tracked, allowing for easy rollback to previous versions if needed.</li><li>Role-Based Access Control: This feature allows administrators to define user roles and permissions, ensuring that only authorized personnel can make changes to critical content.</li></ol><h3 id=\"realworldapplications\">Real-World Applications</h3><p>The combination of JSON:API backend and built-in CMS is ideal for various applications, including:</p><ul><li>E-commerce Platforms: Efficiently manage product listings, customer reviews, and order processing.</li><li>News Websites: Streamline the publication process and ensure timely delivery of news articles.</li><li>Corporate Websites: Maintain up-to-date information about company services, events, and announcements.</li></ul><h3 id=\"conclusion\">Conclusion</h3><p>A JSON:API backend with a built-in CMS offers a robust solution for modern web development needs. By leveraging the strengths of JSON:API and the convenience of a CMS, developers can create scalable, efficient, and user-friendly applications that meet the demands of today\'s digital environment.</p><hr><p>Feel free to modify or expand upon this draft to suit your needs! Is there anything specific you\'d like to add or change?</p></div>','','full_html'),('article',0,2,5,'en',0,'<div><p>In the ever-evolving world of web development, choosing the right Content Management System (CMS) is crucial for creating dynamic and scalable websites. Drupal CMS stands out as a powerful and flexible solution, trusted by developers and organizations worldwide.</p><h3 id=\"whatisdrupalcms\">What is Drupal CMS?</h3><p>Drupal is an open-source CMS that allows users to create, manage, and publish content on the web. Known for its robustness and versatility, Drupal is used to build everything from personal blogs to enterprise-level applications. Its modular architecture and extensive community support make it a preferred choice for developers seeking a customizable and scalable platform.</p><h3 id=\"keyfeaturesofdrupalcms\">Key Features of Drupal CMS</h3><ol><li>Modular Architecture: Drupal\'s core functionality can be extended with thousands of modules, allowing developers to add features and customize their sites to meet specific needs.</li><li>Scalability: Drupal is designed to handle high-traffic websites and large amounts of content, making it suitable for enterprises and organizations with growing digital needs.</li><li>Security: Drupal has a strong focus on security, with regular updates and a dedicated security team ensuring that vulnerabilities are promptly addressed.</li><li>Multilingual Support: Drupal offers robust multilingual capabilities, enabling the creation of websites that cater to diverse audiences.</li><li>Responsive Design: With built-in support for responsive design, Drupal ensures that websites look great on all devices, from desktops to mobile phones.</li></ol><h3 id=\"benefitsofusingdrupalcms\">Benefits of Using Drupal CMS</h3><ol><li>Flexibility: Drupal\'s modular system allows for extensive customization, enabling developers to create unique and tailored solutions.</li><li>Community Support: The Drupal community is vast and active, providing a wealth of resources, documentation, and support for users at all levels.</li><li>SEO-Friendly: Drupal includes features and modules that help optimize websites for search engines, improving visibility and traffic.</li><li>Integration Capabilities: Drupal can easily integrate with other systems and technologies, such as CRM, e-commerce platforms, and marketing automation tools.</li></ol><h3 id=\"realworldapplications\">Real-World Applications</h3><p>Drupal CMS is used by a wide range of organizations, including:</p><ul><li>Government Websites: Many government agencies use Drupal for its security and scalability.</li><li>Educational Institutions: Universities and schools leverage Drupal to manage content and provide online learning resources.</li><li>Media and Publishing: News organizations and publishers use Drupal to deliver content efficiently and manage large volumes of articles.</li><li>Corporate Websites: Businesses use Drupal to create professional websites that showcase their services and products.</li></ul><h3 id=\"conclusion\">Conclusion</h3><p>Drupal CMS is a powerful and flexible platform that offers a wide range of features and benefits for web development. Its modular architecture, scalability, and strong community support make it an ideal choice for developers and organizations looking to create dynamic and robust websites. Whether you\'re building a small blog or a large enterprise application, Drupal provides the tools and capabilities needed to succeed in the digital landscape.</p><hr><p>Feel free to modify or expand upon this draft to suit your needs! Is there anything specific you\'d like to add or change?</p></div>','','full_html'),('article',0,3,9,'en',0,'<p>Next.js is a powerful and flexible framework for building web applications using React components. Developed by Vercel, Next.js has become a popular choice among developers for its ability to create high-quality, performant web applications with ease. This article explores the key features and benefits of Next.js, and why it stands out in the world of web development.</p><h3>Key Features</h3><p>1. Built-in Optimizations<br>Next.js comes with automatic optimizations for images, fonts, and scripts, which improve user experience and Core Web Vitals. These optimizations ensure that your application loads quickly and runs smoothly.</p><p>2. Data Fetching<br>Next.js supports both server-side and client-side data fetching, allowing you to make your React components async and await your data. This flexibility enables developers to build dynamic and interactive applications.</p><p>3. Advanced Routing<br>The framework offers a file-system based router that supports advanced routing patterns and nested layouts. This makes it easy to create complex and scalable web applications.</p><p>4. CSS Support<br>Next.js provides support for various styling methods, including CSS Modules, Tailwind CSS, and popular community libraries. This allows developers to style their applications using their preferred tools.</p><p>5. Server Actions<br>With Next.js, you can run server code by calling a function, skipping the API. This feature simplifies the process of revalidating cached data and updating the UI in one network roundtrip.</p><p>6. React Server Components<br>Next.js leverages the latest React features, including Server Components, to add components without sending additional client-side JavaScript. This results in faster and more efficient web applications.</p><h3>Benefits</h3><p>1. Performance<br>Next.js is designed to deliver high performance out of the box. Its built-in optimizations and efficient rendering methods ensure that your application is fast and responsive.</p><p>2. Developer Experience<br>The framework abstracts and automatically configures the necessary tooling for React, such as bundling and compiling. This allows developers to focus on building their applications rather than dealing with configuration.</p><p>3. Flexibility<br>Next.js supports various rendering methods, including client-side rendering, server-side rendering, and static site generation. This flexibility enables developers to choose the best approach for their specific use case.</p><p>4. Community and Ecosystem<br>Next.js has a strong community and ecosystem, with numerous plugins, templates, and examples available. This makes it easy to get started and find solutions to common problems.</p><h3>Getting Started</h3><p>To start a new Next.js project, you can use the create-next-app command, which sets up everything automatically for you. Here are the steps to create a new project:</p><p>Install Node.js: Ensure you have Node.js installed on your system.<br>Run the command: Open your terminal and run npx create-next-app@latest.<br>Follow the prompts: Answer the prompts to configure your new Next.js project.</p><h3>Conclusion</h3><p>Next.js is a powerful framework that simplifies the process of building modern web applications with React. Its built-in optimizations, flexible rendering methods, and strong community support make it an excellent choice for developers looking to create high-quality web applications. Whether you\'re building a small personal project or a large enterprise application, Next.js provides the tools and features you need to succeed.</p>','','full_html'),('page',0,4,14,'en',0,'<p class=\"\" data-start=\"93\" data-end=\"292\">JsonDrop is your powerful Drupal-based backend server leveraging Drupal’s robust JSON:API ecosystem. Rapidly prototype, build, and scale your APIs with minimal configuration and maximum flexibility.</p><h3 class=\"\" data-start=\"294\" data-end=\"312\">Why JsonDrop API?</h3><img data-entity-uuid=\"e5738396-f733-4814-b20c-5375ee9cfd39\" data-entity-type=\"file\" src=\"/sites/default/files/inline-images/json-api.jpg\" width=\"1536\" height=\"1024\" alt=\"JsonAPI and Drupal\"><p class=\"\" data-start=\"314\" data-end=\"461\"><strong data-start=\"314\" data-end=\"344\">Drupal-Powered Flexibility</strong><br>Harness the extensive power and reliability of Drupal and JSON:API to quickly spin up robust, feature-rich APIs.</p><p class=\"\" data-start=\"463\" data-end=\"629\"><strong data-start=\"463\" data-end=\"484\">Rapid Prototyping</strong><br>Save valuable development time by creating functional prototypes faster than ever. JSON Drop makes iterating and refining your API effortless.</p><p class=\"\" data-start=\"631\" data-end=\"829\"><strong data-start=\"631\" data-end=\"655\">Seamless Integration</strong><br>Easily connect your frontend applications and services with our clearly defined JSON endpoints. JsonDrop API integrates smoothly with modern frontend frameworks and services.</p><p class=\"\" data-start=\"831\" data-end=\"984\"><strong data-start=\"831\" data-end=\"856\">Extensible &amp; Scalable</strong><br>Expand your backend effortlessly with Drupal’s rich ecosystem of modules. Grow from prototype to production without friction.</p><h3 class=\"\" data-start=\"986\" data-end=\"1003\">Key Features:</h3><ul data-start=\"1005\" data-end=\"1514\"><li class=\"\" data-start=\"1005\" data-end=\"1091\"><p class=\"\" data-start=\"1007\" data-end=\"1091\"><strong data-start=\"1007\" data-end=\"1036\">Drupal JSON:API Ecosystem</strong>: Ready-to-use, standards-compliant JSON API endpoints.</p></li><li class=\"\" data-start=\"1092\" data-end=\"1189\"><p class=\"\" data-start=\"1094\" data-end=\"1189\"><strong data-start=\"1094\" data-end=\"1124\">Efficient Content Modeling</strong>: Easily create structured content, custom fields, and relations.</p></li><li class=\"\" data-start=\"1190\" data-end=\"1293\"><p class=\"\" data-start=\"1192\" data-end=\"1293\"><strong data-start=\"1192\" data-end=\"1217\">Secure Authentication</strong>: Built-in authentication options to secure your API endpoints effortlessly.</p></li><li class=\"\" data-start=\"1294\" data-end=\"1403\"><p class=\"\" data-start=\"1296\" data-end=\"1403\"><strong data-start=\"1296\" data-end=\"1324\">Extensive Module Library</strong>: Access thousands of Drupal modules to instantly add powerful functionalities.</p></li><li class=\"\" data-start=\"1404\" data-end=\"1514\"><p class=\"\" data-start=\"1406\" data-end=\"1514\"><strong data-start=\"1406\" data-end=\"1434\">Developer-Friendly Tools</strong>: Clear documentation, easy-to-use interfaces, and developer-oriented workflows.</p></li></ul><h3 class=\"\" data-start=\"1516\" data-end=\"1530\">Ideal for:</h3><ul data-start=\"1532\" data-end=\"1705\"><li class=\"\" data-start=\"1532\" data-end=\"1594\"><p class=\"\" data-start=\"1534\" data-end=\"1594\">Frontend developers who want a hassle-free backend solution.</p></li><li class=\"\" data-start=\"1595\" data-end=\"1640\"><p class=\"\" data-start=\"1597\" data-end=\"1640\">Teams building prototypes and MVPs quickly.</p></li><li class=\"\" data-start=\"1641\" data-end=\"1705\"><p class=\"\" data-start=\"1643\" data-end=\"1705\">Businesses aiming to reduce backend development time and cost.</p></li></ul><hr><p class=\"\" data-start=\"1712\" data-end=\"1882\">Get started today and experience the ease of Drupal’s JSON:API ecosystem with JsonDrop API —your ultimate backend solution for rapid development and flexible API prototyping.</p>','','full_html');
/*!40000 ALTER TABLE `node__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__comment`
--

DROP TABLE IF EXISTS `node__comment`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__comment` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_status` int NOT NULL DEFAULT '0' COMMENT 'Whether comments are allowed on this entity: 0 = no, 1 = closed (read only), 2 = open (read/write).',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field comment.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__comment`
--

LOCK TABLES `node__comment` WRITE;
/*!40000 ALTER TABLE `node__comment` DISABLE KEYS */;
INSERT INTO `node__comment` VALUES ('article',0,1,6,'en',0,2),('article',0,2,5,'en',0,2),('article',0,3,9,'en',0,2);
/*!40000 ALTER TABLE `node__comment` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__field_image`
--

DROP TABLE IF EXISTS `node__field_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__field_image`
--

LOCK TABLES `node__field_image` WRITE;
/*!40000 ALTER TABLE `node__field_image` DISABLE KEYS */;
INSERT INTO `node__field_image` VALUES ('article',0,1,6,'en',0,1,'sadf','',1024,1024),('article',0,2,5,'en',0,2,'Drupal CMS','',1024,1024),('article',0,3,9,'en',0,4,'Next.js','',1024,1024);
/*!40000 ALTER TABLE `node__field_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__field_tags`
--

DROP TABLE IF EXISTS `node__field_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_tags.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__field_tags`
--

LOCK TABLES `node__field_tags` WRITE;
/*!40000 ALTER TABLE `node__field_tags` DISABLE KEYS */;
INSERT INTO `node__field_tags` VALUES ('article',0,1,6,'en',0,1),('article',0,2,5,'en',0,1),('article',0,2,5,'en',1,2),('article',0,3,9,'en',0,3);
/*!40000 ALTER TABLE `node__field_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__webform`
--

DROP TABLE IF EXISTS `node__webform`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__webform` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `webform_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `webform_default_data` text COMMENT 'Default submission data.',
  `webform_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `webform_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `webform_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `webform_target_id` (`webform_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field webform.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__webform`
--

LOCK TABLES `node__webform` WRITE;
/*!40000 ALTER TABLE `node__webform` DISABLE KEYS */;
/*!40000 ALTER TABLE `node__webform` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_access`
--

DROP TABLE IF EXISTS `node_access`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_access` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid this record affects.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "language".langcode of this node.',
  `fallback` tinyint unsigned NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether this record should be used as a fallback if a language condition is not provided.',
  `gid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The grant ID a user must possess in the specified realm to gain this row''s privileges on the node.',
  `realm` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The realm in which the user must possess the grant ID. Modules can define one or more realms by implementing hook_node_grants().',
  `grant_view` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can view this node.',
  `grant_update` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can edit this node.',
  `grant_delete` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can delete this node.',
  PRIMARY KEY (`nid`,`gid`,`realm`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Identifies which realm/grant pairs a user must possess in…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_access`
--

LOCK TABLES `node_access` WRITE;
/*!40000 ALTER TABLE `node_access` DISABLE KEYS */;
INSERT INTO `node_access` VALUES (0,'',1,0,'all',1,0,0);
/*!40000 ALTER TABLE `node_access` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_field_data`
--

DROP TABLE IF EXISTS `node_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_field_data` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) NOT NULL,
  `created` int NOT NULL,
  `changed` int NOT NULL,
  `promote` tinyint NOT NULL,
  `sticky` tinyint NOT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  `rh_action` varchar(255) DEFAULT NULL,
  `rh_redirect` varchar(255) DEFAULT NULL,
  `rh_redirect_response` int DEFAULT NULL,
  `rh_redirect_fallback_action` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`nid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`),
  KEY `node_field__uid__target_id` (`uid`),
  KEY `node_field__created` (`created`),
  KEY `node_field__changed` (`changed`),
  KEY `node__status_type` (`status`,`type`,`nid`),
  KEY `node__frontpage` (`promote`,`status`,`sticky`,`created`),
  KEY `node__title_type` (`title`(191),`type`(4))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_field_data`
--

LOCK TABLES `node_field_data` WRITE;
/*!40000 ALTER TABLE `node_field_data` DISABLE KEYS */;
INSERT INTO `node_field_data` VALUES (1,6,'article','en',1,1,'JSON:API backend with built-in CMS',1742136181,1742138857,1,0,1,1,'bundle_default',NULL,301,'bundle_default'),(2,5,'article','en',1,1,'Drupal CMS',1742136412,1742138840,1,0,1,1,'bundle_default',NULL,301,'bundle_default'),(3,9,'article','en',1,1,'Next.js: The React Framework for Modern Web Development',1742153852,1742154706,1,0,1,1,'bundle_default',NULL,301,'bundle_default'),(4,14,'page','en',1,1,'JsonDrop API',1742757271,1743937139,0,0,1,1,'bundle_default',NULL,301,'bundle_default');
/*!40000 ALTER TABLE `node_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_field_revision`
--

DROP TABLE IF EXISTS `node_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_field_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) DEFAULT NULL,
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `promote` tinyint DEFAULT NULL,
  `sticky` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node_field__uid__target_id` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_field_revision`
--

LOCK TABLES `node_field_revision` WRITE;
/*!40000 ALTER TABLE `node_field_revision` DISABLE KEYS */;
INSERT INTO `node_field_revision` VALUES (1,1,'en',1,1,'JSON:API backend with built-in CMS',1742136181,1742136377,1,0,1,1),(2,2,'en',1,1,'Drupal CMS',1742136412,1742136512,1,0,1,1),(2,3,'en',1,1,'Drupal CMS',1742136412,1742138766,1,0,1,1),(1,4,'en',1,1,'JSON:API backend with built-in CMS',1742136181,1742138788,1,0,1,1),(2,5,'en',1,1,'Drupal CMS',1742136412,1742138840,1,0,1,1),(1,6,'en',1,1,'JSON:API backend with built-in CMS',1742136181,1742138857,1,0,1,1),(3,7,'en',1,1,'Next.js: The React Framework for Modern Web Development',1742153852,1742153978,1,0,1,1),(3,8,'en',1,1,'Next.js: The React Framework for Modern Web Development',1742153852,1742154261,1,0,1,1),(3,9,'en',1,1,'Next.js: The React Framework for Modern Web Development',1742153852,1742154706,1,0,1,1),(4,13,'en',1,1,'JsonDrop API',1742757271,1743626192,0,0,1,1),(4,14,'en',1,1,'JsonDrop API',1742757271,1743937139,0,0,1,1);
/*!40000 ALTER TABLE `node_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision`
--

DROP TABLE IF EXISTS `node_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_timestamp` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`),
  KEY `node__nid` (`nid`),
  KEY `node_field__langcode` (`langcode`),
  KEY `node_field__revision_uid__target_id` (`revision_uid`)
) ENGINE=InnoDB AUTO_INCREMENT=15 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision`
--

LOCK TABLES `node_revision` WRITE;
/*!40000 ALTER TABLE `node_revision` DISABLE KEYS */;
INSERT INTO `node_revision` VALUES (1,1,'en',1,1742136377,NULL,1),(2,2,'en',1,1742136512,NULL,1),(2,3,'en',1,1742138766,NULL,1),(1,4,'en',1,1742138788,NULL,1),(2,5,'en',1,1742138840,NULL,1),(1,6,'en',1,1742138857,NULL,1),(3,7,'en',1,1742153978,NULL,1),(3,8,'en',1,1742154261,NULL,1),(3,9,'en',1,1742154706,NULL,1),(4,13,'en',1,1743626192,NULL,1),(4,14,'en',1,1743937139,NULL,1);
/*!40000 ALTER TABLE `node_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__body`
--

DROP TABLE IF EXISTS `node_revision__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__body`
--

LOCK TABLES `node_revision__body` WRITE;
/*!40000 ALTER TABLE `node_revision__body` DISABLE KEYS */;
INSERT INTO `node_revision__body` VALUES ('article',0,1,1,'en',0,'<p><meta content=\"text/html; charset=us-ascii\" http-equiv=\"Content-Type\"><style>a{text-decoration:none;color:#464feb}</style></p><div style=\"font-family:&apos;Segoe UI&apos;;font-size:14px;font-style:normal;font-weight:400;line-height:20px;\"><p>In today\'s fast-paced digital landscape, the need for efficient and scalable web solutions is paramount. One such solution that has gained significant traction is the JSON:API backend with a built-in Content Management System (CMS). This powerful combination offers a streamlined approach to managing and delivering content across various platforms.</p><h3 id=\"whatisjsonapi\">What is JSON:API?</h3><p>JSON:API is a specification for building APIs in JSON format. It standardizes how clients should request and modify data from a server, making it easier to develop and maintain APIs. By adhering to JSON:API standards, developers can ensure consistency, reduce the complexity of their code, and improve the overall performance of their applications.</p><h3 id=\"benefitsofjsonapibackend\">Benefits of JSON:API Backend</h3><ol><li><strong>Consistency</strong>: JSON:API provides a uniform structure for API responses, which simplifies the development process and ensures that all endpoints behave predictably.</li><li><strong>Efficiency</strong>: With JSON:API, data can be fetched and manipulated in a more efficient manner, reducing the amount of code needed and improving the speed of operations.</li><li><strong>Scalability</strong>: JSON:API\'s standardized approach allows for easier scaling of applications, as new endpoints can be added without disrupting existing functionality.</li></ol><h3 id=\"integratingabuiltincms\">Integrating a Built-in CMS</h3><p>A built-in CMS enhances the capabilities of a JSON:API backend by providing a user-friendly interface for managing content. This integration allows non-technical users to create, edit, and publish content without needing to understand the underlying API structure.</p><h4 id=\"keyfeaturesofabuiltincms\">Key Features of a Built-in CMS</h4><ol><li><strong>User-Friendly Interface</strong>: A CMS with an intuitive interface enables users to manage content effortlessly, reducing the need for extensive training.</li><li><strong>Content Versioning</strong>: Built-in version control ensures that changes to content are tracked, allowing for easy rollback to previous versions if needed.</li><li><strong>Role-Based Access Control</strong>: This feature allows administrators to define user roles and permissions, ensuring that only authorized personnel can make changes to critical content.</li></ol><h3 id=\"realworldapplications\">Real-World Applications</h3><p>The combination of JSON:API backend and built-in CMS is ideal for various applications, including:</p><ul><li><strong>E-commerce Platforms</strong>: Efficiently manage product listings, customer reviews, and order processing.</li><li><strong>News Websites</strong>: Streamline the publication process and ensure timely delivery of news articles.</li><li><strong>Corporate Websites</strong>: Maintain up-to-date information about company services, events, and announcements.</li></ul><h3 id=\"conclusion\">Conclusion</h3><p>A JSON:API backend with a built-in CMS offers a robust solution for modern web development needs. By leveraging the strengths of JSON:API and the convenience of a CMS, developers can create scalable, efficient, and user-friendly applications that meet the demands of today\'s digital environment.</p><hr><p>Feel free to modify or expand upon this draft to suit your needs! Is there anything specific you\'d like to add or change?</p></div>','','full_html'),('article',0,1,4,'en',0,'<div style=\"font-family:&apos;Segoe UI&apos;;font-size:14px;font-style:normal;font-weight:400;line-height:20px;\"><p>In today\'s fast-paced digital landscape, the need for efficient and scalable web solutions is paramount. One such solution that has gained significant traction is the JSON:API backend with a built-in Content Management System (CMS). This powerful combination offers a streamlined approach to managing and delivering content across various platforms.</p><h3 id=\"whatisjsonapi\">What is JSON:API?</h3><p>JSON:API is a specification for building APIs in JSON format. It standardizes how clients should request and modify data from a server, making it easier to develop and maintain APIs. By adhering to JSON:API standards, developers can ensure consistency, reduce the complexity of their code, and improve the overall performance of their applications.</p><h3 id=\"benefitsofjsonapibackend\">Benefits of JSON:API Backend</h3><ol><li>Consistency: JSON:API provides a uniform structure for API responses, which simplifies the development process and ensures that all endpoints behave predictably.</li><li>Efficiency: With JSON:API, data can be fetched and manipulated in a more efficient manner, reducing the amount of code needed and improving the speed of operations.</li><li>Scalability: JSON:API\'s standardized approach allows for easier scaling of applications, as new endpoints can be added without disrupting existing functionality.</li></ol><h3 id=\"integratingabuiltincms\">Integrating a Built-in CMS</h3><p>A built-in CMS enhances the capabilities of a JSON:API backend by providing a user-friendly interface for managing content. This integration allows non-technical users to create, edit, and publish content without needing to understand the underlying API structure.</p><h4 id=\"keyfeaturesofabuiltincms\">Key Features of a Built-in CMS</h4><ol><li>User-Friendly Interface: A CMS with an intuitive interface enables users to manage content effortlessly, reducing the need for extensive training.</li><li>Content Versioning: Built-in version control ensures that changes to content are tracked, allowing for easy rollback to previous versions if needed.</li><li>Role-Based Access Control: This feature allows administrators to define user roles and permissions, ensuring that only authorized personnel can make changes to critical content.</li></ol><h3 id=\"realworldapplications\">Real-World Applications</h3><p>The combination of JSON:API backend and built-in CMS is ideal for various applications, including:</p><ul><li>E-commerce Platforms: Efficiently manage product listings, customer reviews, and order processing.</li><li>News Websites: Streamline the publication process and ensure timely delivery of news articles.</li><li>Corporate Websites: Maintain up-to-date information about company services, events, and announcements.</li></ul><h3 id=\"conclusion\">Conclusion</h3><p>A JSON:API backend with a built-in CMS offers a robust solution for modern web development needs. By leveraging the strengths of JSON:API and the convenience of a CMS, developers can create scalable, efficient, and user-friendly applications that meet the demands of today\'s digital environment.</p><hr><p>Feel free to modify or expand upon this draft to suit your needs! Is there anything specific you\'d like to add or change?</p></div>','','full_html'),('article',0,1,6,'en',0,'<div><p>In today\'s fast-paced digital landscape, the need for efficient and scalable web solutions is paramount. One such solution that has gained significant traction is the JSON:API backend with a built-in Content Management System (CMS). This powerful combination offers a streamlined approach to managing and delivering content across various platforms.</p><h3 id=\"whatisjsonapi\">What is JSON:API?</h3><p>JSON:API is a specification for building APIs in JSON format. It standardizes how clients should request and modify data from a server, making it easier to develop and maintain APIs. By adhering to JSON:API standards, developers can ensure consistency, reduce the complexity of their code, and improve the overall performance of their applications.</p><h3 id=\"benefitsofjsonapibackend\">Benefits of JSON:API Backend</h3><ol><li>Consistency: JSON:API provides a uniform structure for API responses, which simplifies the development process and ensures that all endpoints behave predictably.</li><li>Efficiency: With JSON:API, data can be fetched and manipulated in a more efficient manner, reducing the amount of code needed and improving the speed of operations.</li><li>Scalability: JSON:API\'s standardized approach allows for easier scaling of applications, as new endpoints can be added without disrupting existing functionality.</li></ol><h3 id=\"integratingabuiltincms\">Integrating a Built-in CMS</h3><p>A built-in CMS enhances the capabilities of a JSON:API backend by providing a user-friendly interface for managing content. This integration allows non-technical users to create, edit, and publish content without needing to understand the underlying API structure.</p><h4 id=\"keyfeaturesofabuiltincms\">Key Features of a Built-in CMS</h4><ol><li>User-Friendly Interface: A CMS with an intuitive interface enables users to manage content effortlessly, reducing the need for extensive training.</li><li>Content Versioning: Built-in version control ensures that changes to content are tracked, allowing for easy rollback to previous versions if needed.</li><li>Role-Based Access Control: This feature allows administrators to define user roles and permissions, ensuring that only authorized personnel can make changes to critical content.</li></ol><h3 id=\"realworldapplications\">Real-World Applications</h3><p>The combination of JSON:API backend and built-in CMS is ideal for various applications, including:</p><ul><li>E-commerce Platforms: Efficiently manage product listings, customer reviews, and order processing.</li><li>News Websites: Streamline the publication process and ensure timely delivery of news articles.</li><li>Corporate Websites: Maintain up-to-date information about company services, events, and announcements.</li></ul><h3 id=\"conclusion\">Conclusion</h3><p>A JSON:API backend with a built-in CMS offers a robust solution for modern web development needs. By leveraging the strengths of JSON:API and the convenience of a CMS, developers can create scalable, efficient, and user-friendly applications that meet the demands of today\'s digital environment.</p><hr><p>Feel free to modify or expand upon this draft to suit your needs! Is there anything specific you\'d like to add or change?</p></div>','','full_html'),('article',0,2,2,'en',0,'<p><meta content=\"text/html; charset=us-ascii\" http-equiv=\"Content-Type\"><style>a{text-decoration:none;color:#464feb}</style></p><div style=\"font-family:&apos;Segoe UI&apos;;font-size:14px;font-style:normal;font-weight:400;line-height:20px;\"><p>In the ever-evolving world of web development, choosing the right Content Management System (CMS) is crucial for creating dynamic and scalable websites. Drupal CMS stands out as a powerful and flexible solution, trusted by developers and organizations worldwide.</p><h3 id=\"whatisdrupalcms\">What is Drupal CMS?</h3><p>Drupal is an open-source CMS that allows users to create, manage, and publish content on the web. Known for its robustness and versatility, Drupal is used to build everything from personal blogs to enterprise-level applications. Its modular architecture and extensive community support make it a preferred choice for developers seeking a customizable and scalable platform.</p><h3 id=\"keyfeaturesofdrupalcms\">Key Features of Drupal CMS</h3><ol><li><strong>Modular Architecture</strong>: Drupal\'s core functionality can be extended with thousands of modules, allowing developers to add features and customize their sites to meet specific needs.</li><li><strong>Scalability</strong>: Drupal is designed to handle high-traffic websites and large amounts of content, making it suitable for enterprises and organizations with growing digital needs.</li><li><strong>Security</strong>: Drupal has a strong focus on security, with regular updates and a dedicated security team ensuring that vulnerabilities are promptly addressed.</li><li><strong>Multilingual Support</strong>: Drupal offers robust multilingual capabilities, enabling the creation of websites that cater to diverse audiences.</li><li><strong>Responsive Design</strong>: With built-in support for responsive design, Drupal ensures that websites look great on all devices, from desktops to mobile phones.</li></ol><h3 id=\"benefitsofusingdrupalcms\">Benefits of Using Drupal CMS</h3><ol><li><strong>Flexibility</strong>: Drupal\'s modular system allows for extensive customization, enabling developers to create unique and tailored solutions.</li><li><strong>Community Support</strong>: The Drupal community is vast and active, providing a wealth of resources, documentation, and support for users at all levels.</li><li><strong>SEO-Friendly</strong>: Drupal includes features and modules that help optimize websites for search engines, improving visibility and traffic.</li><li><strong>Integration Capabilities</strong>: Drupal can easily integrate with other systems and technologies, such as CRM, e-commerce platforms, and marketing automation tools.</li></ol><h3 id=\"realworldapplications\">Real-World Applications</h3><p>Drupal CMS is used by a wide range of organizations, including:</p><ul><li><strong>Government Websites</strong>: Many government agencies use Drupal for its security and scalability.</li><li><strong>Educational Institutions</strong>: Universities and schools leverage Drupal to manage content and provide online learning resources.</li><li><strong>Media and Publishing</strong>: News organizations and publishers use Drupal to deliver content efficiently and manage large volumes of articles.</li><li><strong>Corporate Websites</strong>: Businesses use Drupal to create professional websites that showcase their services and products.</li></ul><h3 id=\"conclusion\">Conclusion</h3><p>Drupal CMS is a powerful and flexible platform that offers a wide range of features and benefits for web development. Its modular architecture, scalability, and strong community support make it an ideal choice for developers and organizations looking to create dynamic and robust websites. Whether you\'re building a small blog or a large enterprise application, Drupal provides the tools and capabilities needed to succeed in the digital landscape.</p><hr><p>Feel free to modify or expand upon this draft to suit your needs! Is there anything specific you\'d like to add or change?</p></div>','','full_html'),('article',0,2,3,'en',0,'<p><meta content=\"text/html; charset=us-ascii\" http-equiv=\"Content-Type\"><style>a{text-decoration:none;color:#464feb}</style></p><div style=\"font-family:&apos;Segoe UI&apos;;font-size:14px;font-style:normal;font-weight:400;line-height:20px;\"><p>In the ever-evolving world of web development, choosing the right Content Management System (CMS) is crucial for creating dynamic and scalable websites. Drupal CMS stands out as a powerful and flexible solution, trusted by developers and organizations worldwide.</p><h3 id=\"whatisdrupalcms\">What is Drupal CMS?</h3><p>Drupal is an open-source CMS that allows users to create, manage, and publish content on the web. Known for its robustness and versatility, Drupal is used to build everything from personal blogs to enterprise-level applications. Its modular architecture and extensive community support make it a preferred choice for developers seeking a customizable and scalable platform.</p><h3 id=\"keyfeaturesofdrupalcms\">Key Features of Drupal CMS</h3><ol><li>Modular Architecture: Drupal\'s core functionality can be extended with thousands of modules, allowing developers to add features and customize their sites to meet specific needs.</li><li>Scalability: Drupal is designed to handle high-traffic websites and large amounts of content, making it suitable for enterprises and organizations with growing digital needs.</li><li>Security: Drupal has a strong focus on security, with regular updates and a dedicated security team ensuring that vulnerabilities are promptly addressed.</li><li>Multilingual Support: Drupal offers robust multilingual capabilities, enabling the creation of websites that cater to diverse audiences.</li><li>Responsive Design: With built-in support for responsive design, Drupal ensures that websites look great on all devices, from desktops to mobile phones.</li></ol><h3 id=\"benefitsofusingdrupalcms\">Benefits of Using Drupal CMS</h3><ol><li>Flexibility: Drupal\'s modular system allows for extensive customization, enabling developers to create unique and tailored solutions.</li><li>Community Support: The Drupal community is vast and active, providing a wealth of resources, documentation, and support for users at all levels.</li><li>SEO-Friendly: Drupal includes features and modules that help optimize websites for search engines, improving visibility and traffic.</li><li>Integration Capabilities: Drupal can easily integrate with other systems and technologies, such as CRM, e-commerce platforms, and marketing automation tools.</li></ol><h3 id=\"realworldapplications\">Real-World Applications</h3><p>Drupal CMS is used by a wide range of organizations, including:</p><ul><li>Government Websites: Many government agencies use Drupal for its security and scalability.</li><li>Educational Institutions: Universities and schools leverage Drupal to manage content and provide online learning resources.</li><li>Media and Publishing: News organizations and publishers use Drupal to deliver content efficiently and manage large volumes of articles.</li><li>Corporate Websites: Businesses use Drupal to create professional websites that showcase their services and products.</li></ul><h3 id=\"conclusion\">Conclusion</h3><p>Drupal CMS is a powerful and flexible platform that offers a wide range of features and benefits for web development. Its modular architecture, scalability, and strong community support make it an ideal choice for developers and organizations looking to create dynamic and robust websites. Whether you\'re building a small blog or a large enterprise application, Drupal provides the tools and capabilities needed to succeed in the digital landscape.</p><hr><p>Feel free to modify or expand upon this draft to suit your needs! Is there anything specific you\'d like to add or change?</p></div>','','full_html'),('article',0,2,5,'en',0,'<div><p>In the ever-evolving world of web development, choosing the right Content Management System (CMS) is crucial for creating dynamic and scalable websites. Drupal CMS stands out as a powerful and flexible solution, trusted by developers and organizations worldwide.</p><h3 id=\"whatisdrupalcms\">What is Drupal CMS?</h3><p>Drupal is an open-source CMS that allows users to create, manage, and publish content on the web. Known for its robustness and versatility, Drupal is used to build everything from personal blogs to enterprise-level applications. Its modular architecture and extensive community support make it a preferred choice for developers seeking a customizable and scalable platform.</p><h3 id=\"keyfeaturesofdrupalcms\">Key Features of Drupal CMS</h3><ol><li>Modular Architecture: Drupal\'s core functionality can be extended with thousands of modules, allowing developers to add features and customize their sites to meet specific needs.</li><li>Scalability: Drupal is designed to handle high-traffic websites and large amounts of content, making it suitable for enterprises and organizations with growing digital needs.</li><li>Security: Drupal has a strong focus on security, with regular updates and a dedicated security team ensuring that vulnerabilities are promptly addressed.</li><li>Multilingual Support: Drupal offers robust multilingual capabilities, enabling the creation of websites that cater to diverse audiences.</li><li>Responsive Design: With built-in support for responsive design, Drupal ensures that websites look great on all devices, from desktops to mobile phones.</li></ol><h3 id=\"benefitsofusingdrupalcms\">Benefits of Using Drupal CMS</h3><ol><li>Flexibility: Drupal\'s modular system allows for extensive customization, enabling developers to create unique and tailored solutions.</li><li>Community Support: The Drupal community is vast and active, providing a wealth of resources, documentation, and support for users at all levels.</li><li>SEO-Friendly: Drupal includes features and modules that help optimize websites for search engines, improving visibility and traffic.</li><li>Integration Capabilities: Drupal can easily integrate with other systems and technologies, such as CRM, e-commerce platforms, and marketing automation tools.</li></ol><h3 id=\"realworldapplications\">Real-World Applications</h3><p>Drupal CMS is used by a wide range of organizations, including:</p><ul><li>Government Websites: Many government agencies use Drupal for its security and scalability.</li><li>Educational Institutions: Universities and schools leverage Drupal to manage content and provide online learning resources.</li><li>Media and Publishing: News organizations and publishers use Drupal to deliver content efficiently and manage large volumes of articles.</li><li>Corporate Websites: Businesses use Drupal to create professional websites that showcase their services and products.</li></ul><h3 id=\"conclusion\">Conclusion</h3><p>Drupal CMS is a powerful and flexible platform that offers a wide range of features and benefits for web development. Its modular architecture, scalability, and strong community support make it an ideal choice for developers and organizations looking to create dynamic and robust websites. Whether you\'re building a small blog or a large enterprise application, Drupal provides the tools and capabilities needed to succeed in the digital landscape.</p><hr><p>Feel free to modify or expand upon this draft to suit your needs! Is there anything specific you\'d like to add or change?</p></div>','','full_html'),('article',0,3,7,'en',0,'<h3>Introduction</h3><p>Next.js is a powerful and flexible framework for building web applications using React components. Developed by Vercel, Next.js has become a popular choice among developers for its ability to create high-quality, performant web applications with ease. This article explores the key features and benefits of Next.js, and why it stands out in the world of web development.</p><h3>Key Features</h3><p>1. Built-in Optimizations<br>Next.js comes with automatic optimizations for images, fonts, and scripts, which improve user experience and Core Web Vitals. These optimizations ensure that your application loads quickly and runs smoothly.</p><p>2. Data Fetching<br>Next.js supports both server-side and client-side data fetching, allowing you to make your React components async and await your data. This flexibility enables developers to build dynamic and interactive applications.</p><p>3. Advanced Routing<br>The framework offers a file-system based router that supports advanced routing patterns and nested layouts. This makes it easy to create complex and scalable web applications.</p><p>4. CSS Support<br>Next.js provides support for various styling methods, including CSS Modules, Tailwind CSS, and popular community libraries. This allows developers to style their applications using their preferred tools.</p><p>5. Server Actions<br>With Next.js, you can run server code by calling a function, skipping the API. This feature simplifies the process of revalidating cached data and updating the UI in one network roundtrip.</p><p>6. React Server Components<br>Next.js leverages the latest React features, including Server Components, to add components without sending additional client-side JavaScript. This results in faster and more efficient web applications.</p><h3>Benefits</h3><p>1. Performance<br>Next.js is designed to deliver high performance out of the box. Its built-in optimizations and efficient rendering methods ensure that your application is fast and responsive.</p><p>2. Developer Experience<br>The framework abstracts and automatically configures the necessary tooling for React, such as bundling and compiling. This allows developers to focus on building their applications rather than dealing with configuration.</p><p>3. Flexibility<br>Next.js supports various rendering methods, including client-side rendering, server-side rendering, and static site generation. This flexibility enables developers to choose the best approach for their specific use case.</p><p>4. Community and Ecosystem<br>Next.js has a strong community and ecosystem, with numerous plugins, templates, and examples available. This makes it easy to get started and find solutions to common problems.</p><h3>Getting Started</h3><p>To start a new Next.js project, you can use the create-next-app command, which sets up everything automatically for you. Here are the steps to create a new project:</p><p>Install Node.js: Ensure you have Node.js installed on your system.<br>Run the command: Open your terminal and run npx create-next-app@latest.<br>Follow the prompts: Answer the prompts to configure your new Next.js project.</p><h3>Conclusion</h3><p>Next.js is a powerful framework that simplifies the process of building modern web applications with React. Its built-in optimizations, flexible rendering methods, and strong community support make it an excellent choice for developers looking to create high-quality web applications. Whether you\'re building a small personal project or a large enterprise application, Next.js provides the tools and features you need to succeed.</p>','','full_html'),('article',0,3,8,'en',0,'<h3>Introduction</h3><p>Next.js is a powerful and flexible framework for building web applications using React components. Developed by Vercel, Next.js has become a popular choice among developers for its ability to create high-quality, performant web applications with ease. This article explores the key features and benefits of Next.js, and why it stands out in the world of web development.</p><h3>Key Features</h3><p>1. Built-in Optimizations<br>Next.js comes with automatic optimizations for images, fonts, and scripts, which improve user experience and Core Web Vitals. These optimizations ensure that your application loads quickly and runs smoothly.</p><p>2. Data Fetching<br>Next.js supports both server-side and client-side data fetching, allowing you to make your React components async and await your data. This flexibility enables developers to build dynamic and interactive applications.</p><p>3. Advanced Routing<br>The framework offers a file-system based router that supports advanced routing patterns and nested layouts. This makes it easy to create complex and scalable web applications.</p><p>4. CSS Support<br>Next.js provides support for various styling methods, including CSS Modules, Tailwind CSS, and popular community libraries. This allows developers to style their applications using their preferred tools.</p><p>5. Server Actions<br>With Next.js, you can run server code by calling a function, skipping the API. This feature simplifies the process of revalidating cached data and updating the UI in one network roundtrip.</p><p>6. React Server Components<br>Next.js leverages the latest React features, including Server Components, to add components without sending additional client-side JavaScript. This results in faster and more efficient web applications.</p><h3>Benefits</h3><p>1. Performance<br>Next.js is designed to deliver high performance out of the box. Its built-in optimizations and efficient rendering methods ensure that your application is fast and responsive.</p><p>2. Developer Experience<br>The framework abstracts and automatically configures the necessary tooling for React, such as bundling and compiling. This allows developers to focus on building their applications rather than dealing with configuration.</p><p>3. Flexibility<br>Next.js supports various rendering methods, including client-side rendering, server-side rendering, and static site generation. This flexibility enables developers to choose the best approach for their specific use case.</p><p>4. Community and Ecosystem<br>Next.js has a strong community and ecosystem, with numerous plugins, templates, and examples available. This makes it easy to get started and find solutions to common problems.</p><h3>Getting Started</h3><p>To start a new Next.js project, you can use the create-next-app command, which sets up everything automatically for you. Here are the steps to create a new project:</p><p>Install Node.js: Ensure you have Node.js installed on your system.<br>Run the command: Open your terminal and run npx create-next-app@latest.<br>Follow the prompts: Answer the prompts to configure your new Next.js project.</p><h3>Conclusion</h3><p>Next.js is a powerful framework that simplifies the process of building modern web applications with React. Its built-in optimizations, flexible rendering methods, and strong community support make it an excellent choice for developers looking to create high-quality web applications. Whether you\'re building a small personal project or a large enterprise application, Next.js provides the tools and features you need to succeed.</p>','','full_html'),('article',0,3,9,'en',0,'<p>Next.js is a powerful and flexible framework for building web applications using React components. Developed by Vercel, Next.js has become a popular choice among developers for its ability to create high-quality, performant web applications with ease. This article explores the key features and benefits of Next.js, and why it stands out in the world of web development.</p><h3>Key Features</h3><p>1. Built-in Optimizations<br>Next.js comes with automatic optimizations for images, fonts, and scripts, which improve user experience and Core Web Vitals. These optimizations ensure that your application loads quickly and runs smoothly.</p><p>2. Data Fetching<br>Next.js supports both server-side and client-side data fetching, allowing you to make your React components async and await your data. This flexibility enables developers to build dynamic and interactive applications.</p><p>3. Advanced Routing<br>The framework offers a file-system based router that supports advanced routing patterns and nested layouts. This makes it easy to create complex and scalable web applications.</p><p>4. CSS Support<br>Next.js provides support for various styling methods, including CSS Modules, Tailwind CSS, and popular community libraries. This allows developers to style their applications using their preferred tools.</p><p>5. Server Actions<br>With Next.js, you can run server code by calling a function, skipping the API. This feature simplifies the process of revalidating cached data and updating the UI in one network roundtrip.</p><p>6. React Server Components<br>Next.js leverages the latest React features, including Server Components, to add components without sending additional client-side JavaScript. This results in faster and more efficient web applications.</p><h3>Benefits</h3><p>1. Performance<br>Next.js is designed to deliver high performance out of the box. Its built-in optimizations and efficient rendering methods ensure that your application is fast and responsive.</p><p>2. Developer Experience<br>The framework abstracts and automatically configures the necessary tooling for React, such as bundling and compiling. This allows developers to focus on building their applications rather than dealing with configuration.</p><p>3. Flexibility<br>Next.js supports various rendering methods, including client-side rendering, server-side rendering, and static site generation. This flexibility enables developers to choose the best approach for their specific use case.</p><p>4. Community and Ecosystem<br>Next.js has a strong community and ecosystem, with numerous plugins, templates, and examples available. This makes it easy to get started and find solutions to common problems.</p><h3>Getting Started</h3><p>To start a new Next.js project, you can use the create-next-app command, which sets up everything automatically for you. Here are the steps to create a new project:</p><p>Install Node.js: Ensure you have Node.js installed on your system.<br>Run the command: Open your terminal and run npx create-next-app@latest.<br>Follow the prompts: Answer the prompts to configure your new Next.js project.</p><h3>Conclusion</h3><p>Next.js is a powerful framework that simplifies the process of building modern web applications with React. Its built-in optimizations, flexible rendering methods, and strong community support make it an excellent choice for developers looking to create high-quality web applications. Whether you\'re building a small personal project or a large enterprise application, Next.js provides the tools and features you need to succeed.</p>','','full_html'),('page',0,4,13,'en',0,'<p class=\"\" data-start=\"93\" data-end=\"292\">JsonDrop is your powerful Drupal-based backend server leveraging Drupal’s robust JSON:API ecosystem. Rapidly prototype, build, and scale your APIs with minimal configuration and maximum flexibility.</p><h3 class=\"\" data-start=\"294\" data-end=\"312\">Why JsonDrop API?</h3><p class=\"\" data-start=\"314\" data-end=\"461\"><strong data-start=\"314\" data-end=\"344\"><img src=\"/sites/default/files/inline-images/json-api.png\" data-entity-uuid=\"6a4e240f-9716-4a36-98eb-f92133542bad\" data-entity-type=\"file\" alt=\"JsonDrop API\" width=\"1536\" height=\"1024\">Drupal-Powered Flexibility</strong><br>Harness the extensive power and reliability of Drupal and JSON:API to quickly spin up robust, feature-rich APIs.</p><p class=\"\" data-start=\"463\" data-end=\"629\"><strong data-start=\"463\" data-end=\"484\">Rapid Prototyping</strong><br>Save valuable development time by creating functional prototypes faster than ever. JSON Drop makes iterating and refining your API effortless.</p><p class=\"\" data-start=\"631\" data-end=\"829\"><strong data-start=\"631\" data-end=\"655\">Seamless Integration</strong><br>Easily connect your frontend applications and services with our clearly defined JSON endpoints. JsonDrop API integrates smoothly with modern frontend frameworks and services.</p><p class=\"\" data-start=\"831\" data-end=\"984\"><strong data-start=\"831\" data-end=\"856\">Extensible &amp; Scalable</strong><br>Expand your backend effortlessly with Drupal’s rich ecosystem of modules. Grow from prototype to production without friction.</p><h3 class=\"\" data-start=\"986\" data-end=\"1003\">Key Features:</h3><ul data-start=\"1005\" data-end=\"1514\"><li class=\"\" data-start=\"1005\" data-end=\"1091\"><p class=\"\" data-start=\"1007\" data-end=\"1091\"><strong data-start=\"1007\" data-end=\"1036\">Drupal JSON:API Ecosystem</strong>: Ready-to-use, standards-compliant JSON API endpoints.</p></li><li class=\"\" data-start=\"1092\" data-end=\"1189\"><p class=\"\" data-start=\"1094\" data-end=\"1189\"><strong data-start=\"1094\" data-end=\"1124\">Efficient Content Modeling</strong>: Easily create structured content, custom fields, and relations.</p></li><li class=\"\" data-start=\"1190\" data-end=\"1293\"><p class=\"\" data-start=\"1192\" data-end=\"1293\"><strong data-start=\"1192\" data-end=\"1217\">Secure Authentication</strong>: Built-in authentication options to secure your API endpoints effortlessly.</p></li><li class=\"\" data-start=\"1294\" data-end=\"1403\"><p class=\"\" data-start=\"1296\" data-end=\"1403\"><strong data-start=\"1296\" data-end=\"1324\">Extensive Module Library</strong>: Access thousands of Drupal modules to instantly add powerful functionalities.</p></li><li class=\"\" data-start=\"1404\" data-end=\"1514\"><p class=\"\" data-start=\"1406\" data-end=\"1514\"><strong data-start=\"1406\" data-end=\"1434\">Developer-Friendly Tools</strong>: Clear documentation, easy-to-use interfaces, and developer-oriented workflows.</p></li></ul><h3 class=\"\" data-start=\"1516\" data-end=\"1530\">Ideal for:</h3><ul data-start=\"1532\" data-end=\"1705\"><li class=\"\" data-start=\"1532\" data-end=\"1594\"><p class=\"\" data-start=\"1534\" data-end=\"1594\">Frontend developers who want a hassle-free backend solution.</p></li><li class=\"\" data-start=\"1595\" data-end=\"1640\"><p class=\"\" data-start=\"1597\" data-end=\"1640\">Teams building prototypes and MVPs quickly.</p></li><li class=\"\" data-start=\"1641\" data-end=\"1705\"><p class=\"\" data-start=\"1643\" data-end=\"1705\">Businesses aiming to reduce backend development time and cost.</p></li></ul><hr><p class=\"\" data-start=\"1712\" data-end=\"1882\">Get started today and experience the ease of Drupal’s JSON:API ecosystem with JsonDrop API —your ultimate backend solution for rapid development and flexible API prototyping.</p>','','full_html'),('page',0,4,14,'en',0,'<p class=\"\" data-start=\"93\" data-end=\"292\">JsonDrop is your powerful Drupal-based backend server leveraging Drupal’s robust JSON:API ecosystem. Rapidly prototype, build, and scale your APIs with minimal configuration and maximum flexibility.</p><h3 class=\"\" data-start=\"294\" data-end=\"312\">Why JsonDrop API?</h3><img data-entity-uuid=\"e5738396-f733-4814-b20c-5375ee9cfd39\" data-entity-type=\"file\" src=\"/sites/default/files/inline-images/json-api.jpg\" width=\"1536\" height=\"1024\" alt=\"JsonAPI and Drupal\"><p class=\"\" data-start=\"314\" data-end=\"461\"><strong data-start=\"314\" data-end=\"344\">Drupal-Powered Flexibility</strong><br>Harness the extensive power and reliability of Drupal and JSON:API to quickly spin up robust, feature-rich APIs.</p><p class=\"\" data-start=\"463\" data-end=\"629\"><strong data-start=\"463\" data-end=\"484\">Rapid Prototyping</strong><br>Save valuable development time by creating functional prototypes faster than ever. JSON Drop makes iterating and refining your API effortless.</p><p class=\"\" data-start=\"631\" data-end=\"829\"><strong data-start=\"631\" data-end=\"655\">Seamless Integration</strong><br>Easily connect your frontend applications and services with our clearly defined JSON endpoints. JsonDrop API integrates smoothly with modern frontend frameworks and services.</p><p class=\"\" data-start=\"831\" data-end=\"984\"><strong data-start=\"831\" data-end=\"856\">Extensible &amp; Scalable</strong><br>Expand your backend effortlessly with Drupal’s rich ecosystem of modules. Grow from prototype to production without friction.</p><h3 class=\"\" data-start=\"986\" data-end=\"1003\">Key Features:</h3><ul data-start=\"1005\" data-end=\"1514\"><li class=\"\" data-start=\"1005\" data-end=\"1091\"><p class=\"\" data-start=\"1007\" data-end=\"1091\"><strong data-start=\"1007\" data-end=\"1036\">Drupal JSON:API Ecosystem</strong>: Ready-to-use, standards-compliant JSON API endpoints.</p></li><li class=\"\" data-start=\"1092\" data-end=\"1189\"><p class=\"\" data-start=\"1094\" data-end=\"1189\"><strong data-start=\"1094\" data-end=\"1124\">Efficient Content Modeling</strong>: Easily create structured content, custom fields, and relations.</p></li><li class=\"\" data-start=\"1190\" data-end=\"1293\"><p class=\"\" data-start=\"1192\" data-end=\"1293\"><strong data-start=\"1192\" data-end=\"1217\">Secure Authentication</strong>: Built-in authentication options to secure your API endpoints effortlessly.</p></li><li class=\"\" data-start=\"1294\" data-end=\"1403\"><p class=\"\" data-start=\"1296\" data-end=\"1403\"><strong data-start=\"1296\" data-end=\"1324\">Extensive Module Library</strong>: Access thousands of Drupal modules to instantly add powerful functionalities.</p></li><li class=\"\" data-start=\"1404\" data-end=\"1514\"><p class=\"\" data-start=\"1406\" data-end=\"1514\"><strong data-start=\"1406\" data-end=\"1434\">Developer-Friendly Tools</strong>: Clear documentation, easy-to-use interfaces, and developer-oriented workflows.</p></li></ul><h3 class=\"\" data-start=\"1516\" data-end=\"1530\">Ideal for:</h3><ul data-start=\"1532\" data-end=\"1705\"><li class=\"\" data-start=\"1532\" data-end=\"1594\"><p class=\"\" data-start=\"1534\" data-end=\"1594\">Frontend developers who want a hassle-free backend solution.</p></li><li class=\"\" data-start=\"1595\" data-end=\"1640\"><p class=\"\" data-start=\"1597\" data-end=\"1640\">Teams building prototypes and MVPs quickly.</p></li><li class=\"\" data-start=\"1641\" data-end=\"1705\"><p class=\"\" data-start=\"1643\" data-end=\"1705\">Businesses aiming to reduce backend development time and cost.</p></li></ul><hr><p class=\"\" data-start=\"1712\" data-end=\"1882\">Get started today and experience the ease of Drupal’s JSON:API ecosystem with JsonDrop API —your ultimate backend solution for rapid development and flexible API prototyping.</p>','','full_html');
/*!40000 ALTER TABLE `node_revision__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__comment`
--

DROP TABLE IF EXISTS `node_revision__comment`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__comment` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_status` int NOT NULL DEFAULT '0' COMMENT 'Whether comments are allowed on this entity: 0 = no, 1 = closed (read only), 2 = open (read/write).',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field comment.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__comment`
--

LOCK TABLES `node_revision__comment` WRITE;
/*!40000 ALTER TABLE `node_revision__comment` DISABLE KEYS */;
INSERT INTO `node_revision__comment` VALUES ('article',0,1,1,'en',0,2),('article',0,1,4,'en',0,2),('article',0,1,6,'en',0,2),('article',0,2,2,'en',0,2),('article',0,2,3,'en',0,2),('article',0,2,5,'en',0,2),('article',0,3,7,'en',0,2),('article',0,3,8,'en',0,2),('article',0,3,9,'en',0,2);
/*!40000 ALTER TABLE `node_revision__comment` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__field_image`
--

DROP TABLE IF EXISTS `node_revision__field_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__field_image`
--

LOCK TABLES `node_revision__field_image` WRITE;
/*!40000 ALTER TABLE `node_revision__field_image` DISABLE KEYS */;
INSERT INTO `node_revision__field_image` VALUES ('article',0,1,1,'en',0,1,'sadf','',1024,1024),('article',0,1,4,'en',0,1,'sadf','',1024,1024),('article',0,1,6,'en',0,1,'sadf','',1024,1024),('article',0,2,2,'en',0,2,'Drupal CMS','',1024,1024),('article',0,2,3,'en',0,2,'Drupal CMS','',1024,1024),('article',0,2,5,'en',0,2,'Drupal CMS','',1024,1024),('article',0,3,7,'en',0,4,'Next.js','',1024,1024),('article',0,3,8,'en',0,4,'Next.js','',1024,1024),('article',0,3,9,'en',0,4,'Next.js','',1024,1024);
/*!40000 ALTER TABLE `node_revision__field_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__field_tags`
--

DROP TABLE IF EXISTS `node_revision__field_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_tags.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__field_tags`
--

LOCK TABLES `node_revision__field_tags` WRITE;
/*!40000 ALTER TABLE `node_revision__field_tags` DISABLE KEYS */;
INSERT INTO `node_revision__field_tags` VALUES ('article',0,1,1,'en',0,1),('article',0,1,4,'en',0,1),('article',0,1,6,'en',0,1),('article',0,2,2,'en',0,1),('article',0,2,2,'en',1,2),('article',0,2,3,'en',0,1),('article',0,2,3,'en',1,2),('article',0,2,5,'en',0,1),('article',0,2,5,'en',1,2),('article',0,3,8,'en',0,3),('article',0,3,9,'en',0,3);
/*!40000 ALTER TABLE `node_revision__field_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__webform`
--

DROP TABLE IF EXISTS `node_revision__webform`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__webform` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `webform_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `webform_default_data` text COMMENT 'Default submission data.',
  `webform_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `webform_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `webform_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `webform_target_id` (`webform_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field webform.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__webform`
--

LOCK TABLES `node_revision__webform` WRITE;
/*!40000 ALTER TABLE `node_revision__webform` DISABLE KEYS */;
/*!40000 ALTER TABLE `node_revision__webform` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `path_alias`
--

DROP TABLE IF EXISTS `path_alias`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `path_alias` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `path_alias_field__uuid__value` (`uuid`),
  UNIQUE KEY `path_alias__revision_id` (`revision_id`),
  KEY `path_alias__alias_langcode_id_status` (`alias`(191),`langcode`,`id`,`status`),
  KEY `path_alias__path_langcode_id_status` (`path`(191),`langcode`,`id`,`status`)
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for path_alias entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `path_alias`
--

LOCK TABLES `path_alias` WRITE;
/*!40000 ALTER TABLE `path_alias` DISABLE KEYS */;
INSERT INTO `path_alias` VALUES (1,1,'7fff9209-0360-4048-97b6-9961377becde','en','/webform/contact','/form/contact',1),(2,2,'780596c7-5863-4496-b359-7783a53c8bd7','und','/webform/contact','/form/contact',1),(3,3,'149d4620-7a28-43ef-83c9-c1c71d54398f','en','/webform/contact/confirmation','/form/contact/confirmation',1),(4,4,'30577f6f-6020-45c2-b019-97ef53a98296','und','/webform/contact/confirmation','/form/contact/confirmation',1),(5,5,'9e40da8c-a4e0-45f9-8d89-eb90d419b612','en','/webform/contact/submissions','/form/contact/submissions',1),(6,6,'3bd9da5a-b054-4b23-b1d0-3e4d00ff4ec9','und','/webform/contact/submissions','/form/contact/submissions',1),(7,7,'99ced2b1-6cf2-4b87-baa8-e2f8bdac3e3b','en','/webform/contact/drafts','/form/contact/drafts',1),(8,8,'3d398837-bd43-408f-9916-afa10b2c4388','und','/webform/contact/drafts','/form/contact/drafts',1),(9,9,'b9651fe6-1881-4073-b811-da912b8a2124','en','/node/1','/article/jsonapi-backend-built-cms',1),(10,10,'941167f6-3ce6-4be0-804c-eeed6aa5348f','en','/node/2','/article/drupal-cms',1),(11,11,'496d8c16-b692-4dd8-a8d8-9698be08f7ba','en','/node/3','/article/nextjs-react-framework-modern-web-development',1),(12,12,'f94a3d42-31a4-4397-b9b6-53ef0f27c010','en','/node/4','/page/jsondrop-api',1);
/*!40000 ALTER TABLE `path_alias` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `path_alias_revision`
--

DROP TABLE IF EXISTS `path_alias_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `path_alias_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `path_alias__id` (`id`),
  KEY `path_alias_revision__alias_langcode_id_status` (`alias`(191),`langcode`,`id`,`status`),
  KEY `path_alias_revision__path_langcode_id_status` (`path`(191),`langcode`,`id`,`status`)
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for path_alias entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `path_alias_revision`
--

LOCK TABLES `path_alias_revision` WRITE;
/*!40000 ALTER TABLE `path_alias_revision` DISABLE KEYS */;
INSERT INTO `path_alias_revision` VALUES (1,1,'en','/webform/contact','/form/contact',1,1),(2,2,'und','/webform/contact','/form/contact',1,1),(3,3,'en','/webform/contact/confirmation','/form/contact/confirmation',1,1),(4,4,'und','/webform/contact/confirmation','/form/contact/confirmation',1,1),(5,5,'en','/webform/contact/submissions','/form/contact/submissions',1,1),(6,6,'und','/webform/contact/submissions','/form/contact/submissions',1,1),(7,7,'en','/webform/contact/drafts','/form/contact/drafts',1,1),(8,8,'und','/webform/contact/drafts','/form/contact/drafts',1,1),(9,9,'en','/node/1','/article/jsonapi-backend-built-cms',1,1),(10,10,'en','/node/2','/article/drupal-cms',1,1),(11,11,'en','/node/3','/article/nextjs-react-framework-modern-web-development',1,1),(12,12,'en','/node/4','/page/jsondrop-api',1,1);
/*!40000 ALTER TABLE `path_alias_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `queue`
--

DROP TABLE IF EXISTS `queue`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `queue` (
  `item_id` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique item ID.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The queue name.',
  `data` longblob COMMENT 'The arbitrary data for the item.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the claim lease expires on the item.',
  `created` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the item was created.',
  PRIMARY KEY (`item_id`),
  KEY `name_created` (`name`,`created`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB AUTO_INCREMENT=311 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores items in queues.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `queue`
--

LOCK TABLES `queue` WRITE;
/*!40000 ALTER TABLE `queue` DISABLE KEYS */;
/*!40000 ALTER TABLE `queue` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `redirect`
--

DROP TABLE IF EXISTS `redirect`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `redirect` (
  `rid` int NOT NULL AUTO_INCREMENT,
  `type` varchar(255) NOT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `language` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `hash` varchar(64) DEFAULT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `redirect_source__path` varchar(2048) DEFAULT NULL COMMENT 'The source path',
  `redirect_source__query` longblob COMMENT 'Serialized array of path queries',
  `redirect_redirect__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `redirect_redirect__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `redirect_redirect__options` longblob COMMENT 'Serialized array of options for the link.',
  `status_code` int DEFAULT NULL,
  `created` int DEFAULT NULL,
  PRIMARY KEY (`rid`),
  UNIQUE KEY `redirect_field__uuid__value` (`uuid`),
  UNIQUE KEY `hash` (`hash`),
  KEY `redirect_field__uid__target_id` (`uid`),
  KEY `redirect_field__redirect_source__path` (`redirect_source__path`(50)),
  KEY `redirect_field__redirect_redirect__uri` (`redirect_redirect__uri`(30)),
  KEY `source_language` (`redirect_source__path`(191),`language`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for redirect entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `redirect`
--

LOCK TABLES `redirect` WRITE;
/*!40000 ALTER TABLE `redirect` DISABLE KEYS */;
INSERT INTO `redirect` VALUES (1,'redirect','fdc426b6-5482-417e-86b7-4890eb53972e','en','5JIMW2TBGya0tSGjl9nYxlvP_VNyF256KGVKZx3FHY0',1,'page/json-drop',_binary 'a:0:{}','internal:/node/4',NULL,_binary 'a:0:{}',301,1743626192);
/*!40000 ALTER TABLE `redirect` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `router`
--

DROP TABLE IF EXISTS `router`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `router` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Machine name of this route',
  `path` varchar(255) NOT NULL DEFAULT '' COMMENT 'The path for this URI',
  `pattern_outline` varchar(255) NOT NULL DEFAULT '' COMMENT 'The pattern',
  `fit` int NOT NULL DEFAULT '0' COMMENT 'A numeric representation of how specific the path is.',
  `route` longblob COMMENT 'A serialized Route object',
  `number_parts` smallint NOT NULL DEFAULT '0' COMMENT 'Number of parts in this router path.',
  PRIMARY KEY (`name`),
  KEY `pattern_outline_parts` (`pattern_outline`(191),`number_parts`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maps paths to various callbacks (access, page and title)';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `router`
--

LOCK TABLES `router` WRITE;
/*!40000 ALTER TABLE `router` DISABLE KEYS */;
INSERT INTO `router` VALUES ('<button>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<current>','/<current>','/<current>',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/<current>\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:0:{}s:7:\"options\";a:2:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/\\<current\\>$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/<current>\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:10:\"/<current>\";s:8:\"numParts\";i:1;}}',1),('<front>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:6:\"_title\";s:4:\"Home\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<nolink>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<none>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('announcements_feed.announcement','/admin/announcements_feed','/admin/announcements_feed',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/announcements_feed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:74:\"\\Drupal\\announcements_feed\\Controller\\AnnounceController::getAnnouncements\";s:6:\"_title\";s:23:\"Community announcements\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"access announcements\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/announcements_feed$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/announcements_feed\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:25:\"/admin/announcements_feed\";s:8:\"numParts\";i:2;}}',2),('big_pipe.nojs','/big_pipe/no-js','/big_pipe/no-js',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:15:\"/big_pipe/no-js\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\big_pipe\\Controller\\BigPipeController:setNoJsCookie\";s:6:\"_title\";s:19:\"BigPipe no-JS check\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:23:\"{^/big_pipe/no\\-js$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/big_pipe/no-js\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:15:\"/big_pipe/no-js\";s:8:\"numParts\";i:2;}}',2),('block.admin_add','/admin/structure/block/add/{plugin_id}/{theme}','/admin/structure/block/add/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/block/add/{plugin_id}/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:66:\"\\Drupal\\block\\Controller\\BlockAddController::blockAddConfigureForm\";s:5:\"theme\";N;s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"plugin_id\";i:1;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/block/add/(?P<plugin_id>[^/]++)(?:/(?P<theme>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"plugin_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/block/add\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"plugin_id\";i:1;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/structure/block/add/%\";s:8:\"numParts\";i:6;}}',6),('block.admin_demo','/admin/structure/block/demo/{theme}','/admin/structure/block/demo/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/block/demo/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:46:\"\\Drupal\\block\\Controller\\BlockController::demo\";s:15:\"_title_callback\";s:21:\"theme_handler:getName\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/block/demo/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/block/demo\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/block/demo/%\";s:8:\"numParts\";i:5;}}',5),('block.admin_display','/admin/structure/block','/admin/structure/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:53:\"\\Drupal\\block\\Controller\\BlockListController::listing\";s:6:\"_title\";s:12:\"Block layout\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/block\";s:8:\"numParts\";i:3;}}',3),('block.admin_display_theme','/admin/structure/block/list/{theme}','/admin/structure/block/list/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/block/list/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:53:\"\\Drupal\\block\\Controller\\BlockListController::listing\";s:6:\"_title\";s:12:\"Block layout\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/block/list/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/block/list\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/block/list/%\";s:8:\"numParts\";i:5;}}',5),('block.admin_library','/admin/structure/block/library/{theme}','/admin/structure/block/library/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/structure/block/library/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\block\\Controller\\BlockLibraryController::listBlocks\";s:6:\"_title\";s:11:\"Place block\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/structure/block/library/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/block/library\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:32:\"/admin/structure/block/library/%\";s:8:\"numParts\";i:5;}}',5),('block.category_autocomplete','/block-category/autocomplete','/block-category/autocomplete',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/block-category/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:69:\"\\Drupal\\block\\Controller\\CategoryAutocompleteController::autocomplete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/block\\-category/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/block-category/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:28:\"/block-category/autocomplete\";s:8:\"numParts\";i:2;}}',2),('block_content.add_form','/block/add/{block_content_type}','/block/add/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/block/add/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\block_content\\Controller\\BlockContentController::addForm\";s:15:\"_title_callback\";s:72:\"\\Drupal\\block_content\\Controller\\BlockContentController::getAddFormTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:34:\"block_content:{block_content_type}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/block/add/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/block/add\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:12:\"/block/add/%\";s:8:\"numParts\";i:3;}}',3),('block_content.add_page','/block/add','/block/add',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/block/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\block_content\\Controller\\BlockContentController::add\";s:6:\"_title\";s:17:\"Add content block\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:13:\"block_content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/block/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/block/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/block/add\";s:8:\"numParts\";i:2;}}',2),('block_content.type_add','/admin/structure/block-content/add','/admin/structure/block-content/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/block-content/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"block_content_type.add\";s:6:\"_title\";s:3:\"Add\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:18:\"block_content_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/structure/block\\-content/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/structure/block-content/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/structure/block-content/add\";s:8:\"numParts\";i:4;}}',4),('ckeditor5.media_entity_metadata','/ckeditor5/{editor}/media-entity-metadata','/ckeditor5/%/media-entity-metadata',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/ckeditor5/{editor}/media-entity-metadata\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:74:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::mediaEntityMetadata\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:10:\"editor.use\";s:14:\"_custom_access\";s:61:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::access\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:3:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";i:2;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/ckeditor5/(?P<editor>[^/]++)/media\\-entity\\-metadata$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/media-entity-metadata\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/ckeditor5\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:34:\"/ckeditor5/%/media-entity-metadata\";s:8:\"numParts\";i:3;}}',3),('ckeditor5.upload_image','/ckeditor5/upload-image/{editor}','/ckeditor5/upload-image/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/ckeditor5/upload-image/{editor}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:61:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::upload\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:10:\"editor.use\";s:14:\"_custom_access\";s:79:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::imageUploadEnabledAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:3:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";i:2;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/ckeditor5/upload\\-image/(?P<editor>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/ckeditor5/upload-image\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:25:\"/ckeditor5/upload-image/%\";s:8:\"numParts\";i:3;}}',3),('ckeditor5_plugin_pack.settings','/admin/config/ckeditor5-plugin-pack','/admin/config/ckeditor5-plugin-pack',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/config/ckeditor5-plugin-pack\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\ckeditor5_plugin_pack\\Form\\SettingsForm\";s:6:\"_title\";s:31:\"CKEditor 5 Plugin Pack settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/ckeditor5\\-plugin\\-pack$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/ckeditor5-plugin-pack\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:35:\"/admin/config/ckeditor5-plugin-pack\";s:8:\"numParts\";i:3;}}',3),('comment.admin','/admin/content/comment','/admin/content/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/content/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:14:\"page_published\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/content/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/content/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/content/comment\";s:8:\"numParts\";i:3;}}',3),('comment.admin_approval','/admin/content/comment/approval','/admin/content/comment/approval',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/content/comment/approval\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:15:\"page_unapproved\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/content/comment/approval$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/content/comment/approval\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/content/comment/approval\";s:8:\"numParts\";i:4;}}',4),('comment.approve','/comment/{comment}/approve','/comment/%/approve',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/comment/{comment}/approve\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:7:\"Approve\";s:11:\"_controller\";s:60:\"\\Drupal\\comment\\Controller\\CommentController::commentApprove\";s:11:\"entity_type\";s:7:\"comment\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"comment.approve\";s:11:\"_csrf_token\";s:4:\"TRUE\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/comment/(?P<comment>\\d+)/approve$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/approve\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:18:\"/comment/%/approve\";s:8:\"numParts\";i:3;}}',3),('comment.multiple_delete_confirm','/admin/content/comment/delete','/admin/content/comment/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/content/comment/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Delete\";s:5:\"_form\";s:42:\"\\Drupal\\comment\\Form\\ConfirmDeleteMultiple\";s:14:\"entity_type_id\";s:7:\"comment\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"comment\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/content/comment/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/content/comment/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/content/comment/delete\";s:8:\"numParts\";i:4;}}',4),('comment.new_comments_node_links','/comments/render_new_comments_node_links','/comments/render_new_comments_node_links',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/comments/render_new_comments_node_links\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\comment\\Controller\\CommentController::renderNewCommentsNodeLinks\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/comments/render_new_comments_node_links$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/comments/render_new_comments_node_links\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:40:\"/comments/render_new_comments_node_links\";s:8:\"numParts\";i:2;}}',2),('comment.node_redirect','/comment/{node}/reply','/comment/%/reply',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/comment/{node}/reply\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\comment\\Controller\\CommentController::redirectNode\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:9:\"node.view\";s:20:\"_module_dependencies\";s:4:\"node\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/comment/(?P<node>\\d+)/reply$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reply\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:16:\"/comment/%/reply\";s:8:\"numParts\";i:3;}}',3),('comment.reply','/comment/reply/{entity_type}/{entity}/{field_name}/{pid}','/comment/reply/%/%/%',24,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/comment/reply/{entity_type}/{entity}/{field_name}/{pid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:58:\"\\Drupal\\comment\\Controller\\CommentController::getReplyForm\";s:6:\"_title\";s:15:\"Add new comment\";s:3:\"pid\";N;}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:61:\"\\Drupal\\comment\\Controller\\CommentController::replyFormAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:{entity_type}\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:3:\"pid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/comment/reply/(?P<entity_type>[^/]++)/(?P<entity>[^/]++)/(?P<field_name>[^/]++)(?:/(?P<pid>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"pid\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/comment/reply\";}}s:9:\"path_vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:3:\"pid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:24;s:14:\"patternOutline\";s:20:\"/comment/reply/%/%/%\";s:8:\"numParts\";i:6;}}',6),('config.diff','/admin/config/development/configuration/sync/diff/{source_name}/{target_name}','/admin/config/development/configuration/sync/diff/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/config/development/configuration/sync/diff/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\config\\Controller\\ConfigController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"source_name\";i:1;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/config/development/configuration/sync/diff/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:49:\"/admin/config/development/configuration/sync/diff\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"source_name\";i:1;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/sync/diff/%\";s:8:\"numParts\";i:8;}}',8),('config.diff_collection','/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}','/admin/config/development/configuration/sync/diff_collection/%/%',252,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\config\\Controller\\ConfigController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"collection\";i:1;s:11:\"source_name\";i:2;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:143:\"{^/admin/config/development/configuration/sync/diff_collection/(?P<collection>[^/]++)/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"collection\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/admin/config/development/configuration/sync/diff_collection\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"collection\";i:1;s:11:\"source_name\";i:2;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:252;s:14:\"patternOutline\";s:64:\"/admin/config/development/configuration/sync/diff_collection/%/%\";s:8:\"numParts\";i:9;}}',9),('config.export_download','/admin/config/development/configuration/full/export-download','/admin/config/development/configuration/full/export-download',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/development/configuration/full/export-download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\config\\Controller\\ConfigController::downloadExport\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/development/configuration/full/export\\-download$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/admin/config/development/configuration/full/export-download\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:60:\"/admin/config/development/configuration/full/export-download\";s:8:\"numParts\";i:6;}}',6),('config.export_full','/admin/config/development/configuration/full/export','/admin/config/development/configuration/full/export',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/development/configuration/full/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\config\\Form\\ConfigExportForm\";s:6:\"_title\";s:6:\"Export\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/development/configuration/full/export$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/development/configuration/full/export\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/full/export\";s:8:\"numParts\";i:6;}}',6),('config.export_single','/admin/config/development/configuration/single/export/{config_type}/{config_name}','/admin/config/development/configuration/single/export',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/config/development/configuration/single/export/{config_type}/{config_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:13:\"Single export\";s:5:\"_form\";s:42:\"\\Drupal\\config\\Form\\ConfigSingleExportForm\";s:11:\"config_type\";N;s:11:\"config_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"config_type\";i:1;s:11:\"config_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:118:\"{^/admin/config/development/configuration/single/export(?:/(?P<config_type>[^/]++)(?:/(?P<config_name>[^/]++))?)?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"config_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"config_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:53:\"/admin/config/development/configuration/single/export\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"config_type\";i:1;s:11:\"config_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:53:\"/admin/config/development/configuration/single/export\";s:8:\"numParts\";i:8;}}',8),('config.import_full','/admin/config/development/configuration/full/import','/admin/config/development/configuration/full/import',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/development/configuration/full/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\config\\Form\\ConfigImportForm\";s:6:\"_title\";s:6:\"Import\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/development/configuration/full/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/development/configuration/full/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/full/import\";s:8:\"numParts\";i:6;}}',6),('config.import_single','/admin/config/development/configuration/single/import','/admin/config/development/configuration/single/import',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/development/configuration/single/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:13:\"Single import\";s:5:\"_form\";s:42:\"\\Drupal\\config\\Form\\ConfigSingleImportForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/development/configuration/single/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:53:\"/admin/config/development/configuration/single/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:53:\"/admin/config/development/configuration/single/import\";s:8:\"numParts\";i:6;}}',6),('config.sync','/admin/config/development/configuration','/admin/config/development/configuration',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/development/configuration\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:30:\"\\Drupal\\config\\Form\\ConfigSync\";s:6:\"_title\";s:11:\"Synchronize\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/config/development/configuration$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/development/configuration\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/config/development/configuration\";s:8:\"numParts\";i:4;}}',4),('config_ignore.settings','/admin/config/development/configuration/ignore','/admin/config/development/configuration/ignore',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/config/development/configuration/ignore\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\config_ignore\\Form\\IgnoreSettingsForm\";s:6:\"_title\";s:6:\"Ignore\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/admin/config/development/configuration/ignore$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/config/development/configuration/ignore\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:46:\"/admin/config/development/configuration/ignore\";s:8:\"numParts\";i:5;}}',5),('config_split.diff','/admin/config/development/configuration/config-split/{config_split}/{operation}/diff/{source_name}/{target_name}','/admin/config/development/configuration/config-split/%/%/diff/%',498,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:112:\"/admin/config/development/configuration/config-split/{config_split}/{operation}/diff/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:63:\"\\Drupal\\config_split\\Controller\\ConfigSplitDiffController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer configuration split\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:12:\"config_split\";i:1;s:9:\"operation\";i:2;s:11:\"source_name\";i:3;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:165:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/(?P<operation>[^/]++)/diff/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/diff\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"operation\";i:4;b:1;}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:4:{i:0;s:12:\"config_split\";i:1;s:9:\"operation\";i:2;s:11:\"source_name\";i:3;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:498;s:14:\"patternOutline\";s:63:\"/admin/config/development/configuration/config-split/%/%/diff/%\";s:8:\"numParts\";i:10;}}',10),('config_split.diff_collection','/admin/config/development/configuration/config-split/{config_split}/{operation}/diff_collection/{collection}/{source_name}/{target_name}','/admin/config/development/configuration/config-split/%/%/diff_collection/%/%',996,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:136:\"/admin/config/development/configuration/config-split/{config_split}/{operation}/diff_collection/{collection}/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:63:\"\\Drupal\\config_split\\Controller\\ConfigSplitDiffController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer configuration split\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:12:\"config_split\";i:1;s:9:\"operation\";i:2;s:10:\"collection\";i:3;s:11:\"source_name\";i:4;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:199:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/(?P<operation>[^/]++)/diff_collection/(?P<collection>[^/]++)/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"collection\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/diff_collection\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"operation\";i:4;b:1;}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:5:{i:0;s:12:\"config_split\";i:1;s:9:\"operation\";i:2;s:10:\"collection\";i:3;s:11:\"source_name\";i:4;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:996;s:14:\"patternOutline\";s:76:\"/admin/config/development/configuration/config-split/%/%/diff_collection/%/%\";s:8:\"numParts\";i:11;}}',11),('config_translation.entity_list','/admin/config/regional/config-translation/{mapper_id}','/admin/config/regional/config-translation/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/regional/config-translation/{mapper_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:78:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationListController::listing\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"translate configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"mapper_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/regional/config\\-translation/(?P<mapper_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"mapper_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/config/regional/config-translation\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"mapper_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:43:\"/admin/config/regional/config-translation/%\";s:8:\"numParts\";i:5;}}',5),('config_translation.item.add.entity.block.edit_form','/admin/structure/block/manage/{block}/translate/{langcode}/add','/admin/structure/block/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/block/manage/{block}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:5:\"block\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"block\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"block\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/block/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.block_content_type.edit_form','/admin/structure/block-content/manage/{block_content_type}/translate/{langcode}/add','/admin/structure/block-content/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/block-content/manage/{block_content_type}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/block-content/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.ckeditor5_template.edit_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate/{langcode}/add','/admin/config/ckeditor5-templates/content-templates/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:18:\"ckeditor5_template\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"ckeditor5_template\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"ckeditor5_template\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:69:\"/admin/config/ckeditor5-templates/content-templates/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.comment_type.edit_form','/admin/structure/comment/manage/{comment_type}/translate/{langcode}/add','/admin/structure/comment/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/comment/manage/{comment_type}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:12:\"comment_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/comment/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.configurable_language.edit_form','/admin/config/regional/language/edit/{configurable_language}/translate/{langcode}/add','/admin/config/regional/language/edit/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/config/regional/language/edit/{configurable_language}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:21:\"configurable_language\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:21:\"configurable_language\";a:2:{s:4:\"type\";s:28:\"entity:configurable_language\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:21:\"configurable_language\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/config/regional/language/edit/(?P<configurable_language>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:21:\"configurable_language\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/regional/language/edit\";}}s:9:\"path_vars\";a:2:{i:0;s:21:\"configurable_language\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:54:\"/admin/config/regional/language/edit/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.config_split.edit_form','/admin/config/development/configuration/config-split/{config_split}/edit/translate/{langcode}/add','/admin/config/development/configuration/config-split/%/edit/translate/%/add',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/config/development/configuration/config-split/{config_split}/edit/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:12:\"config_split\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"config_split\";a:2:{s:4:\"type\";s:19:\"entity:config_split\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"config_split\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:125:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/edit/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"config_split\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:75:\"/admin/config/development/configuration/config-split/%/edit/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.contact_form.edit_form','/admin/structure/contact/manage/{contact_form}/translate/{langcode}/add','/admin/structure/contact/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/contact/manage/{contact_form}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:12:\"contact_form\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/contact/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.date_format.edit_form','/admin/config/regional/date-time/formats/manage/{date_format}/translate/{langcode}/add','/admin/config/regional/date-time/formats/manage/%/translate/%/add',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/config/regional/date-time/formats/manage/{date_format}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:11:\"date_format\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"date_format\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"date_format\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:65:\"/admin/config/regional/date-time/formats/manage/%/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.entity_form_mode.edit_form','/admin/structure/display-modes/form/manage/{entity_form_mode}/translate/{langcode}/add','/admin/structure/display-modes/form/manage/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/display-modes/form/manage/{entity_form_mode}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:16:\"entity_form_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"entity_form_mode\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"entity_form_mode\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:60:\"/admin/structure/display-modes/form/manage/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.entity_view_mode.edit_form','/admin/structure/display-modes/view/manage/{entity_view_mode}/translate/{langcode}/add','/admin/structure/display-modes/view/manage/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/display-modes/view/manage/{entity_view_mode}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:16:\"entity_view_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"entity_view_mode\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"entity_view_mode\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:60:\"/admin/structure/display-modes/view/manage/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.field_config.block_content_field_edit_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/translate/{langcode}/add','/admin/structure/block-content/manage/%/fields/%/translate/%/add',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:105:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:20:\"block_content_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:143:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:64:\"/admin/structure/block-content/manage/%/fields/%/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.field_config.comment_field_edit_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}/translate/{langcode}/add','/admin/structure/comment/manage/%/fields/%/translate/%/add',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:14:\"comment_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:58:\"/admin/structure/comment/manage/%/fields/%/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.field_config.contact_message_field_edit_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}/translate/{langcode}/add','/admin/structure/contact/manage/%/fields/%/translate/%/add',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:22:\"contact_message_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:58:\"/admin/structure/contact/manage/%/fields/%/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.field_config.menu_link_content_field_edit_form','/admin/structure/menu/manage/{menu}/fields/{field_config}/translate/{langcode}/add','/admin/structure/menu/manage/%/fields/%/translate/%/add',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/menu/manage/{menu}/fields/{field_config}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:24:\"menu_link_content_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:55:\"/admin/structure/menu/manage/%/fields/%/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.field_config.node_field_edit_form','/admin/structure/types/manage/{node_type}/fields/{field_config}/translate/{langcode}/add','/admin/structure/types/manage/%/fields/%/translate/%/add',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/types/manage/{node_type}/fields/{field_config}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:11:\"node_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:125:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:56:\"/admin/structure/types/manage/%/fields/%/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.field_config.taxonomy_term_field_edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/translate/{langcode}/add','/admin/structure/taxonomy/manage/%/overview/fields/%/translate/%/add',1973,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:110:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:20:\"taxonomy_term_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:147:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1973;s:14:\"patternOutline\";s:68:\"/admin/structure/taxonomy/manage/%/overview/fields/%/translate/%/add\";s:8:\"numParts\";i:11;}}',11),('config_translation.item.add.entity.field_config.user_field_edit_form','/admin/config/people/accounts/fields/{field_config}/translate/{langcode}/add','/admin/config/people/accounts/fields/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/config/people/accounts/fields/{field_config}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:11:\"user_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"field_config\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"field_config\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:54:\"/admin/config/people/accounts/fields/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.filter_format.edit_form','/admin/config/content/formats/manage/{filter_format}/translate/{langcode}/add','/admin/config/content/formats/manage/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/config/content/formats/manage/{filter_format}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:13:\"filter_format\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"filter_format\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"filter_format\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:54:\"/admin/config/content/formats/manage/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.image_style.edit_form','/admin/config/media/image-styles/manage/{image_style}/translate/{langcode}/add','/admin/config/media/image-styles/manage/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/config/media/image-styles/manage/{image_style}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:11:\"image_style\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:57:\"/admin/config/media/image-styles/manage/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.jsonapi_resource_config.edit_form','/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate/{langcode}/add','/admin/config/services/jsonapi/resource_types/%/edit/translate/%/add',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:23:\"jsonapi_resource_config\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:23:\"jsonapi_resource_config\";a:2:{s:4:\"type\";s:30:\"entity:jsonapi_resource_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:23:\"jsonapi_resource_config\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:128:\"{^/admin/config/services/jsonapi/resource_types/(?P<jsonapi_resource_config>[^/]++)/edit/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:23:\"jsonapi_resource_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/services/jsonapi/resource_types\";}}s:9:\"path_vars\";a:2:{i:0;s:23:\"jsonapi_resource_config\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:68:\"/admin/config/services/jsonapi/resource_types/%/edit/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.linkit_profile.edit_form','/admin/config/content/linkit/manage/{linkit_profile}/translate/{langcode}/add','/admin/config/content/linkit/manage/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/config/content/linkit/manage/{linkit_profile}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:14:\"linkit_profile\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:53:\"/admin/config/content/linkit/manage/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.menu.edit_form','/admin/structure/menu/manage/{menu}/translate/{langcode}/add','/admin/structure/menu/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/menu/manage/{menu}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:4:\"menu\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:46:\"/admin/structure/menu/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.metatag_defaults.edit_form','/admin/config/search/metatag/{metatag_defaults}/translate/{langcode}/add','/admin/config/search/metatag/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/search/metatag/{metatag_defaults}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:16:\"metatag_defaults\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"metatag_defaults\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"metatag_defaults\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:46:\"/admin/config/search/metatag/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.node_type.edit_form','/admin/structure/types/manage/{node_type}/translate/{langcode}/add','/admin/structure/types/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/types/manage/{node_type}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/types/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.pathauto_pattern.edit_form','/admin/config/search/path/patterns/{pathauto_pattern}/translate/{langcode}/add','/admin/config/search/path/patterns/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/config/search/path/patterns/{pathauto_pattern}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:16:\"pathauto_pattern\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"pathauto_pattern\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"pathauto_pattern\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:52:\"/admin/config/search/path/patterns/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.shortcut_set.edit_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/translate/{langcode}/add','/admin/config/user-interface/shortcut/manage/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:84:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:12:\"shortcut_set\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"shortcut_set\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"shortcut_set\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:62:\"/admin/config/user-interface/shortcut/manage/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.simple_sitemap.edit_form','/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate/{langcode}/add','/admin/config/search/simplesitemap/variants/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:14:\"simple_sitemap\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:14:\"simple_sitemap\";a:2:{s:4:\"type\";s:21:\"entity:simple_sitemap\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"simple_sitemap\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/config/search/simplesitemap/variants/(?P<simple_sitemap>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"simple_sitemap\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/variants\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"simple_sitemap\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:61:\"/admin/config/search/simplesitemap/variants/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.simple_sitemap_type.edit_form','/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate/{langcode}/add','/admin/config/search/simplesitemap/types/%/translate/%/add',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:19:\"simple_sitemap_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"simple_sitemap_type\";a:2:{s:4:\"type\";s:26:\"entity:simple_sitemap_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"simple_sitemap_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/config/search/simplesitemap/types/(?P<simple_sitemap_type>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"simple_sitemap_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/search/simplesitemap/types\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"simple_sitemap_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:58:\"/admin/config/search/simplesitemap/types/%/translate/%/add\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.add.entity.taxonomy_vocabulary.edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/translate/{langcode}/add','/admin/structure/taxonomy/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/taxonomy/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.user.admin_form','/admin/config/people/accounts/translate/{langcode}/add','/admin/config/people/accounts/translate/%/add',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/people/accounts/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:22:\"entity.user.admin_form\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/people/accounts/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/people/accounts/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:45:\"/admin/config/people/accounts/translate/%/add\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.add.entity.user_role.edit_form','/admin/people/roles/manage/{user_role}/translate/{langcode}/add','/admin/people/roles/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/people/roles/manage/{user_role}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:9:\"user_role\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"user_role\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"user_role\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:44:\"/admin/people/roles/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.view.edit_form','/admin/structure/views/view/{view}/translate/{langcode}/add','/admin/structure/views/view/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/views/view/{view}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:4:\"view\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/views/view/(?P<view>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:45:\"/admin/structure/views/view/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.webform.edit_form','/admin/structure/webform/manage/{webform}/translate/{langcode}/add','/admin/structure/webform/manage/%/translate/%/add',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/webform/manage/{webform}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:7:\"webform\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/translate/%/add\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.add.entity.webform_access_group.edit_form','/admin/structure/webform/access/group/manage/{webform_access_group}/translate/{langcode}/add','/admin/structure/webform/access/group/manage/%/translate/%/add',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/webform/access/group/manage/{webform_access_group}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:20:\"webform_access_group\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:20:\"webform_access_group\";a:2:{s:4:\"type\";s:27:\"entity:webform_access_group\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:20:\"webform_access_group\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/webform/access/group/manage/(?P<webform_access_group>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"webform_access_group\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/structure/webform/access/group/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:20:\"webform_access_group\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:62:\"/admin/structure/webform/access/group/manage/%/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.webform_access_type.edit_form','/admin/structure/webform/access/type/manage/{webform_access_type}/translate/{langcode}/add','/admin/structure/webform/access/type/manage/%/translate/%/add',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/webform/access/type/manage/{webform_access_type}/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:19:\"webform_access_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"webform_access_type\";a:2:{s:4:\"type\";s:26:\"entity:webform_access_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"webform_access_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/webform/access/type/manage/(?P<webform_access_type>[^/]++)/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"webform_access_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/access/type/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"webform_access_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:61:\"/admin/structure/webform/access/type/manage/%/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.entity.webform_options.edit_form','/admin/structure/webform/options/manage/{webform_options}/edit/translate/{langcode}/add','/admin/structure/webform/options/manage/%/edit/translate/%/add',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/webform/options/manage/{webform_options}/edit/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:15:\"webform_options\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"webform_options\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/webform/options/manage/(?P<webform_options>[^/]++)/edit/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"webform_options\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:62:\"/admin/structure/webform/options/manage/%/edit/translate/%/add\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.add.system.rss_feeds_settings','/admin/config/services/rss-publishing/translate/{langcode}/add','/admin/config/services/rss-publishing/translate/%/add',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/config/services/rss-publishing/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:25:\"system.rss_feeds_settings\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/services/rss\\-publishing/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/services/rss-publishing/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:53:\"/admin/config/services/rss-publishing/translate/%/add\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.add.system.site_information_settings','/admin/config/system/site-information/translate/{langcode}/add','/admin/config/system/site-information/translate/%/add',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/config/system/site-information/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:32:\"system.site_information_settings\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/system/site\\-information/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/system/site-information/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:53:\"/admin/config/system/site-information/translate/%/add\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.add.system.site_maintenance_mode','/admin/config/development/maintenance/translate/{langcode}/add','/admin/config/development/maintenance/translate/%/add',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/config/development/maintenance/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:28:\"system.site_maintenance_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/development/maintenance/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/development/maintenance/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:53:\"/admin/config/development/maintenance/translate/%/add\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.add.webform.config','/admin/structure/webform/config/translate/{langcode}/add','/admin/structure/webform/config/translate/%/add',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/webform/config/translate/{langcode}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\config_translation\\Form\\ConfigTranslationAddForm\";s:9:\"plugin_id\";s:14:\"webform.config\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/webform/config/translate/(?P<langcode>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/config/translate/%/add\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.delete.entity.block.edit_form','/admin/structure/block/manage/{block}/translate/{langcode}/delete','/admin/structure/block/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block/manage/{block}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:5:\"block\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"block\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"block\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/block/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.block_content_type.edit_form','/admin/structure/block-content/manage/{block_content_type}/translate/{langcode}/delete','/admin/structure/block-content/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/block-content/manage/{block_content_type}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/block-content/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.ckeditor5_template.edit_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate/{langcode}/delete','/admin/config/ckeditor5-templates/content-templates/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:100:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:18:\"ckeditor5_template\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"ckeditor5_template\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"ckeditor5_template\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:72:\"/admin/config/ckeditor5-templates/content-templates/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.comment_type.edit_form','/admin/structure/comment/manage/{comment_type}/translate/{langcode}/delete','/admin/structure/comment/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/structure/comment/manage/{comment_type}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:12:\"comment_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/comment/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.configurable_language.edit_form','/admin/config/regional/language/edit/{configurable_language}/translate/{langcode}/delete','/admin/config/regional/language/edit/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/config/regional/language/edit/{configurable_language}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:21:\"configurable_language\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:21:\"configurable_language\";a:2:{s:4:\"type\";s:28:\"entity:configurable_language\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:21:\"configurable_language\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/config/regional/language/edit/(?P<configurable_language>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:21:\"configurable_language\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/regional/language/edit\";}}s:9:\"path_vars\";a:2:{i:0;s:21:\"configurable_language\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:57:\"/admin/config/regional/language/edit/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.config_split.edit_form','/admin/config/development/configuration/config-split/{config_split}/edit/translate/{langcode}/delete','/admin/config/development/configuration/config-split/%/edit/translate/%/delete',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:100:\"/admin/config/development/configuration/config-split/{config_split}/edit/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:12:\"config_split\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"config_split\";a:2:{s:4:\"type\";s:19:\"entity:config_split\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"config_split\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:128:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/edit/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"config_split\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:78:\"/admin/config/development/configuration/config-split/%/edit/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.contact_form.edit_form','/admin/structure/contact/manage/{contact_form}/translate/{langcode}/delete','/admin/structure/contact/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/structure/contact/manage/{contact_form}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:12:\"contact_form\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/contact/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.date_format.edit_form','/admin/config/regional/date-time/formats/manage/{date_format}/translate/{langcode}/delete','/admin/config/regional/date-time/formats/manage/%/translate/%/delete',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/config/regional/date-time/formats/manage/{date_format}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:11:\"date_format\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"date_format\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"date_format\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:68:\"/admin/config/regional/date-time/formats/manage/%/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.entity_form_mode.edit_form','/admin/structure/display-modes/form/manage/{entity_form_mode}/translate/{langcode}/delete','/admin/structure/display-modes/form/manage/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/structure/display-modes/form/manage/{entity_form_mode}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:16:\"entity_form_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"entity_form_mode\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"entity_form_mode\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:63:\"/admin/structure/display-modes/form/manage/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.entity_view_mode.edit_form','/admin/structure/display-modes/view/manage/{entity_view_mode}/translate/{langcode}/delete','/admin/structure/display-modes/view/manage/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/structure/display-modes/view/manage/{entity_view_mode}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:16:\"entity_view_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"entity_view_mode\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"entity_view_mode\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:63:\"/admin/structure/display-modes/view/manage/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.field_config.block_content_field_edit_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/translate/{langcode}/delete','/admin/structure/block-content/manage/%/fields/%/translate/%/delete',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:108:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:20:\"block_content_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:146:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:67:\"/admin/structure/block-content/manage/%/fields/%/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.field_config.comment_field_edit_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}/translate/{langcode}/delete','/admin/structure/comment/manage/%/fields/%/translate/%/delete',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:96:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:14:\"comment_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:133:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:61:\"/admin/structure/comment/manage/%/fields/%/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.field_config.contact_message_field_edit_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}/translate/{langcode}/delete','/admin/structure/contact/manage/%/fields/%/translate/%/delete',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:96:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:22:\"contact_message_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:133:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:61:\"/admin/structure/contact/manage/%/fields/%/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.field_config.menu_link_content_field_edit_form','/admin/structure/menu/manage/{menu}/fields/{field_config}/translate/{langcode}/delete','/admin/structure/menu/manage/%/fields/%/translate/%/delete',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/menu/manage/{menu}/fields/{field_config}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:24:\"menu_link_content_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:58:\"/admin/structure/menu/manage/%/fields/%/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.field_config.node_field_edit_form','/admin/structure/types/manage/{node_type}/fields/{field_config}/translate/{langcode}/delete','/admin/structure/types/manage/%/fields/%/translate/%/delete',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:91:\"/admin/structure/types/manage/{node_type}/fields/{field_config}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:11:\"node_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:128:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:59:\"/admin/structure/types/manage/%/fields/%/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.field_config.taxonomy_term_field_edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/translate/{langcode}/delete','/admin/structure/taxonomy/manage/%/overview/fields/%/translate/%/delete',1973,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:113:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:20:\"taxonomy_term_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:150:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1973;s:14:\"patternOutline\";s:71:\"/admin/structure/taxonomy/manage/%/overview/fields/%/translate/%/delete\";s:8:\"numParts\";i:11;}}',11),('config_translation.item.delete.entity.field_config.user_field_edit_form','/admin/config/people/accounts/fields/{field_config}/translate/{langcode}/delete','/admin/config/people/accounts/fields/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/config/people/accounts/fields/{field_config}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:11:\"user_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"field_config\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"field_config\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:57:\"/admin/config/people/accounts/fields/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.filter_format.edit_form','/admin/config/content/formats/manage/{filter_format}/translate/{langcode}/delete','/admin/config/content/formats/manage/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/config/content/formats/manage/{filter_format}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:13:\"filter_format\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"filter_format\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"filter_format\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:57:\"/admin/config/content/formats/manage/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.image_style.edit_form','/admin/config/media/image-styles/manage/{image_style}/translate/{langcode}/delete','/admin/config/media/image-styles/manage/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/config/media/image-styles/manage/{image_style}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:11:\"image_style\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:60:\"/admin/config/media/image-styles/manage/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.jsonapi_resource_config.edit_form','/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate/{langcode}/delete','/admin/config/services/jsonapi/resource_types/%/edit/translate/%/delete',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:104:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:23:\"jsonapi_resource_config\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:23:\"jsonapi_resource_config\";a:2:{s:4:\"type\";s:30:\"entity:jsonapi_resource_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:23:\"jsonapi_resource_config\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:131:\"{^/admin/config/services/jsonapi/resource_types/(?P<jsonapi_resource_config>[^/]++)/edit/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:23:\"jsonapi_resource_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/services/jsonapi/resource_types\";}}s:9:\"path_vars\";a:2:{i:0;s:23:\"jsonapi_resource_config\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:71:\"/admin/config/services/jsonapi/resource_types/%/edit/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.linkit_profile.edit_form','/admin/config/content/linkit/manage/{linkit_profile}/translate/{langcode}/delete','/admin/config/content/linkit/manage/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/config/content/linkit/manage/{linkit_profile}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:14:\"linkit_profile\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:56:\"/admin/config/content/linkit/manage/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.menu.edit_form','/admin/structure/menu/manage/{menu}/translate/{langcode}/delete','/admin/structure/menu/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/menu/manage/{menu}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:4:\"menu\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/menu/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.metatag_defaults.edit_form','/admin/config/search/metatag/{metatag_defaults}/translate/{langcode}/delete','/admin/config/search/metatag/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/config/search/metatag/{metatag_defaults}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:16:\"metatag_defaults\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"metatag_defaults\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"metatag_defaults\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/config/search/metatag/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.node_type.edit_form','/admin/structure/types/manage/{node_type}/translate/{langcode}/delete','/admin/structure/types/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/types/manage/{node_type}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/types/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.pathauto_pattern.edit_form','/admin/config/search/path/patterns/{pathauto_pattern}/translate/{langcode}/delete','/admin/config/search/path/patterns/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/config/search/path/patterns/{pathauto_pattern}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:16:\"pathauto_pattern\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"pathauto_pattern\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"pathauto_pattern\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:55:\"/admin/config/search/path/patterns/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.shortcut_set.edit_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/translate/{langcode}/delete','/admin/config/user-interface/shortcut/manage/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:12:\"shortcut_set\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"shortcut_set\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"shortcut_set\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:65:\"/admin/config/user-interface/shortcut/manage/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.simple_sitemap.edit_form','/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate/{langcode}/delete','/admin/config/search/simplesitemap/variants/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:14:\"simple_sitemap\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:14:\"simple_sitemap\";a:2:{s:4:\"type\";s:21:\"entity:simple_sitemap\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"simple_sitemap\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/config/search/simplesitemap/variants/(?P<simple_sitemap>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"simple_sitemap\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/variants\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"simple_sitemap\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:64:\"/admin/config/search/simplesitemap/variants/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.simple_sitemap_type.edit_form','/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate/{langcode}/delete','/admin/config/search/simplesitemap/types/%/translate/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:19:\"simple_sitemap_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"simple_sitemap_type\";a:2:{s:4:\"type\";s:26:\"entity:simple_sitemap_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"simple_sitemap_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/config/search/simplesitemap/types/(?P<simple_sitemap_type>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"simple_sitemap_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/search/simplesitemap/types\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"simple_sitemap_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:61:\"/admin/config/search/simplesitemap/types/%/translate/%/delete\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.delete.entity.taxonomy_vocabulary.edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/translate/{langcode}/delete','/admin/structure/taxonomy/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/taxonomy/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.user.admin_form','/admin/config/people/accounts/translate/{langcode}/delete','/admin/config/people/accounts/translate/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/config/people/accounts/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:22:\"entity.user.admin_form\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/config/people/accounts/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/people/accounts/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/config/people/accounts/translate/%/delete\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.delete.entity.user_role.edit_form','/admin/people/roles/manage/{user_role}/translate/{langcode}/delete','/admin/people/roles/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/people/roles/manage/{user_role}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:9:\"user_role\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"user_role\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"user_role\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/people/roles/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.view.edit_form','/admin/structure/views/view/{view}/translate/{langcode}/delete','/admin/structure/views/view/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/views/view/{view}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:4:\"view\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/views/view/(?P<view>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/views/view/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.webform.edit_form','/admin/structure/webform/manage/{webform}/translate/{langcode}/delete','/admin/structure/webform/manage/%/translate/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/webform/manage/{webform}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:7:\"webform\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/translate/%/delete\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.delete.entity.webform_access_group.edit_form','/admin/structure/webform/access/group/manage/{webform_access_group}/translate/{langcode}/delete','/admin/structure/webform/access/group/manage/%/translate/%/delete',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:95:\"/admin/structure/webform/access/group/manage/{webform_access_group}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:20:\"webform_access_group\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:20:\"webform_access_group\";a:2:{s:4:\"type\";s:27:\"entity:webform_access_group\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:20:\"webform_access_group\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/webform/access/group/manage/(?P<webform_access_group>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"webform_access_group\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/structure/webform/access/group/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:20:\"webform_access_group\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:65:\"/admin/structure/webform/access/group/manage/%/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.webform_access_type.edit_form','/admin/structure/webform/access/type/manage/{webform_access_type}/translate/{langcode}/delete','/admin/structure/webform/access/type/manage/%/translate/%/delete',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/webform/access/type/manage/{webform_access_type}/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:19:\"webform_access_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"webform_access_type\";a:2:{s:4:\"type\";s:26:\"entity:webform_access_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"webform_access_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:120:\"{^/admin/structure/webform/access/type/manage/(?P<webform_access_type>[^/]++)/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"webform_access_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/access/type/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"webform_access_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:64:\"/admin/structure/webform/access/type/manage/%/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.entity.webform_options.edit_form','/admin/structure/webform/options/manage/{webform_options}/edit/translate/{langcode}/delete','/admin/structure/webform/options/manage/%/edit/translate/%/delete',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/webform/options/manage/{webform_options}/edit/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:15:\"webform_options\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"webform_options\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/webform/options/manage/(?P<webform_options>[^/]++)/edit/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"webform_options\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:65:\"/admin/structure/webform/options/manage/%/edit/translate/%/delete\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.delete.system.rss_feeds_settings','/admin/config/services/rss-publishing/translate/{langcode}/delete','/admin/config/services/rss-publishing/translate/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/config/services/rss-publishing/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:25:\"system.rss_feeds_settings\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/config/services/rss\\-publishing/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/services/rss-publishing/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:56:\"/admin/config/services/rss-publishing/translate/%/delete\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.delete.system.site_information_settings','/admin/config/system/site-information/translate/{langcode}/delete','/admin/config/system/site-information/translate/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/config/system/site-information/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:32:\"system.site_information_settings\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/config/system/site\\-information/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/system/site-information/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:56:\"/admin/config/system/site-information/translate/%/delete\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.delete.system.site_maintenance_mode','/admin/config/development/maintenance/translate/{langcode}/delete','/admin/config/development/maintenance/translate/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/config/development/maintenance/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:28:\"system.site_maintenance_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/config/development/maintenance/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/development/maintenance/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:56:\"/admin/config/development/maintenance/translate/%/delete\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.delete.webform.config','/admin/structure/webform/config/translate/{langcode}/delete','/admin/structure/webform/config/translate/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/webform/config/translate/{langcode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\config_translation\\Form\\ConfigTranslationDeleteForm\";s:9:\"plugin_id\";s:14:\"webform.config\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/webform/config/translate/(?P<langcode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:50:\"/admin/structure/webform/config/translate/%/delete\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.edit.entity.block.edit_form','/admin/structure/block/manage/{block}/translate/{langcode}/edit','/admin/structure/block/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/block/manage/{block}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:5:\"block\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"block\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"block\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/block/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.block_content_type.edit_form','/admin/structure/block-content/manage/{block_content_type}/translate/{langcode}/edit','/admin/structure/block-content/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:84:\"/admin/structure/block-content/manage/{block_content_type}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.ckeditor5_template.edit_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate/{langcode}/edit','/admin/config/ckeditor5-templates/content-templates/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:18:\"ckeditor5_template\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"ckeditor5_template\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:127:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"ckeditor5_template\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:70:\"/admin/config/ckeditor5-templates/content-templates/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.comment_type.edit_form','/admin/structure/comment/manage/{comment_type}/translate/{langcode}/edit','/admin/structure/comment/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/comment/manage/{comment_type}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:12:\"comment_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/comment/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.configurable_language.edit_form','/admin/config/regional/language/edit/{configurable_language}/translate/{langcode}/edit','/admin/config/regional/language/edit/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/config/regional/language/edit/{configurable_language}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:21:\"configurable_language\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:21:\"configurable_language\";a:2:{s:4:\"type\";s:28:\"entity:configurable_language\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:21:\"configurable_language\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/config/regional/language/edit/(?P<configurable_language>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:21:\"configurable_language\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/regional/language/edit\";}}s:9:\"path_vars\";a:2:{i:0;s:21:\"configurable_language\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:55:\"/admin/config/regional/language/edit/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.config_split.edit_form','/admin/config/development/configuration/config-split/{config_split}/edit/translate/{langcode}/edit','/admin/config/development/configuration/config-split/%/edit/translate/%/edit',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/config/development/configuration/config-split/{config_split}/edit/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:12:\"config_split\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"config_split\";a:2:{s:4:\"type\";s:19:\"entity:config_split\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"config_split\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/edit/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"config_split\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:76:\"/admin/config/development/configuration/config-split/%/edit/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.contact_form.edit_form','/admin/structure/contact/manage/{contact_form}/translate/{langcode}/edit','/admin/structure/contact/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/contact/manage/{contact_form}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:12:\"contact_form\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.date_format.edit_form','/admin/config/regional/date-time/formats/manage/{date_format}/translate/{langcode}/edit','/admin/config/regional/date-time/formats/manage/%/translate/%/edit',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/config/regional/date-time/formats/manage/{date_format}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:11:\"date_format\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"date_format\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"date_format\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:66:\"/admin/config/regional/date-time/formats/manage/%/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.entity_form_mode.edit_form','/admin/structure/display-modes/form/manage/{entity_form_mode}/translate/{langcode}/edit','/admin/structure/display-modes/form/manage/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/display-modes/form/manage/{entity_form_mode}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:16:\"entity_form_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"entity_form_mode\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"entity_form_mode\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:61:\"/admin/structure/display-modes/form/manage/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.entity_view_mode.edit_form','/admin/structure/display-modes/view/manage/{entity_view_mode}/translate/{langcode}/edit','/admin/structure/display-modes/view/manage/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/display-modes/view/manage/{entity_view_mode}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:16:\"entity_view_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"entity_view_mode\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"entity_view_mode\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:61:\"/admin/structure/display-modes/view/manage/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.field_config.block_content_field_edit_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/translate/{langcode}/edit','/admin/structure/block-content/manage/%/fields/%/translate/%/edit',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:106:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:20:\"block_content_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:144:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:65:\"/admin/structure/block-content/manage/%/fields/%/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.field_config.comment_field_edit_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}/translate/{langcode}/edit','/admin/structure/comment/manage/%/fields/%/translate/%/edit',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:94:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:14:\"comment_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:131:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:59:\"/admin/structure/comment/manage/%/fields/%/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.field_config.contact_message_field_edit_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}/translate/{langcode}/edit','/admin/structure/contact/manage/%/fields/%/translate/%/edit',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:94:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:22:\"contact_message_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:131:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:59:\"/admin/structure/contact/manage/%/fields/%/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.field_config.menu_link_content_field_edit_form','/admin/structure/menu/manage/{menu}/fields/{field_config}/translate/{langcode}/edit','/admin/structure/menu/manage/%/fields/%/translate/%/edit',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/menu/manage/{menu}/fields/{field_config}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:24:\"menu_link_content_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:120:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:56:\"/admin/structure/menu/manage/%/fields/%/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.field_config.node_field_edit_form','/admin/structure/types/manage/{node_type}/fields/{field_config}/translate/{langcode}/edit','/admin/structure/types/manage/%/fields/%/translate/%/edit',981,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/structure/types/manage/{node_type}/fields/{field_config}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:11:\"node_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:981;s:14:\"patternOutline\";s:57:\"/admin/structure/types/manage/%/fields/%/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.field_config.taxonomy_term_field_edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/translate/{langcode}/edit','/admin/structure/taxonomy/manage/%/overview/fields/%/translate/%/edit',1973,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:111:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:20:\"taxonomy_term_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:148:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1973;s:14:\"patternOutline\";s:69:\"/admin/structure/taxonomy/manage/%/overview/fields/%/translate/%/edit\";s:8:\"numParts\";i:11;}}',11),('config_translation.item.edit.entity.field_config.user_field_edit_form','/admin/config/people/accounts/fields/{field_config}/translate/{langcode}/edit','/admin/config/people/accounts/fields/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/config/people/accounts/fields/{field_config}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:11:\"user_fields\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"field_config\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"field_config\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:55:\"/admin/config/people/accounts/fields/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.filter_format.edit_form','/admin/config/content/formats/manage/{filter_format}/translate/{langcode}/edit','/admin/config/content/formats/manage/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/config/content/formats/manage/{filter_format}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:13:\"filter_format\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"filter_format\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"filter_format\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:55:\"/admin/config/content/formats/manage/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.image_style.edit_form','/admin/config/media/image-styles/manage/{image_style}/translate/{langcode}/edit','/admin/config/media/image-styles/manage/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/config/media/image-styles/manage/{image_style}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:11:\"image_style\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:58:\"/admin/config/media/image-styles/manage/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.jsonapi_resource_config.edit_form','/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate/{langcode}/edit','/admin/config/services/jsonapi/resource_types/%/edit/translate/%/edit',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:23:\"jsonapi_resource_config\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:23:\"jsonapi_resource_config\";a:2:{s:4:\"type\";s:30:\"entity:jsonapi_resource_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:23:\"jsonapi_resource_config\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/admin/config/services/jsonapi/resource_types/(?P<jsonapi_resource_config>[^/]++)/edit/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:23:\"jsonapi_resource_config\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/services/jsonapi/resource_types\";}}s:9:\"path_vars\";a:2:{i:0;s:23:\"jsonapi_resource_config\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:69:\"/admin/config/services/jsonapi/resource_types/%/edit/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.linkit_profile.edit_form','/admin/config/content/linkit/manage/{linkit_profile}/translate/{langcode}/edit','/admin/config/content/linkit/manage/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/config/content/linkit/manage/{linkit_profile}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:14:\"linkit_profile\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:54:\"/admin/config/content/linkit/manage/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.menu.edit_form','/admin/structure/menu/manage/{menu}/translate/{langcode}/edit','/admin/structure/menu/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/menu/manage/{menu}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:4:\"menu\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/menu/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.metatag_defaults.edit_form','/admin/config/search/metatag/{metatag_defaults}/translate/{langcode}/edit','/admin/config/search/metatag/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/config/search/metatag/{metatag_defaults}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:16:\"metatag_defaults\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"metatag_defaults\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"metatag_defaults\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/config/search/metatag/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.node_type.edit_form','/admin/structure/types/manage/{node_type}/translate/{langcode}/edit','/admin/structure/types/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/types/manage/{node_type}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.pathauto_pattern.edit_form','/admin/config/search/path/patterns/{pathauto_pattern}/translate/{langcode}/edit','/admin/config/search/path/patterns/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/config/search/path/patterns/{pathauto_pattern}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:16:\"pathauto_pattern\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:16:\"pathauto_pattern\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:2:{i:0;s:16:\"pathauto_pattern\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:53:\"/admin/config/search/path/patterns/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.shortcut_set.edit_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/translate/{langcode}/edit','/admin/config/user-interface/shortcut/manage/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:12:\"shortcut_set\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"shortcut_set\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"shortcut_set\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:63:\"/admin/config/user-interface/shortcut/manage/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.simple_sitemap.edit_form','/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate/{langcode}/edit','/admin/config/search/simplesitemap/variants/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:14:\"simple_sitemap\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:14:\"simple_sitemap\";a:2:{s:4:\"type\";s:21:\"entity:simple_sitemap\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"simple_sitemap\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/config/search/simplesitemap/variants/(?P<simple_sitemap>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"simple_sitemap\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/variants\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"simple_sitemap\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:62:\"/admin/config/search/simplesitemap/variants/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.simple_sitemap_type.edit_form','/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate/{langcode}/edit','/admin/config/search/simplesitemap/types/%/translate/%/edit',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:19:\"simple_sitemap_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"simple_sitemap_type\";a:2:{s:4:\"type\";s:26:\"entity:simple_sitemap_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"simple_sitemap_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/config/search/simplesitemap/types/(?P<simple_sitemap_type>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"simple_sitemap_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/search/simplesitemap/types\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"simple_sitemap_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:59:\"/admin/config/search/simplesitemap/types/%/translate/%/edit\";s:8:\"numParts\";i:9;}}',9),('config_translation.item.edit.entity.taxonomy_vocabulary.edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/translate/{langcode}/edit','/admin/structure/taxonomy/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/taxonomy/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.user.admin_form','/admin/config/people/accounts/translate/{langcode}/edit','/admin/config/people/accounts/translate/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/config/people/accounts/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:22:\"entity.user.admin_form\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/config/people/accounts/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/people/accounts/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/translate/%/edit\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.edit.entity.user_role.edit_form','/admin/people/roles/manage/{user_role}/translate/{langcode}/edit','/admin/people/roles/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/people/roles/manage/{user_role}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:9:\"user_role\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"user_role\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"user_role\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:45:\"/admin/people/roles/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.view.edit_form','/admin/structure/views/view/{view}/translate/{langcode}/edit','/admin/structure/views/view/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/views/view/{view}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:4:\"view\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/views/view/(?P<view>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:46:\"/admin/structure/views/view/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.webform.edit_form','/admin/structure/webform/manage/{webform}/translate/{langcode}/edit','/admin/structure/webform/manage/%/translate/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/webform/manage/{webform}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:7:\"webform\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/webform/manage/%/translate/%/edit\";s:8:\"numParts\";i:8;}}',8),('config_translation.item.edit.entity.webform_access_group.edit_form','/admin/structure/webform/access/group/manage/{webform_access_group}/translate/{langcode}/edit','/admin/structure/webform/access/group/manage/%/translate/%/edit',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/webform/access/group/manage/{webform_access_group}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:20:\"webform_access_group\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:20:\"webform_access_group\";a:2:{s:4:\"type\";s:27:\"entity:webform_access_group\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:20:\"webform_access_group\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:120:\"{^/admin/structure/webform/access/group/manage/(?P<webform_access_group>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"webform_access_group\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/structure/webform/access/group/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:20:\"webform_access_group\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:63:\"/admin/structure/webform/access/group/manage/%/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.webform_access_type.edit_form','/admin/structure/webform/access/type/manage/{webform_access_type}/translate/{langcode}/edit','/admin/structure/webform/access/type/manage/%/translate/%/edit',1013,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:91:\"/admin/structure/webform/access/type/manage/{webform_access_type}/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:19:\"webform_access_type\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"webform_access_type\";a:2:{s:4:\"type\";s:26:\"entity:webform_access_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"webform_access_type\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:118:\"{^/admin/structure/webform/access/type/manage/(?P<webform_access_type>[^/]++)/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"webform_access_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/access/type/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"webform_access_type\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1013;s:14:\"patternOutline\";s:62:\"/admin/structure/webform/access/type/manage/%/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.entity.webform_options.edit_form','/admin/structure/webform/options/manage/{webform_options}/edit/translate/{langcode}/edit','/admin/structure/webform/options/manage/%/edit/translate/%/edit',1005,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/webform/options/manage/{webform_options}/edit/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:15:\"webform_options\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"webform_options\";i:1;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/webform/options/manage/(?P<webform_options>[^/]++)/edit/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"webform_options\";i:1;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1005;s:14:\"patternOutline\";s:63:\"/admin/structure/webform/options/manage/%/edit/translate/%/edit\";s:8:\"numParts\";i:10;}}',10),('config_translation.item.edit.system.rss_feeds_settings','/admin/config/services/rss-publishing/translate/{langcode}/edit','/admin/config/services/rss-publishing/translate/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/services/rss-publishing/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:25:\"system.rss_feeds_settings\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/config/services/rss\\-publishing/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/services/rss-publishing/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/config/services/rss-publishing/translate/%/edit\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.edit.system.site_information_settings','/admin/config/system/site-information/translate/{langcode}/edit','/admin/config/system/site-information/translate/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/system/site-information/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:32:\"system.site_information_settings\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/config/system/site\\-information/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/system/site-information/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/config/system/site-information/translate/%/edit\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.edit.system.site_maintenance_mode','/admin/config/development/maintenance/translate/{langcode}/edit','/admin/config/development/maintenance/translate/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/development/maintenance/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:28:\"system.site_maintenance_mode\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/development/maintenance/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/development/maintenance/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/config/development/maintenance/translate/%/edit\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.edit.webform.config','/admin/structure/webform/config/translate/{langcode}/edit','/admin/structure/webform/config/translate/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/webform/config/translate/{langcode}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:57:\"\\Drupal\\config_translation\\Form\\ConfigTranslationEditForm\";s:9:\"plugin_id\";s:14:\"webform.config\";}s:12:\"requirements\";a:1:{s:31:\"_config_translation_form_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"config_translation.access.form\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/webform/config/translate/(?P<langcode>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/translate\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/config/translate/%/edit\";s:8:\"numParts\";i:7;}}',7),('config_translation.item.overview.entity.user.admin_form','/admin/config/people/accounts/translate','/admin/config/people/accounts/translate',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/people/accounts/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:22:\"entity.user.admin_form\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/config/people/accounts/translate$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/people/accounts/translate\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/config/people/accounts/translate\";s:8:\"numParts\";i:5;}}',5),('config_translation.item.overview.system.rss_feeds_settings','/admin/config/services/rss-publishing/translate','/admin/config/services/rss-publishing/translate',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/services/rss-publishing/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:25:\"system.rss_feeds_settings\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/config/services/rss\\-publishing/translate$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/services/rss-publishing/translate\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:47:\"/admin/config/services/rss-publishing/translate\";s:8:\"numParts\";i:5;}}',5),('config_translation.item.overview.system.site_information_settings','/admin/config/system/site-information/translate','/admin/config/system/site-information/translate',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/system/site-information/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:32:\"system.site_information_settings\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/config/system/site\\-information/translate$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/system/site-information/translate\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:47:\"/admin/config/system/site-information/translate\";s:8:\"numParts\";i:5;}}',5),('config_translation.item.overview.system.site_maintenance_mode','/admin/config/development/maintenance/translate','/admin/config/development/maintenance/translate',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/development/maintenance/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:28:\"system.site_maintenance_mode\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/development/maintenance/translate$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/development/maintenance/translate\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:47:\"/admin/config/development/maintenance/translate\";s:8:\"numParts\";i:5;}}',5),('config_translation.item.overview.webform.config','/admin/structure/webform/config/translate','/admin/structure/webform/config/translate',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/config/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:14:\"webform.config\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/structure/webform/config/translate$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/translate\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/config/translate\";s:8:\"numParts\";i:5;}}',5),('config_translation.mapper_list','/admin/config/regional/config-translation','/admin/config/regional/config-translation',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/config/regional/config-translation\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:25:\"Configuration translation\";s:11:\"_controller\";s:73:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationMapperList::render\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"translate configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/config/regional/config\\-translation$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/config/regional/config-translation\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:41:\"/admin/config/regional/config-translation\";s:8:\"numParts\";i:4;}}',4),('contact.form_add','/admin/structure/contact/add','/admin/structure/contact/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/contact/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"contact_form.add\";s:6:\"_title\";s:16:\"Add contact form\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer contact forms\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/structure/contact/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/contact/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/structure/contact/add\";s:8:\"numParts\";i:4;}}',4),('contact.site_page','/contact','/contact',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:61:\"\\Drupal\\contact\\Controller\\ContactController::contactSitePage\";s:12:\"contact_form\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"access site-wide contact form\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:15:\"{^/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/contact\";s:8:\"numParts\";i:1;}}',1),('contextual.render','/contextual/render','/contextual/render',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/contextual/render\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\contextual\\ContextualController::render\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"access contextual links\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/contextual/render$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/contextual/render\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:18:\"/contextual/render\";s:8:\"numParts\";i:2;}}',2),('dblog.access_denied','/admin/reports/access-denied','/admin/reports/access-denied',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:26:\"Top \'access denied\' errors\";s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:4:\"type\";s:13:\"access denied\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/access\\-denied$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/access-denied\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/reports/access-denied\";s:8:\"numParts\";i:3;}}',3),('dblog.confirm','/admin/reports/dblog/confirm','/admin/reports/dblog/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/dblog/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\dblog\\Form\\DblogClearLogConfirmForm\";s:6:\"_title\";s:34:\"Confirm delete recent log messages\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/reports/dblog/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/dblog/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/reports/dblog/confirm\";s:8:\"numParts\";i:4;}}',4),('dblog.event','/admin/reports/dblog/event/{event_id}','/admin/reports/dblog/event/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/reports/dblog/event/{event_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\dblog\\Controller\\DbLogController::eventDetails\";s:6:\"_title\";s:7:\"Details\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"event_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/reports/dblog/event/(?P<event_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"event_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/reports/dblog/event\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"event_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/reports/dblog/event/%\";s:8:\"numParts\";i:5;}}',5),('dblog.overview','/admin/reports/dblog','/admin/reports/dblog',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/reports/dblog\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"watchdog\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/reports/dblog$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/reports/dblog\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/reports/dblog\";s:8:\"numParts\";i:3;}}',3),('dblog.page_not_found','/admin/reports/page-not-found','/admin/reports/page-not-found',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/page-not-found\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:27:\"Top \'page not found\' errors\";s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:4:\"type\";s:14:\"page not found\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/page\\-not\\-found$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/page-not-found\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:29:\"/admin/reports/page-not-found\";s:8:\"numParts\";i:3;}}',3),('diff.fields_list','/admin/config/content/diff/fields','/admin/config/content/diff/fields',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/content/diff/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\diff\\Form\\FieldsSettingsForm\";s:6:\"_title\";s:15:\"Fields Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/content/diff/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/content/diff/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:33:\"/admin/config/content/diff/fields\";s:8:\"numParts\";i:5;}}',5),('diff.general_settings','/admin/config/content/diff/general','/admin/config/content/diff/general',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/content/diff/general\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\diff\\Form\\GeneralSettingsForm\";s:6:\"_title\";s:21:\"Diff General Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/content/diff/general$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/content/diff/general\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/config/content/diff/general\";s:8:\"numParts\";i:5;}}',5),('diff.revisions_diff','/node/{node}/revisions/view/{left_revision}/{right_revision}/{filter}','/node/%/revisions/view/%/%/%',88,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/node/{node}/revisions/view/{left_revision}/{right_revision}/{filter}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\diff\\Controller\\NodeRevisionController::compareNodeRevisions\";s:6:\"_title\";s:21:\"Diff General Settings\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"node.view all revisions\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:4:\"node\";i:1;s:13:\"left_revision\";i:2;s:14:\"right_revision\";i:3;s:6:\"filter\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/node/(?P<node>[^/]++)/revisions/view/(?P<left_revision>[^/]++)/(?P<right_revision>[^/]++)/(?P<filter>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"filter\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"right_revision\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"left_revision\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/revisions/view\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:4:{i:0;s:4:\"node\";i:1;s:13:\"left_revision\";i:2;s:14:\"right_revision\";i:3;s:6:\"filter\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:88;s:14:\"patternOutline\";s:28:\"/node/%/revisions/view/%/%/%\";s:8:\"numParts\";i:7;}}',7),('editor.filter_xss','/editor/filter_xss/{filter_format}','/editor/filter_xss/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/editor/filter_xss/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:42:\"\\Drupal\\editor\\EditorController::filterXss\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"filter_format.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/editor/filter_xss/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/editor/filter_xss\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:20:\"/editor/filter_xss/%\";s:8:\"numParts\";i:3;}}',3),('entity.block.config_translation_overview','/admin/structure/block/manage/{block}/translate','/admin/structure/block/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/structure/block/manage/{block}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:5:\"block\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/block/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.block.delete_form','/admin/structure/block/manage/{block}/delete','/admin/structure/block/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/block/manage/{block}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"block.delete\";s:6:\"_title\";s:12:\"Remove block\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/block/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.block.disable','/admin/structure/block/manage/{block}/disable','/admin/structure/block/manage/%/disable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/block/manage/{block}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\block\\Controller\\BlockController::performOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:13:\"block.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/block/manage/%/disable\";s:8:\"numParts\";i:6;}}',6),('entity.block.edit_form','/admin/structure/block/manage/{block}','/admin/structure/block/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/structure/block/manage/{block}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"block.default\";s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"block.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/structure/block/manage/(?P<block>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/block/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.block.enable','/admin/structure/block/manage/{block}/enable','/admin/structure/block/manage/%/enable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/block/manage/{block}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\block\\Controller\\BlockController::performOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"block.enable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/block/manage/%/enable\";s:8:\"numParts\";i:6;}}',6),('entity.block_content.canonical','/admin/content/block/{block_content}','/admin/content/block/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/content/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"block_content.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/content/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/admin/content/block/%\";s:8:\"numParts\";i:4;}}',4),('entity.block_content.collection','/admin/content/block','/admin/content/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"block_content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"access block library\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/block\";s:8:\"numParts\";i:3;}}',3),('entity.block_content.delete_form','/admin/content/block/{block_content}/delete','/admin/content/block/%/delete',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/content/block/{block_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"block_content.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.delete\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/content/block/(?P<block_content>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:29:\"/admin/content/block/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.block_content.edit_form','/admin/content/block/{block_content}','/admin/content/block/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/content/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:18:\"block_content.edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/content/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/admin/content/block/%\";s:8:\"numParts\";i:4;}}',4),('entity.block_content.field_ui_fields','/admin/structure/block-content/manage/{block_content_type}/fields','/admin/structure/block-content/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/block-content/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.block_content.revision_delete_form','/admin/content/block/{block_content}/revision/{block_content_revision}/delete','/admin/content/block/%/revision/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"block_content.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:38:\"block_content_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"block_content_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:block_content\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"block_content_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:40:\"/admin/content/block/%/revision/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.block_content.revision_revert_form','/admin/content/block/{block_content}/revision/{block_content_revision}/revert','/admin/content/block/%/revision/%/revert',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"block_content.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"block_content_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"block_content_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:block_content\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"block_content_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:40:\"/admin/content/block/%/revision/%/revert\";s:8:\"numParts\";i:7;}}',7),('entity.block_content.version_history','/admin/content/block/{block_content}/revisions','/admin/content/block/%/revisions',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/content/block/{block_content}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:32:\"block_content.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:13:\"block_content\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/content/block/(?P<block_content>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:32:\"/admin/content/block/%/revisions\";s:8:\"numParts\";i:5;}}',5),('entity.block_content_type.collection','/admin/structure/block-content','/admin/structure/block-content',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/structure/block-content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:18:\"block_content_type\";s:6:\"_title\";s:11:\"Block types\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer block types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/block\\-content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/block-content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/structure/block-content\";s:8:\"numParts\";i:3;}}',3),('entity.block_content_type.config_translation_overview','/admin/structure/block-content/manage/{block_content_type}/translate','/admin/structure/block-content/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/block-content/manage/{block_content_type}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:49:\"/admin/structure/block-content/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.block_content_type.delete_form','/admin/structure/block-content/manage/{block_content_type}/delete','/admin/structure/block-content/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"block_content_type.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/block-content/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.block_content_type.edit_form','/admin/structure/block-content/manage/{block_content_type}','/admin/structure/block-content/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/block-content/manage/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"block_content_type.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:39:\"/admin/structure/block-content/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.block_content_type.entity_permissions_form','/admin/structure/block-content/manage/{block_content_type}/permissions','/admin/structure/block-content/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/block-content/manage/{block_content_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:13:\"block_content\";s:18:\"bundle_entity_type\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:3:{s:4:\"type\";s:25:\"entity:block_content_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:51:\"/admin/structure/block-content/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.ckeditor5_template.add_form','/admin/config/ckeditor5-templates/content-templates/add','/admin/config/ckeditor5-templates/content-templates/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"ckeditor5_template.add\";s:6:\"_title\";s:24:\"Add a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:8:\"numParts\";i:5;}}',5),('entity.ckeditor5_template.collection','/admin/config/ckeditor5-templates/content-templates','/admin/config/ckeditor5-templates/content-templates',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:18:\"ckeditor5_template\";s:6:\"_title\";s:41:\"CKEditor5 Content Templates Configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/ckeditor5\\-templates/content\\-templates$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:8:\"numParts\";i:4;}}',4),('entity.ckeditor5_template.config_translation_overview','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate','/admin/config/ckeditor5-templates/content-templates/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:18:\"ckeditor5_template\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:63:\"/admin/config/ckeditor5-templates/content-templates/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.ckeditor5_template.delete_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/delete','/admin/config/ckeditor5-templates/content-templates/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"ckeditor5_template.delete\";s:6:\"_title\";s:27:\"Delete a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:60:\"/admin/config/ckeditor5-templates/content-templates/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.ckeditor5_template.edit_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}','/admin/config/ckeditor5-templates/content-templates/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"ckeditor5_template.edit\";s:6:\"_title\";s:25:\"Edit a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:53:\"/admin/config/ckeditor5-templates/content-templates/%\";s:8:\"numParts\";i:5;}}',5),('entity.comment.canonical','/comment/{comment}','/comment/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/comment/{comment}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:67:\"\\Drupal\\comment\\Controller\\CommentController::commentPermalinkTitle\";s:11:\"_controller\";s:62:\"\\Drupal\\comment\\Controller\\CommentController::commentPermalink\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"comment.view\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/comment/(?P<comment>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/comment/%\";s:8:\"numParts\";i:2;}}',2),('entity.comment.delete_form','/comment/{comment}/delete','/comment/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/comment/{comment}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:6:\"Delete\";s:12:\"_entity_form\";s:14:\"comment.delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"comment.delete\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/comment/(?P<comment>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/comment/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.comment.delete_multiple_form','/admin/content/comment/delete','/admin/content/comment/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/content/comment/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Delete\";s:5:\"_form\";s:42:\"\\Drupal\\comment\\Form\\ConfirmDeleteMultiple\";s:14:\"entity_type_id\";s:7:\"comment\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"comment\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/content/comment/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/content/comment/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/content/comment/delete\";s:8:\"numParts\";i:4;}}',4),('entity.comment.edit_form','/comment/{comment}/edit','/comment/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/comment/{comment}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:4:\"Edit\";s:12:\"_entity_form\";s:15:\"comment.default\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"comment.update\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/comment/(?P<comment>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/comment/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.comment.field_ui_fields','/admin/structure/comment/manage/{comment_type}/fields','/admin/structure/comment/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/comment/manage/{comment_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/comment/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.comment_type.add_form','/admin/structure/comment/types/add','/admin/structure/comment/types/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/comment/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"comment_type.add\";s:6:\"_title\";s:16:\"Add comment type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer comment types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/structure/comment/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/structure/comment/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/structure/comment/types/add\";s:8:\"numParts\";i:5;}}',5),('entity.comment_type.collection','/admin/structure/comment','/admin/structure/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"comment_type\";s:6:\"_title\";s:13:\"Comment types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer comment types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/comment\";s:8:\"numParts\";i:3;}}',3),('entity.comment_type.config_translation_overview','/admin/structure/comment/manage/{comment_type}/translate','/admin/structure/comment/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/comment/manage/{comment_type}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:12:\"comment_type\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/comment/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.comment_type.delete_form','/admin/structure/comment/manage/{comment_type}/delete','/admin/structure/comment/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/comment/manage/{comment_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"comment_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"comment_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/comment/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.comment_type.edit_form','/admin/structure/comment/manage/{comment_type}','/admin/structure/comment/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/comment/manage/{comment_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"comment_type.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"comment_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/comment/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.comment_type.entity_permissions_form','/admin/structure/comment/manage/{comment_type}/permissions','/admin/structure/comment/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/comment/manage/{comment_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:7:\"comment\";s:18:\"bundle_entity_type\";s:12:\"comment_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:3:{s:4:\"type\";s:19:\"entity:comment_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:45:\"/admin/structure/comment/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.configurable_language.collection','/admin/config/regional/language','/admin/config/regional/language',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/regional/language\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:21:\"configurable_language\";s:6:\"_title\";s:9:\"Languages\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer languages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/config/regional/language$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/regional/language\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/regional/language\";s:8:\"numParts\";i:4;}}',4),('entity.configurable_language.config_translation_overview','/admin/config/regional/language/edit/{configurable_language}/translate','/admin/config/regional/language/edit/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/config/regional/language/edit/{configurable_language}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:21:\"configurable_language\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:21:\"configurable_language\";a:2:{s:4:\"type\";s:28:\"entity:configurable_language\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:21:\"configurable_language\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/regional/language/edit/(?P<configurable_language>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:21:\"configurable_language\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/regional/language/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:21:\"configurable_language\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/config/regional/language/edit/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.configurable_language.delete_form','/admin/config/regional/language/delete/{configurable_language}','/admin/config/regional/language/delete/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/config/regional/language/delete/{configurable_language}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:28:\"configurable_language.delete\";s:6:\"_title\";s:15:\"Delete language\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:28:\"configurable_language.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:21:\"configurable_language\";a:2:{s:4:\"type\";s:28:\"entity:configurable_language\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:21:\"configurable_language\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/regional/language/delete/(?P<configurable_language>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:21:\"configurable_language\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/config/regional/language/delete\";}}s:9:\"path_vars\";a:1:{i:0;s:21:\"configurable_language\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:40:\"/admin/config/regional/language/delete/%\";s:8:\"numParts\";i:6;}}',6),('entity.configurable_language.edit_form','/admin/config/regional/language/edit/{configurable_language}','/admin/config/regional/language/edit/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/regional/language/edit/{configurable_language}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:26:\"configurable_language.edit\";s:6:\"_title\";s:13:\"Edit language\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:28:\"configurable_language.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:21:\"configurable_language\";a:2:{s:4:\"type\";s:28:\"entity:configurable_language\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:21:\"configurable_language\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/regional/language/edit/(?P<configurable_language>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:21:\"configurable_language\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/regional/language/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:21:\"configurable_language\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/regional/language/edit/%\";s:8:\"numParts\";i:6;}}',6),('entity.config_split.activate','/admin/config/development/configuration/config-split/{config_split}/activate','/admin/config/development/configuration/config-split/%/activate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/config/development/configuration/config-split/{config_split}/activate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:49:\"\\Drupal\\config_split\\Form\\ConfigSplitActivateForm\";s:6:\"_title\";s:8:\"Activate\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:57:\"\\Drupal\\config_split\\Form\\ConfigSplitActivateForm::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/activate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/activate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:63:\"/admin/config/development/configuration/config-split/%/activate\";s:8:\"numParts\";i:7;}}',7),('entity.config_split.add_form','/admin/config/development/configuration/config-split/add','/admin/config/development/configuration/config-split/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/config/development/configuration/config-split/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:16:\"config_split.add\";s:14:\"entity_type_id\";s:12:\"config_split\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:12:\"config_split\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/development/configuration/config\\-split/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:56:\"/admin/config/development/configuration/config-split/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:56:\"/admin/config/development/configuration/config-split/add\";s:8:\"numParts\";i:6;}}',6),('entity.config_split.canonical','/admin/config/development/configuration/config-split/{config_split}','/admin/config/development/configuration/config-split/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/config/development/configuration/config-split/{config_split}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_view\";s:17:\"config_split.full\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"config_split.view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"config_split\";a:2:{s:4:\"type\";s:19:\"entity:config_split\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:54:\"/admin/config/development/configuration/config-split/%\";s:8:\"numParts\";i:6;}}',6),('entity.config_split.collection','/admin/config/development/configuration/config-split','/admin/config/development/configuration/config-split',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/development/configuration/config-split\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"config_split\";s:6:\"_title\";s:27:\"Configuration Split setting\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer configuration split\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/development/configuration/config\\-split$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:52:\"/admin/config/development/configuration/config-split\";s:8:\"numParts\";i:5;}}',5),('entity.config_split.config_translation_overview','/admin/config/development/configuration/config-split/{config_split}/edit/translate','/admin/config/development/configuration/config-split/%/edit/translate',251,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/config/development/configuration/config-split/{config_split}/edit/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:12:\"config_split\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"config_split\";a:2:{s:4:\"type\";s:19:\"entity:config_split\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/edit/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:69:\"/admin/config/development/configuration/config-split/%/edit/translate\";s:8:\"numParts\";i:8;}}',8),('entity.config_split.deactivate','/admin/config/development/configuration/config-split/{config_split}/deactivate','/admin/config/development/configuration/config-split/%/deactivate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/config/development/configuration/config-split/{config_split}/deactivate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\config_split\\Form\\ConfigSplitDeactivateForm\";s:6:\"_title\";s:10:\"Deactivate\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:59:\"\\Drupal\\config_split\\Form\\ConfigSplitDeactivateForm::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/deactivate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/deactivate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:65:\"/admin/config/development/configuration/config-split/%/deactivate\";s:8:\"numParts\";i:7;}}',7),('entity.config_split.delete_form','/admin/config/development/configuration/config-split/{config_split}/delete','/admin/config/development/configuration/config-split/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/config/development/configuration/config-split/{config_split}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"config_split.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"config_split.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"config_split\";a:2:{s:4:\"type\";s:19:\"entity:config_split\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:61:\"/admin/config/development/configuration/config-split/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.config_split.disable','/admin/config/development/configuration/config-split/{config_split}/disable','/admin/config/development/configuration/config-split/%/disable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/config/development/configuration/config-split/{config_split}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:68:\"\\Drupal\\config_split\\Controller\\ConfigSplitController::disableEntity\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:30:\"administer configuration split\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:62:\"/admin/config/development/configuration/config-split/%/disable\";s:8:\"numParts\";i:7;}}',7),('entity.config_split.edit_form','/admin/config/development/configuration/config-split/{config_split}/edit','/admin/config/development/configuration/config-split/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/development/configuration/config-split/{config_split}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"config_split.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"config_split.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"config_split\";a:2:{s:4:\"type\";s:19:\"entity:config_split\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:59:\"/admin/config/development/configuration/config-split/%/edit\";s:8:\"numParts\";i:7;}}',7),('entity.config_split.enable','/admin/config/development/configuration/config-split/{config_split}/enable','/admin/config/development/configuration/config-split/%/enable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/config/development/configuration/config-split/{config_split}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\config_split\\Controller\\ConfigSplitController::enableEntity\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:30:\"administer configuration split\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:61:\"/admin/config/development/configuration/config-split/%/enable\";s:8:\"numParts\";i:7;}}',7),('entity.config_split.export','/admin/config/development/configuration/config-split/{config_split}/export','/admin/config/development/configuration/config-split/%/export',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/config/development/configuration/config-split/{config_split}/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\config_split\\Form\\ConfigSplitExportForm\";s:6:\"_title\";s:6:\"Export\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:55:\"\\Drupal\\config_split\\Form\\ConfigSplitExportForm::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/export$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/export\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:61:\"/admin/config/development/configuration/config-split/%/export\";s:8:\"numParts\";i:7;}}',7),('entity.config_split.import','/admin/config/development/configuration/config-split/{config_split}/import','/admin/config/development/configuration/config-split/%/import',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/config/development/configuration/config-split/{config_split}/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\config_split\\Form\\ConfigSplitImportForm\";s:6:\"_title\";s:6:\"Import\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:55:\"\\Drupal\\config_split\\Form\\ConfigSplitImportForm::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"config_split\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/config/development/configuration/config\\-split/(?P<config_split>[^/]++)/import$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/import\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"config_split\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/development/configuration/config-split\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"config_split\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:61:\"/admin/config/development/configuration/config-split/%/import\";s:8:\"numParts\";i:7;}}',7),('entity.contact_form.canonical','/contact/{contact_form}','/contact/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/contact/{contact_form}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:61:\"\\Drupal\\contact\\Controller\\ContactController::contactSitePage\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"contact_form.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/contact/(?P<contact_form>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/contact/%\";s:8:\"numParts\";i:2;}}',2),('entity.contact_form.collection','/admin/structure/contact','/admin/structure/contact',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"contact_form\";s:6:\"_title\";s:13:\"Contact forms\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer contact forms\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/contact\";s:8:\"numParts\";i:3;}}',3),('entity.contact_form.config_translation_overview','/admin/structure/contact/manage/{contact_form}/translate','/admin/structure/contact/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/contact/manage/{contact_form}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:12:\"contact_form\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/contact/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.contact_form.delete_form','/admin/structure/contact/manage/{contact_form}/delete','/admin/structure/contact/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/contact/manage/{contact_form}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"contact_form.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"contact_form.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/contact/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.contact_form.edit_form','/admin/structure/contact/manage/{contact_form}','/admin/structure/contact/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/contact/manage/{contact_form}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"contact_form.edit\";s:6:\"_title\";s:17:\"Edit contact form\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"contact_form.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/contact/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.contact_form.entity_permissions_form','/admin/structure/contact/manage/{contact_form}/permissions','/admin/structure/contact/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/contact/manage/{contact_form}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:18:\"bundle_entity_type\";s:12:\"contact_form\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:3:{s:4:\"type\";s:19:\"entity:contact_form\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:45:\"/admin/structure/contact/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.contact_message.field_ui_fields','/admin/structure/contact/manage/{contact_form}/fields','/admin/structure/contact/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/contact/manage/{contact_form}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/contact/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.date_format.collection','/admin/config/regional/date-time','/admin/config/regional/date-time',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/regional/date-time\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"date_format\";s:6:\"_title\";s:21:\"Date and time formats\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/regional/date\\-time$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/regional/date-time\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/regional/date-time\";s:8:\"numParts\";i:4;}}',4),('entity.date_format.config_translation_overview','/admin/config/regional/date-time/formats/manage/{date_format}/translate','/admin/config/regional/date-time/formats/manage/%/translate',253,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/config/regional/date-time/formats/manage/{date_format}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:11:\"date_format\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:253;s:14:\"patternOutline\";s:59:\"/admin/config/regional/date-time/formats/manage/%/translate\";s:8:\"numParts\";i:8;}}',8),('entity.date_format.delete_form','/admin/config/regional/date-time/formats/manage/{date_format}/delete','/admin/config/regional/date-time/formats/manage/%/delete',253,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/regional/date-time/formats/manage/{date_format}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"date_format.delete\";s:6:\"_title\";s:18:\"Delete date format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"date_format.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:253;s:14:\"patternOutline\";s:56:\"/admin/config/regional/date-time/formats/manage/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.date_format.edit_form','/admin/config/regional/date-time/formats/manage/{date_format}','/admin/config/regional/date-time/formats/manage/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/regional/date-time/formats/manage/{date_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"date_format.edit\";s:6:\"_title\";s:16:\"Edit date format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"date_format.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:49:\"/admin/config/regional/date-time/formats/manage/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.block_content.default','/admin/structure/block-content/manage/{block_content_type}/form-display','/admin/structure/block-content/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block-content/manage/{block_content_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:52:\"/admin/structure/block-content/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.block_content.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}','/admin/structure/block-content/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:54:\"/admin/structure/block-content/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.comment.default','/admin/structure/comment/manage/{comment_type}/form-display','/admin/structure/comment/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/comment/manage/{comment_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/comment/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.comment.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}','/admin/structure/comment/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/comment/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.contact_message.default','/admin/structure/contact/manage/{contact_form}/form-display','/admin/structure/contact/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/contact/manage/{contact_form}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/contact/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.contact_message.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}','/admin/structure/contact/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/contact/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.menu_link_content.default','/admin/structure/menu/manage/{menu}/form-display','/admin/structure/menu/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/menu/manage/{menu}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:41:\"administer menu_link_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/menu/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.menu_link_content.form_mode','/admin/structure/menu/manage/{menu}/form-display/{form_mode_name}','/admin/structure/menu/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/menu/manage/{menu}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:41:\"administer menu_link_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:45:\"/admin/structure/menu/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.node.default','/admin/structure/types/manage/{node_type}/form-display','/admin/structure/types/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/types/manage/{node_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/types/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.node.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}','/admin/structure/types/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/types/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.taxonomy_term.default','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display','/admin/structure/taxonomy/manage/%/overview/form-display',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/taxonomy/manage/%/overview/form-display\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.taxonomy_term.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}','/admin/structure/taxonomy/manage/%/overview/form-display/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:58:\"/admin/structure/taxonomy/manage/%/overview/form-display/%\";s:8:\"numParts\";i:8;}}',8),('entity.entity_form_display.user.default','/admin/config/people/accounts/form-display','/admin/config/people/accounts/form-display',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/people/accounts/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer user form display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/config/people/accounts/form\\-display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:42:\"/admin/config/people/accounts/form-display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_form_display.user.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}','/admin/config/people/accounts/form-display/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/people/accounts/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer user form display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/people/accounts/form-display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_mode.add_form','/admin/structure/display-modes/form/add/{entity_type_id}','/admin/structure/display-modes/form/add/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/display-modes/form/add/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"entity_form_mode.add\";s:6:\"_title\";s:13:\"Add form mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/display\\-modes/form/add/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/form/add\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/structure/display-modes/form/add/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_mode.collection','/admin/structure/display-modes/form','/admin/structure/display-modes/form',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/display-modes/form\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"entity_form_mode\";s:6:\"_title\";s:10:\"Form modes\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/display\\-modes/form$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/structure/display-modes/form\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/structure/display-modes/form\";s:8:\"numParts\";i:4;}}',4),('entity.entity_form_mode.config_translation_overview','/admin/structure/display-modes/form/manage/{entity_form_mode}/translate','/admin/structure/display-modes/form/manage/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/display-modes/form/manage/{entity_form_mode}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:16:\"entity_form_mode\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/structure/display-modes/form/manage/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_mode.delete_form','/admin/structure/display-modes/form/manage/{entity_form_mode}/delete','/admin/structure/display-modes/form/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/display-modes/form/manage/{entity_form_mode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"entity_form_mode.delete\";s:6:\"_title\";s:16:\"Delete form mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_form_mode.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/structure/display-modes/form/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_mode.edit_form','/admin/structure/display-modes/form/manage/{entity_form_mode}','/admin/structure/display-modes/form/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/display-modes/form/manage/{entity_form_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"entity_form_mode.edit\";s:6:\"_title\";s:14:\"Edit form mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_form_mode.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/structure/display-modes/form/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.block_content.default','/admin/structure/block-content/manage/{block_content_type}/display','/admin/structure/block-content/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/block-content/manage/{block_content_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:47:\"/admin/structure/block-content/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.block_content.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}','/admin/structure/block-content/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:49:\"/admin/structure/block-content/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.comment.default','/admin/structure/comment/manage/{comment_type}/display','/admin/structure/comment/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/comment/manage/{comment_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/comment/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.comment.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}','/admin/structure/comment/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:43:\"/admin/structure/comment/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.contact_message.default','/admin/structure/contact/manage/{contact_form}/display','/admin/structure/contact/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/contact/manage/{contact_form}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/contact/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.contact_message.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}','/admin/structure/contact/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:43:\"/admin/structure/contact/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.menu_link_content.default','/admin/structure/menu/manage/{menu}/display','/admin/structure/menu/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/structure/menu/manage/{menu}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:36:\"administer menu_link_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/menu/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.menu_link_content.view_mode','/admin/structure/menu/manage/{menu}/display/{view_mode_name}','/admin/structure/menu/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/menu/manage/{menu}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:36:\"administer menu_link_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:40:\"/admin/structure/menu/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.node.default','/admin/structure/types/manage/{node_type}/display','/admin/structure/types/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/types/manage/{node_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/types/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.node.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}','/admin/structure/types/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:41:\"/admin/structure/types/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.taxonomy_term.default','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display','/admin/structure/taxonomy/manage/%/overview/display',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/taxonomy/manage/%/overview/display\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.taxonomy_term.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}','/admin/structure/taxonomy/manage/%/overview/display/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:53:\"/admin/structure/taxonomy/manage/%/overview/display/%\";s:8:\"numParts\";i:8;}}',8),('entity.entity_view_display.user.default','/admin/config/people/accounts/display','/admin/config/people/accounts/display',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/people/accounts/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/people/accounts/display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/people/accounts/display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_view_display.user.view_mode','/admin/config/people/accounts/display/{view_mode_name}','/admin/config/people/accounts/display/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/people/accounts/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:39:\"/admin/config/people/accounts/display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_mode.add_form','/admin/structure/display-modes/view/add/{entity_type_id}','/admin/structure/display-modes/view/add/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/display-modes/view/add/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"entity_view_mode.add\";s:6:\"_title\";s:13:\"Add view mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/display\\-modes/view/add/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/view/add\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/structure/display-modes/view/add/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_mode.collection','/admin/structure/display-modes/view','/admin/structure/display-modes/view',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/display-modes/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"entity_view_mode\";s:6:\"_title\";s:10:\"View modes\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/display\\-modes/view$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/structure/display-modes/view\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/structure/display-modes/view\";s:8:\"numParts\";i:4;}}',4),('entity.entity_view_mode.config_translation_overview','/admin/structure/display-modes/view/manage/{entity_view_mode}/translate','/admin/structure/display-modes/view/manage/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/display-modes/view/manage/{entity_view_mode}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:16:\"entity_view_mode\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/structure/display-modes/view/manage/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_mode.delete_form','/admin/structure/display-modes/view/manage/{entity_view_mode}/delete','/admin/structure/display-modes/view/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/display-modes/view/manage/{entity_view_mode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"entity_view_mode.delete\";s:6:\"_title\";s:16:\"Delete view mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_view_mode.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/structure/display-modes/view/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_mode.edit_form','/admin/structure/display-modes/view/manage/{entity_view_mode}','/admin/structure/display-modes/view/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/display-modes/view/manage/{entity_view_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"entity_view_mode.edit\";s:6:\"_title\";s:14:\"Edit view mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_view_mode.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/structure/display-modes/view/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.field_config.block_content_field_delete_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete','/admin/structure/block-content/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/block-content/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.block_content_field_edit_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}','/admin/structure/block-content/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/block-content/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.comment_field_delete_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}/delete','/admin/structure/comment/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/comment/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.comment_field_edit_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}','/admin/structure/comment/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:42:\"/admin/structure/comment/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.config_translation_overview.block_content','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/translate','/admin/structure/block-content/manage/%/fields/%/translate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:20:\"block_content_fields\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:118:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/block-content/manage/%/fields/%/translate\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.config_translation_overview.comment','/admin/structure/comment/manage/{comment_type}/fields/{field_config}/translate','/admin/structure/comment/manage/%/fields/%/translate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:14:\"comment_fields\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/comment/manage/%/fields/%/translate\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.config_translation_overview.contact_message','/admin/structure/contact/manage/{contact_form}/fields/{field_config}/translate','/admin/structure/contact/manage/%/fields/%/translate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:22:\"contact_message_fields\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/contact/manage/%/fields/%/translate\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.config_translation_overview.menu_link_content','/admin/structure/menu/manage/{menu}/fields/{field_config}/translate','/admin/structure/menu/manage/%/fields/%/translate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/menu/manage/{menu}/fields/{field_config}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:24:\"menu_link_content_fields\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields/(?P<field_config>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/menu/manage/%/fields/%/translate\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.config_translation_overview.node','/admin/structure/types/manage/{node_type}/fields/{field_config}/translate','/admin/structure/types/manage/%/fields/%/translate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/types/manage/{node_type}/fields/{field_config}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:11:\"node_fields\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/types/manage/%/fields/%/translate\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.config_translation_overview.taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/translate','/admin/structure/taxonomy/manage/%/overview/fields/%/translate',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:95:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:20:\"taxonomy_term_fields\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:62:\"/admin/structure/taxonomy/manage/%/overview/fields/%/translate\";s:8:\"numParts\";i:9;}}',9),('entity.field_config.config_translation_overview.user','/admin/config/people/accounts/fields/{field_config}/translate','/admin/config/people/accounts/fields/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/people/accounts/fields/{field_config}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:11:\"user_fields\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/config/people/accounts/fields/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.contact_message_field_delete_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete','/admin/structure/contact/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/contact/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.contact_message_field_edit_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}','/admin/structure/contact/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:42:\"/admin/structure/contact/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.menu_link_content_field_delete_form','/admin/structure/menu/manage/{menu}/fields/{field_config}/delete','/admin/structure/menu/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/menu/manage/{menu}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:46:\"/admin/structure/menu/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.menu_link_content_field_edit_form','/admin/structure/menu/manage/{menu}/fields/{field_config}','/admin/structure/menu/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/menu/manage/{menu}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:39:\"/admin/structure/menu/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.node_field_delete_form','/admin/structure/types/manage/{node_type}/fields/{field_config}/delete','/admin/structure/types/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/types/manage/{node_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:97:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/types/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.node_field_edit_form','/admin/structure/types/manage/{node_type}/fields/{field_config}','/admin/structure/types/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/types/manage/{node_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:40:\"/admin/structure/types/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.taxonomy_term_field_delete_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete','/admin/structure/taxonomy/manage/%/overview/fields/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:59:\"/admin/structure/taxonomy/manage/%/overview/fields/%/delete\";s:8:\"numParts\";i:9;}}',9),('entity.field_config.taxonomy_term_field_edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}','/admin/structure/taxonomy/manage/%/overview/fields/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:52:\"/admin/structure/taxonomy/manage/%/overview/fields/%\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.user_field_delete_form','/admin/config/people/accounts/fields/{field_config}/delete','/admin/config/people/accounts/fields/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/config/people/accounts/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:45:\"/admin/config/people/accounts/fields/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.user_field_edit_form','/admin/config/people/accounts/fields/{field_config}','/admin/config/people/accounts/fields/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/people/accounts/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/people/accounts/fields/%\";s:8:\"numParts\";i:6;}}',6),('entity.field_storage_config.collection','/admin/reports/fields','/admin/reports/fields',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:20:\"field_storage_config\";s:6:\"_title\";s:10:\"Field list\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/fields\";s:8:\"numParts\";i:3;}}',3),('entity.file.delete_form','/file/{file}/delete','/file/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/file/{file}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"file.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:4:\"file\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"file.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"file\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"file\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/file/(?P<file>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"file\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/file\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"file\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/file/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.filter_format.config_translation_overview','/admin/config/content/formats/manage/{filter_format}/translate','/admin/config/content/formats/manage/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/config/content/formats/manage/{filter_format}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:13:\"filter_format\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/config/content/formats/manage/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.filter_format.disable','/admin/config/content/formats/manage/{filter_format}/disable','/admin/config/content/formats/manage/%/disable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/content/formats/manage/{filter_format}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"filter_format.disable\";s:6:\"_title\";s:19:\"Disable text format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:21:\"filter_format.disable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/content/formats/manage/%/disable\";s:8:\"numParts\";i:7;}}',7),('entity.filter_format.edit_form','/admin/config/content/formats/manage/{filter_format}','/admin/config/content/formats/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/content/formats/manage/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"filter_format.edit\";s:15:\"_title_callback\";s:52:\"\\Drupal\\filter\\Controller\\FilterController::getLabel\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:20:\"filter_format.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/content/formats/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.filter_format.enable','/admin/config/content/formats/manage/{filter_format}/enable','/admin/config/content/formats/manage/%/enable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/content/formats/manage/{filter_format}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"filter_format.enable\";s:6:\"_title\";s:18:\"Enable text format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:20:\"filter_format.enable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:45:\"/admin/config/content/formats/manage/%/enable\";s:8:\"numParts\";i:7;}}',7),('entity.image_style.collection','/admin/config/media/image-styles','/admin/config/media/image-styles',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/media/image-styles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"image_style\";s:6:\"_title\";s:12:\"Image styles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/media/image\\-styles$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/media/image-styles\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/media/image-styles\";s:8:\"numParts\";i:4;}}',4),('entity.image_style.config_translation_overview','/admin/config/media/image-styles/manage/{image_style}/translate','/admin/config/media/image-styles/manage/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/media/image-styles/manage/{image_style}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:11:\"image_style\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/media/image-styles/manage/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.image_style.delete_form','/admin/config/media/image-styles/manage/{image_style}/delete','/admin/config/media/image-styles/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/media/image-styles/manage/{image_style}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"image_style.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"image_style.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/config/media/image-styles/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.image_style.edit_form','/admin/config/media/image-styles/manage/{image_style}','/admin/config/media/image-styles/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/media/image-styles/manage/{image_style}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"image_style.edit\";s:6:\"_title\";s:10:\"Edit style\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/config/media/image-styles/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.image_style.flush_form','/admin/config/media/image-styles/manage/{image_style}/flush','/admin/config/media/image-styles/manage/%/flush',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/media/image-styles/manage/{image_style}/flush\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"image_style.flush\";s:6:\"_title\";s:5:\"Flush\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/flush$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/flush\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:47:\"/admin/config/media/image-styles/manage/%/flush\";s:8:\"numParts\";i:7;}}',7),('entity.jsonapi_resource_config.add_form','/admin/config/services/jsonapi/add/resource_types/{entity_type_id}/{bundle}','/admin/config/services/jsonapi/add/resource_types/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/config/services/jsonapi/add/resource_types/{entity_type_id}/{bundle}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:27:\"jsonapi_resource_config.add\";s:14:\"entity_type_id\";s:23:\"jsonapi_resource_config\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:23:\"jsonapi_resource_config\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"entity_type_id\";i:1;s:6:\"bundle\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/config/services/jsonapi/add/resource_types/(?P<entity_type_id>[^/]++)/(?P<bundle>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"bundle\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:49:\"/admin/config/services/jsonapi/add/resource_types\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"entity_type_id\";i:1;s:6:\"bundle\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:51:\"/admin/config/services/jsonapi/add/resource_types/%\";s:8:\"numParts\";i:8;}}',8),('entity.jsonapi_resource_config.collection','/admin/config/services/jsonapi/resource_types','/admin/config/services/jsonapi/resource_types',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/services/jsonapi/resource_types\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:23:\"jsonapi_resource_config\";s:6:\"_title\";s:27:\"JSON:API Resource overrides\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/config/services/jsonapi/resource_types$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/services/jsonapi/resource_types\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:45:\"/admin/config/services/jsonapi/resource_types\";s:8:\"numParts\";i:5;}}',5),('entity.jsonapi_resource_config.config_translation_overview','/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate','/admin/config/services/jsonapi/resource_types/%/edit/translate',251,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:23:\"jsonapi_resource_config\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:23:\"jsonapi_resource_config\";a:2:{s:4:\"type\";s:30:\"entity:jsonapi_resource_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:23:\"jsonapi_resource_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/config/services/jsonapi/resource_types/(?P<jsonapi_resource_config>[^/]++)/edit/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:23:\"jsonapi_resource_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/services/jsonapi/resource_types\";}}s:9:\"path_vars\";a:1:{i:0;s:23:\"jsonapi_resource_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:62:\"/admin/config/services/jsonapi/resource_types/%/edit/translate\";s:8:\"numParts\";i:8;}}',8),('entity.jsonapi_resource_config.delete_form','/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/delete','/admin/config/services/jsonapi/resource_types/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:30:\"jsonapi_resource_config.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:30:\"jsonapi_resource_config.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:23:\"jsonapi_resource_config\";a:2:{s:4:\"type\";s:30:\"entity:jsonapi_resource_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:23:\"jsonapi_resource_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/config/services/jsonapi/resource_types/(?P<jsonapi_resource_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:23:\"jsonapi_resource_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/services/jsonapi/resource_types\";}}s:9:\"path_vars\";a:1:{i:0;s:23:\"jsonapi_resource_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/config/services/jsonapi/resource_types/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.jsonapi_resource_config.edit_form','/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit','/admin/config/services/jsonapi/resource_types/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/config/services/jsonapi/resource_types/{jsonapi_resource_config}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:28:\"jsonapi_resource_config.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:30:\"jsonapi_resource_config.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:23:\"jsonapi_resource_config\";a:2:{s:4:\"type\";s:30:\"entity:jsonapi_resource_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:23:\"jsonapi_resource_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/config/services/jsonapi/resource_types/(?P<jsonapi_resource_config>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:23:\"jsonapi_resource_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/services/jsonapi/resource_types\";}}s:9:\"path_vars\";a:1:{i:0;s:23:\"jsonapi_resource_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:52:\"/admin/config/services/jsonapi/resource_types/%/edit\";s:8:\"numParts\";i:7;}}',7),('entity.linkit_profile.add_form','/admin/config/content/linkit/add','/admin/config/content/linkit/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/content/linkit/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"linkit_profile.add\";s:6:\"_title\";s:11:\"Add profile\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/content/linkit/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/content/linkit/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:32:\"/admin/config/content/linkit/add\";s:8:\"numParts\";i:5;}}',5),('entity.linkit_profile.collection','/admin/config/content/linkit','/admin/config/content/linkit',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/config/content/linkit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:14:\"linkit_profile\";s:6:\"_title\";s:15:\"Linkit profiles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/config/content/linkit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/content/linkit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/config/content/linkit\";s:8:\"numParts\";i:4;}}',4),('entity.linkit_profile.config_translation_overview','/admin/config/content/linkit/manage/{linkit_profile}/translate','/admin/config/content/linkit/manage/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/config/content/linkit/manage/{linkit_profile}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:14:\"linkit_profile\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:47:\"/admin/config/content/linkit/manage/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.linkit_profile.delete_form','/admin/config/content/linkit/manage/{linkit_profile}/delete','/admin/config/content/linkit/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/content/linkit/manage/{linkit_profile}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:21:\"linkit_profile.delete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:44:\"/admin/config/content/linkit/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.linkit_profile.edit_form','/admin/config/content/linkit/manage/{linkit_profile}','/admin/config/content/linkit/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/content/linkit/manage/{linkit_profile}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"linkit_profile.edit\";s:15:\"_title_callback\";s:55:\"Drupal\\linkit\\Controller\\LinkitController::profileTitle\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:37:\"/admin/config/content/linkit/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.menu.add_form','/admin/structure/menu/add','/admin/structure/menu/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/structure/menu/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:8:\"menu.add\";s:6:\"_title\";s:8:\"Add menu\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/structure/menu/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/structure/menu/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/structure/menu/add\";s:8:\"numParts\";i:4;}}',4),('entity.menu.add_link_form','/admin/structure/menu/manage/{menu}/add','/admin/structure/menu/manage/%/add',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/menu/manage/{menu}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"Drupal\\menu_item_extras\\Controller\\MenuController::addLink\";s:6:\"_title\";s:13:\"Add menu link\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:17:\"menu_link_content\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/menu/manage/%/add\";s:8:\"numParts\";i:6;}}',6),('entity.menu.clear_extra_data','/admin/structure/menu/manage/{menu}/clear','/admin/structure/menu/manage/%/clear',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/menu/manage/{menu}/clear\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:10:\"menu.clear\";s:15:\"_title_callback\";s:52:\"\\Drupal\\menu_ui\\Controller\\MenuController::menuTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/clear$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/clear\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/menu/manage/%/clear\";s:8:\"numParts\";i:6;}}',6),('entity.menu.collection','/admin/structure/menu','/admin/structure/menu',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/structure/menu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:4:\"menu\";s:6:\"_title\";s:5:\"Menus\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/structure/menu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/structure/menu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/structure/menu\";s:8:\"numParts\";i:3;}}',3),('entity.menu.config_translation_overview','/admin/structure/menu/manage/{menu}/translate','/admin/structure/menu/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/menu/manage/{menu}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:4:\"menu\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/menu/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.menu.delete_form','/admin/structure/menu/manage/{menu}/delete','/admin/structure/menu/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/menu/manage/{menu}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"menu.delete\";s:6:\"_title\";s:11:\"Delete menu\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/menu/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.menu.edit_form','/admin/structure/menu/manage/{menu}','/admin/structure/menu/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/menu/manage/{menu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:9:\"menu.edit\";s:15:\"_title_callback\";s:52:\"\\Drupal\\menu_ui\\Controller\\MenuController::menuTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:30:\"/admin/structure/menu/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.menu.view_modes_settings','/admin/structure/menu/manage/{menu}/view_modes_settings/default','/admin/structure/menu/manage/%/view_modes_settings/default',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/menu/manage/{menu}/view_modes_settings/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"menu.view_modes_settings\";s:15:\"_title_callback\";s:52:\"\\Drupal\\menu_ui\\Controller\\MenuController::menuTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/view_modes_settings/default$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/view_modes_settings/default\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:58:\"/admin/structure/menu/manage/%/view_modes_settings/default\";s:8:\"numParts\";i:7;}}',7),('entity.menu_link_content.canonical','/admin/structure/menu/item/{menu_link_content}/edit','/admin/structure/menu/item/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"menu_link_content.default\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/item/%/edit\";s:8:\"numParts\";i:6;}}',6),('entity.menu_link_content.delete_form','/admin/structure/menu/item/{menu_link_content}/delete','/admin/structure/menu/item/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/menu/item/{menu_link_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"menu_link_content.delete\";s:6:\"_title\";s:16:\"Delete menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:35:\"/admin/structure/menu/item/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.menu_link_content.edit_form','/admin/structure/menu/item/{menu_link_content}/edit','/admin/structure/menu/item/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"menu_link_content.default\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/item/%/edit\";s:8:\"numParts\";i:6;}}',6),('entity.menu_link_content.field_ui_fields','/admin/structure/menu/manage/{menu}/fields','/admin/structure/menu/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/menu/manage/{menu}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:35:\"administer menu_link_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/menu/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.metatag_defaults.add_form','/admin/config/search/metatag/add','/admin/config/search/metatag/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/search/metatag/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"metatag_defaults.add\";s:6:\"_title\";s:21:\"Add default meta tags\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/search/metatag/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/search/metatag/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:32:\"/admin/config/search/metatag/add\";s:8:\"numParts\";i:5;}}',5),('entity.metatag_defaults.collection','/admin/config/search/metatag','/admin/config/search/metatag',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/config/search/metatag\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"metatag_defaults\";s:6:\"_title\";s:7:\"Metatag\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/config/search/metatag$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/config/search/metatag\";s:8:\"numParts\";i:4;}}',4),('entity.metatag_defaults.config_translation_overview','/admin/config/search/metatag/{metatag_defaults}/translate','/admin/config/search/metatag/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/config/search/metatag/{metatag_defaults}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:16:\"metatag_defaults\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/config/search/metatag/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.metatag_defaults.delete_form','/admin/config/search/metatag/{metatag_defaults}/delete','/admin/config/search/metatag/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/search/metatag/{metatag_defaults}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"metatag_defaults.delete\";s:6:\"_title\";s:24:\"Delete default meta tags\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/config/search/metatag/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.metatag_defaults.edit_form','/admin/config/search/metatag/{metatag_defaults}','/admin/config/search/metatag/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/search/metatag/{metatag_defaults}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"metatag_defaults.edit\";s:15:\"_title_callback\";s:50:\"\\Drupal\\metatag\\Form\\MetatagDefaultsForm::getTitle\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:30:\"/admin/config/search/metatag/%\";s:8:\"numParts\";i:5;}}',5),('entity.metatag_defaults.revert_form','/admin/config/search/metatag/{metatag_defaults}/revert','/admin/config/search/metatag/%/revert',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/search/metatag/{metatag_defaults}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"metatag_defaults.revert\";s:6:\"_title\";s:24:\"Revert default meta tags\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/config/search/metatag/%/revert\";s:8:\"numParts\";i:6;}}',6),('entity.node.canonical','/node/{node}','/node/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/node/{node}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\node\\Controller\\NodeViewController::view\";s:15:\"_title_callback\";s:49:\"\\Drupal\\node\\Controller\\NodeViewController::title\";}s:12:\"requirements\";a:2:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"node.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/node/(?P<node>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/node/%\";s:8:\"numParts\";i:2;}}',2),('entity.node.delete_form','/node/{node}/delete','/node/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/node/{node}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"node.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"node.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/node/(?P<node>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/node/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.node.delete_multiple_form','/admin/content/node/delete','/admin/content/node/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/content/node/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\node\\Form\\DeleteMultiple\";s:14:\"entity_type_id\";s:4:\"node\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:4:\"node\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/node/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/node/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/content/node/delete\";s:8:\"numParts\";i:4;}}',4),('entity.node.edit_form','/node/{node}/edit','/node/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/node/{node}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:9:\"node.edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"node.update\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/node/(?P<node>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:12:\"/node/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.node.field_ui_fields','/admin/structure/types/manage/{node_type}/fields','/admin/structure/types/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/types/manage/{node_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/types/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.node.preview','/node/preview/{node_preview}/{view_mode_id}','/node/preview/%/%',12,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/node/preview/{node_preview}/{view_mode_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"\\Drupal\\node\\Controller\\NodePreviewController::view\";s:15:\"_title_callback\";s:52:\"\\Drupal\\node\\Controller\\NodePreviewController::title\";}s:12:\"requirements\";a:1:{s:20:\"_node_preview_access\";s:14:\"{node_preview}\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"node_preview\";a:2:{s:4:\"type\";s:12:\"node_preview\";s:9:\"converter\";s:42:\"drupal.proxy_original_service.node_preview\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:25:\"access_check.node.preview\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"node_preview\";i:1;s:12:\"view_mode_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/node/preview/(?P<node_preview>[^/]++)/(?P<view_mode_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"view_mode_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"node_preview\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/node/preview\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"node_preview\";i:1;s:12:\"view_mode_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:12;s:14:\"patternOutline\";s:17:\"/node/preview/%/%\";s:8:\"numParts\";i:4;}}',4),('entity.node.revision','/node/{node}/revisions/{node_revision}/view','/node/%/revisions/%/view',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/node/{node}/revisions/{node_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\node\\Controller\\NodeController::revisionShow\";s:15:\"_title_callback\";s:57:\"\\Drupal\\node\\Controller\\NodeController::revisionPageTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"node_revision.view revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:24:\"/node/%/revisions/%/view\";s:8:\"numParts\";i:5;}}',5),('entity.node.version_history','/node/{node}/revisions','/node/%/revisions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/node/{node}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:9:\"Revisions\";s:11:\"_controller\";s:64:\"\\Drupal\\diff\\Controller\\NodeRevisionController::revisionOverview\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:23:\"node.view all revisions\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/node/(?P<node>\\d+)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/node/%/revisions\";s:8:\"numParts\";i:3;}}',3),('entity.node.webform.confirmation','/node/{node}/webform/confirmation','/node/%/webform/confirmation',11,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/node/{node}/webform/confirmation\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::confirmation\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:9:\"operation\";s:4:\"view\";s:13:\"entity_access\";s:25:\"webform.submission_create\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:3:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/node/(?P<node>[^/]++)/webform/confirmation$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/webform/confirmation\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:28:\"/node/%/webform/confirmation\";s:8:\"numParts\";i:4;}}',4),('entity.node.webform.entity_reference.set','/node/{node}/webform/change/{webform}','/node/%/webform/change/%',22,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/node/{node}/webform/change/{webform}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:76:\"\\Drupal\\webform_node\\Controller\\WebformNodeEntityReferenceController::change\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";}s:12:\"requirements\";a:2:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.custom\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/node/(?P<node>[^/]++)/webform/change/(?P<webform>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/webform/change\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:22;s:14:\"patternOutline\";s:24:\"/node/%/webform/change/%\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform.results_clear','/node/{node}/webform/results/clear','/node/%/webform/results/clear',23,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/node/{node}/webform/results/clear\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"Drupal\\webform\\Form\\WebformResultsClearForm\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:9:\"operation\";s:25:\"webform_submission_delete\";s:13:\"entity_access\";s:28:\"webform.submission_purge_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/node/(?P<node>[^/]++)/webform/results/clear$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/webform/results/clear\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:23;s:14:\"patternOutline\";s:29:\"/node/%/webform/results/clear\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform.results_export','/node/{node}/webform/results/download','/node/%/webform/results/download',23,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/node/{node}/webform/results/download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformResultsExportController::index\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/node/(?P<node>[^/]++)/webform/results/download$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/webform/results/download\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:23;s:14:\"patternOutline\";s:32:\"/node/%/webform/results/download\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform.results_export_file','/node/{node}/webform/results/download/file/{filename}','/node/%/webform/results/download/file/%',94,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/node/{node}/webform/results/download/file/{filename}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:63:\"\\Drupal\\webform\\Controller\\WebformResultsExportController::file\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"filename\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/node/(?P<node>[^/]++)/webform/results/download/file/(?P<filename>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"filename\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/webform/results/download/file\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"filename\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:94;s:14:\"patternOutline\";s:39:\"/node/%/webform/results/download/file/%\";s:8:\"numParts\";i:7;}}',7),('entity.node.webform.results_submissions','/node/{node}/webform/results/submissions/{submission_view}','/node/%/webform/results/submissions',23,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/node/{node}/webform/results/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:15:\"submission_view\";s:0:\"\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/node/(?P<node>[^/]++)/webform/results/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/webform/results/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:23;s:14:\"patternOutline\";s:35:\"/node/%/webform/results/submissions\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform.results_submissions.custom','/node/{node}/webform/results/submissions/custom','/node/%/webform/results/submissions/custom',47,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/node/{node}/webform/results/submissions/custom\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:44:\"Drupal\\webform\\Form\\WebformResultsCustomForm\";s:6:\"_title\";s:15:\"Customize table\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/node/(?P<node>[^/]++)/webform/results/submissions/custom$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/webform/results/submissions/custom\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:47;s:14:\"patternOutline\";s:42:\"/node/%/webform/results/submissions/custom\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform.results_submissions.custom.user','/node/{node}/webform/results/submissions/custom/user','/node/%/webform/results/submissions/custom/user',95,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/node/{node}/webform/results/submissions/custom/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:5:\"_form\";s:44:\"Drupal\\webform\\Form\\WebformResultsCustomForm\";s:6:\"_title\";s:18:\"Customize my table\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";s:4:\"type\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>[^/]++)/webform/results/submissions/custom/user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/webform/results/submissions/custom/user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:95;s:14:\"patternOutline\";s:47:\"/node/%/webform/results/submissions/custom/user\";s:8:\"numParts\";i:7;}}',7),('entity.node.webform.test_form','/node/{node}/webform/test','/node/%/webform/test',11,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/node/{node}/webform/test\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:58:\"\\Drupal\\webform\\Controller\\WebformTestController::testForm\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:12:\"webform.test\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/node/(?P<node>[^/]++)/webform/test$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/webform/test\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:20:\"/node/%/webform/test\";s:8:\"numParts\";i:4;}}',4),('entity.node.webform.user.drafts','/node/{node}/webform/drafts/{submission_view}','/node/%/webform/drafts',11,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/webform/drafts/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:6:\"Drafts\";s:15:\"submission_view\";s:0:\"\";s:9:\"operation\";s:4:\"view\";s:13:\"entity_access\";s:25:\"webform.submission_create\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:71:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformDraftsAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/node/(?P<node>[^/]++)/webform/drafts(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/webform/drafts\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:22:\"/node/%/webform/drafts\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform.user.submission','/node/{node}/webform/submissions/{webform_submission}','/node/%/webform/submissions/%',22,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/node/{node}/webform/submissions/{webform_submission}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"html\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:23:\"webform_submission.view\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/node/(?P<node>[^/]++)/webform/submissions/(?P<webform_submission>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/webform/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:22;s:14:\"patternOutline\";s:29:\"/node/%/webform/submissions/%\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform.user.submission.delete','/node/{node}/webform/submissions/{webform_submission}/delete','/node/%/webform/submissions/%/delete',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/node/{node}/webform/submissions/{webform_submission}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:25:\"webform_submission.delete\";s:6:\"_title\";s:25:\"Delete webform submission\";s:9:\"operation\";s:25:\"webform_submission_delete\";s:13:\"entity_access\";s:25:\"webform_submission.delete\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/node/(?P<node>[^/]++)/webform/submissions/(?P<webform_submission>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/webform/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:36:\"/node/%/webform/submissions/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform.user.submission.duplicate','/node/{node}/webform/submissions/{webform_submission}/duplicate','/node/%/webform/submissions/%/duplicate',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/node/{node}/webform/submissions/{webform_submission}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:28:\"webform_submission.duplicate\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"duplicate\";b:1;s:9:\"operation\";s:28:\"webform_submission_duplicate\";s:13:\"entity_access\";s:25:\"webform_submission.update\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/node/(?P<node>[^/]++)/webform/submissions/(?P<webform_submission>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/webform/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:39:\"/node/%/webform/submissions/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform.user.submission.edit','/node/{node}/webform/submissions/{webform_submission}/edit','/node/%/webform/submissions/%/edit',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/node/{node}/webform/submissions/{webform_submission}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:23:\"webform_submission.edit\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"operation\";s:23:\"webform_submission_edit\";s:13:\"entity_access\";s:25:\"webform_submission.update\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/node/(?P<node>[^/]++)/webform/submissions/(?P<webform_submission>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/webform/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:34:\"/node/%/webform/submissions/%/edit\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform.user.submissions','/node/{node}/webform/submissions/{submission_view}','/node/%/webform/submissions',11,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/node/{node}/webform/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:11:\"Submissions\";s:15:\"submission_view\";s:0:\"\";s:9:\"operation\";s:0:\"\";s:13:\"entity_access\";s:27:\"webform.submission_view_own\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/node/(?P<node>[^/]++)/webform/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/webform/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:27:\"/node/%/webform/submissions\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform_options_limit.summary','/node/{node}/webform/results/options-limit','/node/%/webform/results/options-limit',23,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/node/{node}/webform/results/options-limit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:77:\"\\Drupal\\webform_options_limit\\Controller\\WebformOptionsLimitController::index\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:79:\"\\Drupal\\webform_options_limit\\Access\\WebformOptionsLimitAccess::checkNodeAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/node/(?P<node>[^/]++)/webform/results/options\\-limit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/webform/results/options-limit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:23;s:14:\"patternOutline\";s:37:\"/node/%/webform/results/options-limit\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform_submission.canonical','/node/{node}/webform/submission/{webform_submission}','/node/%/webform/submission/%',22,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/node/{node}/webform/submission/{webform_submission}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"html\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:23:\"webform_submission.view\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:22;s:14:\"patternOutline\";s:28:\"/node/%/webform/submission/%\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform_submission.delete_form','/node/{node}/webform/submission/{webform_submission}/delete','/node/%/webform/submission/%/delete',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/node/{node}/webform/submission/{webform_submission}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:25:\"webform_submission.delete\";s:6:\"_title\";s:25:\"Delete webform submission\";s:9:\"operation\";s:25:\"webform_submission_delete\";s:13:\"entity_access\";s:25:\"webform_submission.delete\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:35:\"/node/%/webform/submission/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform_submission.duplicate_form','/node/{node}/webform/submission/{webform_submission}/duplicate','/node/%/webform/submission/%/duplicate',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/node/{node}/webform/submission/{webform_submission}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:28:\"webform_submission.duplicate\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"operation\";s:28:\"webform_submission_duplicate\";s:13:\"entity_access\";s:28:\"webform_submission.duplicate\";s:9:\"duplicate\";b:1;}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:38:\"/node/%/webform/submission/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform_submission.edit_form','/node/{node}/webform/submission/{webform_submission}/edit','/node/%/webform/submission/%/edit',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/node/{node}/webform/submission/{webform_submission}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:23:\"webform_submission.edit\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"operation\";s:23:\"webform_submission_edit\";s:13:\"entity_access\";s:25:\"webform_submission.update\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:33:\"/node/%/webform/submission/%/edit\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform_submission.edit_form.all','/node/{node}/webform/submission/{webform_submission}/edit/all','/node/%/webform/submission/%/edit/all',91,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/node/{node}/webform/submission/{webform_submission}/edit/all\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:27:\"webform_submission.edit_all\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"operation\";s:27:\"webform_submission_edit_all\";s:13:\"entity_access\";s:25:\"webform_submission.update\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/edit/all$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/edit/all\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:91;s:14:\"patternOutline\";s:37:\"/node/%/webform/submission/%/edit/all\";s:8:\"numParts\";i:7;}}',7),('entity.node.webform_submission.notes_form','/node/{node}/webform/submission/{webform_submission}/notes','/node/%/webform/submission/%/notes',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/node/{node}/webform/submission/{webform_submission}/notes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"webform_submission.notes\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"operation\";s:24:\"webform_submission_notes\";s:13:\"entity_access\";s:29:\"webform_submission.update_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/notes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/notes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:34:\"/node/%/webform/submission/%/notes\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform_submission.resend_form','/node/{node}/webform/submission/{webform_submission}/resend','/node/%/webform/submission/%/resend',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/node/{node}/webform/submission/{webform_submission}/resend\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionResendForm\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"operation\";s:25:\"webform_submission_resend\";s:13:\"entity_access\";s:25:\"webform_submission.resend\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/resend$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/resend\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:35:\"/node/%/webform/submission/%/resend\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform_submission.table','/node/{node}/webform/submission/{webform_submission}/table','/node/%/webform/submission/%/table',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/node/{node}/webform/submission/{webform_submission}/table\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:5:\"table\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform_submission.view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/table$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/table\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:34:\"/node/%/webform/submission/%/table\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform_submission.text','/node/{node}/webform/submission/{webform_submission}/text','/node/%/webform/submission/%/text',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/node/{node}/webform/submission/{webform_submission}/text\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"text\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform_submission.view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/text$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/text\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:33:\"/node/%/webform/submission/%/text\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform_submission.yaml','/node/{node}/webform/submission/{webform_submission}/yaml','/node/%/webform/submission/%/yaml',45,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/node/{node}/webform/submission/{webform_submission}/yaml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"yaml\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform_submission.view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformSubmissionAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/node/(?P<node>[^/]++)/webform/submission/(?P<webform_submission>[^/]++)/yaml$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/yaml\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:45;s:14:\"patternOutline\";s:33:\"/node/%/webform/submission/%/yaml\";s:8:\"numParts\";i:6;}}',6),('entity.node.webform_submission_export_import.results_import','/node/{node}/webform/results/upload','/node/%/webform/results/upload',23,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/node/{node}/webform/results/upload\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:85:\"\\Drupal\\webform_submission_export_import\\Form\\WebformSubmissionExportImportUploadForm\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:9:\"operation\";s:25:\"webform_submission_update\";s:13:\"entity_access\";s:29:\"webform.submission_update_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/node/(?P<node>[^/]++)/webform/results/upload$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/webform/results/upload\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:23;s:14:\"patternOutline\";s:30:\"/node/%/webform/results/upload\";s:8:\"numParts\";i:5;}}',5),('entity.node.webform_submission_export_import.results_import.example.download','/node/{node}/webform/results/upload/example/download','/node/%/webform/results/upload/example/download',95,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/node/{node}/webform/results/upload/example/download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:101:\"\\Drupal\\webform_submission_export_import\\Controller\\WebformSubmissionExportImportController::download\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>[^/]++)/webform/results/upload/example/download$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/webform/results/upload/example/download\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:95;s:14:\"patternOutline\";s:47:\"/node/%/webform/results/upload/example/download\";s:8:\"numParts\";i:7;}}',7),('entity.node.webform_submission_export_import.results_import.example.view','/node/{node}/webform/results/upload/example/view','/node/%/webform/results/upload/example/view',95,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/node/{node}/webform/results/upload/example/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:97:\"\\Drupal\\webform_submission_export_import\\Controller\\WebformSubmissionExportImportController::view\";s:9:\"operation\";s:23:\"webform_submission_view\";s:13:\"entity_access\";s:27:\"webform.submission_view_any\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_node\\Access\\WebformNodeAccess::checkWebformResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/node/(?P<node>[^/]++)/webform/results/upload/example/view$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/webform/results/upload/example/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:95;s:14:\"patternOutline\";s:43:\"/node/%/webform/results/upload/example/view\";s:8:\"numParts\";i:7;}}',7),('entity.node_type.collection','/admin/structure/types','/admin/structure/types',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/types\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:9:\"node_type\";s:6:\"_title\";s:13:\"Content types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/types$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/types\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/types\";s:8:\"numParts\";i:3;}}',3),('entity.node_type.config_translation_overview','/admin/structure/types/manage/{node_type}/translate','/admin/structure/types/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/types/manage/{node_type}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/types/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.node_type.delete_form','/admin/structure/types/manage/{node_type}/delete','/admin/structure/types/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/types/manage/{node_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"node_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"node_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/types/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.node_type.edit_form','/admin/structure/types/manage/{node_type}','/admin/structure/types/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/types/manage/{node_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"node_type.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/types/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.node_type.entity_permissions_form','/admin/structure/types/manage/{node_type}/permissions','/admin/structure/types/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/types/manage/{node_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:4:\"node\";s:18:\"bundle_entity_type\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:3:{s:4:\"type\";s:16:\"entity:node_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/types/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.pathauto_pattern.add_form','/admin/config/search/path/patterns/add','/admin/config/search/path/patterns/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/config/search/path/patterns/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:24:\"pathauto_pattern.default\";s:6:\"_title\";s:20:\"Add Pathauto pattern\";s:12:\"tempstore_id\";s:16:\"pathauto.pattern\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"administer pathauto\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/search/path/patterns/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/config/search/path/patterns/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:38:\"/admin/config/search/path/patterns/add\";s:8:\"numParts\";i:6;}}',6),('entity.pathauto_pattern.collection','/admin/config/search/path/patterns','/admin/config/search/path/patterns',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/search/path/patterns\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"pathauto_pattern\";s:6:\"_title\";s:8:\"Patterns\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"administer pathauto\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/search/path/patterns$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/config/search/path/patterns\";s:8:\"numParts\";i:5;}}',5),('entity.pathauto_pattern.config_translation_overview','/admin/config/search/path/patterns/{pathauto_pattern}/translate','/admin/config/search/path/patterns/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/search/path/patterns/{pathauto_pattern}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:16:\"pathauto_pattern\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/search/path/patterns/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.pathauto_pattern.delete_form','/admin/config/search/path/patterns/{pathauto_pattern}/delete','/admin/config/search/path/patterns/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/search/path/patterns/{pathauto_pattern}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"pathauto_pattern.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"pathauto_pattern.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:43:\"/admin/config/search/path/patterns/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.pathauto_pattern.disable','/admin/config/search/path/patterns/{pathauto_pattern}/disable','/admin/config/search/path/patterns/%/disable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/search/path/patterns/{pathauto_pattern}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:24:\"pathauto_pattern.disable\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"pathauto_pattern.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:44:\"/admin/config/search/path/patterns/%/disable\";s:8:\"numParts\";i:7;}}',7),('entity.pathauto_pattern.duplicate_form','/admin/config/search/path/patterns/{pathauto_pattern}/duplicate','/admin/config/search/path/patterns/%/duplicate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/search/path/patterns/{pathauto_pattern}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:26:\"pathauto_pattern.duplicate\";s:6:\"_title\";s:26:\"Duplicate Pathauto pattern\";s:12:\"tempstore_id\";s:16:\"pathauto.pattern\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"administer pathauto\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/search/path/patterns/%/duplicate\";s:8:\"numParts\";i:7;}}',7),('entity.pathauto_pattern.edit_form','/admin/config/search/path/patterns/{pathauto_pattern}','/admin/config/search/path/patterns/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/search/path/patterns/{pathauto_pattern}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"pathauto_pattern.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"pathauto_pattern.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:36:\"/admin/config/search/path/patterns/%\";s:8:\"numParts\";i:6;}}',6),('entity.pathauto_pattern.enable','/admin/config/search/path/patterns/{pathauto_pattern}/enable','/admin/config/search/path/patterns/%/enable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/search/path/patterns/{pathauto_pattern}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:23:\"pathauto_pattern.enable\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"pathauto_pattern.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:43:\"/admin/config/search/path/patterns/%/enable\";s:8:\"numParts\";i:7;}}',7),('entity.path_alias.add_form','/admin/config/search/path/add','/admin/config/search/path/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/search/path/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:18:\"path_alias.default\";s:14:\"entity_type_id\";s:10:\"path_alias\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:10:\"path_alias\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/search/path/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/search/path/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:29:\"/admin/config/search/path/add\";s:8:\"numParts\";i:5;}}',5),('entity.path_alias.collection','/admin/config/search/path','/admin/config/search/path',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/search/path\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:10:\"path_alias\";s:6:\"_title\";s:11:\"URL aliases\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer url aliases\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/search/path$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/search/path\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/config/search/path\";s:8:\"numParts\";i:4;}}',4),('entity.path_alias.delete_form','/admin/config/search/path/delete/{path_alias}','/admin/config/search/path/delete/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/search/path/delete/{path_alias}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"path_alias.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"path_alias.delete\";s:10:\"path_alias\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"path_alias\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"path_alias\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/config/search/path/delete/(?P<path_alias>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:10:\"path_alias\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/search/path/delete\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"path_alias\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:34:\"/admin/config/search/path/delete/%\";s:8:\"numParts\";i:6;}}',6),('entity.path_alias.edit_form','/admin/config/search/path/edit/{path_alias}','/admin/config/search/path/edit/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/config/search/path/edit/{path_alias}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"path_alias.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"path_alias.update\";s:10:\"path_alias\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"path_alias\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"path_alias\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/config/search/path/edit/(?P<path_alias>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:10:\"path_alias\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/search/path/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"path_alias\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:32:\"/admin/config/search/path/edit/%\";s:8:\"numParts\";i:6;}}',6),('entity.redirect.canonical','/admin/config/search/redirect/edit/{redirect}','/admin/config/search/redirect/edit/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/search/redirect/edit/{redirect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"redirect.edit\";s:6:\"_title\";s:17:\"Edit URL redirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"redirect.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/config/search/redirect/edit/(?P<redirect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/redirect/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:36:\"/admin/config/search/redirect/edit/%\";s:8:\"numParts\";i:6;}}',6),('entity.redirect.delete_form','/admin/config/search/redirect/delete/{redirect}','/admin/config/search/redirect/delete/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/search/redirect/delete/{redirect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"redirect.delete\";s:6:\"_title\";s:19:\"Delete URL redirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"redirect.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/search/redirect/delete/(?P<redirect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/search/redirect/delete\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/search/redirect/delete/%\";s:8:\"numParts\";i:6;}}',6),('entity.redirect.edit_form','/admin/config/search/redirect/edit/{redirect}','/admin/config/search/redirect/edit/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/search/redirect/edit/{redirect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"redirect.edit\";s:6:\"_title\";s:17:\"Edit URL redirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"redirect.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/config/search/redirect/edit/(?P<redirect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/redirect/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:36:\"/admin/config/search/redirect/edit/%\";s:8:\"numParts\";i:6;}}',6),('entity.redirect.multiple_delete_confirm','/admin/config/search/redirect/delete','/admin/config/search/redirect/delete',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/search/redirect/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:48:\"\\Drupal\\redirect\\Form\\RedirectDeleteMultipleForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer redirects\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/search/redirect/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/search/redirect/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/search/redirect/delete\";s:8:\"numParts\";i:5;}}',5),('entity.shortcut.canonical','/admin/config/user-interface/shortcut/link/{shortcut}','/admin/config/user-interface/shortcut/link/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut.default\";s:6:\"_title\";s:4:\"Edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/user-interface/shortcut/link/%\";s:8:\"numParts\";i:6;}}',6),('entity.shortcut.delete_form','/admin/config/user-interface/shortcut/link/{shortcut}/delete','/admin/config/user-interface/shortcut/link/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"shortcut.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.delete\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/user-interface/shortcut/link/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut.edit_form','/admin/config/user-interface/shortcut/link/{shortcut}','/admin/config/user-interface/shortcut/link/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut.default\";s:6:\"_title\";s:4:\"Edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/user-interface/shortcut/link/%\";s:8:\"numParts\";i:6;}}',6),('entity.shortcut.link_delete_inline','/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline','/admin/config/user-interface/shortcut/link/%/delete-inline',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\shortcut\\Controller\\ShortcutController::deleteShortcutLinkInline\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"shortcut.delete\";s:11:\"_csrf_token\";s:4:\"TRUE\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete\\-inline$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/delete-inline\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:58:\"/admin/config/user-interface/shortcut/link/%/delete-inline\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.collection','/admin/config/user-interface/shortcut','/admin/config/user-interface/shortcut',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/user-interface/shortcut\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"shortcut_set\";s:6:\"_title\";s:9:\"Shortcuts\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer shortcuts\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/user\\-interface/shortcut$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/user-interface/shortcut\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/user-interface/shortcut\";s:8:\"numParts\";i:4;}}',4),('entity.shortcut_set.config_translation_overview','/admin/config/user-interface/shortcut/manage/{shortcut_set}/translate','/admin/config/user-interface/shortcut/manage/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:12:\"shortcut_set\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:56:\"/admin/config/user-interface/shortcut/manage/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.customize_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize','/admin/config/user-interface/shortcut/manage/%/customize',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"shortcut_set.customize\";s:6:\"_title\";s:10:\"List links\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/customize$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/customize\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:56:\"/admin/config/user-interface/shortcut/manage/%/customize\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.delete_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete','/admin/config/user-interface/shortcut/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"shortcut_set.delete\";s:6:\"_title\";s:19:\"Delete shortcut set\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:53:\"/admin/config/user-interface/shortcut/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.edit_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}','/admin/config/user-interface/shortcut/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"shortcut_set.edit\";s:6:\"_title\";s:17:\"Edit shortcut set\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:46:\"/admin/config/user-interface/shortcut/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.simple_sitemap.collection','/admin/config/search/simplesitemap','/admin/config/search/simplesitemap',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/search/simplesitemap\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:14:\"simple_sitemap\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/search/simplesitemap$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/simplesitemap\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/config/search/simplesitemap\";s:8:\"numParts\";i:4;}}',4),('entity.simple_sitemap.config_translation_overview','/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate','/admin/config/search/simplesitemap/variants/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:14:\"simple_sitemap\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:14:\"simple_sitemap\";a:2:{s:4:\"type\";s:21:\"entity:simple_sitemap\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"simple_sitemap\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/search/simplesitemap/variants/(?P<simple_sitemap>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"simple_sitemap\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/variants\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"simple_sitemap\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:55:\"/admin/config/search/simplesitemap/variants/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.simple_sitemap.delete_form','/admin/config/search/simplesitemap/variants/{simple_sitemap}/delete','/admin/config/search/simplesitemap/variants/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"simple_sitemap.delete\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"simple_sitemap\";a:2:{s:4:\"type\";s:21:\"entity:simple_sitemap\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"simple_sitemap\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/config/search/simplesitemap/variants/(?P<simple_sitemap>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"simple_sitemap\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/variants\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"simple_sitemap\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:52:\"/admin/config/search/simplesitemap/variants/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.simple_sitemap.edit_form','/admin/config/search/simplesitemap/variants/{simple_sitemap}','/admin/config/search/simplesitemap/variants/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/search/simplesitemap/variants/{simple_sitemap}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"simple_sitemap.edit\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"simple_sitemap\";a:2:{s:4:\"type\";s:21:\"entity:simple_sitemap\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"simple_sitemap\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/search/simplesitemap/variants/(?P<simple_sitemap>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"simple_sitemap\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/variants\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"simple_sitemap\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:45:\"/admin/config/search/simplesitemap/variants/%\";s:8:\"numParts\";i:6;}}',6),('entity.simple_sitemap_type.collection','/admin/config/search/simplesitemap/types','/admin/config/search/simplesitemap/types',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/config/search/simplesitemap/types\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:19:\"simple_sitemap_type\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/config/search/simplesitemap/types$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/search/simplesitemap/types\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/config/search/simplesitemap/types\";s:8:\"numParts\";i:5;}}',5),('entity.simple_sitemap_type.config_translation_overview','/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate','/admin/config/search/simplesitemap/types/%/translate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:19:\"simple_sitemap_type\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"simple_sitemap_type\";a:2:{s:4:\"type\";s:26:\"entity:simple_sitemap_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"simple_sitemap_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/config/search/simplesitemap/types/(?P<simple_sitemap_type>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"simple_sitemap_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/search/simplesitemap/types\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"simple_sitemap_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:52:\"/admin/config/search/simplesitemap/types/%/translate\";s:8:\"numParts\";i:7;}}',7),('entity.simple_sitemap_type.delete_form','/admin/config/search/simplesitemap/types/{simple_sitemap_type}/delete','/admin/config/search/simplesitemap/types/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:26:\"simple_sitemap_type.delete\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:19:\"simple_sitemap_type\";a:2:{s:4:\"type\";s:26:\"entity:simple_sitemap_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"simple_sitemap_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/search/simplesitemap/types/(?P<simple_sitemap_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"simple_sitemap_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/search/simplesitemap/types\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"simple_sitemap_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:49:\"/admin/config/search/simplesitemap/types/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.simple_sitemap_type.edit_form','/admin/config/search/simplesitemap/types/{simple_sitemap_type}','/admin/config/search/simplesitemap/types/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/config/search/simplesitemap/types/{simple_sitemap_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"simple_sitemap_type.edit\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:19:\"simple_sitemap_type\";a:2:{s:4:\"type\";s:26:\"entity:simple_sitemap_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"simple_sitemap_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/search/simplesitemap/types/(?P<simple_sitemap_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"simple_sitemap_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/search/simplesitemap/types\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"simple_sitemap_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:42:\"/admin/config/search/simplesitemap/types/%\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.add_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add','/admin/structure/taxonomy/manage/%/add',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\taxonomy\\Controller\\TaxonomyController::addForm\";s:6:\"_title\";s:8:\"Add term\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:35:\"taxonomy_term:{taxonomy_vocabulary}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/taxonomy/manage/%/add\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.canonical','/taxonomy/term/{taxonomy_term}','/taxonomy/term/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/taxonomy/term/{taxonomy_term}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:57:\"\\Drupal\\taxonomy\\Controller\\TaxonomyController::termTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:13:\"taxonomy_term\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/taxonomy/term/%\";s:8:\"numParts\";i:3;}}',3),('entity.taxonomy_term.delete_form','/taxonomy/term/{taxonomy_term}/delete','/taxonomy/term/%/delete',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/taxonomy/term/{taxonomy_term}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"taxonomy_term.delete\";s:6:\"_title\";s:11:\"Delete term\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"taxonomy_term.delete\";s:13:\"taxonomy_term\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:23:\"/taxonomy/term/%/delete\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_term.edit_form','/taxonomy/term/{taxonomy_term}/edit','/taxonomy/term/%/edit',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/taxonomy/term/{taxonomy_term}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"taxonomy_term.default\";s:6:\"_title\";s:9:\"Edit term\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"taxonomy_term.update\";s:13:\"taxonomy_term\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:21:\"/taxonomy/term/%/edit\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_term.field_ui_fields','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields','/admin/structure/taxonomy/manage/%/overview/fields',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/taxonomy/manage/%/overview/fields\";s:8:\"numParts\";i:7;}}',7),('entity.taxonomy_term.revision','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view','/taxonomy/term/%/revision/%/view',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController\";s:15:\"_title_callback\";s:65:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:36:\"taxonomy_term_revision.view revision\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:32:\"/taxonomy/term/%/revision/%/view\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.revision_delete_form','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete','/taxonomy/term/%/revision/%/delete',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"taxonomy_term.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:38:\"taxonomy_term_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:34:\"/taxonomy/term/%/revision/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.revision_revert_form','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert','/taxonomy/term/%/revision/%/revert',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"taxonomy_term.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"taxonomy_term_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:34:\"/taxonomy/term/%/revision/%/revert\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.version_history','/taxonomy/term/{taxonomy_term}/revisions','/taxonomy/term/%/revisions',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/taxonomy/term/{taxonomy_term}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:32:\"taxonomy_term.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:26:\"/taxonomy/term/%/revisions\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_vocabulary.add_form','/admin/structure/taxonomy/add','/admin/structure/taxonomy/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/taxonomy/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:27:\"taxonomy_vocabulary.default\";s:14:\"entity_type_id\";s:19:\"taxonomy_vocabulary\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:19:\"taxonomy_vocabulary\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/taxonomy/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/taxonomy/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/taxonomy/add\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_vocabulary.collection','/admin/structure/taxonomy','/admin/structure/taxonomy',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/structure/taxonomy\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:19:\"taxonomy_vocabulary\";s:6:\"_title\";s:8:\"Taxonomy\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:44:\"administer taxonomy+access taxonomy overview\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/structure/taxonomy$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/structure/taxonomy\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/structure/taxonomy\";s:8:\"numParts\";i:3;}}',3),('entity.taxonomy_vocabulary.config_translation_overview','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/translate','/admin/structure/taxonomy/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/taxonomy/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_vocabulary.delete_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete','/admin/structure/taxonomy/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:26:\"taxonomy_vocabulary.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"taxonomy_vocabulary.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/taxonomy/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_vocabulary.edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}','/admin/structure/taxonomy/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:27:\"taxonomy_vocabulary.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"taxonomy_vocabulary.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:34:\"/admin/structure/taxonomy/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.taxonomy_vocabulary.entity_permissions_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions','/admin/structure/taxonomy/manage/%/overview/permissions',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:18:\"bundle_entity_type\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/overview/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:55:\"/admin/structure/taxonomy/manage/%/overview/permissions\";s:8:\"numParts\";i:7;}}',7),('entity.taxonomy_vocabulary.overview_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview','/admin/structure/taxonomy/manage/%/overview',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:5:\"_form\";s:34:\"Drupal\\taxonomy\\Form\\OverviewTerms\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:44:\"taxonomy_vocabulary.access taxonomy overview\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:21:\"with_config_overrides\";b:1;s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/overview\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/taxonomy/manage/%/overview\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_vocabulary.reset_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset','/admin/structure/taxonomy/manage/%/reset',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"taxonomy_vocabulary.reset\";s:6:\"_title\";s:5:\"Reset\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:37:\"taxonomy_vocabulary.reset all weights\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:21:\"with_config_overrides\";b:1;s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/reset$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reset\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/taxonomy/manage/%/reset\";s:8:\"numParts\";i:6;}}',6),('entity.user.admin_form','/admin/config/people/accounts','/admin/config/people/accounts',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/people/accounts\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\user\\AccountSettingsForm\";s:6:\"_title\";s:16:\"Account settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer account settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/people/accounts$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/people/accounts\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/people/accounts\";s:8:\"numParts\";i:4;}}',4),('entity.user.cancel_form','/user/{user}/cancel','/user/%/cancel',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/user/{user}/cancel\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:14:\"Cancel account\";s:12:\"_entity_form\";s:11:\"user.cancel\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"user.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/user/(?P<user>\\d+)/cancel$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/cancel\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/user/%/cancel\";s:8:\"numParts\";i:3;}}',3),('entity.user.canonical','/user/{user}','/user/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/{user}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_view\";s:9:\"user.full\";s:15:\"_title_callback\";s:48:\"Drupal\\user\\Controller\\UserController::userTitle\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"user.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/user/(?P<user>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/user/%\";s:8:\"numParts\";i:2;}}',2),('entity.user.collection','/admin/people','/admin/people',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:17:\"user_admin_people\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:16:\"administer users\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/people\";s:8:\"numParts\";i:2;}}',2),('entity.user.contact_form','/user/{user}/contact','/user/%/contact',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/user/{user}/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:65:\"\\Drupal\\contact\\Controller\\ContactController::contactPersonalPage\";}s:12:\"requirements\";a:2:{s:28:\"_access_contact_personal_tab\";s:4:\"TRUE\";s:4:\"user\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:29:\"access_check.contact_personal\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/user/(?P<user>\\d+)/contact$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/user/%/contact\";s:8:\"numParts\";i:3;}}',3),('entity.user.edit_form','/user/{user}/edit','/user/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/user/{user}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"user.default\";s:15:\"_title_callback\";s:48:\"Drupal\\user\\Controller\\UserController::userTitle\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"user.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/user/(?P<user>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:12:\"/user/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.user.field_ui_fields','/admin/config/people/accounts/fields','/admin/config/people/accounts/fields',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/people/accounts/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/people/accounts/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/people/accounts/fields\";s:8:\"numParts\";i:5;}}',5),('entity.user_role.collection','/admin/people/roles','/admin/people/roles',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/people/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:9:\"user_role\";s:6:\"_title\";s:5:\"Roles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/people/roles$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/people/roles\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/people/roles\";s:8:\"numParts\";i:3;}}',3),('entity.user_role.config_translation_overview','/admin/people/roles/manage/{user_role}/translate','/admin/people/roles/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/people/roles/manage/{user_role}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:9:\"user_role\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/people/roles/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.user_role.delete_form','/admin/people/roles/manage/{user_role}/delete','/admin/people/roles/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/people/roles/manage/{user_role}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"user_role.delete\";s:6:\"_title\";s:11:\"Delete role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:35:\"/admin/people/roles/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.user_role.edit_form','/admin/people/roles/manage/{user_role}','/admin/people/roles/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/people/roles/manage/{user_role}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"user_role.default\";s:6:\"_title\";s:9:\"Edit role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/people/roles/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.user_role.edit_permissions_form','/admin/people/permissions/{user_role}','/admin/people/permissions/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/people/permissions/{user_role}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:49:\"\\Drupal\\user\\Form\\UserPermissionsRoleSpecificForm\";s:6:\"_title\";s:9:\"Edit role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/people/permissions/(?P<user_role>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/people/permissions\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:27:\"/admin/people/permissions/%\";s:8:\"numParts\";i:4;}}',4),('entity.view.break_lock_form','/admin/structure/views/view/{view}/break-lock','/admin/structure/views/view/%/break-lock',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/views/view/{view}/break-lock\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"view.break_lock\";s:6:\"_title\";s:10:\"Break lock\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"view.break-lock\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/views/view/(?P<view>[^/]++)/break\\-lock$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/break-lock\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/views/view/%/break-lock\";s:8:\"numParts\";i:6;}}',6),('entity.view.collection','/admin/structure/views','/admin/structure/views',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/views\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:4:\"view\";s:6:\"_title\";s:5:\"Views\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/views$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/views\";s:8:\"numParts\";i:3;}}',3),('entity.view.config_translation_overview','/admin/structure/views/view/{view}/translate','/admin/structure/views/view/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/views/view/{view}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:4:\"view\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/views/view/(?P<view>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/views/view/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.view.delete_form','/admin/structure/views/view/{view}/delete','/admin/structure/views/view/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/views/view/{view}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"view.delete\";s:6:\"_title\";s:11:\"Delete view\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/views/view/(?P<view>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/views/view/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.view.disable','/admin/structure/views/view/{view}/disable','/admin/structure/views/view/%/disable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/views/view/{view}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"view.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/views/view/(?P<view>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/views/view/%/disable\";s:8:\"numParts\";i:6;}}',6),('entity.view.duplicate_form','/admin/structure/views/view/{view}/duplicate','/admin/structure/views/view/%/duplicate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/views/view/{view}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"view.duplicate\";s:6:\"_title\";s:14:\"Duplicate view\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"view.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/views/view/(?P<view>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/views/view/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.view.edit_display_form','/admin/structure/views/view/{view}/edit/{display_id}','/admin/structure/views/view/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/structure/views/view/{view}/edit/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit\";s:10:\"display_id\";N;}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/views/view/(?P<view>[^/]++)/edit(?:/(?P<display_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/views/view/%/edit\";s:8:\"numParts\";i:7;}}',7),('entity.view.edit_form','/admin/structure/views/view/{view}','/admin/structure/views/view/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/views/view/{view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/structure/views/view/(?P<view>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/views/view/%\";s:8:\"numParts\";i:5;}}',5),('entity.view.enable','/admin/structure/views/view/{view}/enable','/admin/structure/views/view/%/enable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/views/view/{view}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.enable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/views/view/(?P<view>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/views/view/%/enable\";s:8:\"numParts\";i:6;}}',6),('entity.view.preview_form','/admin/structure/views/view/{view}/preview/{display_id}','/admin/structure/views/view/%/preview',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/views/view/{view}/preview/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"view.preview\";s:10:\"display_id\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/views/view/(?P<view>[^/]++)/preview(?:/(?P<display_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/preview\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/views/view/%/preview\";s:8:\"numParts\";i:7;}}',7),('entity.webform.access_denied','/webform/{webform}/access-denied','/webform/%/access-denied',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/webform/{webform}/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::accessDenied\";s:15:\"_title_callback\";s:69:\"\\Drupal\\webform\\Controller\\WebformEntityController::accessDeniedTitle\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/webform/(?P<webform>[^/]++)/access\\-denied$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/access-denied\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:24:\"/webform/%/access-denied\";s:8:\"numParts\";i:3;}}',3),('entity.webform.add_form','/admin/structure/webform/add','/admin/structure/webform/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/webform/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"webform.add\";s:6:\"_title\";s:11:\"Add webform\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:7:\"webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/structure/webform/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/webform/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/structure/webform/add\";s:8:\"numParts\";i:4;}}',4),('entity.webform.assets.css','/webform/css/{webform}/custom.css','/webform/css/%/custom.css',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/webform/css/{webform}/custom.css\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\webform\\Controller\\WebformEntityController::css\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/webform/css/(?P<webform>[^/]++)/custom\\.css$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/custom.css\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/webform/css\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:25:\"/webform/css/%/custom.css\";s:8:\"numParts\";i:4;}}',4),('entity.webform.assets.javascript','/webform/javascript/{webform}/custom.js','/webform/javascript/%/custom.js',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/webform/javascript/{webform}/custom.js\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformEntityController::javascript\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/webform/javascript/(?P<webform>[^/]++)/custom\\.js$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/custom.js\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/javascript\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:31:\"/webform/javascript/%/custom.js\";s:8:\"numParts\";i:4;}}',4),('entity.webform.autocomplete','/admin/structure/webform/autocomplete','/admin/structure/webform/autocomplete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/structure/webform/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::autocomplete\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/structure/webform/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/webform/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/structure/webform/autocomplete\";s:8:\"numParts\";i:4;}}',4),('entity.webform.autocomplete.archived','/admin/structure/webform/autocomplete/archived','/admin/structure/webform/autocomplete/archived',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/webform/autocomplete/archived\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::autocomplete\";s:8:\"archived\";b:1;}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/admin/structure/webform/autocomplete/archived$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/structure/webform/autocomplete/archived\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/autocomplete/archived\";s:8:\"numParts\";i:5;}}',5),('entity.webform.canonical','/webform/{webform}','/webform/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/webform/{webform}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\webform\\Controller\\WebformEntityController::addForm\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform.submission_page\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/webform/(?P<webform>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/webform/%\";s:8:\"numParts\";i:2;}}',2),('entity.webform.collection','/admin/structure/webform','/admin/structure/webform',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:7:\"webform\";s:6:\"_title\";s:8:\"Webforms\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/webform$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/webform\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/webform\";s:8:\"numParts\";i:3;}}',3),('entity.webform.config_translation_overview','/admin/structure/webform/manage/{webform}/translate','/admin/structure/webform/manage/%/translate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/webform/manage/{webform}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:7:\"webform\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/manage/%/translate\";s:8:\"numParts\";i:6;}}',6),('entity.webform.confirmation','/webform/{webform}/confirmation','/webform/%/confirmation',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/webform/{webform}/confirmation\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::confirmation\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/webform/(?P<webform>[^/]++)/confirmation$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/confirmation\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:23:\"/webform/%/confirmation\";s:8:\"numParts\";i:3;}}',3),('entity.webform.delete_form','/admin/structure/webform/manage/{webform}/delete','/admin/structure/webform/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"webform.delete\";s:6:\"_title\";s:14:\"Delete webform\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.webform.duplicate_form','/admin/structure/webform/manage/{webform}/duplicate','/admin/structure/webform/manage/%/duplicate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/webform/manage/{webform}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"webform.duplicate\";s:6:\"_title\";s:17:\"Duplicate webform\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"webform.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/manage/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.webform.edit_form','/admin/structure/webform/manage/{webform}','/admin/structure/webform/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/manage/{webform}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"webform.edit\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/webform/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.webform.export_form','/admin/structure/webform/manage/{webform}/export','/admin/structure/webform/manage/%/export',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"webform.export\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/export$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/export\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/export\";s:8:\"numParts\";i:6;}}',6),('entity.webform.handler','/admin/structure/webform/manage/{webform}/handlers/add','/admin/structure/webform/manage/%/handlers/add',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/webform/manage/{webform}/handlers/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:71:\"\\Drupal\\webform\\Controller\\WebformPluginHandlerController::listHandlers\";s:6:\"_title\";s:16:\"Select a handler\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/handlers/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/handlers/add\";s:8:\"numParts\";i:7;}}',7),('entity.webform.handler.add_email','/admin/structure/webform/manage/{webform}/handlers/add/email','/admin/structure/webform/manage/%/handlers/add/email',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/manage/{webform}/handlers/add/email\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformHandlerAddForm\";s:6:\"_title\";s:9:\"Add email\";s:15:\"webform_handler\";s:5:\"email\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add/email$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/handlers/add/email\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/handlers/add/email\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.add_form','/admin/structure/webform/manage/{webform}/handlers/add/{webform_handler}','/admin/structure/webform/manage/%/handlers/add/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/webform/manage/{webform}/handlers/add/{webform_handler}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformHandlerAddForm\";s:6:\"_title\";s:19:\"Add webform handler\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add/(?P<webform_handler>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/handlers/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/handlers/add/%\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.delete_form','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/delete','/admin/structure/webform/manage/%/handlers/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\webform\\Form\\WebformHandlerDeleteForm\";s:6:\"_title\";s:22:\"Delete webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/handlers/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.disable','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/disable','/admin/structure/webform/manage/%/handlers/%/disable',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityHandlersForm::ajaxOperation\";s:9:\"operation\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/handlers/%/disable\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.duplicate_form','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/duplicate','/admin/structure/webform/manage/%/handlers/%/duplicate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\webform\\Form\\WebformHandlerDuplicateForm\";s:6:\"_title\";s:25:\"Duplicate webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/handlers/%/duplicate\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.edit_form','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/edit','/admin/structure/webform/manage/%/handlers/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformHandlerEditForm\";s:6:\"_title\";s:20:\"Edit webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/handlers/%/edit\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handler.enable','/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/enable','/admin/structure/webform/manage/%/handlers/%/enable',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityHandlersForm::ajaxOperation\";s:9:\"operation\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/handlers/%/enable\";s:8:\"numParts\";i:8;}}',8),('entity.webform.handlers','/admin/structure/webform/manage/{webform}/handlers','/admin/structure/webform/manage/%/handlers',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.handlers\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/handlers\";s:8:\"numParts\";i:6;}}',6),('entity.webform.multiple_delete_confirm','/admin/structure/webform/delete','/admin/structure/webform/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:52:\"\\Drupal\\webform\\Form\\WebformEntityDeleteMultipleForm\";s:14:\"entity_type_id\";s:7:\"webform\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/delete\";s:8:\"numParts\";i:4;}}',4),('entity.webform.references','/admin/structure/webform/manage/{webform}/references','/admin/structure/webform/manage/%/references',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/structure/webform/manage/{webform}/references\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:76:\"\\Drupal\\webform_node\\Controller\\WebformNodeReferencesListController::listing\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/references$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/references\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/webform/manage/%/references\";s:8:\"numParts\";i:6;}}',6),('entity.webform.references.add_form','/admin/structure/webform/manage/{webform}/references/add','/admin/structure/webform/manage/%/references/add',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/webform/manage/{webform}/references/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:54:\"\\Drupal\\webform_node\\Form\\WebformNodeReferencesAddForm\";s:6:\"_title\";s:13:\"Add reference\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/references/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/references/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/references/add\";s:8:\"numParts\";i:7;}}',7),('entity.webform.results.source_entity.autocomplete','/admin/structure/webform/manage/{webform}/results/source-entity/autocomplete','/admin/structure/webform/manage/%/results/source-entity/autocomplete',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/results/source-entity/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:81:\"\\Drupal\\webform\\Controller\\WebformSubmissionsController::sourceEntityAutocomplete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/source\\-entity/autocomplete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/results/source-entity/autocomplete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:68:\"/admin/structure/webform/manage/%/results/source-entity/autocomplete\";s:8:\"numParts\";i:8;}}',8),('entity.webform.results_clear','/admin/structure/webform/manage/{webform}/results/clear','/admin/structure/webform/manage/%/results/clear',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/results/clear\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"Drupal\\webform\\Form\\WebformResultsClearForm\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:28:\"webform.submission_purge_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/clear$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/results/clear\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/results/clear\";s:8:\"numParts\";i:7;}}',7),('entity.webform.results_export','/admin/structure/webform/manage/{webform}/results/download','/admin/structure/webform/manage/%/results/download',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/webform/manage/{webform}/results/download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformResultsExportController::index\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/download$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/results/download\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/webform/manage/%/results/download\";s:8:\"numParts\";i:7;}}',7),('entity.webform.results_export_file','/admin/structure/webform/manage/{webform}/results/download/file/{filename}','/admin/structure/webform/manage/%/results/download/file/%',494,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/structure/webform/manage/{webform}/results/download/file/{filename}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:63:\"\\Drupal\\webform\\Controller\\WebformResultsExportController::file\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"filename\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/download/file/(?P<filename>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"filename\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/results/download/file\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"filename\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:494;s:14:\"patternOutline\";s:57:\"/admin/structure/webform/manage/%/results/download/file/%\";s:8:\"numParts\";i:9;}}',9),('entity.webform.results_submissions','/admin/structure/webform/manage/{webform}/results/submissions/{submission_view}','/admin/structure/webform/manage/%/results/submissions',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/results/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/results/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/results/submissions\";s:8:\"numParts\";i:8;}}',8),('entity.webform.results_submissions.custom','/admin/structure/webform/manage/{webform}/results/submissions/custom','/admin/structure/webform/manage/%/results/submissions/custom',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/webform/manage/{webform}/results/submissions/custom\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"Drupal\\webform\\Form\\WebformResultsCustomForm\";s:6:\"_title\";s:15:\"Customize table\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions/custom$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/results/submissions/custom\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:60:\"/admin/structure/webform/manage/%/results/submissions/custom\";s:8:\"numParts\";i:8;}}',8),('entity.webform.results_submissions.custom.user','/admin/structure/webform/manage/{webform}/results/submissions/custom/user','/admin/structure/webform/manage/%/results/submissions/custom/user',495,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/results/submissions/custom/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:44:\"Drupal\\webform\\Form\\WebformResultsCustomForm\";s:6:\"_title\";s:18:\"Customize my table\";s:4:\"type\";s:4:\"user\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions/custom/user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/results/submissions/custom/user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:495;s:14:\"patternOutline\";s:65:\"/admin/structure/webform/manage/%/results/submissions/custom/user\";s:8:\"numParts\";i:9;}}',9),('entity.webform.schema_form','/admin/structure/webform/manage/{webform}/schema','/admin/structure/webform/manage/%/schema',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/schema\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"webform.schema\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:21:\"access webform schema\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/schema$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/schema\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/schema\";s:8:\"numParts\";i:6;}}',6),('entity.webform.settings','/admin/structure/webform/manage/{webform}/settings','/admin/structure/webform/manage/%/settings',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.settings\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/settings\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/settings\";s:8:\"numParts\";i:6;}}',6),('entity.webform.settings_access','/admin/structure/webform/manage/{webform}/access','/admin/structure/webform/manage/%/access',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/access\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform.settings_access\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/access$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/access\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/access\";s:8:\"numParts\";i:6;}}',6),('entity.webform.settings_assets','/admin/structure/webform/manage/{webform}/settings/assets','/admin/structure/webform/manage/%/settings/assets',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/webform/manage/{webform}/settings/assets\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform.settings_assets\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"edit webform assets\";s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/assets$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/settings/assets\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/settings/assets\";s:8:\"numParts\";i:7;}}',7),('entity.webform.settings_confirmation','/admin/structure/webform/manage/{webform}/settings/confirmation','/admin/structure/webform/manage/%/settings/confirmation',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/webform/manage/{webform}/settings/confirmation\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"webform.settings_confirmation\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/confirmation$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/settings/confirmation\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:55:\"/admin/structure/webform/manage/%/settings/confirmation\";s:8:\"numParts\";i:7;}}',7),('entity.webform.settings_form','/admin/structure/webform/manage/{webform}/settings/form','/admin/structure/webform/manage/%/settings/form',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/settings/form\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"webform.settings_form\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/form$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/settings/form\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/settings/form\";s:8:\"numParts\";i:7;}}',7),('entity.webform.settings_submissions','/admin/structure/webform/manage/{webform}/settings/submissions','/admin/structure/webform/manage/%/settings/submissions',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/webform/manage/{webform}/settings/submissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:28:\"webform.settings_submissions\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/submissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/settings/submissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/settings/submissions\";s:8:\"numParts\";i:7;}}',7),('entity.webform.source_form','/admin/structure/webform/manage/{webform}/source','/admin/structure/webform/manage/%/source',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/source\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";s:12:\"_entity_form\";s:14:\"webform.source\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:67:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformSourceAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/source$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/source\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/source\";s:8:\"numParts\";i:6;}}',6),('entity.webform.test_form','/webform/{webform}/test','/webform/%/test',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/webform/{webform}/test\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\webform\\Controller\\WebformTestController::testForm\";s:15:\"_title_callback\";s:55:\"\\Drupal\\webform\\Controller\\WebformTestController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.test\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/webform/(?P<webform>[^/]++)/test$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/test\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/webform/%/test\";s:8:\"numParts\";i:3;}}',3),('entity.webform.user.drafts','/webform/{webform}/drafts/{submission_view}','/webform/%/drafts',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/webform/{webform}/drafts/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:6:\"Drafts\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform.submission_create\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess::checkDraftsAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/webform/(?P<webform>[^/]++)/drafts(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/drafts\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/webform/%/drafts\";s:8:\"numParts\";i:4;}}',4),('entity.webform.user.submission','/webform/{webform}/submissions/{webform_submission}','/webform/%/submissions/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/webform/{webform}/submissions/{webform_submission}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"html\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:24:\"/webform/%/submissions/%\";s:8:\"numParts\";i:4;}}',4),('entity.webform.user.submission.attachment','/webform/{webform}/submissions/{webform_submission}/attachment/{element}/{filename}','/webform/%/submissions/%/attachment/%/%',84,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/webform/{webform}/submissions/{webform_submission}/attachment/{element}/{filename}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:75:\"\\Drupal\\webform_attachment\\Controller\\WebformAttachmentController::download\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";i:2;s:7:\"element\";i:3;s:8:\"filename\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/attachment/(?P<element>[^/]++)/(?P<filename>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"filename\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"element\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/attachment\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:4:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";i:2;s:7:\"element\";i:3;s:8:\"filename\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:84;s:14:\"patternOutline\";s:39:\"/webform/%/submissions/%/attachment/%/%\";s:8:\"numParts\";i:7;}}',7),('entity.webform.user.submission.delete','/webform/{webform}/submissions/{webform_submission}/delete','/webform/%/submissions/%/delete',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/webform/{webform}/submissions/{webform_submission}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_submission.delete\";s:6:\"_title\";s:25:\"Delete webform submission\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.delete\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:31:\"/webform/%/submissions/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.webform.user.submission.duplicate','/webform/{webform}/submissions/{webform_submission}/duplicate','/webform/%/submissions/%/duplicate',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/webform/{webform}/submissions/{webform_submission}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:28:\"webform_submission.duplicate\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"duplicate\";b:1;s:7:\"setting\";s:25:\"submission_user_duplicate\";s:5:\"value\";b:1;}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:28:\"webform_submission.duplicate\";s:14:\"_custom_access\";s:68:\"\\Drupal\\webform\\Access\\WebformEntityAccess::checkWebformSettingValue\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:34:\"/webform/%/submissions/%/duplicate\";s:8:\"numParts\";i:5;}}',5),('entity.webform.user.submission.edit','/webform/{webform}/submissions/{webform_submission}/edit','/webform/%/submissions/%/edit',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/webform/{webform}/submissions/{webform_submission}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform_submission.edit\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:29:\"/webform/%/submissions/%/edit\";s:8:\"numParts\";i:5;}}',5),('entity.webform.user.submissions','/webform/{webform}/submissions/{submission_view}','/webform/%/submissions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/webform/{webform}/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:11:\"Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:27:\"webform.submission_view_own\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/webform/(?P<webform>[^/]++)/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:22:\"/webform/%/submissions\";s:8:\"numParts\";i:4;}}',4),('entity.webform.variant','/admin/structure/webform/manage/{webform}/variants/add','/admin/structure/webform/manage/%/variants/add',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/webform/manage/{webform}/variants/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:71:\"\\Drupal\\webform\\Controller\\WebformPluginVariantController::listVariants\";s:6:\"_title\";s:16:\"Select a variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/variants/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/variants/add\";s:8:\"numParts\";i:7;}}',7),('entity.webform.variant.add_form','/admin/structure/webform/manage/{webform}/variants/add/{webform_variant}','/admin/structure/webform/manage/%/variants/add/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/webform/manage/{webform}/variants/add/{webform_variant}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformVariantAddForm\";s:6:\"_title\";s:19:\"Add webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:69:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantCreateAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/add/(?P<webform_variant>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/variants/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/variants/add/%\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.apply_form','/admin/structure/webform/manage/{webform}/variants/apply','/admin/structure/webform/manage/%/variants/apply',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/webform/manage/{webform}/variants/apply\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\webform\\Form\\WebformVariantApplyForm\";s:6:\"_title\";s:21:\"Apply webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/apply$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/variants/apply\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/variants/apply\";s:8:\"numParts\";i:7;}}',7),('entity.webform.variant.delete_form','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/delete','/admin/structure/webform/manage/%/variants/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\webform\\Form\\WebformVariantDeleteForm\";s:6:\"_title\";s:22:\"Delete webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/variants/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.disable','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/disable','/admin/structure/webform/manage/%/variants/%/disable',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityVariantsForm::ajaxOperation\";s:9:\"operation\";s:7:\"disable\";}s:12:\"requirements\";a:4:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:4:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";i:3;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/variants/%/disable\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.duplicate_form','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/duplicate','/admin/structure/webform/manage/%/variants/%/duplicate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\webform\\Form\\WebformVariantDuplicateForm\";s:6:\"_title\";s:25:\"Duplicate webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/variants/%/duplicate\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.edit_form','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/edit','/admin/structure/webform/manage/%/variants/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantEditForm\";s:6:\"_title\";s:20:\"Edit webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/variants/%/edit\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.enable','/admin/structure/webform/manage/{webform}/variants/{webform_variant}/enable','/admin/structure/webform/manage/%/variants/%/enable',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityVariantsForm::ajaxOperation\";s:9:\"operation\";s:6:\"enable\";}s:12:\"requirements\";a:4:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:4:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";i:3;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/variants/%/enable\";s:8:\"numParts\";i:8;}}',8),('entity.webform.variant.test_form','/admin/structure/webform/manage/{webform}/variants/test','/admin/structure/webform/manage/%/variants/test',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/variants/test\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantViewForm\";s:6:\"_title\";s:21:\"Test webform variants\";s:9:\"operation\";s:4:\"test\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/test$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/variants/test\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/variants/test\";s:8:\"numParts\";i:7;}}',7),('entity.webform.variant.view_form','/admin/structure/webform/manage/{webform}/variants/view','/admin/structure/webform/manage/%/variants/view',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/variants/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantViewForm\";s:6:\"_title\";s:21:\"View webform variants\";s:9:\"operation\";s:4:\"view\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/view$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/variants/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/variants/view\";s:8:\"numParts\";i:7;}}',7),('entity.webform.variants','/admin/structure/webform/manage/{webform}/variants','/admin/structure/webform/manage/%/variants',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.variants\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/variants\";s:8:\"numParts\";i:6;}}',6),('entity.webform_access_group.add_form','/admin/structure/webform/access/group/manage/add','/admin/structure/webform/access/group/manage/add',127,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/access/group/manage/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"webform_access_group.add\";s:6:\"_title\";s:24:\"Add webform access group\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:20:\"webform_access_group\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/structure/webform/access/group/manage/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/admin/structure/webform/access/group/manage/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:127;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/access/group/manage/add\";s:8:\"numParts\";i:7;}}',7),('entity.webform_access_group.collection','/admin/structure/webform/access/group/manage','/admin/structure/webform/access/group/manage',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/webform/access/group/manage\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:20:\"webform_access_group\";s:6:\"_title\";s:22:\"Webforms: Access Group\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:72:\"\\Drupal\\webform_access\\Access\\WebformAccessGroupAccess::checkAdminAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/structure/webform/access/group/manage$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/structure/webform/access/group/manage\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:44:\"/admin/structure/webform/access/group/manage\";s:8:\"numParts\";i:6;}}',6),('entity.webform_access_group.config_translation_overview','/admin/structure/webform/access/group/manage/{webform_access_group}/translate','/admin/structure/webform/access/group/manage/%/translate',253,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/structure/webform/access/group/manage/{webform_access_group}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:20:\"webform_access_group\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:20:\"webform_access_group\";a:2:{s:4:\"type\";s:27:\"entity:webform_access_group\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:20:\"webform_access_group\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/webform/access/group/manage/(?P<webform_access_group>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"webform_access_group\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/structure/webform/access/group/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:20:\"webform_access_group\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:253;s:14:\"patternOutline\";s:56:\"/admin/structure/webform/access/group/manage/%/translate\";s:8:\"numParts\";i:8;}}',8),('entity.webform_access_group.delete_form','/admin/structure/webform/access/group/{webform_access_group}/delete','/admin/structure/webform/access/group/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/webform/access/group/{webform_access_group}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:27:\"webform_access_group.delete\";s:6:\"_title\";s:27:\"Delete webform access group\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:27:\"webform_access_group.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:20:\"webform_access_group\";a:2:{s:4:\"type\";s:27:\"entity:webform_access_group\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:20:\"webform_access_group\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/webform/access/group/(?P<webform_access_group>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"webform_access_group\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/webform/access/group\";}}s:9:\"path_vars\";a:1:{i:0;s:20:\"webform_access_group\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/access/group/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.webform_access_group.duplicate_form','/admin/structure/webform/access/group/{webform_access_group}/duplicate','/admin/structure/webform/access/group/%/duplicate',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/webform/access/group/{webform_access_group}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:30:\"webform_access_group.duplicate\";s:6:\"_title\";s:30:\"Duplicate webform access group\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:30:\"webform_access_group.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:20:\"webform_access_group\";a:2:{s:4:\"type\";s:27:\"entity:webform_access_group\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:20:\"webform_access_group\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/webform/access/group/(?P<webform_access_group>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"webform_access_group\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/webform/access/group\";}}s:9:\"path_vars\";a:1:{i:0;s:20:\"webform_access_group\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/access/group/%/duplicate\";s:8:\"numParts\";i:7;}}',7),('entity.webform_access_group.edit_form','/admin/structure/webform/access/group/manage/{webform_access_group}','/admin/structure/webform/access/group/manage/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/webform/access/group/manage/{webform_access_group}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_access_group.edit\";s:6:\"_title\";s:25:\"Edit webform access group\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:27:\"webform_access_group.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:20:\"webform_access_group\";a:2:{s:4:\"type\";s:27:\"entity:webform_access_group\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:20:\"webform_access_group\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/webform/access/group/manage/(?P<webform_access_group>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"webform_access_group\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/structure/webform/access/group/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:20:\"webform_access_group\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/access/group/manage/%\";s:8:\"numParts\";i:7;}}',7),('entity.webform_access_type.add_form','/admin/structure/webform/access/type/manage/add','/admin/structure/webform/access/type/manage/add',127,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/structure/webform/access/type/manage/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform_access_type.add\";s:6:\"_title\";s:23:\"Add webform access type\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:19:\"webform_access_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/structure/webform/access/type/manage/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/structure/webform/access/type/manage/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:127;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/access/type/manage/add\";s:8:\"numParts\";i:7;}}',7),('entity.webform_access_type.collection','/admin/structure/webform/access/type/manage','/admin/structure/webform/access/type/manage',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/structure/webform/access/type/manage\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:19:\"webform_access_type\";s:6:\"_title\";s:22:\"Webforms: Access Group\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/structure/webform/access/type/manage$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/access/type/manage\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/access/type/manage\";s:8:\"numParts\";i:6;}}',6),('entity.webform_access_type.config_translation_overview','/admin/structure/webform/access/type/manage/{webform_access_type}/translate','/admin/structure/webform/access/type/manage/%/translate',253,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/access/type/manage/{webform_access_type}/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:19:\"webform_access_type\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"webform_access_type\";a:2:{s:4:\"type\";s:26:\"entity:webform_access_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"webform_access_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/webform/access/type/manage/(?P<webform_access_type>[^/]++)/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"webform_access_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/access/type/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"webform_access_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:253;s:14:\"patternOutline\";s:55:\"/admin/structure/webform/access/type/manage/%/translate\";s:8:\"numParts\";i:8;}}',8),('entity.webform_access_type.delete_form','/admin/structure/webform/access/type/{webform_access_type}/delete','/admin/structure/webform/access/type/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/webform/access/type/{webform_access_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:26:\"webform_access_type.delete\";s:6:\"_title\";s:26:\"Delete webform access type\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"webform_access_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"webform_access_type\";a:2:{s:4:\"type\";s:26:\"entity:webform_access_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"webform_access_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/webform/access/type/(?P<webform_access_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"webform_access_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/structure/webform/access/type\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"webform_access_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:45:\"/admin/structure/webform/access/type/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.webform_access_type.edit_form','/admin/structure/webform/access/type/manage/{webform_access_type}','/admin/structure/webform/access/type/manage/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/webform/access/type/manage/{webform_access_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"webform_access_type.edit\";s:6:\"_title\";s:24:\"Edit webform access type\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"webform_access_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"webform_access_type\";a:2:{s:4:\"type\";s:26:\"entity:webform_access_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"webform_access_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/webform/access/type/manage/(?P<webform_access_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"webform_access_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/access/type/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"webform_access_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:45:\"/admin/structure/webform/access/type/manage/%\";s:8:\"numParts\";i:7;}}',7),('entity.webform_options.add_form','/admin/structure/webform/options/manage/add','/admin/structure/webform/options/manage/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/structure/webform/options/manage/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"webform_options.add\";s:6:\"_title\";s:19:\"Add webform options\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:15:\"webform_options\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/structure/webform/options/manage/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/options/manage/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/options/manage/add\";s:8:\"numParts\";i:6;}}',6),('entity.webform_options.autocomplete','/admin/structure/webform/options/autocomplete','/admin/structure/webform/options/autocomplete',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/webform/options/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformOptionsController::autocomplete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/webform/options/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/structure/webform/options/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:45:\"/admin/structure/webform/options/autocomplete\";s:8:\"numParts\";i:5;}}',5),('entity.webform_options.collection','/admin/structure/webform/options/manage','/admin/structure/webform/options/manage',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/webform/options/manage\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:15:\"webform_options\";s:6:\"_title\";s:17:\"Webforms: Options\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/structure/webform/options/manage$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/webform/options/manage\";s:8:\"numParts\";i:5;}}',5),('entity.webform_options.config_translation_overview','/admin/structure/webform/options/manage/{webform_options}/edit/translate','/admin/structure/webform/options/manage/%/edit/translate',251,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/webform/options/manage/{webform_options}/edit/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:75:\"\\Drupal\\config_translation\\Controller\\ConfigTranslationController::itemPage\";s:9:\"plugin_id\";s:15:\"webform_options\";}s:12:\"requirements\";a:1:{s:35:\"_config_translation_overview_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:34:\"config_translation.access.overview\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/webform/options/manage/(?P<webform_options>[^/]++)/edit/translate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/edit/translate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:56:\"/admin/structure/webform/options/manage/%/edit/translate\";s:8:\"numParts\";i:8;}}',8),('entity.webform_options.delete_form','/admin/structure/webform/options/{webform_options}/delete','/admin/structure/webform/options/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/webform/options/{webform_options}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"webform_options.delete\";s:6:\"_title\";s:22:\"Delete webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:22:\"webform_options.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/webform/options/(?P<webform_options>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/webform/options\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/options/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.webform_options.duplicate_form','/admin/structure/webform/options/{webform_options}/duplicate','/admin/structure/webform/options/%/duplicate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/options/{webform_options}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_options.duplicate\";s:6:\"_title\";s:25:\"Duplicate webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_options.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/webform/options/(?P<webform_options>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/webform/options\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/webform/options/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.webform_options.edit_form','/admin/structure/webform/options/manage/{webform_options}/edit','/admin/structure/webform/options/manage/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/webform/options/manage/{webform_options}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"webform_options.edit\";s:6:\"_title\";s:20:\"Edit webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:22:\"webform_options.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/webform/options/manage/(?P<webform_options>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/options/manage/%/edit\";s:8:\"numParts\";i:7;}}',7),('entity.webform_options.source_form','/admin/structure/webform/options/manage/{webform_options}/source','/admin/structure/webform/options/manage/%/source',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/webform/options/manage/{webform_options}/source\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:22:\"webform_options.source\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:73:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformOptionSourceAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/webform/options/manage/(?P<webform_options>[^/]++)/source$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/source\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/options/manage/%/source\";s:8:\"numParts\";i:7;}}',7),('entity.webform_options_limit.summary','/admin/structure/webform/manage/{webform}/results/options-limit','/admin/structure/webform/manage/%/results/options-limit',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/webform/manage/{webform}/results/options-limit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:77:\"\\Drupal\\webform_options_limit\\Controller\\WebformOptionsLimitController::index\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:75:\"\\Drupal\\webform_options_limit\\Access\\WebformOptionsLimitAccess::checkAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/options\\-limit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/results/options-limit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:55:\"/admin/structure/webform/manage/%/results/options-limit\";s:8:\"numParts\";i:7;}}',7),('entity.webform_submission.access_denied','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied','/admin/structure/webform/manage/%/submission/%/access-denied',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::accessDenied\";s:15:\"_title_callback\";s:73:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::accessDeniedTitle\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/access\\-denied$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/access-denied\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:60:\"/admin/structure/webform/manage/%/submission/%/access-denied\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.canonical','/admin/structure/webform/manage/{webform}/submission/{webform_submission}','/admin/structure/webform/manage/%/submission/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"html\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/submission/%\";s:8:\"numParts\";i:7;}}',7),('entity.webform_submission.collection','/admin/structure/webform/submissions/manage/{submission_view}','/admin/structure/webform/submissions/manage',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/webform/submissions/manage/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:21:\"Webforms: Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform\\Access\\WebformAccountAccess:checkSubmissionAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/webform/submissions/manage(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/submissions/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/submissions/manage\";s:8:\"numParts\";i:6;}}',6),('entity.webform_submission.collection_purge','/admin/structure/webform/submissions/purge','/admin/structure/webform/submissions/purge',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/webform/submissions/purge\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionsPurgeForm\";s:6:\"_title\";s:27:\"Webforms: Submissions purge\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/structure/webform/submissions/purge$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/webform/submissions/purge\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/submissions/purge\";s:8:\"numParts\";i:5;}}',5),('entity.webform_submission.delete_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete','/admin/structure/webform/manage/%/submission/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_submission.delete\";s:6:\"_title\";s:25:\"Delete webform submission\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.duplicate_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate','/admin/structure/webform/manage/%/submission/%/duplicate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:28:\"webform_submission.duplicate\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"duplicate\";b:1;}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"webform_submission.update_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:110:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/webform/manage/%/submission/%/duplicate\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.edit_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit','/admin/structure/webform/manage/%/submission/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform_submission.edit\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/edit\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.edit_form.all','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit/all','/admin/structure/webform/manage/%/submission/%/edit/all',491,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit/all\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:27:\"webform_submission.edit_all\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:14:\"_custom_access\";s:70:\"\\Drupal\\webform\\Access\\WebformSubmissionAccess::checkWizardPagesAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/edit/all$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/edit/all\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:55:\"/admin/structure/webform/manage/%/submission/%/edit/all\";s:8:\"numParts\";i:9;}}',9),('entity.webform_submission.locked_toggle','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/locked','/admin/structure/webform/manage/%/submission/%/locked',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/locked\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::locked\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/locked$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/locked\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/locked\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.notes_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes','/admin/structure/webform/manage/%/submission/%/notes',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"webform_submission.notes\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"webform_submission.notes\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/notes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/notes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/submission/%/notes\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.resend_form','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend','/admin/structure/webform/manage/%/submission/%/resend',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionResendForm\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.resend\";s:14:\"_custom_access\";s:65:\"\\Drupal\\webform\\Access\\WebformSubmissionAccess::checkResendAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/resend$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/resend\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/resend\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.sticky_toggle','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/sticky','/admin/structure/webform/manage/%/submission/%/sticky',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/sticky\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::sticky\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/sticky$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/sticky\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/sticky\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.table','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table','/admin/structure/webform/manage/%/submission/%/table',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:5:\"table\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/table$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/table\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/submission/%/table\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.text','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text','/admin/structure/webform/manage/%/submission/%/text',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"text\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:27:\"webform_submission.view_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/text$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/text\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/text\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission.user','/user/{user}/submissions/{submission_view}','/user/%/submissions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/user/{user}/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:11:\"Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkUserSubmissionsAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"user\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/user/(?P<user>[^/]++)/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"user\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"user\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:19:\"/user/%/submissions\";s:8:\"numParts\";i:4;}}',4),('entity.webform_submission.yaml','/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml','/admin/structure/webform/manage/%/submission/%/yaml',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"yaml\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"edit webform source\";s:14:\"_entity_access\";s:27:\"webform_submission.view_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/yaml$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/yaml\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/yaml\";s:8:\"numParts\";i:8;}}',8),('entity.webform_submission_export_import.results_import','/admin/structure/webform/manage/{webform}/results/upload','/admin/structure/webform/manage/%/results/upload',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/webform/manage/{webform}/results/upload\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:85:\"\\Drupal\\webform_submission_export_import\\Form\\WebformSubmissionExportImportUploadForm\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"webform.submission_update_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/upload$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/results/upload\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/results/upload\";s:8:\"numParts\";i:7;}}',7),('entity.webform_submission_export_import.results_import.example.download','/admin/structure/webform/manage/{webform}/results/upload/example/download','/admin/structure/webform/manage/%/results/upload/example/download',495,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/results/upload/example/download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:101:\"\\Drupal\\webform_submission_export_import\\Controller\\WebformSubmissionExportImportController::download\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"webform.submission_update_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/upload/example/download$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/results/upload/example/download\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:495;s:14:\"patternOutline\";s:65:\"/admin/structure/webform/manage/%/results/upload/example/download\";s:8:\"numParts\";i:9;}}',9),('entity.webform_submission_export_import.results_import.example.view','/admin/structure/webform/manage/{webform}/results/upload/example/view','/admin/structure/webform/manage/%/results/upload/example/view',495,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/webform/manage/{webform}/results/upload/example/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:97:\"\\Drupal\\webform_submission_export_import\\Controller\\WebformSubmissionExportImportController::view\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"webform.submission_update_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/upload/example/view$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/results/upload/example/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:495;s:14:\"patternOutline\";s:61:\"/admin/structure/webform/manage/%/results/upload/example/view\";s:8:\"numParts\";i:9;}}',9),('entity.webform_ui.change_element','/admin/structure/webform/manage/{webform}/element/{key}/change','/admin/structure/webform/manage/%/element/%/change',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/webform/manage/{webform}/element/{key}/change\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:54:\"\\Drupal\\webform_ui\\Form\\WebformUiElementTypeChangeForm\";s:6:\"_title\";s:23:\"Select new element type\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformEditAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/element/(?P<key>[^/]++)/change$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/change\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/element\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/webform/manage/%/element/%/change\";s:8:\"numParts\";i:8;}}',8),('entity.webform_ui.element','/admin/structure/webform/manage/{webform}/element/add','/admin/structure/webform/manage/%/element/add',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/webform/manage/{webform}/element/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:54:\"\\Drupal\\webform_ui\\Form\\WebformUiElementTypeSelectForm\";s:6:\"_title\";s:17:\"Select an element\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformEditAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/element/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/element/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:45:\"/admin/structure/webform/manage/%/element/add\";s:8:\"numParts\";i:7;}}',7),('entity.webform_ui.element.add_form','/admin/structure/webform/manage/{webform}/element/add/{type}','/admin/structure/webform/manage/%/element/add/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/manage/{webform}/element/add/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\webform_ui\\Form\\WebformUiElementAddForm\";s:6:\"_title\";s:11:\"Add element\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:68:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformElementAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/element/add/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/element/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/element/add/%\";s:8:\"numParts\";i:8;}}',8),('entity.webform_ui.element.add_layout','/admin/structure/webform/manage/{webform}/element/add/layout','/admin/structure/webform/manage/%/element/add/layout',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/manage/{webform}/element/add/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:47:\"\\Drupal\\webform_ui\\Form\\WebformUiElementAddForm\";s:6:\"_title\";s:10:\"Add layout\";s:4:\"type\";s:15:\"webform_flexbox\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:68:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformElementAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/element/add/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/element/add/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/element/add/layout\";s:8:\"numParts\";i:8;}}',8),('entity.webform_ui.element.add_page','/admin/structure/webform/manage/{webform}/element/add/page','/admin/structure/webform/manage/%/element/add/page',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/webform/manage/{webform}/element/add/page\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:47:\"\\Drupal\\webform_ui\\Form\\WebformUiElementAddForm\";s:6:\"_title\";s:8:\"Add page\";s:4:\"type\";s:19:\"webform_wizard_page\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:68:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformElementAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/element/add/page$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/element/add/page\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:50:\"/admin/structure/webform/manage/%/element/add/page\";s:8:\"numParts\";i:8;}}',8),('entity.webform_ui.element.delete_form','/admin/structure/webform/manage/{webform}/element/{key}/delete','/admin/structure/webform/manage/%/element/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/webform/manage/{webform}/element/{key}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:50:\"\\Drupal\\webform_ui\\Form\\WebformUiElementDeleteForm\";s:6:\"_title\";s:14:\"Delete element\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformEditAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/element/(?P<key>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/element\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/webform/manage/%/element/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.webform_ui.element.duplicate_form','/admin/structure/webform/manage/{webform}/element/{key}/duplicate','/admin/structure/webform/manage/%/element/%/duplicate',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/webform/manage/{webform}/element/{key}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:53:\"\\Drupal\\webform_ui\\Form\\WebformUiElementDuplicateForm\";s:6:\"_title\";s:17:\"Duplicate element\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformEditAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/element/(?P<key>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/element\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/element/%/duplicate\";s:8:\"numParts\";i:8;}}',8),('entity.webform_ui.element.edit_form','/admin/structure/webform/manage/{webform}/element/{key}/edit','/admin/structure/webform/manage/%/element/%/edit',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/manage/{webform}/element/{key}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\webform_ui\\Form\\WebformUiElementEditForm\";s:6:\"_title\";s:12:\"Edit element\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform_ui\\Access\\WebformUiAccess::checkWebformEditAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/element/(?P<key>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/element\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/element/%/edit\";s:8:\"numParts\";i:8;}}',8),('field_ui.display_mode','/admin/structure/display-modes','/admin/structure/display-modes',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/structure/display-modes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:13:\"Display modes\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:24:\"administer display modes\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/display\\-modes$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/display-modes\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/structure/display-modes\";s:8:\"numParts\";i:3;}}',3),('field_ui.entity_form_mode_add','/admin/structure/display-modes/form/add','/admin/structure/display-modes/form/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/display-modes/form/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:78:\"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::formModeTypeSelection\";s:6:\"_title\";s:28:\"Choose form mode entity type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/display\\-modes/form/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/form/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/display-modes/form/add\";s:8:\"numParts\";i:5;}}',5),('field_ui.entity_view_mode_add','/admin/structure/display-modes/view/add','/admin/structure/display-modes/view/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/display-modes/view/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:78:\"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::viewModeTypeSelection\";s:6:\"_title\";s:28:\"Choose view mode entity type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/display\\-modes/view/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/view/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/display-modes/view/add\";s:8:\"numParts\";i:5;}}',5),('field_ui.field_add_block_content','/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}','/admin/structure/block-content/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:95:\"/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:53:\"/admin/structure/block-content/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_comment','/admin/structure/comment/manage/{comment_type}/add-field/{entity_type}/{field_name}','/admin/structure/comment/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/comment/manage/{comment_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:47:\"/admin/structure/comment/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_contact_message','/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}','/admin/structure/contact/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:47:\"/admin/structure/contact/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_menu_link_content','/admin/structure/menu/manage/{menu}/add-field/{entity_type}/{field_name}','/admin/structure/menu/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/menu/manage/{menu}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:35:\"administer menu_link_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"menu\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:110:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"menu\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:44:\"/admin/structure/menu/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_node','/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}','/admin/structure/types/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:45:\"/admin/structure/types/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}','/admin/structure/taxonomy/manage/%/overview/add-field/%/%',492,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:100:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:138:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/overview/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:492;s:14:\"patternOutline\";s:57:\"/admin/structure/taxonomy/manage/%/overview/add-field/%/%\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_add_user','/admin/config/people/accounts/add-field/{entity_type}/{field_name}','/admin/config/people/accounts/add-field/%/%',124,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/config/people/accounts/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"entity_type\";i:1;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/config/people/accounts/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/people/accounts/add-field\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"entity_type\";i:1;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:124;s:14:\"patternOutline\";s:43:\"/admin/config/people/accounts/add-field/%/%\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.display','/admin/structure/block-content/manage/{block_content_type}/display/add-group','/admin/structure/block-content/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/block-content/manage/{block_content_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:57:\"/admin/structure/block-content/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.display.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/add-group','/admin/structure/block-content/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:59:\"/admin/structure/block-content/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_block_content.form_display','/admin/structure/block-content/manage/{block_content_type}/form-display/add-group','/admin/structure/block-content/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/block-content/manage/{block_content_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:62:\"/admin/structure/block-content/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.form_display.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/add-group','/admin/structure/block-content/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:128:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:64:\"/admin/structure/block-content/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_comment.display','/admin/structure/comment/manage/{comment_type}/display/add-group','/admin/structure/comment/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/comment/manage/{comment_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/comment/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_comment.display.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/add-group','/admin/structure/comment/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/comment/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_comment.form_display','/admin/structure/comment/manage/{comment_type}/form-display/add-group','/admin/structure/comment/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/comment/manage/{comment_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/comment/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_comment.form_display.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/add-group','/admin/structure/comment/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/comment/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_contact_message.display','/admin/structure/contact/manage/{contact_form}/display/add-group','/admin/structure/contact/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/contact/manage/{contact_form}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/contact/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_contact_message.display.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/add-group','/admin/structure/contact/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/contact/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8);
INSERT INTO `router` VALUES ('field_ui.field_group_add_contact_message.form_display','/admin/structure/contact/manage/{contact_form}/form-display/add-group','/admin/structure/contact/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/contact/manage/{contact_form}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/contact/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_contact_message.form_display.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/add-group','/admin/structure/contact/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/contact/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_menu_link_content.display','/admin/structure/menu/manage/{menu}/display/add-group','/admin/structure/menu/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/menu/manage/{menu}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:36:\"administer menu_link_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:4:\"menu\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/menu/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_menu_link_content.display.view_mode','/admin/structure/menu/manage/{menu}/display/{view_mode_name}/add-group','/admin/structure/menu/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/menu/manage/{menu}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:36:\"administer menu_link_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:4:\"menu\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/menu/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_menu_link_content.form_display','/admin/structure/menu/manage/{menu}/form-display/add-group','/admin/structure/menu/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/menu/manage/{menu}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:41:\"administer menu_link_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:4:\"menu\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:53:\"/admin/structure/menu/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_menu_link_content.form_display.form_mode','/admin/structure/menu/manage/{menu}/form-display/{form_mode_name}/add-group','/admin/structure/menu/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/menu/manage/{menu}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:41:\"administer menu_link_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:4:\"menu\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/menu/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_node.display','/admin/structure/types/manage/{node_type}/display/add-group','/admin/structure/types/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/types/manage/{node_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/types/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_node.display.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}/add-group','/admin/structure/types/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/types/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_node.form_display','/admin/structure/types/manage/{node_type}/form-display/add-group','/admin/structure/types/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/types/manage/{node_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/types/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_node.form_display.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/add-group','/admin/structure/types/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:110:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/types/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_taxonomy_term.display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/add-group','/admin/structure/taxonomy/manage/%/overview/display/add-group',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/overview/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:61:\"/admin/structure/taxonomy/manage/%/overview/display/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_taxonomy_term.display.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/add-group','/admin/structure/taxonomy/manage/%/overview/display/%/add-group',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:63:\"/admin/structure/taxonomy/manage/%/overview/display/%/add-group\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_add_taxonomy_term.form_display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/add-group','/admin/structure/taxonomy/manage/%/overview/form-display/add-group',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/overview/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:66:\"/admin/structure/taxonomy/manage/%/overview/form-display/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_taxonomy_term.form_display.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/add-group','/admin/structure/taxonomy/manage/%/overview/form-display/%/add-group',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:103:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:132:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:68:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/add-group\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_add_user.display','/admin/config/people/accounts/display/add-group','/admin/config/people/accounts/display/add-group',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/people/accounts/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/config/people/accounts/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/people/accounts/display/add-group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:47:\"/admin/config/people/accounts/display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_user.display.view_mode','/admin/config/people/accounts/display/{view_mode_name}/add-group','/admin/config/people/accounts/display/%/add-group',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/config/people/accounts/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:49:\"/admin/config/people/accounts/display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_user.form_display','/admin/config/people/accounts/form-display/add-group','/admin/config/people/accounts/form-display/add-group',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/people/accounts/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/config/people/accounts/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/people/accounts/form-display/add-group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:52:\"/admin/config/people/accounts/form-display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_user.form_display.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}/add-group','/admin/config/people/accounts/form-display/%/add-group',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/people/accounts/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/config/people/accounts/form-display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_block_content.display','/admin/structure/block-content/manage/{block_content_type}/display/{field_group_name}/delete','/admin/structure/block-content/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/block-content/manage/{block_content_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:120:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_block_content.display.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/block-content/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:109:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:147:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:58:\"/admin/structure/block-content/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_block_content.form_display','/admin/structure/block-content/manage/{block_content_type}/form-display/{field_group_name}/delete','/admin/structure/block-content/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:61:\"/admin/structure/block-content/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_block_content.form_display.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/block-content/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:114:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:153:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:63:\"/admin/structure/block-content/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_comment.display','/admin/structure/comment/manage/{comment_type}/display/{field_group_name}/delete','/admin/structure/comment/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/comment/manage/{comment_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/comment/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_comment.display.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/comment/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:52:\"/admin/structure/comment/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_comment.form_display','/admin/structure/comment/manage/{comment_type}/form-display/{field_group_name}/delete','/admin/structure/comment/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/comment/manage/{comment_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/comment/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_comment.form_display.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/comment/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:140:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:57:\"/admin/structure/comment/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_contact_message.display','/admin/structure/contact/manage/{contact_form}/display/{field_group_name}/delete','/admin/structure/contact/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/contact/manage/{contact_form}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_contact_message.display.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/contact/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:52:\"/admin/structure/contact/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_contact_message.form_display','/admin/structure/contact/manage/{contact_form}/form-display/{field_group_name}/delete','/admin/structure/contact/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/contact/manage/{contact_form}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/contact/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_contact_message.form_display.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/contact/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:140:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:57:\"/admin/structure/contact/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_menu_link_content.display','/admin/structure/menu/manage/{menu}/display/{field_group_name}/delete','/admin/structure/menu/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/menu/manage/{menu}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:36:\"administer menu_link_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:4:\"menu\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/menu/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_menu_link_content.display.view_mode','/admin/structure/menu/manage/{menu}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/menu/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/menu/manage/{menu}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:36:\"administer menu_link_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:4:\"menu\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"menu\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:123:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"menu\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:49:\"/admin/structure/menu/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_menu_link_content.form_display','/admin/structure/menu/manage/{menu}/form-display/{field_group_name}/delete','/admin/structure/menu/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/structure/menu/manage/{menu}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:41:\"administer menu_link_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:4:\"menu\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"menu\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"menu\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/menu/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_menu_link_content.form_display.form_mode','/admin/structure/menu/manage/{menu}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/menu/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:91:\"/admin/structure/menu/manage/{menu}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:41:\"administer menu_link_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:4:\"menu\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"menu\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"menu\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:54:\"/admin/structure/menu/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_node.display','/admin/structure/types/manage/{node_type}/display/{field_group_name}/delete','/admin/structure/types/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/types/manage/{node_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_node.display.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/types/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:50:\"/admin/structure/types/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_node.form_display','/admin/structure/types/manage/{node_type}/form-display/{field_group_name}/delete','/admin/structure/types/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/types/manage/{node_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/types/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_node.form_display.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/types/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:135:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:55:\"/admin/structure/types/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_taxonomy_term.display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/display/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:124:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/display/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_taxonomy_term.display.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/display/%/%/delete',985,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:114:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:151:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:985;s:14:\"patternOutline\";s:62:\"/admin/structure/taxonomy/manage/%/overview/display/%/%/delete\";s:8:\"numParts\";i:10;}}',10),('field_ui.field_group_delete_taxonomy_term.form_display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/form-display/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:65:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_taxonomy_term.form_display.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/form-display/%/%/delete',985,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:119:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:157:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:985;s:14:\"patternOutline\";s:67:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/%/delete\";s:8:\"numParts\";i:10;}}',10),('field_ui.field_group_delete_user.display','/admin/config/people/accounts/display/{field_group_name}/delete','/admin/config/people/accounts/display/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/people/accounts/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/people/accounts/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_user.display.view_mode','/admin/config/people/accounts/display/{view_mode_name}/{field_group_name}/delete','/admin/config/people/accounts/display/%/%/delete',249,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/config/people/accounts/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"view_mode_name\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"view_mode_name\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:249;s:14:\"patternOutline\";s:48:\"/admin/config/people/accounts/display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_user.form_display','/admin/config/people/accounts/form-display/{field_group_name}/delete','/admin/config/people/accounts/form-display/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/people/accounts/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/people/accounts/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/people/accounts/form-display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_user.form_display.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}/{field_group_name}/delete','/admin/config/people/accounts/form-display/%/%/delete',249,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/config/people/accounts/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"form_mode_name\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"form_mode_name\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:249;s:14:\"patternOutline\";s:53:\"/admin/config/people/accounts/form-display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_add_block_content','/admin/structure/block-content/manage/{block_content_type}/fields/add-field','/admin/structure/block-content/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/block-content/manage/{block_content_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_comment','/admin/structure/comment/manage/{comment_type}/fields/add-field','/admin/structure/comment/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/comment/manage/{comment_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/comment/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_contact_message','/admin/structure/contact/manage/{contact_form}/fields/add-field','/admin/structure/contact/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/contact/manage/{contact_form}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_menu_link_content','/admin/structure/menu/manage/{menu}/fields/add-field','/admin/structure/menu/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/structure/menu/manage/{menu}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:35:\"administer menu_link_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/menu/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_node','/admin/structure/types/manage/{node_type}/fields/add-field','/admin/structure/types/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/types/manage/{node_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field','/admin/structure/taxonomy/manage/%/overview/fields/add-field',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/overview/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/fields/add-field\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_add_user','/admin/config/people/accounts/fields/add-field','/admin/config/people/accounts/fields/add-field',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/config/people/accounts/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/people/accounts/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/config/people/accounts/fields/add-field\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/fields/add-field\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_storage_config_reuse_block_content','/admin/structure/block-content/manage/{block_content_type}/fields/reuse','/admin/structure/block-content/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block-content/manage/{block_content_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:52:\"/admin/structure/block-content/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_comment','/admin/structure/comment/manage/{comment_type}/fields/reuse','/admin/structure/comment/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/comment/manage/{comment_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/comment/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_contact_message','/admin/structure/contact/manage/{contact_form}/fields/reuse','/admin/structure/contact/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/contact/manage/{contact_form}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/contact/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_menu_link_content','/admin/structure/menu/manage/{menu}/fields/reuse','/admin/structure/menu/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/menu/manage/{menu}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:35:\"administer menu_link_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:43:\"/admin/structure/menu/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_node','/admin/structure/types/manage/{node_type}/fields/reuse','/admin/structure/types/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/types/manage/{node_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:44:\"/admin/structure/types/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse','/admin/structure/taxonomy/manage/%/overview/fields/reuse',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:56:\"/admin/structure/taxonomy/manage/%/overview/fields/reuse\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_reuse_user','/admin/config/people/accounts/fields/reuse','/admin/config/people/accounts/fields/reuse',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/people/accounts/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/config/people/accounts/fields/reuse$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/fields/reuse\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:42:\"/admin/config/people/accounts/fields/reuse\";s:8:\"numParts\";i:6;}}',6),('file.ajax_progress','/file/progress/{key}','/file/progress/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/file/progress/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\file\\Controller\\FileWidgetAjaxController::progress\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/file/progress/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/file/progress\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/file/progress/%\";s:8:\"numParts\";i:3;}}',3),('filter.admin_overview','/admin/config/content/formats','/admin/config/content/formats',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/content/formats\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:13:\"filter_format\";s:6:\"_title\";s:24:\"Text formats and editors\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer filters\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/content/formats$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/content/formats\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/content/formats\";s:8:\"numParts\";i:4;}}',4),('filter.format_add','/admin/config/content/formats/add','/admin/config/content/formats/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/content/formats/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"filter_format.add\";s:6:\"_title\";s:15:\"Add text format\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:13:\"filter_format\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/content/formats/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/content/formats/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:33:\"/admin/config/content/formats/add\";s:8:\"numParts\";i:5;}}',5),('filter.tips','/filter/tips/{filter_format}','/filter/tips/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/filter/tips/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\filter\\Controller\\FilterController::filterTips\";s:6:\"_title\";s:12:\"Compose tips\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"filter_format.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/filter/tips/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/filter/tips\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:14:\"/filter/tips/%\";s:8:\"numParts\";i:3;}}',3),('filter.tips_all','/filter/tips','/filter/tips',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/filter/tips\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\filter\\Controller\\FilterController::filterTips\";s:6:\"_title\";s:12:\"Compose tips\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/filter/tips$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/filter/tips\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/filter/tips\";s:8:\"numParts\";i:2;}}',2),('glightbox.admin_settings','/admin/config/media/glightbox','/admin/config/media/glightbox',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/media/glightbox\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\glightbox\\Form\\GLightboxSettingsForm\";s:6:\"_title\";s:18:\"GLightbox settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/media/glightbox$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/media/glightbox\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/media/glightbox\";s:8:\"numParts\";i:4;}}',4),('help.help_topic','/admin/help/topic/{id}','/admin/help/topic/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/help/topic/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:64:\"\\Drupal\\help\\Controller\\HelpTopicPluginController::viewHelpTopic\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/help/topic/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/help/topic\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:19:\"/admin/help/topic/%\";s:8:\"numParts\";i:4;}}',4),('help.main','/admin/help','/admin/help',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/admin/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\help\\Controller\\HelpController::helpMain\";s:6:\"_title\";s:4:\"Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/admin/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/admin/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/admin/help\";s:8:\"numParts\";i:2;}}',2),('help.page','/admin/help/{name}','/admin/help/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/help/{name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\help\\Controller\\HelpController::helpPage\";s:6:\"_title\";s:4:\"Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/help/(?P<name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/admin/help\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:13:\"/admin/help/%\";s:8:\"numParts\";i:3;}}',3),('history.get_last_node_view','/history/get_node_read_timestamps','/history/get_node_read_timestamps',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/history/get_node_read_timestamps\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\history\\Controller\\HistoryController::getNodeReadTimestamps\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/history/get_node_read_timestamps$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/history/get_node_read_timestamps\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:33:\"/history/get_node_read_timestamps\";s:8:\"numParts\";i:2;}}',2),('history.read_node','/history/{node}/read','/history/%/read',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/history/{node}/read\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:54:\"\\Drupal\\history\\Controller\\HistoryController::readNode\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:9:\"node.view\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/history/(?P<node>\\d+)/read$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/read\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/history\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/history/%/read\";s:8:\"numParts\";i:3;}}',3),('image.effect_add_form','/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}','/admin/config/media/image-styles/manage/%/add/%',250,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\image\\Form\\ImageEffectAddForm\";s:6:\"_title\";s:16:\"Add image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/add/(?P<image_effect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:47:\"/admin/config/media/image-styles/manage/%/add/%\";s:8:\"numParts\";i:8;}}',8),('image.effect_delete','/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete','/admin/config/media/image-styles/manage/%/effects/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\image\\Form\\ImageEffectDeleteForm\";s:6:\"_title\";s:19:\"Delete image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/effects\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:58:\"/admin/config/media/image-styles/manage/%/effects/%/delete\";s:8:\"numParts\";i:9;}}',9),('image.effect_edit_form','/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}','/admin/config/media/image-styles/manage/%/effects/%',250,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\image\\Form\\ImageEffectEditForm\";s:6:\"_title\";s:17:\"Edit image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/effects\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:51:\"/admin/config/media/image-styles/manage/%/effects/%\";s:8:\"numParts\";i:8;}}',8),('image.style_add','/admin/config/media/image-styles/add','/admin/config/media/image-styles/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/media/image-styles/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"image_style.add\";s:6:\"_title\";s:15:\"Add image style\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/media/image\\-styles/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/media/image-styles/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/media/image-styles/add\";s:8:\"numParts\";i:5;}}',5),('image.style_private','/system/files/styles/{image_style}/{scheme}','/system/files/styles/%/%',28,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/system/files/styles/{image_style}/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:62:\"\\Drupal\\image\\Controller\\ImageStyleDownloadController::deliver\";s:26:\"required_derivative_scheme\";s:7:\"private\";s:25:\"_disable_route_normalizer\";b:1;}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/system/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/system/files/styles\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:24:\"/system/files/styles/%/%\";s:8:\"numParts\";i:5;}}',5),('image.style_public','/sites/default/files/styles/{image_style}/{scheme}','/sites/default/files/styles/%/%',60,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/sites/default/files/styles/{image_style}/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:61:\"Drupal\\image\\Controller\\ImageStyleDownloadController::deliver\";s:26:\"required_derivative_scheme\";s:6:\"public\";s:25:\"_disable_route_normalizer\";b:1;}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/sites/default/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/sites/default/files/styles\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:60;s:14:\"patternOutline\";s:31:\"/sites/default/files/styles/%/%\";s:8:\"numParts\";i:6;}}',6),('jsonapi.action--action.collection','/jsonapi/action/action','/jsonapi/action/action',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/jsonapi/action/action\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:14:\"action--action\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/jsonapi/action/action$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/jsonapi/action/action\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/jsonapi/action/action\";s:8:\"numParts\";i:3;}}',3),('jsonapi.action--action.individual','/jsonapi/action/action/{entity}','/jsonapi/action/action/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/action/action/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:14:\"action--action\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:13:\"entity:action\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/jsonapi/action/action/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/jsonapi/action/action\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:24:\"/jsonapi/action/action/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.base_field_override--base_field_override.collection','/jsonapi/base_field_override/base_field_override','/jsonapi/base_field_override/base_field_override',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/base_field_override/base_field_override\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:40:\"base_field_override--base_field_override\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/jsonapi/base_field_override/base_field_override$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/base_field_override/base_field_override\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:48:\"/jsonapi/base_field_override/base_field_override\";s:8:\"numParts\";i:3;}}',3),('jsonapi.base_field_override--base_field_override.individual','/jsonapi/base_field_override/base_field_override/{entity}','/jsonapi/base_field_override/base_field_override/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/base_field_override/base_field_override/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:40:\"base_field_override--base_field_override\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:26:\"entity:base_field_override\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/base_field_override/base_field_override/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/base_field_override/base_field_override\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:50:\"/jsonapi/base_field_override/base_field_override/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.behavior_settings--behavior_settings.collection','/jsonapi/behavior_settings/behavior_settings','/jsonapi/behavior_settings/behavior_settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/jsonapi/behavior_settings/behavior_settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:36:\"behavior_settings--behavior_settings\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/jsonapi/behavior_settings/behavior_settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/jsonapi/behavior_settings/behavior_settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:44:\"/jsonapi/behavior_settings/behavior_settings\";s:8:\"numParts\";i:3;}}',3),('jsonapi.behavior_settings--behavior_settings.individual','/jsonapi/behavior_settings/behavior_settings/{entity}','/jsonapi/behavior_settings/behavior_settings/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/jsonapi/behavior_settings/behavior_settings/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:36:\"behavior_settings--behavior_settings\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:behavior_settings\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/jsonapi/behavior_settings/behavior_settings/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/jsonapi/behavior_settings/behavior_settings\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:46:\"/jsonapi/behavior_settings/behavior_settings/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.block--block.collection','/jsonapi/block/block','/jsonapi/block/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/jsonapi/block/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:12:\"block--block\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/jsonapi/block/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/jsonapi/block/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/jsonapi/block/block\";s:8:\"numParts\";i:3;}}',3),('jsonapi.block--block.individual','/jsonapi/block/block/{entity}','/jsonapi/block/block/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/jsonapi/block/block/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:12:\"block--block\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/jsonapi/block/block/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/jsonapi/block/block\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/jsonapi/block/block/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.block_content--basic.block_content_type.related','/jsonapi/block_content/basic/{entity}/block_content_type','/jsonapi/block_content/basic/%/block_content_type',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/jsonapi/block_content/basic/{entity}/block_content_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:18:\"block_content_type\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:23:\"block_content_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/block_content_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/block_content_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:49:\"/jsonapi/block_content/basic/%/block_content_type\";s:8:\"numParts\";i:5;}}',5),('jsonapi.block_content--basic.block_content_type.relationship.delete','/jsonapi/block_content/basic/{entity}/relationships/block_content_type','/jsonapi/block_content/basic/%/relationships/block_content_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/jsonapi/block_content/basic/{entity}/relationships/block_content_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:18:\"block_content_type\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:23:\"block_content_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/relationships/block_content_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/relationships/block_content_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:63:\"/jsonapi/block_content/basic/%/relationships/block_content_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.block_content--basic.block_content_type.relationship.get','/jsonapi/block_content/basic/{entity}/relationships/block_content_type','/jsonapi/block_content/basic/%/relationships/block_content_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/jsonapi/block_content/basic/{entity}/relationships/block_content_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:18:\"block_content_type\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:23:\"block_content_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/relationships/block_content_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/relationships/block_content_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:63:\"/jsonapi/block_content/basic/%/relationships/block_content_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.block_content--basic.block_content_type.relationship.patch','/jsonapi/block_content/basic/{entity}/relationships/block_content_type','/jsonapi/block_content/basic/%/relationships/block_content_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/jsonapi/block_content/basic/{entity}/relationships/block_content_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:18:\"block_content_type\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:23:\"block_content_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/relationships/block_content_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/relationships/block_content_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:63:\"/jsonapi/block_content/basic/%/relationships/block_content_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.block_content--basic.block_content_type.relationship.post','/jsonapi/block_content/basic/{entity}/relationships/block_content_type','/jsonapi/block_content/basic/%/relationships/block_content_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/jsonapi/block_content/basic/{entity}/relationships/block_content_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:18:\"block_content_type\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:23:\"block_content_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/relationships/block_content_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/relationships/block_content_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:63:\"/jsonapi/block_content/basic/%/relationships/block_content_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.block_content--basic.collection','/jsonapi/block_content/basic','/jsonapi/block_content/basic',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/jsonapi/block_content/basic\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/jsonapi/block_content/basic$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/jsonapi/block_content/basic\";s:8:\"numParts\";i:3;}}',3),('jsonapi.block_content--basic.collection.post','/jsonapi/block_content/basic','/jsonapi/block_content/basic',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/jsonapi/block_content/basic\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:19:\"block_content:basic\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/jsonapi/block_content/basic$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/jsonapi/block_content/basic\";s:8:\"numParts\";i:3;}}',3),('jsonapi.block_content--basic.individual','/jsonapi/block_content/basic/{entity}','/jsonapi/block_content/basic/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/block_content/basic/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:30:\"/jsonapi/block_content/basic/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.block_content--basic.individual.delete','/jsonapi/block_content/basic/{entity}','/jsonapi/block_content/basic/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/block_content/basic/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:30:\"/jsonapi/block_content/basic/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.block_content--basic.individual.patch','/jsonapi/block_content/basic/{entity}','/jsonapi/block_content/basic/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/block_content/basic/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:30:\"/jsonapi/block_content/basic/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.block_content--basic.revision_user.related','/jsonapi/block_content/basic/{entity}/revision_user','/jsonapi/block_content/basic/%/revision_user',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/block_content/basic/{entity}/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:13:\"revision_user\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:44:\"/jsonapi/block_content/basic/%/revision_user\";s:8:\"numParts\";i:5;}}',5),('jsonapi.block_content--basic.revision_user.relationship.delete','/jsonapi/block_content/basic/{entity}/relationships/revision_user','/jsonapi/block_content/basic/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/jsonapi/block_content/basic/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:58:\"/jsonapi/block_content/basic/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.block_content--basic.revision_user.relationship.get','/jsonapi/block_content/basic/{entity}/relationships/revision_user','/jsonapi/block_content/basic/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/jsonapi/block_content/basic/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:58:\"/jsonapi/block_content/basic/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.block_content--basic.revision_user.relationship.patch','/jsonapi/block_content/basic/{entity}/relationships/revision_user','/jsonapi/block_content/basic/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/jsonapi/block_content/basic/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:58:\"/jsonapi/block_content/basic/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.block_content--basic.revision_user.relationship.post','/jsonapi/block_content/basic/{entity}/relationships/revision_user','/jsonapi/block_content/basic/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/jsonapi/block_content/basic/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:20:\"block_content--basic\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/jsonapi/block_content/basic/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/block_content/basic\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:58:\"/jsonapi/block_content/basic/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.block_content_type--block_content_type.collection','/jsonapi/block_content_type/block_content_type','/jsonapi/block_content_type/block_content_type',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/jsonapi/block_content_type/block_content_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:38:\"block_content_type--block_content_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/jsonapi/block_content_type/block_content_type$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/jsonapi/block_content_type/block_content_type\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:46:\"/jsonapi/block_content_type/block_content_type\";s:8:\"numParts\";i:3;}}',3),('jsonapi.block_content_type--block_content_type.individual','/jsonapi/block_content_type/block_content_type/{entity}','/jsonapi/block_content_type/block_content_type/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/block_content_type/block_content_type/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:38:\"block_content_type--block_content_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/block_content_type/block_content_type/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/jsonapi/block_content_type/block_content_type\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:48:\"/jsonapi/block_content_type/block_content_type/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.ckeditor5_template--ckeditor5_template.collection','/jsonapi/ckeditor5_template/ckeditor5_template','/jsonapi/ckeditor5_template/ckeditor5_template',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/jsonapi/ckeditor5_template/ckeditor5_template\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:38:\"ckeditor5_template--ckeditor5_template\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/jsonapi/ckeditor5_template/ckeditor5_template$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/jsonapi/ckeditor5_template/ckeditor5_template\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:46:\"/jsonapi/ckeditor5_template/ckeditor5_template\";s:8:\"numParts\";i:3;}}',3),('jsonapi.ckeditor5_template--ckeditor5_template.individual','/jsonapi/ckeditor5_template/ckeditor5_template/{entity}','/jsonapi/ckeditor5_template/ckeditor5_template/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/ckeditor5_template/ckeditor5_template/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:38:\"ckeditor5_template--ckeditor5_template\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/ckeditor5_template/ckeditor5_template/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/jsonapi/ckeditor5_template/ckeditor5_template\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:48:\"/jsonapi/ckeditor5_template/ckeditor5_template/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.comment--comment.collection','/jsonapi/comment/comment','/jsonapi/comment/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/jsonapi/comment/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/jsonapi/comment/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/jsonapi/comment/comment\";s:8:\"numParts\";i:3;}}',3),('jsonapi.comment--comment.collection.post','/jsonapi/comment/comment','/jsonapi/comment/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/jsonapi/comment/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:15:\"comment:comment\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/jsonapi/comment/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/jsonapi/comment/comment\";s:8:\"numParts\";i:3;}}',3),('jsonapi.comment--comment.comment_type.related','/jsonapi/comment/comment/{entity}/comment_type','/jsonapi/comment/comment/%/comment_type',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/jsonapi/comment/comment/{entity}/comment_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:12:\"comment_type\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:17:\"comment_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/comment_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/comment_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:39:\"/jsonapi/comment/comment/%/comment_type\";s:8:\"numParts\";i:5;}}',5),('jsonapi.comment--comment.comment_type.relationship.delete','/jsonapi/comment/comment/{entity}/relationships/comment_type','/jsonapi/comment/comment/%/relationships/comment_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/jsonapi/comment/comment/{entity}/relationships/comment_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"comment_type\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"comment_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/comment_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/comment_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:53:\"/jsonapi/comment/comment/%/relationships/comment_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.comment_type.relationship.get','/jsonapi/comment/comment/{entity}/relationships/comment_type','/jsonapi/comment/comment/%/relationships/comment_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/jsonapi/comment/comment/{entity}/relationships/comment_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"comment_type\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"comment_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/comment_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/comment_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:53:\"/jsonapi/comment/comment/%/relationships/comment_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.comment_type.relationship.patch','/jsonapi/comment/comment/{entity}/relationships/comment_type','/jsonapi/comment/comment/%/relationships/comment_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/jsonapi/comment/comment/{entity}/relationships/comment_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"comment_type\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"comment_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/comment_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/comment_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:53:\"/jsonapi/comment/comment/%/relationships/comment_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.comment_type.relationship.post','/jsonapi/comment/comment/{entity}/relationships/comment_type','/jsonapi/comment/comment/%/relationships/comment_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/jsonapi/comment/comment/{entity}/relationships/comment_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"comment_type\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"comment_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/comment_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/comment_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:53:\"/jsonapi/comment/comment/%/relationships/comment_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.entity_id.related','/jsonapi/comment/comment/{entity}/entity_id','/jsonapi/comment/comment/%/entity_id',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/comment/comment/{entity}/entity_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:9:\"entity_id\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:14:\"entity_id.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/entity_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/entity_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:36:\"/jsonapi/comment/comment/%/entity_id\";s:8:\"numParts\";i:5;}}',5),('jsonapi.comment--comment.entity_id.relationship.delete','/jsonapi/comment/comment/{entity}/relationships/entity_id','/jsonapi/comment/comment/%/relationships/entity_id',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/comment/comment/{entity}/relationships/entity_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"entity_id\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"entity_id.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/entity_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/entity_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/comment/comment/%/relationships/entity_id\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.entity_id.relationship.get','/jsonapi/comment/comment/{entity}/relationships/entity_id','/jsonapi/comment/comment/%/relationships/entity_id',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/comment/comment/{entity}/relationships/entity_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"entity_id\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"entity_id.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/entity_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/entity_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/comment/comment/%/relationships/entity_id\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.entity_id.relationship.patch','/jsonapi/comment/comment/{entity}/relationships/entity_id','/jsonapi/comment/comment/%/relationships/entity_id',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/comment/comment/{entity}/relationships/entity_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"entity_id\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"entity_id.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/entity_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/entity_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/comment/comment/%/relationships/entity_id\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.entity_id.relationship.post','/jsonapi/comment/comment/{entity}/relationships/entity_id','/jsonapi/comment/comment/%/relationships/entity_id',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/comment/comment/{entity}/relationships/entity_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"entity_id\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"entity_id.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/entity_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/entity_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/comment/comment/%/relationships/entity_id\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.individual','/jsonapi/comment/comment/{entity}','/jsonapi/comment/comment/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/comment/comment/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:26:\"/jsonapi/comment/comment/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.comment--comment.individual.delete','/jsonapi/comment/comment/{entity}','/jsonapi/comment/comment/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/comment/comment/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:26:\"/jsonapi/comment/comment/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.comment--comment.individual.patch','/jsonapi/comment/comment/{entity}','/jsonapi/comment/comment/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/comment/comment/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:26:\"/jsonapi/comment/comment/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.comment--comment.pid.related','/jsonapi/comment/comment/{entity}/pid','/jsonapi/comment/comment/%/pid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/comment/comment/{entity}/pid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"pid\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"pid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/pid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/pid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:30:\"/jsonapi/comment/comment/%/pid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.comment--comment.pid.relationship.delete','/jsonapi/comment/comment/{entity}/relationships/pid','/jsonapi/comment/comment/%/relationships/pid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/comment/comment/{entity}/relationships/pid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"pid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"pid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/pid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/pid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/comment/comment/%/relationships/pid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.pid.relationship.get','/jsonapi/comment/comment/{entity}/relationships/pid','/jsonapi/comment/comment/%/relationships/pid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/comment/comment/{entity}/relationships/pid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"pid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"pid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/pid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/pid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/comment/comment/%/relationships/pid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.pid.relationship.patch','/jsonapi/comment/comment/{entity}/relationships/pid','/jsonapi/comment/comment/%/relationships/pid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/comment/comment/{entity}/relationships/pid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"pid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"pid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/pid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/pid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/comment/comment/%/relationships/pid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.pid.relationship.post','/jsonapi/comment/comment/{entity}/relationships/pid','/jsonapi/comment/comment/%/relationships/pid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/comment/comment/{entity}/relationships/pid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"pid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"pid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/pid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/pid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/comment/comment/%/relationships/pid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.uid.related','/jsonapi/comment/comment/{entity}/uid','/jsonapi/comment/comment/%/uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/comment/comment/{entity}/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"uid\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:30:\"/jsonapi/comment/comment/%/uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.comment--comment.uid.relationship.delete','/jsonapi/comment/comment/{entity}/relationships/uid','/jsonapi/comment/comment/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/comment/comment/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/comment/comment/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.uid.relationship.get','/jsonapi/comment/comment/{entity}/relationships/uid','/jsonapi/comment/comment/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/comment/comment/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/comment/comment/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.uid.relationship.patch','/jsonapi/comment/comment/{entity}/relationships/uid','/jsonapi/comment/comment/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/comment/comment/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/comment/comment/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment--comment.uid.relationship.post','/jsonapi/comment/comment/{entity}/relationships/uid','/jsonapi/comment/comment/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/comment/comment/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:16:\"comment--comment\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/comment/comment/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/comment/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/comment/comment/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.comment_type--comment_type.collection','/jsonapi/comment_type/comment_type','/jsonapi/comment_type/comment_type',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/comment_type/comment_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:26:\"comment_type--comment_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/jsonapi/comment_type/comment_type$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/comment_type/comment_type\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:34:\"/jsonapi/comment_type/comment_type\";s:8:\"numParts\";i:3;}}',3),('jsonapi.comment_type--comment_type.individual','/jsonapi/comment_type/comment_type/{entity}','/jsonapi/comment_type/comment_type/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/comment_type/comment_type/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:26:\"comment_type--comment_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/comment_type/comment_type/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/comment_type/comment_type\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:36:\"/jsonapi/comment_type/comment_type/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.configurable_language--configurable_language.collection','/jsonapi/configurable_language/configurable_language','/jsonapi/configurable_language/configurable_language',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/jsonapi/configurable_language/configurable_language\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:44:\"configurable_language--configurable_language\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/jsonapi/configurable_language/configurable_language$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/jsonapi/configurable_language/configurable_language\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:52:\"/jsonapi/configurable_language/configurable_language\";s:8:\"numParts\";i:3;}}',3),('jsonapi.configurable_language--configurable_language.individual','/jsonapi/configurable_language/configurable_language/{entity}','/jsonapi/configurable_language/configurable_language/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/configurable_language/configurable_language/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:44:\"configurable_language--configurable_language\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:28:\"entity:configurable_language\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/configurable_language/configurable_language/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/jsonapi/configurable_language/configurable_language\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:54:\"/jsonapi/configurable_language/configurable_language/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.config_split--config_split.collection','/jsonapi/config_split/config_split','/jsonapi/config_split/config_split',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/config_split/config_split\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:26:\"config_split--config_split\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/jsonapi/config_split/config_split$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/config_split/config_split\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:34:\"/jsonapi/config_split/config_split\";s:8:\"numParts\";i:3;}}',3),('jsonapi.config_split--config_split.individual','/jsonapi/config_split/config_split/{entity}','/jsonapi/config_split/config_split/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/config_split/config_split/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:26:\"config_split--config_split\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:19:\"entity:config_split\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/config_split/config_split/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/config_split/config_split\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:36:\"/jsonapi/config_split/config_split/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.contact_form--contact_form.collection','/jsonapi/contact_form/contact_form','/jsonapi/contact_form/contact_form',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/contact_form/contact_form\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:26:\"contact_form--contact_form\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/jsonapi/contact_form/contact_form$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/contact_form/contact_form\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:34:\"/jsonapi/contact_form/contact_form\";s:8:\"numParts\";i:3;}}',3),('jsonapi.contact_form--contact_form.individual','/jsonapi/contact_form/contact_form/{entity}','/jsonapi/contact_form/contact_form/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/contact_form/contact_form/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:26:\"contact_form--contact_form\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/contact_form/contact_form/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/contact_form/contact_form\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:36:\"/jsonapi/contact_form/contact_form/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.contact_message--feedback.collection.post','/jsonapi/contact_message/feedback','/jsonapi/contact_message/feedback',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/contact_message/feedback\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:25:\"contact_message--feedback\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:24:\"contact_message:feedback\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/jsonapi/contact_message/feedback$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/contact_message/feedback\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:33:\"/jsonapi/contact_message/feedback\";s:8:\"numParts\";i:3;}}',3),('jsonapi.contact_message--personal.collection.post','/jsonapi/contact_message/personal','/jsonapi/contact_message/personal',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/contact_message/personal\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:25:\"contact_message--personal\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:24:\"contact_message:personal\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/jsonapi/contact_message/personal$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/contact_message/personal\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:33:\"/jsonapi/contact_message/personal\";s:8:\"numParts\";i:3;}}',3),('jsonapi.date_format--date_format.collection','/jsonapi/date_format/date_format','/jsonapi/date_format/date_format',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/date_format/date_format\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:24:\"date_format--date_format\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/date_format/date_format$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/date_format/date_format\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/jsonapi/date_format/date_format\";s:8:\"numParts\";i:3;}}',3),('jsonapi.date_format--date_format.individual','/jsonapi/date_format/date_format/{entity}','/jsonapi/date_format/date_format/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/date_format/date_format/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:24:\"date_format--date_format\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/date_format/date_format/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/date_format/date_format\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/jsonapi/date_format/date_format/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.editor--editor.collection','/jsonapi/editor/editor','/jsonapi/editor/editor',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/jsonapi/editor/editor\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:14:\"editor--editor\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/jsonapi/editor/editor$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/jsonapi/editor/editor\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/jsonapi/editor/editor\";s:8:\"numParts\";i:3;}}',3),('jsonapi.editor--editor.individual','/jsonapi/editor/editor/{entity}','/jsonapi/editor/editor/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/editor/editor/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:14:\"editor--editor\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/jsonapi/editor/editor/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/jsonapi/editor/editor\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:24:\"/jsonapi/editor/editor/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.entity_form_display--entity_form_display.collection','/jsonapi/entity_form_display/entity_form_display','/jsonapi/entity_form_display/entity_form_display',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/entity_form_display/entity_form_display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:40:\"entity_form_display--entity_form_display\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/jsonapi/entity_form_display/entity_form_display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/entity_form_display/entity_form_display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:48:\"/jsonapi/entity_form_display/entity_form_display\";s:8:\"numParts\";i:3;}}',3),('jsonapi.entity_form_display--entity_form_display.individual','/jsonapi/entity_form_display/entity_form_display/{entity}','/jsonapi/entity_form_display/entity_form_display/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/entity_form_display/entity_form_display/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:40:\"entity_form_display--entity_form_display\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:26:\"entity:entity_form_display\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/entity_form_display/entity_form_display/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/entity_form_display/entity_form_display\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:50:\"/jsonapi/entity_form_display/entity_form_display/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.entity_form_mode--entity_form_mode.collection','/jsonapi/entity_form_mode/entity_form_mode','/jsonapi/entity_form_mode/entity_form_mode',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/entity_form_mode/entity_form_mode\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:34:\"entity_form_mode--entity_form_mode\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/jsonapi/entity_form_mode/entity_form_mode$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/entity_form_mode/entity_form_mode\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:42:\"/jsonapi/entity_form_mode/entity_form_mode\";s:8:\"numParts\";i:3;}}',3),('jsonapi.entity_form_mode--entity_form_mode.individual','/jsonapi/entity_form_mode/entity_form_mode/{entity}','/jsonapi/entity_form_mode/entity_form_mode/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/entity_form_mode/entity_form_mode/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:34:\"entity_form_mode--entity_form_mode\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/entity_form_mode/entity_form_mode/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/entity_form_mode/entity_form_mode\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:44:\"/jsonapi/entity_form_mode/entity_form_mode/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.entity_view_display--entity_view_display.collection','/jsonapi/entity_view_display/entity_view_display','/jsonapi/entity_view_display/entity_view_display',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/entity_view_display/entity_view_display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:40:\"entity_view_display--entity_view_display\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/jsonapi/entity_view_display/entity_view_display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/entity_view_display/entity_view_display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:48:\"/jsonapi/entity_view_display/entity_view_display\";s:8:\"numParts\";i:3;}}',3),('jsonapi.entity_view_display--entity_view_display.individual','/jsonapi/entity_view_display/entity_view_display/{entity}','/jsonapi/entity_view_display/entity_view_display/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/entity_view_display/entity_view_display/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:40:\"entity_view_display--entity_view_display\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:26:\"entity:entity_view_display\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/entity_view_display/entity_view_display/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/entity_view_display/entity_view_display\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:50:\"/jsonapi/entity_view_display/entity_view_display/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.entity_view_mode--entity_view_mode.collection','/jsonapi/entity_view_mode/entity_view_mode','/jsonapi/entity_view_mode/entity_view_mode',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/entity_view_mode/entity_view_mode\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:34:\"entity_view_mode--entity_view_mode\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/jsonapi/entity_view_mode/entity_view_mode$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/entity_view_mode/entity_view_mode\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:42:\"/jsonapi/entity_view_mode/entity_view_mode\";s:8:\"numParts\";i:3;}}',3),('jsonapi.entity_view_mode--entity_view_mode.individual','/jsonapi/entity_view_mode/entity_view_mode/{entity}','/jsonapi/entity_view_mode/entity_view_mode/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/entity_view_mode/entity_view_mode/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:34:\"entity_view_mode--entity_view_mode\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/entity_view_mode/entity_view_mode/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/entity_view_mode/entity_view_mode\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:44:\"/jsonapi/entity_view_mode/entity_view_mode/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.field_config--field_config.collection','/jsonapi/field_config/field_config','/jsonapi/field_config/field_config',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/field_config/field_config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:26:\"field_config--field_config\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/jsonapi/field_config/field_config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/field_config/field_config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:34:\"/jsonapi/field_config/field_config\";s:8:\"numParts\";i:3;}}',3),('jsonapi.field_config--field_config.individual','/jsonapi/field_config/field_config/{entity}','/jsonapi/field_config/field_config/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/field_config/field_config/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:26:\"field_config--field_config\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/field_config/field_config/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/field_config/field_config\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:36:\"/jsonapi/field_config/field_config/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.field_storage_config--field_storage_config.collection','/jsonapi/field_storage_config/field_storage_config','/jsonapi/field_storage_config/field_storage_config',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/jsonapi/field_storage_config/field_storage_config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:42:\"field_storage_config--field_storage_config\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/field_storage_config/field_storage_config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:50:\"/jsonapi/field_storage_config/field_storage_config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:50:\"/jsonapi/field_storage_config/field_storage_config\";s:8:\"numParts\";i:3;}}',3),('jsonapi.field_storage_config--field_storage_config.individual','/jsonapi/field_storage_config/field_storage_config/{entity}','/jsonapi/field_storage_config/field_storage_config/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/jsonapi/field_storage_config/field_storage_config/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:42:\"field_storage_config--field_storage_config\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:27:\"entity:field_storage_config\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/jsonapi/field_storage_config/field_storage_config/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:50:\"/jsonapi/field_storage_config/field_storage_config\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:52:\"/jsonapi/field_storage_config/field_storage_config/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.file--file.collection','/jsonapi/file/file','/jsonapi/file/file',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/jsonapi/file/file\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/jsonapi/file/file$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/jsonapi/file/file\";s:8:\"numParts\";i:3;}}',3),('jsonapi.file--file.collection.post','/jsonapi/file/file','/jsonapi/file/file',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/jsonapi/file/file\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:9:\"file:file\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/jsonapi/file/file$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/jsonapi/file/file\";s:8:\"numParts\";i:3;}}',3),('jsonapi.file--file.individual','/jsonapi/file/file/{entity}','/jsonapi/file/file/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/file/file/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/file/file/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/file/file/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.file--file.individual.delete','/jsonapi/file/file/{entity}','/jsonapi/file/file/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/file/file/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/file/file/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/file/file/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.file--file.individual.patch','/jsonapi/file/file/{entity}','/jsonapi/file/file/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/file/file/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/file/file/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/file/file/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.file--file.uid.related','/jsonapi/file/file/{entity}/uid','/jsonapi/file/file/%/uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/file/file/{entity}/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"uid\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/jsonapi/file/file/(?P<entity>[^/]++)/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:24:\"/jsonapi/file/file/%/uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.file--file.uid.relationship.delete','/jsonapi/file/file/{entity}/relationships/uid','/jsonapi/file/file/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/file/file/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/file/file/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:38:\"/jsonapi/file/file/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.file--file.uid.relationship.get','/jsonapi/file/file/{entity}/relationships/uid','/jsonapi/file/file/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/file/file/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/file/file/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:38:\"/jsonapi/file/file/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.file--file.uid.relationship.patch','/jsonapi/file/file/{entity}/relationships/uid','/jsonapi/file/file/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/file/file/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/file/file/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:38:\"/jsonapi/file/file/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.file--file.uid.relationship.post','/jsonapi/file/file/{entity}/relationships/uid','/jsonapi/file/file/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/file/file/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:10:\"file--file\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/file/file/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/file/file\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:38:\"/jsonapi/file/file/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.filter_format--filter_format.collection','/jsonapi/filter_format/filter_format','/jsonapi/filter_format/filter_format',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/jsonapi/filter_format/filter_format\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:28:\"filter_format--filter_format\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/jsonapi/filter_format/filter_format$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/jsonapi/filter_format/filter_format\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:36:\"/jsonapi/filter_format/filter_format\";s:8:\"numParts\";i:3;}}',3),('jsonapi.filter_format--filter_format.individual','/jsonapi/filter_format/filter_format/{entity}','/jsonapi/filter_format/filter_format/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/filter_format/filter_format/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:28:\"filter_format--filter_format\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/filter_format/filter_format/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/jsonapi/filter_format/filter_format\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:38:\"/jsonapi/filter_format/filter_format/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.image_style--image_style.collection','/jsonapi/image_style/image_style','/jsonapi/image_style/image_style',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/image_style/image_style\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:24:\"image_style--image_style\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/image_style/image_style$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/image_style/image_style\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/jsonapi/image_style/image_style\";s:8:\"numParts\";i:3;}}',3),('jsonapi.image_style--image_style.individual','/jsonapi/image_style/image_style/{entity}','/jsonapi/image_style/image_style/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/image_style/image_style/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:24:\"image_style--image_style\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/image_style/image_style/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/image_style/image_style\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/jsonapi/image_style/image_style/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.jsonapi_resource_config--jsonapi_resource_config.collection','/jsonapi/jsonapi_resource_config/jsonapi_resource_config','/jsonapi/jsonapi_resource_config/jsonapi_resource_config',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/jsonapi/jsonapi_resource_config/jsonapi_resource_config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:48:\"jsonapi_resource_config--jsonapi_resource_config\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/jsonapi/jsonapi_resource_config/jsonapi_resource_config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:56:\"/jsonapi/jsonapi_resource_config/jsonapi_resource_config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:56:\"/jsonapi/jsonapi_resource_config/jsonapi_resource_config\";s:8:\"numParts\";i:3;}}',3),('jsonapi.jsonapi_resource_config--jsonapi_resource_config.individual','/jsonapi/jsonapi_resource_config/jsonapi_resource_config/{entity}','/jsonapi/jsonapi_resource_config/jsonapi_resource_config/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/jsonapi/jsonapi_resource_config/jsonapi_resource_config/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:48:\"jsonapi_resource_config--jsonapi_resource_config\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:30:\"entity:jsonapi_resource_config\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/jsonapi/jsonapi_resource_config/jsonapi_resource_config/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:56:\"/jsonapi/jsonapi_resource_config/jsonapi_resource_config\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:58:\"/jsonapi/jsonapi_resource_config/jsonapi_resource_config/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.language_content_settings--language_content_settings.collection','/jsonapi/language_content_settings/language_content_settings','/jsonapi/language_content_settings/language_content_settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/jsonapi/language_content_settings/language_content_settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:52:\"language_content_settings--language_content_settings\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/jsonapi/language_content_settings/language_content_settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/jsonapi/language_content_settings/language_content_settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:60:\"/jsonapi/language_content_settings/language_content_settings\";s:8:\"numParts\";i:3;}}',3),('jsonapi.language_content_settings--language_content_settings.individual','/jsonapi/language_content_settings/language_content_settings/{entity}','/jsonapi/language_content_settings/language_content_settings/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/language_content_settings/language_content_settings/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:52:\"language_content_settings--language_content_settings\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:32:\"entity:language_content_settings\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/language_content_settings/language_content_settings/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/jsonapi/language_content_settings/language_content_settings\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:62:\"/jsonapi/language_content_settings/language_content_settings/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.linkit_profile--linkit_profile.collection','/jsonapi/linkit_profile/linkit_profile','/jsonapi/linkit_profile/linkit_profile',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/jsonapi/linkit_profile/linkit_profile\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:30:\"linkit_profile--linkit_profile\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/jsonapi/linkit_profile/linkit_profile$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/jsonapi/linkit_profile/linkit_profile\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:38:\"/jsonapi/linkit_profile/linkit_profile\";s:8:\"numParts\";i:3;}}',3),('jsonapi.linkit_profile--linkit_profile.individual','/jsonapi/linkit_profile/linkit_profile/{entity}','/jsonapi/linkit_profile/linkit_profile/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/linkit_profile/linkit_profile/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:30:\"linkit_profile--linkit_profile\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/jsonapi/linkit_profile/linkit_profile/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/jsonapi/linkit_profile/linkit_profile\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:40:\"/jsonapi/linkit_profile/linkit_profile/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu--menu.collection','/jsonapi/menu/menu','/jsonapi/menu/menu',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/jsonapi/menu/menu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:10:\"menu--menu\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/jsonapi/menu/menu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/menu/menu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/jsonapi/menu/menu\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu--menu.individual','/jsonapi/menu/menu/{entity}','/jsonapi/menu/menu/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/menu/menu/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:10:\"menu--menu\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/menu/menu/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/menu/menu\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/menu/menu/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--account.bundle.related','/jsonapi/menu_link_content/account/{entity}/bundle','/jsonapi/menu_link_content/account/%/bundle',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/jsonapi/menu_link_content/account/{entity}/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:6:\"bundle\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:43:\"/jsonapi/menu_link_content/account/%/bundle\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--account.bundle.relationship.delete','/jsonapi/menu_link_content/account/{entity}/relationships/bundle','/jsonapi/menu_link_content/account/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/jsonapi/menu_link_content/account/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/jsonapi/menu_link_content/account/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--account.bundle.relationship.get','/jsonapi/menu_link_content/account/{entity}/relationships/bundle','/jsonapi/menu_link_content/account/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/jsonapi/menu_link_content/account/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/jsonapi/menu_link_content/account/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--account.bundle.relationship.patch','/jsonapi/menu_link_content/account/{entity}/relationships/bundle','/jsonapi/menu_link_content/account/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/jsonapi/menu_link_content/account/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/jsonapi/menu_link_content/account/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--account.bundle.relationship.post','/jsonapi/menu_link_content/account/{entity}/relationships/bundle','/jsonapi/menu_link_content/account/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/jsonapi/menu_link_content/account/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/jsonapi/menu_link_content/account/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--account.collection','/jsonapi/menu_link_content/account','/jsonapi/menu_link_content/account',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/menu_link_content/account\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/jsonapi/menu_link_content/account$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:34:\"/jsonapi/menu_link_content/account\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--account.collection.post','/jsonapi/menu_link_content/account','/jsonapi/menu_link_content/account',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/menu_link_content/account\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:25:\"menu_link_content:account\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/jsonapi/menu_link_content/account$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:34:\"/jsonapi/menu_link_content/account\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--account.individual','/jsonapi/menu_link_content/account/{entity}','/jsonapi/menu_link_content/account/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/menu_link_content/account/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:36:\"/jsonapi/menu_link_content/account/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--account.individual.delete','/jsonapi/menu_link_content/account/{entity}','/jsonapi/menu_link_content/account/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/menu_link_content/account/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:36:\"/jsonapi/menu_link_content/account/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--account.individual.patch','/jsonapi/menu_link_content/account/{entity}','/jsonapi/menu_link_content/account/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/menu_link_content/account/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:36:\"/jsonapi/menu_link_content/account/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--account.revision_user.related','/jsonapi/menu_link_content/account/{entity}/revision_user','/jsonapi/menu_link_content/account/%/revision_user',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/menu_link_content/account/{entity}/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:13:\"revision_user\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:50:\"/jsonapi/menu_link_content/account/%/revision_user\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--account.revision_user.relationship.delete','/jsonapi/menu_link_content/account/{entity}/relationships/revision_user','/jsonapi/menu_link_content/account/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/jsonapi/menu_link_content/account/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:64:\"/jsonapi/menu_link_content/account/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--account.revision_user.relationship.get','/jsonapi/menu_link_content/account/{entity}/relationships/revision_user','/jsonapi/menu_link_content/account/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/jsonapi/menu_link_content/account/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:64:\"/jsonapi/menu_link_content/account/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--account.revision_user.relationship.patch','/jsonapi/menu_link_content/account/{entity}/relationships/revision_user','/jsonapi/menu_link_content/account/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/jsonapi/menu_link_content/account/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:64:\"/jsonapi/menu_link_content/account/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--account.revision_user.relationship.post','/jsonapi/menu_link_content/account/{entity}/relationships/revision_user','/jsonapi/menu_link_content/account/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/jsonapi/menu_link_content/account/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:26:\"menu_link_content--account\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/jsonapi/menu_link_content/account/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/menu_link_content/account\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:64:\"/jsonapi/menu_link_content/account/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--admin.bundle.related','/jsonapi/menu_link_content/admin/{entity}/bundle','/jsonapi/menu_link_content/admin/%/bundle',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/menu_link_content/admin/{entity}/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:6:\"bundle\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/jsonapi/menu_link_content/admin/%/bundle\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--admin.bundle.relationship.delete','/jsonapi/menu_link_content/admin/{entity}/relationships/bundle','/jsonapi/menu_link_content/admin/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/menu_link_content/admin/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/menu_link_content/admin/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--admin.bundle.relationship.get','/jsonapi/menu_link_content/admin/{entity}/relationships/bundle','/jsonapi/menu_link_content/admin/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/menu_link_content/admin/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/menu_link_content/admin/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--admin.bundle.relationship.patch','/jsonapi/menu_link_content/admin/{entity}/relationships/bundle','/jsonapi/menu_link_content/admin/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/menu_link_content/admin/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/menu_link_content/admin/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--admin.bundle.relationship.post','/jsonapi/menu_link_content/admin/{entity}/relationships/bundle','/jsonapi/menu_link_content/admin/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/menu_link_content/admin/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/menu_link_content/admin/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--admin.collection','/jsonapi/menu_link_content/admin','/jsonapi/menu_link_content/admin',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/menu_link_content/admin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/menu_link_content/admin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/jsonapi/menu_link_content/admin\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--admin.collection.post','/jsonapi/menu_link_content/admin','/jsonapi/menu_link_content/admin',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/menu_link_content/admin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:23:\"menu_link_content:admin\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/menu_link_content/admin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/jsonapi/menu_link_content/admin\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--admin.individual','/jsonapi/menu_link_content/admin/{entity}','/jsonapi/menu_link_content/admin/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/menu_link_content/admin/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/jsonapi/menu_link_content/admin/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--admin.individual.delete','/jsonapi/menu_link_content/admin/{entity}','/jsonapi/menu_link_content/admin/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/menu_link_content/admin/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/jsonapi/menu_link_content/admin/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--admin.individual.patch','/jsonapi/menu_link_content/admin/{entity}','/jsonapi/menu_link_content/admin/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/menu_link_content/admin/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/jsonapi/menu_link_content/admin/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--admin.revision_user.related','/jsonapi/menu_link_content/admin/{entity}/revision_user','/jsonapi/menu_link_content/admin/%/revision_user',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/menu_link_content/admin/{entity}/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:13:\"revision_user\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:48:\"/jsonapi/menu_link_content/admin/%/revision_user\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--admin.revision_user.relationship.delete','/jsonapi/menu_link_content/admin/{entity}/relationships/revision_user','/jsonapi/menu_link_content/admin/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/menu_link_content/admin/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/menu_link_content/admin/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--admin.revision_user.relationship.get','/jsonapi/menu_link_content/admin/{entity}/relationships/revision_user','/jsonapi/menu_link_content/admin/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/menu_link_content/admin/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/menu_link_content/admin/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--admin.revision_user.relationship.patch','/jsonapi/menu_link_content/admin/{entity}/relationships/revision_user','/jsonapi/menu_link_content/admin/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/menu_link_content/admin/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/menu_link_content/admin/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--admin.revision_user.relationship.post','/jsonapi/menu_link_content/admin/{entity}/relationships/revision_user','/jsonapi/menu_link_content/admin/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/menu_link_content/admin/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--admin\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/menu_link_content/admin/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/admin\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/menu_link_content/admin/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--footer.bundle.related','/jsonapi/menu_link_content/footer/{entity}/bundle','/jsonapi/menu_link_content/footer/%/bundle',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/jsonapi/menu_link_content/footer/{entity}/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:6:\"bundle\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:42:\"/jsonapi/menu_link_content/footer/%/bundle\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--footer.bundle.relationship.delete','/jsonapi/menu_link_content/footer/{entity}/relationships/bundle','/jsonapi/menu_link_content/footer/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/jsonapi/menu_link_content/footer/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:56:\"/jsonapi/menu_link_content/footer/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--footer.bundle.relationship.get','/jsonapi/menu_link_content/footer/{entity}/relationships/bundle','/jsonapi/menu_link_content/footer/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/jsonapi/menu_link_content/footer/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:56:\"/jsonapi/menu_link_content/footer/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--footer.bundle.relationship.patch','/jsonapi/menu_link_content/footer/{entity}/relationships/bundle','/jsonapi/menu_link_content/footer/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/jsonapi/menu_link_content/footer/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:56:\"/jsonapi/menu_link_content/footer/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--footer.bundle.relationship.post','/jsonapi/menu_link_content/footer/{entity}/relationships/bundle','/jsonapi/menu_link_content/footer/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/jsonapi/menu_link_content/footer/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:56:\"/jsonapi/menu_link_content/footer/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--footer.collection','/jsonapi/menu_link_content/footer','/jsonapi/menu_link_content/footer',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/menu_link_content/footer\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/jsonapi/menu_link_content/footer$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:33:\"/jsonapi/menu_link_content/footer\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--footer.collection.post','/jsonapi/menu_link_content/footer','/jsonapi/menu_link_content/footer',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/menu_link_content/footer\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:24:\"menu_link_content:footer\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/jsonapi/menu_link_content/footer$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:33:\"/jsonapi/menu_link_content/footer\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--footer.individual','/jsonapi/menu_link_content/footer/{entity}','/jsonapi/menu_link_content/footer/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/menu_link_content/footer/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:35:\"/jsonapi/menu_link_content/footer/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--footer.individual.delete','/jsonapi/menu_link_content/footer/{entity}','/jsonapi/menu_link_content/footer/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/menu_link_content/footer/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:35:\"/jsonapi/menu_link_content/footer/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--footer.individual.patch','/jsonapi/menu_link_content/footer/{entity}','/jsonapi/menu_link_content/footer/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/menu_link_content/footer/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:35:\"/jsonapi/menu_link_content/footer/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--footer.revision_user.related','/jsonapi/menu_link_content/footer/{entity}/revision_user','/jsonapi/menu_link_content/footer/%/revision_user',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/jsonapi/menu_link_content/footer/{entity}/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:13:\"revision_user\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:49:\"/jsonapi/menu_link_content/footer/%/revision_user\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--footer.revision_user.relationship.delete','/jsonapi/menu_link_content/footer/{entity}/relationships/revision_user','/jsonapi/menu_link_content/footer/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/jsonapi/menu_link_content/footer/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:63:\"/jsonapi/menu_link_content/footer/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--footer.revision_user.relationship.get','/jsonapi/menu_link_content/footer/{entity}/relationships/revision_user','/jsonapi/menu_link_content/footer/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/jsonapi/menu_link_content/footer/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:63:\"/jsonapi/menu_link_content/footer/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--footer.revision_user.relationship.patch','/jsonapi/menu_link_content/footer/{entity}/relationships/revision_user','/jsonapi/menu_link_content/footer/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/jsonapi/menu_link_content/footer/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:63:\"/jsonapi/menu_link_content/footer/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--footer.revision_user.relationship.post','/jsonapi/menu_link_content/footer/{entity}/relationships/revision_user','/jsonapi/menu_link_content/footer/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/jsonapi/menu_link_content/footer/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:25:\"menu_link_content--footer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/jsonapi/menu_link_content/footer/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/jsonapi/menu_link_content/footer\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:63:\"/jsonapi/menu_link_content/footer/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--main.bundle.related','/jsonapi/menu_link_content/main/{entity}/bundle','/jsonapi/menu_link_content/main/%/bundle',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/menu_link_content/main/{entity}/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:6:\"bundle\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:40:\"/jsonapi/menu_link_content/main/%/bundle\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--main.bundle.relationship.delete','/jsonapi/menu_link_content/main/{entity}/relationships/bundle','/jsonapi/menu_link_content/main/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/menu_link_content/main/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:54:\"/jsonapi/menu_link_content/main/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--main.bundle.relationship.get','/jsonapi/menu_link_content/main/{entity}/relationships/bundle','/jsonapi/menu_link_content/main/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/menu_link_content/main/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:54:\"/jsonapi/menu_link_content/main/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--main.bundle.relationship.patch','/jsonapi/menu_link_content/main/{entity}/relationships/bundle','/jsonapi/menu_link_content/main/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/menu_link_content/main/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:54:\"/jsonapi/menu_link_content/main/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--main.bundle.relationship.post','/jsonapi/menu_link_content/main/{entity}/relationships/bundle','/jsonapi/menu_link_content/main/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/menu_link_content/main/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:54:\"/jsonapi/menu_link_content/main/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--main.collection','/jsonapi/menu_link_content/main','/jsonapi/menu_link_content/main',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/menu_link_content/main\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/jsonapi/menu_link_content/main$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:31:\"/jsonapi/menu_link_content/main\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--main.collection.post','/jsonapi/menu_link_content/main','/jsonapi/menu_link_content/main',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/menu_link_content/main\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:22:\"menu_link_content:main\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/jsonapi/menu_link_content/main$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:31:\"/jsonapi/menu_link_content/main\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--main.individual','/jsonapi/menu_link_content/main/{entity}','/jsonapi/menu_link_content/main/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/menu_link_content/main/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:33:\"/jsonapi/menu_link_content/main/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--main.individual.delete','/jsonapi/menu_link_content/main/{entity}','/jsonapi/menu_link_content/main/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/menu_link_content/main/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:33:\"/jsonapi/menu_link_content/main/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--main.individual.patch','/jsonapi/menu_link_content/main/{entity}','/jsonapi/menu_link_content/main/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/menu_link_content/main/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:33:\"/jsonapi/menu_link_content/main/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--main.revision_user.related','/jsonapi/menu_link_content/main/{entity}/revision_user','/jsonapi/menu_link_content/main/%/revision_user',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/menu_link_content/main/{entity}/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:13:\"revision_user\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:47:\"/jsonapi/menu_link_content/main/%/revision_user\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--main.revision_user.relationship.delete','/jsonapi/menu_link_content/main/{entity}/relationships/revision_user','/jsonapi/menu_link_content/main/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/jsonapi/menu_link_content/main/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:61:\"/jsonapi/menu_link_content/main/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--main.revision_user.relationship.get','/jsonapi/menu_link_content/main/{entity}/relationships/revision_user','/jsonapi/menu_link_content/main/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/jsonapi/menu_link_content/main/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:61:\"/jsonapi/menu_link_content/main/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--main.revision_user.relationship.patch','/jsonapi/menu_link_content/main/{entity}/relationships/revision_user','/jsonapi/menu_link_content/main/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/jsonapi/menu_link_content/main/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:61:\"/jsonapi/menu_link_content/main/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--main.revision_user.relationship.post','/jsonapi/menu_link_content/main/{entity}/relationships/revision_user','/jsonapi/menu_link_content/main/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/jsonapi/menu_link_content/main/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:23:\"menu_link_content--main\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/jsonapi/menu_link_content/main/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/menu_link_content/main\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:61:\"/jsonapi/menu_link_content/main/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--tools.bundle.related','/jsonapi/menu_link_content/tools/{entity}/bundle','/jsonapi/menu_link_content/tools/%/bundle',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/menu_link_content/tools/{entity}/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:6:\"bundle\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/jsonapi/menu_link_content/tools/%/bundle\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--tools.bundle.relationship.delete','/jsonapi/menu_link_content/tools/{entity}/relationships/bundle','/jsonapi/menu_link_content/tools/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/menu_link_content/tools/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/menu_link_content/tools/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--tools.bundle.relationship.get','/jsonapi/menu_link_content/tools/{entity}/relationships/bundle','/jsonapi/menu_link_content/tools/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/menu_link_content/tools/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/menu_link_content/tools/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--tools.bundle.relationship.patch','/jsonapi/menu_link_content/tools/{entity}/relationships/bundle','/jsonapi/menu_link_content/tools/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/menu_link_content/tools/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/menu_link_content/tools/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--tools.bundle.relationship.post','/jsonapi/menu_link_content/tools/{entity}/relationships/bundle','/jsonapi/menu_link_content/tools/%/relationships/bundle',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/menu_link_content/tools/{entity}/relationships/bundle\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"bundle\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"bundle.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/relationships/bundle$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/bundle\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/menu_link_content/tools/%/relationships/bundle\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--tools.collection','/jsonapi/menu_link_content/tools','/jsonapi/menu_link_content/tools',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/menu_link_content/tools\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/menu_link_content/tools$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/jsonapi/menu_link_content/tools\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--tools.collection.post','/jsonapi/menu_link_content/tools','/jsonapi/menu_link_content/tools',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/menu_link_content/tools\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:23:\"menu_link_content:tools\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/menu_link_content/tools$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/jsonapi/menu_link_content/tools\";s:8:\"numParts\";i:3;}}',3),('jsonapi.menu_link_content--tools.individual','/jsonapi/menu_link_content/tools/{entity}','/jsonapi/menu_link_content/tools/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/menu_link_content/tools/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/jsonapi/menu_link_content/tools/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--tools.individual.delete','/jsonapi/menu_link_content/tools/{entity}','/jsonapi/menu_link_content/tools/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/menu_link_content/tools/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/jsonapi/menu_link_content/tools/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--tools.individual.patch','/jsonapi/menu_link_content/tools/{entity}','/jsonapi/menu_link_content/tools/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/menu_link_content/tools/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/jsonapi/menu_link_content/tools/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.menu_link_content--tools.revision_user.related','/jsonapi/menu_link_content/tools/{entity}/revision_user','/jsonapi/menu_link_content/tools/%/revision_user',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/menu_link_content/tools/{entity}/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:13:\"revision_user\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:48:\"/jsonapi/menu_link_content/tools/%/revision_user\";s:8:\"numParts\";i:5;}}',5),('jsonapi.menu_link_content--tools.revision_user.relationship.delete','/jsonapi/menu_link_content/tools/{entity}/relationships/revision_user','/jsonapi/menu_link_content/tools/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/menu_link_content/tools/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/menu_link_content/tools/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--tools.revision_user.relationship.get','/jsonapi/menu_link_content/tools/{entity}/relationships/revision_user','/jsonapi/menu_link_content/tools/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/menu_link_content/tools/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/menu_link_content/tools/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--tools.revision_user.relationship.patch','/jsonapi/menu_link_content/tools/{entity}/relationships/revision_user','/jsonapi/menu_link_content/tools/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/menu_link_content/tools/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/menu_link_content/tools/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.menu_link_content--tools.revision_user.relationship.post','/jsonapi/menu_link_content/tools/{entity}/relationships/revision_user','/jsonapi/menu_link_content/tools/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/menu_link_content/tools/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:24:\"menu_link_content--tools\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/menu_link_content/tools/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/menu_link_content/tools\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/menu_link_content/tools/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.metatag_defaults--metatag_defaults.collection','/jsonapi/metatag_defaults/metatag_defaults','/jsonapi/metatag_defaults/metatag_defaults',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/metatag_defaults/metatag_defaults\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:34:\"metatag_defaults--metatag_defaults\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/jsonapi/metatag_defaults/metatag_defaults$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/metatag_defaults/metatag_defaults\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:42:\"/jsonapi/metatag_defaults/metatag_defaults\";s:8:\"numParts\";i:3;}}',3),('jsonapi.metatag_defaults--metatag_defaults.individual','/jsonapi/metatag_defaults/metatag_defaults/{entity}','/jsonapi/metatag_defaults/metatag_defaults/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/metatag_defaults/metatag_defaults/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:34:\"metatag_defaults--metatag_defaults\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/metatag_defaults/metatag_defaults/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/metatag_defaults/metatag_defaults\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:44:\"/jsonapi/metatag_defaults/metatag_defaults/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--article.collection','/jsonapi/node/article','/jsonapi/node/article',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/jsonapi/node/article\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/jsonapi/node/article$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/jsonapi/node/article\";s:8:\"numParts\";i:3;}}',3),('jsonapi.node--article.collection.post','/jsonapi/node/article','/jsonapi/node/article',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/jsonapi/node/article\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:12:\"node:article\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/jsonapi/node/article$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/jsonapi/node/article\";s:8:\"numParts\";i:3;}}',3),('jsonapi.node--article.field_image.related','/jsonapi/node/article/{entity}/field_image','/jsonapi/node/article/%/field_image',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/node/article/{entity}/field_image\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:11:\"field_image\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:16:\"field_image.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/field_image$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/field_image\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:35:\"/jsonapi/node/article/%/field_image\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--article.field_image.relationship.delete','/jsonapi/node/article/{entity}/relationships/field_image','/jsonapi/node/article/%/relationships/field_image',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/jsonapi/node/article/{entity}/relationships/field_image\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:11:\"field_image\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:16:\"field_image.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/field_image$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/relationships/field_image\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:49:\"/jsonapi/node/article/%/relationships/field_image\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.field_image.relationship.get','/jsonapi/node/article/{entity}/relationships/field_image','/jsonapi/node/article/%/relationships/field_image',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/jsonapi/node/article/{entity}/relationships/field_image\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:11:\"field_image\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:16:\"field_image.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/field_image$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/relationships/field_image\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:49:\"/jsonapi/node/article/%/relationships/field_image\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.field_image.relationship.patch','/jsonapi/node/article/{entity}/relationships/field_image','/jsonapi/node/article/%/relationships/field_image',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/jsonapi/node/article/{entity}/relationships/field_image\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:11:\"field_image\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:16:\"field_image.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/field_image$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/relationships/field_image\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:49:\"/jsonapi/node/article/%/relationships/field_image\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.field_image.relationship.post','/jsonapi/node/article/{entity}/relationships/field_image','/jsonapi/node/article/%/relationships/field_image',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/jsonapi/node/article/{entity}/relationships/field_image\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:11:\"field_image\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:16:\"field_image.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/field_image$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/relationships/field_image\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:49:\"/jsonapi/node/article/%/relationships/field_image\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.field_tags.related','/jsonapi/node/article/{entity}/field_tags','/jsonapi/node/article/%/field_tags',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/jsonapi/node/article/{entity}/field_tags\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:10:\"field_tags\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:15:\"field_tags.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/field_tags$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/field_tags\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:34:\"/jsonapi/node/article/%/field_tags\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--article.field_tags.relationship.delete','/jsonapi/node/article/{entity}/relationships/field_tags','/jsonapi/node/article/%/relationships/field_tags',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/node/article/{entity}/relationships/field_tags\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:10:\"field_tags\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:15:\"field_tags.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/field_tags$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/relationships/field_tags\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:48:\"/jsonapi/node/article/%/relationships/field_tags\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.field_tags.relationship.get','/jsonapi/node/article/{entity}/relationships/field_tags','/jsonapi/node/article/%/relationships/field_tags',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/node/article/{entity}/relationships/field_tags\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:10:\"field_tags\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:15:\"field_tags.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/field_tags$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/relationships/field_tags\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:48:\"/jsonapi/node/article/%/relationships/field_tags\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.field_tags.relationship.patch','/jsonapi/node/article/{entity}/relationships/field_tags','/jsonapi/node/article/%/relationships/field_tags',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/node/article/{entity}/relationships/field_tags\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:10:\"field_tags\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:15:\"field_tags.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/field_tags$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/relationships/field_tags\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:48:\"/jsonapi/node/article/%/relationships/field_tags\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.field_tags.relationship.post','/jsonapi/node/article/{entity}/relationships/field_tags','/jsonapi/node/article/%/relationships/field_tags',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/node/article/{entity}/relationships/field_tags\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:10:\"field_tags\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:15:\"field_tags.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/field_tags$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/relationships/field_tags\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:48:\"/jsonapi/node/article/%/relationships/field_tags\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.file_upload.existing_resource','/jsonapi/node/article/{entity}/{file_field_name}','/jsonapi/node/article/%/%',28,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/article/{entity}/{file_field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:55:\"jsonapi.file_upload:handleFileUploadForExistingResource\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:3:\"bin\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:6:\"entity\";i:1;s:15:\"file_field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/(?P<file_field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"file_field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:2:{i:0;s:6:\"entity\";i:1;s:15:\"file_field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:25:\"/jsonapi/node/article/%/%\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--article.file_upload.new_resource','/jsonapi/node/article/{file_field_name}','/jsonapi/node/article/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/jsonapi/node/article/{file_field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:50:\"jsonapi.file_upload:handleFileUploadForNewResource\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:3:\"bin\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"file_field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/jsonapi/node/article/(?P<file_field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"file_field_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"file_field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:23:\"/jsonapi/node/article/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--article.individual','/jsonapi/node/article/{entity}','/jsonapi/node/article/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/node/article/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/jsonapi/node/article/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:23:\"/jsonapi/node/article/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--article.individual.delete','/jsonapi/node/article/{entity}','/jsonapi/node/article/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/node/article/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/jsonapi/node/article/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:23:\"/jsonapi/node/article/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--article.individual.patch','/jsonapi/node/article/{entity}','/jsonapi/node/article/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/node/article/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/jsonapi/node/article/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:23:\"/jsonapi/node/article/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--article.menu_link.related','/jsonapi/node/article/{entity}/menu_link','/jsonapi/node/article/%/menu_link',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/node/article/{entity}/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:9:\"menu_link\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:33:\"/jsonapi/node/article/%/menu_link\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--article.menu_link.relationship.delete','/jsonapi/node/article/{entity}/relationships/menu_link','/jsonapi/node/article/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/article/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/article/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.menu_link.relationship.get','/jsonapi/node/article/{entity}/relationships/menu_link','/jsonapi/node/article/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/article/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/article/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.menu_link.relationship.patch','/jsonapi/node/article/{entity}/relationships/menu_link','/jsonapi/node/article/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/article/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/article/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.menu_link.relationship.post','/jsonapi/node/article/{entity}/relationships/menu_link','/jsonapi/node/article/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/article/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/article/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.node_type.related','/jsonapi/node/article/{entity}/node_type','/jsonapi/node/article/%/node_type',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/node/article/{entity}/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:9:\"node_type\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:33:\"/jsonapi/node/article/%/node_type\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--article.node_type.relationship.delete','/jsonapi/node/article/{entity}/relationships/node_type','/jsonapi/node/article/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/article/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/article/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.node_type.relationship.get','/jsonapi/node/article/{entity}/relationships/node_type','/jsonapi/node/article/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/article/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/article/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.node_type.relationship.patch','/jsonapi/node/article/{entity}/relationships/node_type','/jsonapi/node/article/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/article/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/article/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.node_type.relationship.post','/jsonapi/node/article/{entity}/relationships/node_type','/jsonapi/node/article/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/article/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/article/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.revision_uid.related','/jsonapi/node/article/{entity}/revision_uid','/jsonapi/node/article/%/revision_uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/node/article/{entity}/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:12:\"revision_uid\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:36:\"/jsonapi/node/article/%/revision_uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--article.revision_uid.relationship.delete','/jsonapi/node/article/{entity}/relationships/revision_uid','/jsonapi/node/article/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/node/article/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/node/article/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.revision_uid.relationship.get','/jsonapi/node/article/{entity}/relationships/revision_uid','/jsonapi/node/article/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/node/article/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/node/article/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.revision_uid.relationship.patch','/jsonapi/node/article/{entity}/relationships/revision_uid','/jsonapi/node/article/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/node/article/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/node/article/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.revision_uid.relationship.post','/jsonapi/node/article/{entity}/relationships/revision_uid','/jsonapi/node/article/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/node/article/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/node/article/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.uid.related','/jsonapi/node/article/{entity}/uid','/jsonapi/node/article/%/uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/node/article/{entity}/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"uid\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:27:\"/jsonapi/node/article/%/uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--article.uid.relationship.delete','/jsonapi/node/article/{entity}/relationships/uid','/jsonapi/node/article/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/article/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:41:\"/jsonapi/node/article/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.uid.relationship.get','/jsonapi/node/article/{entity}/relationships/uid','/jsonapi/node/article/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/article/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:41:\"/jsonapi/node/article/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.uid.relationship.patch','/jsonapi/node/article/{entity}/relationships/uid','/jsonapi/node/article/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/article/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:41:\"/jsonapi/node/article/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--article.uid.relationship.post','/jsonapi/node/article/{entity}/relationships/uid','/jsonapi/node/article/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/article/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--article\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/node/article/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/article\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:41:\"/jsonapi/node/article/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.collection','/jsonapi/node/page','/jsonapi/node/page',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/jsonapi/node/page\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/jsonapi/node/page$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/jsonapi/node/page\";s:8:\"numParts\";i:3;}}',3),('jsonapi.node--page.collection.post','/jsonapi/node/page','/jsonapi/node/page',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/jsonapi/node/page\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:9:\"node:page\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/jsonapi/node/page$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/jsonapi/node/page\";s:8:\"numParts\";i:3;}}',3),('jsonapi.node--page.individual','/jsonapi/node/page/{entity}','/jsonapi/node/page/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/node/page/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/node/page/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/node/page/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--page.individual.delete','/jsonapi/node/page/{entity}','/jsonapi/node/page/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/node/page/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/node/page/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/node/page/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--page.individual.patch','/jsonapi/node/page/{entity}','/jsonapi/node/page/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/node/page/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/node/page/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/node/page/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--page.menu_link.related','/jsonapi/node/page/{entity}/menu_link','/jsonapi/node/page/%/menu_link',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/node/page/{entity}/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:9:\"menu_link\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:30:\"/jsonapi/node/page/%/menu_link\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--page.menu_link.relationship.delete','/jsonapi/node/page/{entity}/relationships/menu_link','/jsonapi/node/page/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/node/page/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/node/page/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.menu_link.relationship.get','/jsonapi/node/page/{entity}/relationships/menu_link','/jsonapi/node/page/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/node/page/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/node/page/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.menu_link.relationship.patch','/jsonapi/node/page/{entity}/relationships/menu_link','/jsonapi/node/page/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/node/page/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/node/page/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.menu_link.relationship.post','/jsonapi/node/page/{entity}/relationships/menu_link','/jsonapi/node/page/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/node/page/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/node/page/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.node_type.related','/jsonapi/node/page/{entity}/node_type','/jsonapi/node/page/%/node_type',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/node/page/{entity}/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:9:\"node_type\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:30:\"/jsonapi/node/page/%/node_type\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--page.node_type.relationship.delete','/jsonapi/node/page/{entity}/relationships/node_type','/jsonapi/node/page/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/node/page/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/node/page/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.node_type.relationship.get','/jsonapi/node/page/{entity}/relationships/node_type','/jsonapi/node/page/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/node/page/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/node/page/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.node_type.relationship.patch','/jsonapi/node/page/{entity}/relationships/node_type','/jsonapi/node/page/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/node/page/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/node/page/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.node_type.relationship.post','/jsonapi/node/page/{entity}/relationships/node_type','/jsonapi/node/page/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/node/page/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:44:\"/jsonapi/node/page/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.revision_uid.related','/jsonapi/node/page/{entity}/revision_uid','/jsonapi/node/page/%/revision_uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/node/page/{entity}/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:12:\"revision_uid\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:33:\"/jsonapi/node/page/%/revision_uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--page.revision_uid.relationship.delete','/jsonapi/node/page/{entity}/relationships/revision_uid','/jsonapi/node/page/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/page/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/page/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.revision_uid.relationship.get','/jsonapi/node/page/{entity}/relationships/revision_uid','/jsonapi/node/page/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/page/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/page/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.revision_uid.relationship.patch','/jsonapi/node/page/{entity}/relationships/revision_uid','/jsonapi/node/page/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/page/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/page/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.revision_uid.relationship.post','/jsonapi/node/page/{entity}/relationships/revision_uid','/jsonapi/node/page/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/page/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/page/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.uid.related','/jsonapi/node/page/{entity}/uid','/jsonapi/node/page/%/uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/node/page/{entity}/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"uid\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:24:\"/jsonapi/node/page/%/uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--page.uid.relationship.delete','/jsonapi/node/page/{entity}/relationships/uid','/jsonapi/node/page/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/node/page/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:38:\"/jsonapi/node/page/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.uid.relationship.get','/jsonapi/node/page/{entity}/relationships/uid','/jsonapi/node/page/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/node/page/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:38:\"/jsonapi/node/page/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.uid.relationship.patch','/jsonapi/node/page/{entity}/relationships/uid','/jsonapi/node/page/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/node/page/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:38:\"/jsonapi/node/page/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--page.uid.relationship.post','/jsonapi/node/page/{entity}/relationships/uid','/jsonapi/node/page/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/node/page/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:10:\"node--page\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/jsonapi/node/page/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/node/page\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:38:\"/jsonapi/node/page/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.collection','/jsonapi/node/webform','/jsonapi/node/webform',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/jsonapi/node/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/jsonapi/node/webform$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/jsonapi/node/webform\";s:8:\"numParts\";i:3;}}',3),('jsonapi.node--webform.collection.post','/jsonapi/node/webform','/jsonapi/node/webform',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/jsonapi/node/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:12:\"node:webform\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/jsonapi/node/webform$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/jsonapi/node/webform\";s:8:\"numParts\";i:3;}}',3),('jsonapi.node--webform.individual','/jsonapi/node/webform/{entity}','/jsonapi/node/webform/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/node/webform/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:23:\"/jsonapi/node/webform/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--webform.individual.delete','/jsonapi/node/webform/{entity}','/jsonapi/node/webform/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/node/webform/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:23:\"/jsonapi/node/webform/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--webform.individual.patch','/jsonapi/node/webform/{entity}','/jsonapi/node/webform/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/node/webform/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:23:\"/jsonapi/node/webform/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.node--webform.menu_link.related','/jsonapi/node/webform/{entity}/menu_link','/jsonapi/node/webform/%/menu_link',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/node/webform/{entity}/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:9:\"menu_link\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:33:\"/jsonapi/node/webform/%/menu_link\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--webform.menu_link.relationship.delete','/jsonapi/node/webform/{entity}/relationships/menu_link','/jsonapi/node/webform/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/webform/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/webform/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.menu_link.relationship.get','/jsonapi/node/webform/{entity}/relationships/menu_link','/jsonapi/node/webform/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/webform/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/webform/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.menu_link.relationship.patch','/jsonapi/node/webform/{entity}/relationships/menu_link','/jsonapi/node/webform/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/webform/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/webform/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.menu_link.relationship.post','/jsonapi/node/webform/{entity}/relationships/menu_link','/jsonapi/node/webform/%/relationships/menu_link',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/webform/{entity}/relationships/menu_link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"menu_link\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"menu_link.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/menu_link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/menu_link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/webform/%/relationships/menu_link\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.node_type.related','/jsonapi/node/webform/{entity}/node_type','/jsonapi/node/webform/%/node_type',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/node/webform/{entity}/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:9:\"node_type\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:33:\"/jsonapi/node/webform/%/node_type\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--webform.node_type.relationship.delete','/jsonapi/node/webform/{entity}/relationships/node_type','/jsonapi/node/webform/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/webform/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/webform/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.node_type.relationship.get','/jsonapi/node/webform/{entity}/relationships/node_type','/jsonapi/node/webform/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/webform/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/webform/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.node_type.relationship.patch','/jsonapi/node/webform/{entity}/relationships/node_type','/jsonapi/node/webform/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/webform/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/webform/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.node_type.relationship.post','/jsonapi/node/webform/{entity}/relationships/node_type','/jsonapi/node/webform/%/relationships/node_type',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/node/webform/{entity}/relationships/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:9:\"node_type\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:14:\"node_type.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/node_type$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/relationships/node_type\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/node/webform/%/relationships/node_type\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.revision_uid.related','/jsonapi/node/webform/{entity}/revision_uid','/jsonapi/node/webform/%/revision_uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/node/webform/{entity}/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:12:\"revision_uid\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:36:\"/jsonapi/node/webform/%/revision_uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--webform.revision_uid.relationship.delete','/jsonapi/node/webform/{entity}/relationships/revision_uid','/jsonapi/node/webform/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/node/webform/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/node/webform/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.revision_uid.relationship.get','/jsonapi/node/webform/{entity}/relationships/revision_uid','/jsonapi/node/webform/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/node/webform/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/node/webform/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.revision_uid.relationship.patch','/jsonapi/node/webform/{entity}/relationships/revision_uid','/jsonapi/node/webform/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/node/webform/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/node/webform/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.revision_uid.relationship.post','/jsonapi/node/webform/{entity}/relationships/revision_uid','/jsonapi/node/webform/%/relationships/revision_uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/node/webform/{entity}/relationships/revision_uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"revision_uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"revision_uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/revision_uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/revision_uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/node/webform/%/relationships/revision_uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.uid.related','/jsonapi/node/webform/{entity}/uid','/jsonapi/node/webform/%/uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/node/webform/{entity}/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"uid\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:27:\"/jsonapi/node/webform/%/uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--webform.uid.relationship.delete','/jsonapi/node/webform/{entity}/relationships/uid','/jsonapi/node/webform/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/webform/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:41:\"/jsonapi/node/webform/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.uid.relationship.get','/jsonapi/node/webform/{entity}/relationships/uid','/jsonapi/node/webform/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/webform/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:41:\"/jsonapi/node/webform/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.uid.relationship.patch','/jsonapi/node/webform/{entity}/relationships/uid','/jsonapi/node/webform/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/webform/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:41:\"/jsonapi/node/webform/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.uid.relationship.post','/jsonapi/node/webform/{entity}/relationships/uid','/jsonapi/node/webform/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/node/webform/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:41:\"/jsonapi/node/webform/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.webform.related','/jsonapi/node/webform/{entity}/webform','/jsonapi/node/webform/%/webform',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/jsonapi/node/webform/{entity}/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:7:\"webform\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:12:\"webform.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/webform$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:31:\"/jsonapi/node/webform/%/webform\";s:8:\"numParts\";i:5;}}',5),('jsonapi.node--webform.webform.relationship.delete','/jsonapi/node/webform/{entity}/relationships/webform','/jsonapi/node/webform/%/relationships/webform',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/jsonapi/node/webform/{entity}/relationships/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:7:\"webform\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:12:\"webform.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/webform$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/relationships/webform\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:45:\"/jsonapi/node/webform/%/relationships/webform\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.webform.relationship.get','/jsonapi/node/webform/{entity}/relationships/webform','/jsonapi/node/webform/%/relationships/webform',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/jsonapi/node/webform/{entity}/relationships/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:7:\"webform\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:12:\"webform.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/webform$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/relationships/webform\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:45:\"/jsonapi/node/webform/%/relationships/webform\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.webform.relationship.patch','/jsonapi/node/webform/{entity}/relationships/webform','/jsonapi/node/webform/%/relationships/webform',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/jsonapi/node/webform/{entity}/relationships/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:7:\"webform\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:12:\"webform.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/webform$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/relationships/webform\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:45:\"/jsonapi/node/webform/%/relationships/webform\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node--webform.webform.relationship.post','/jsonapi/node/webform/{entity}/relationships/webform','/jsonapi/node/webform/%/relationships/webform',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/jsonapi/node/webform/{entity}/relationships/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:7:\"webform\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:13:\"node--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:12:\"webform.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/jsonapi/node/webform/(?P<entity>[^/]++)/relationships/webform$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/relationships/webform\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/jsonapi/node/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:45:\"/jsonapi/node/webform/%/relationships/webform\";s:8:\"numParts\";i:6;}}',6),('jsonapi.node_type--node_type.collection','/jsonapi/node_type/node_type','/jsonapi/node_type/node_type',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/jsonapi/node_type/node_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:20:\"node_type--node_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/jsonapi/node_type/node_type$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/node_type/node_type\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/jsonapi/node_type/node_type\";s:8:\"numParts\";i:3;}}',3),('jsonapi.node_type--node_type.individual','/jsonapi/node_type/node_type/{entity}','/jsonapi/node_type/node_type/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/node_type/node_type/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:20:\"node_type--node_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/node_type/node_type/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/node_type/node_type\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:30:\"/jsonapi/node_type/node_type/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.pathauto_pattern--pathauto_pattern.collection','/jsonapi/pathauto_pattern/pathauto_pattern','/jsonapi/pathauto_pattern/pathauto_pattern',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/pathauto_pattern/pathauto_pattern\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:34:\"pathauto_pattern--pathauto_pattern\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/jsonapi/pathauto_pattern/pathauto_pattern$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/pathauto_pattern/pathauto_pattern\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:42:\"/jsonapi/pathauto_pattern/pathauto_pattern\";s:8:\"numParts\";i:3;}}',3),('jsonapi.pathauto_pattern--pathauto_pattern.individual','/jsonapi/pathauto_pattern/pathauto_pattern/{entity}','/jsonapi/pathauto_pattern/pathauto_pattern/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/pathauto_pattern/pathauto_pattern/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:34:\"pathauto_pattern--pathauto_pattern\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/jsonapi/pathauto_pattern/pathauto_pattern/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/pathauto_pattern/pathauto_pattern\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:44:\"/jsonapi/pathauto_pattern/pathauto_pattern/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.path_alias--path_alias.collection','/jsonapi/path_alias/path_alias','/jsonapi/path_alias/path_alias',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/path_alias/path_alias\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:22:\"path_alias--path_alias\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/jsonapi/path_alias/path_alias$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/jsonapi/path_alias/path_alias\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/jsonapi/path_alias/path_alias\";s:8:\"numParts\";i:3;}}',3),('jsonapi.path_alias--path_alias.collection.post','/jsonapi/path_alias/path_alias','/jsonapi/path_alias/path_alias',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/path_alias/path_alias\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:22:\"path_alias--path_alias\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:21:\"path_alias:path_alias\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/jsonapi/path_alias/path_alias$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/jsonapi/path_alias/path_alias\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/jsonapi/path_alias/path_alias\";s:8:\"numParts\";i:3;}}',3),('jsonapi.path_alias--path_alias.individual','/jsonapi/path_alias/path_alias/{entity}','/jsonapi/path_alias/path_alias/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/jsonapi/path_alias/path_alias/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:22:\"path_alias--path_alias\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/jsonapi/path_alias/path_alias/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/jsonapi/path_alias/path_alias\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:32:\"/jsonapi/path_alias/path_alias/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.path_alias--path_alias.individual.delete','/jsonapi/path_alias/path_alias/{entity}','/jsonapi/path_alias/path_alias/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/jsonapi/path_alias/path_alias/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:22:\"path_alias--path_alias\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/jsonapi/path_alias/path_alias/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/jsonapi/path_alias/path_alias\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:32:\"/jsonapi/path_alias/path_alias/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.path_alias--path_alias.individual.patch','/jsonapi/path_alias/path_alias/{entity}','/jsonapi/path_alias/path_alias/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/jsonapi/path_alias/path_alias/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:22:\"path_alias--path_alias\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/jsonapi/path_alias/path_alias/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/jsonapi/path_alias/path_alias\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:32:\"/jsonapi/path_alias/path_alias/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.redirect--redirect.collection','/jsonapi/redirect/redirect','/jsonapi/redirect/redirect',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/jsonapi/redirect/redirect\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/jsonapi/redirect/redirect$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/jsonapi/redirect/redirect\";s:8:\"numParts\";i:3;}}',3),('jsonapi.redirect--redirect.collection.post','/jsonapi/redirect/redirect','/jsonapi/redirect/redirect',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/jsonapi/redirect/redirect\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:17:\"redirect:redirect\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/jsonapi/redirect/redirect$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/jsonapi/redirect/redirect\";s:8:\"numParts\";i:3;}}',3),('jsonapi.redirect--redirect.individual','/jsonapi/redirect/redirect/{entity}','/jsonapi/redirect/redirect/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/redirect/redirect/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/jsonapi/redirect/redirect/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:28:\"/jsonapi/redirect/redirect/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.redirect--redirect.individual.delete','/jsonapi/redirect/redirect/{entity}','/jsonapi/redirect/redirect/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/redirect/redirect/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/jsonapi/redirect/redirect/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:28:\"/jsonapi/redirect/redirect/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.redirect--redirect.individual.patch','/jsonapi/redirect/redirect/{entity}','/jsonapi/redirect/redirect/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/redirect/redirect/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/jsonapi/redirect/redirect/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:28:\"/jsonapi/redirect/redirect/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.redirect--redirect.uid.related','/jsonapi/redirect/redirect/{entity}/uid','/jsonapi/redirect/redirect/%/uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/jsonapi/redirect/redirect/{entity}/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"uid\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/jsonapi/redirect/redirect/(?P<entity>[^/]++)/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:32:\"/jsonapi/redirect/redirect/%/uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.redirect--redirect.uid.relationship.delete','/jsonapi/redirect/redirect/{entity}/relationships/uid','/jsonapi/redirect/redirect/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/jsonapi/redirect/redirect/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/jsonapi/redirect/redirect/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:46:\"/jsonapi/redirect/redirect/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.redirect--redirect.uid.relationship.get','/jsonapi/redirect/redirect/{entity}/relationships/uid','/jsonapi/redirect/redirect/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/jsonapi/redirect/redirect/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/jsonapi/redirect/redirect/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:46:\"/jsonapi/redirect/redirect/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.redirect--redirect.uid.relationship.patch','/jsonapi/redirect/redirect/{entity}/relationships/uid','/jsonapi/redirect/redirect/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/jsonapi/redirect/redirect/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/jsonapi/redirect/redirect/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:46:\"/jsonapi/redirect/redirect/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.redirect--redirect.uid.relationship.post','/jsonapi/redirect/redirect/{entity}/relationships/uid','/jsonapi/redirect/redirect/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/jsonapi/redirect/redirect/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:18:\"redirect--redirect\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/jsonapi/redirect/redirect/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/jsonapi/redirect/redirect\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:46:\"/jsonapi/redirect/redirect/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.resource_list','/jsonapi','/jsonapi',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/jsonapi\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:43:\"Drupal\\jsonapi\\Controller\\EntryPoint::index\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:15:\"{^/jsonapi$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/jsonapi\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/jsonapi\";s:8:\"numParts\";i:1;}}',1),('jsonapi.rest_resource_config--rest_resource_config.collection','/jsonapi/rest_resource_config/rest_resource_config','/jsonapi/rest_resource_config/rest_resource_config',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/jsonapi/rest_resource_config/rest_resource_config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:42:\"rest_resource_config--rest_resource_config\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/rest_resource_config/rest_resource_config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:50:\"/jsonapi/rest_resource_config/rest_resource_config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:50:\"/jsonapi/rest_resource_config/rest_resource_config\";s:8:\"numParts\";i:3;}}',3),('jsonapi.rest_resource_config--rest_resource_config.individual','/jsonapi/rest_resource_config/rest_resource_config/{entity}','/jsonapi/rest_resource_config/rest_resource_config/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/jsonapi/rest_resource_config/rest_resource_config/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:42:\"rest_resource_config--rest_resource_config\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:27:\"entity:rest_resource_config\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/jsonapi/rest_resource_config/rest_resource_config/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:50:\"/jsonapi/rest_resource_config/rest_resource_config\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:52:\"/jsonapi/rest_resource_config/rest_resource_config/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.settings','/admin/config/services/jsonapi','/admin/config/services/jsonapi',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/config/services/jsonapi\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\jsonapi\\Form\\JsonApiSettingsForm\";s:6:\"_title\";s:8:\"JSON:API\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/admin/config/services/jsonapi$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/services/jsonapi\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/config/services/jsonapi\";s:8:\"numParts\";i:4;}}',4),('jsonapi.shortcut--default.collection','/jsonapi/shortcut/default','/jsonapi/shortcut/default',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/jsonapi/shortcut/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/jsonapi/shortcut/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/jsonapi/shortcut/default\";s:8:\"numParts\";i:3;}}',3),('jsonapi.shortcut--default.collection.post','/jsonapi/shortcut/default','/jsonapi/shortcut/default',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/jsonapi/shortcut/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:16:\"shortcut:default\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/jsonapi/shortcut/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/jsonapi/shortcut/default\";s:8:\"numParts\";i:3;}}',3),('jsonapi.shortcut--default.individual','/jsonapi/shortcut/default/{entity}','/jsonapi/shortcut/default/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/shortcut/default/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/jsonapi/shortcut/default/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:27:\"/jsonapi/shortcut/default/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.shortcut--default.individual.delete','/jsonapi/shortcut/default/{entity}','/jsonapi/shortcut/default/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/shortcut/default/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/jsonapi/shortcut/default/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:27:\"/jsonapi/shortcut/default/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.shortcut--default.individual.patch','/jsonapi/shortcut/default/{entity}','/jsonapi/shortcut/default/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/shortcut/default/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/jsonapi/shortcut/default/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:27:\"/jsonapi/shortcut/default/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.shortcut--default.shortcut_set.related','/jsonapi/shortcut/default/{entity}/shortcut_set','/jsonapi/shortcut/default/%/shortcut_set',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/shortcut/default/{entity}/shortcut_set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:12:\"shortcut_set\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:17:\"shortcut_set.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/jsonapi/shortcut/default/(?P<entity>[^/]++)/shortcut_set$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/shortcut_set\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:40:\"/jsonapi/shortcut/default/%/shortcut_set\";s:8:\"numParts\";i:5;}}',5),('jsonapi.shortcut--default.shortcut_set.relationship.delete','/jsonapi/shortcut/default/{entity}/relationships/shortcut_set','/jsonapi/shortcut/default/%/relationships/shortcut_set',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/shortcut/default/{entity}/relationships/shortcut_set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"shortcut_set\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"shortcut_set.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/shortcut/default/(?P<entity>[^/]++)/relationships/shortcut_set$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/shortcut_set\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:54:\"/jsonapi/shortcut/default/%/relationships/shortcut_set\";s:8:\"numParts\";i:6;}}',6),('jsonapi.shortcut--default.shortcut_set.relationship.get','/jsonapi/shortcut/default/{entity}/relationships/shortcut_set','/jsonapi/shortcut/default/%/relationships/shortcut_set',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/shortcut/default/{entity}/relationships/shortcut_set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"shortcut_set\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"shortcut_set.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/shortcut/default/(?P<entity>[^/]++)/relationships/shortcut_set$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/shortcut_set\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:54:\"/jsonapi/shortcut/default/%/relationships/shortcut_set\";s:8:\"numParts\";i:6;}}',6),('jsonapi.shortcut--default.shortcut_set.relationship.patch','/jsonapi/shortcut/default/{entity}/relationships/shortcut_set','/jsonapi/shortcut/default/%/relationships/shortcut_set',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/shortcut/default/{entity}/relationships/shortcut_set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"shortcut_set\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"shortcut_set.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/shortcut/default/(?P<entity>[^/]++)/relationships/shortcut_set$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/shortcut_set\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:54:\"/jsonapi/shortcut/default/%/relationships/shortcut_set\";s:8:\"numParts\";i:6;}}',6),('jsonapi.shortcut--default.shortcut_set.relationship.post','/jsonapi/shortcut/default/{entity}/relationships/shortcut_set','/jsonapi/shortcut/default/%/relationships/shortcut_set',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/jsonapi/shortcut/default/{entity}/relationships/shortcut_set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"shortcut_set\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:17:\"shortcut--default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"shortcut_set.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/jsonapi/shortcut/default/(?P<entity>[^/]++)/relationships/shortcut_set$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/shortcut_set\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/jsonapi/shortcut/default\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:54:\"/jsonapi/shortcut/default/%/relationships/shortcut_set\";s:8:\"numParts\";i:6;}}',6),('jsonapi.shortcut_set--shortcut_set.collection','/jsonapi/shortcut_set/shortcut_set','/jsonapi/shortcut_set/shortcut_set',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/jsonapi/shortcut_set/shortcut_set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:26:\"shortcut_set--shortcut_set\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/jsonapi/shortcut_set/shortcut_set$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/shortcut_set/shortcut_set\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:34:\"/jsonapi/shortcut_set/shortcut_set\";s:8:\"numParts\";i:3;}}',3),('jsonapi.shortcut_set--shortcut_set.individual','/jsonapi/shortcut_set/shortcut_set/{entity}','/jsonapi/shortcut_set/shortcut_set/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/shortcut_set/shortcut_set/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:26:\"shortcut_set--shortcut_set\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/shortcut_set/shortcut_set/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/jsonapi/shortcut_set/shortcut_set\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:36:\"/jsonapi/shortcut_set/shortcut_set/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.simple_sitemap--simple_sitemap.collection','/jsonapi/simple_sitemap/simple_sitemap','/jsonapi/simple_sitemap/simple_sitemap',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/jsonapi/simple_sitemap/simple_sitemap\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:30:\"simple_sitemap--simple_sitemap\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/jsonapi/simple_sitemap/simple_sitemap$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/jsonapi/simple_sitemap/simple_sitemap\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:38:\"/jsonapi/simple_sitemap/simple_sitemap\";s:8:\"numParts\";i:3;}}',3),('jsonapi.simple_sitemap--simple_sitemap.individual','/jsonapi/simple_sitemap/simple_sitemap/{entity}','/jsonapi/simple_sitemap/simple_sitemap/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/simple_sitemap/simple_sitemap/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:30:\"simple_sitemap--simple_sitemap\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:21:\"entity:simple_sitemap\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/jsonapi/simple_sitemap/simple_sitemap/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/jsonapi/simple_sitemap/simple_sitemap\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:40:\"/jsonapi/simple_sitemap/simple_sitemap/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.simple_sitemap_type--simple_sitemap_type.collection','/jsonapi/simple_sitemap_type/simple_sitemap_type','/jsonapi/simple_sitemap_type/simple_sitemap_type',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/simple_sitemap_type/simple_sitemap_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:40:\"simple_sitemap_type--simple_sitemap_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/jsonapi/simple_sitemap_type/simple_sitemap_type$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/simple_sitemap_type/simple_sitemap_type\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:48:\"/jsonapi/simple_sitemap_type/simple_sitemap_type\";s:8:\"numParts\";i:3;}}',3),('jsonapi.simple_sitemap_type--simple_sitemap_type.individual','/jsonapi/simple_sitemap_type/simple_sitemap_type/{entity}','/jsonapi/simple_sitemap_type/simple_sitemap_type/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/simple_sitemap_type/simple_sitemap_type/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:40:\"simple_sitemap_type--simple_sitemap_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:26:\"entity:simple_sitemap_type\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/simple_sitemap_type/simple_sitemap_type/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/simple_sitemap_type/simple_sitemap_type\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:50:\"/jsonapi/simple_sitemap_type/simple_sitemap_type/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.taxonomy_term--tags.collection','/jsonapi/taxonomy_term/tags','/jsonapi/taxonomy_term/tags',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/taxonomy_term/tags\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/jsonapi/taxonomy_term/tags$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/jsonapi/taxonomy_term/tags\";s:8:\"numParts\";i:3;}}',3),('jsonapi.taxonomy_term--tags.collection.post','/jsonapi/taxonomy_term/tags','/jsonapi/taxonomy_term/tags',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/taxonomy_term/tags\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:18:\"taxonomy_term:tags\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/jsonapi/taxonomy_term/tags$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/jsonapi/taxonomy_term/tags\";s:8:\"numParts\";i:3;}}',3),('jsonapi.taxonomy_term--tags.individual','/jsonapi/taxonomy_term/tags/{entity}','/jsonapi/taxonomy_term/tags/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/jsonapi/taxonomy_term/tags/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:29:\"/jsonapi/taxonomy_term/tags/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.taxonomy_term--tags.individual.delete','/jsonapi/taxonomy_term/tags/{entity}','/jsonapi/taxonomy_term/tags/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/jsonapi/taxonomy_term/tags/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:29:\"/jsonapi/taxonomy_term/tags/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.taxonomy_term--tags.individual.patch','/jsonapi/taxonomy_term/tags/{entity}','/jsonapi/taxonomy_term/tags/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/jsonapi/taxonomy_term/tags/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:29:\"/jsonapi/taxonomy_term/tags/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.taxonomy_term--tags.parent.related','/jsonapi/taxonomy_term/tags/{entity}/parent','/jsonapi/taxonomy_term/tags/%/parent',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/jsonapi/taxonomy_term/tags/{entity}/parent\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:6:\"parent\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:11:\"parent.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/parent$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/parent\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:36:\"/jsonapi/taxonomy_term/tags/%/parent\";s:8:\"numParts\";i:5;}}',5),('jsonapi.taxonomy_term--tags.parent.relationship.delete','/jsonapi/taxonomy_term/tags/{entity}/relationships/parent','/jsonapi/taxonomy_term/tags/%/relationships/parent',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/parent\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"parent\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"parent.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/parent$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/parent\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/taxonomy_term/tags/%/relationships/parent\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.parent.relationship.get','/jsonapi/taxonomy_term/tags/{entity}/relationships/parent','/jsonapi/taxonomy_term/tags/%/relationships/parent',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/parent\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"parent\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"parent.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/parent$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/parent\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/taxonomy_term/tags/%/relationships/parent\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.parent.relationship.patch','/jsonapi/taxonomy_term/tags/{entity}/relationships/parent','/jsonapi/taxonomy_term/tags/%/relationships/parent',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/parent\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"parent\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"parent.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/parent$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/parent\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/taxonomy_term/tags/%/relationships/parent\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.parent.relationship.post','/jsonapi/taxonomy_term/tags/{entity}/relationships/parent','/jsonapi/taxonomy_term/tags/%/relationships/parent',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/parent\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:6:\"parent\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:11:\"parent.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/parent$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/relationships/parent\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:50:\"/jsonapi/taxonomy_term/tags/%/relationships/parent\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.revision_user.related','/jsonapi/taxonomy_term/tags/{entity}/revision_user','/jsonapi/taxonomy_term/tags/%/revision_user',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/jsonapi/taxonomy_term/tags/{entity}/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:13:\"revision_user\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:43:\"/jsonapi/taxonomy_term/tags/%/revision_user\";s:8:\"numParts\";i:5;}}',5),('jsonapi.taxonomy_term--tags.revision_user.relationship.delete','/jsonapi/taxonomy_term/tags/{entity}/relationships/revision_user','/jsonapi/taxonomy_term/tags/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/jsonapi/taxonomy_term/tags/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.revision_user.relationship.get','/jsonapi/taxonomy_term/tags/{entity}/relationships/revision_user','/jsonapi/taxonomy_term/tags/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/jsonapi/taxonomy_term/tags/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.revision_user.relationship.patch','/jsonapi/taxonomy_term/tags/{entity}/relationships/revision_user','/jsonapi/taxonomy_term/tags/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/jsonapi/taxonomy_term/tags/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.revision_user.relationship.post','/jsonapi/taxonomy_term/tags/{entity}/relationships/revision_user','/jsonapi/taxonomy_term/tags/%/relationships/revision_user',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/revision_user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:13:\"revision_user\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:18:\"revision_user.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/revision_user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/relationships/revision_user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/jsonapi/taxonomy_term/tags/%/relationships/revision_user\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.vid.related','/jsonapi/taxonomy_term/tags/{entity}/vid','/jsonapi/taxonomy_term/tags/%/vid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/taxonomy_term/tags/{entity}/vid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"vid\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"vid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/vid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/vid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:33:\"/jsonapi/taxonomy_term/tags/%/vid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.taxonomy_term--tags.vid.relationship.delete','/jsonapi/taxonomy_term/tags/{entity}/relationships/vid','/jsonapi/taxonomy_term/tags/%/relationships/vid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/vid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"vid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"vid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/vid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/vid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/taxonomy_term/tags/%/relationships/vid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.vid.relationship.get','/jsonapi/taxonomy_term/tags/{entity}/relationships/vid','/jsonapi/taxonomy_term/tags/%/relationships/vid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/vid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"vid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"vid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/vid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/vid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/taxonomy_term/tags/%/relationships/vid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.vid.relationship.patch','/jsonapi/taxonomy_term/tags/{entity}/relationships/vid','/jsonapi/taxonomy_term/tags/%/relationships/vid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/vid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"vid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"vid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/vid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/vid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/taxonomy_term/tags/%/relationships/vid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_term--tags.vid.relationship.post','/jsonapi/taxonomy_term/tags/{entity}/relationships/vid','/jsonapi/taxonomy_term/tags/%/relationships/vid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/taxonomy_term/tags/{entity}/relationships/vid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"vid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:19:\"taxonomy_term--tags\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"vid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/taxonomy_term/tags/(?P<entity>[^/]++)/relationships/vid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/vid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/taxonomy_term/tags\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/taxonomy_term/tags/%/relationships/vid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.taxonomy_vocabulary--taxonomy_vocabulary.collection','/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary','/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:40:\"taxonomy_vocabulary--taxonomy_vocabulary\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:48:\"/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary\";s:8:\"numParts\";i:3;}}',3),('jsonapi.taxonomy_vocabulary--taxonomy_vocabulary.individual','/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary/{entity}','/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:40:\"taxonomy_vocabulary--taxonomy_vocabulary\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:50:\"/jsonapi/taxonomy_vocabulary/taxonomy_vocabulary/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.user--user.collection','/jsonapi/user/user','/jsonapi/user/user',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/jsonapi/user/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/jsonapi/user/user$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/jsonapi/user/user\";s:8:\"numParts\";i:3;}}',3),('jsonapi.user--user.collection.post','/jsonapi/user/user','/jsonapi/user/user',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/jsonapi/user/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:9:\"user:user\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/jsonapi/user/user$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/jsonapi/user/user\";s:8:\"numParts\";i:3;}}',3),('jsonapi.user--user.file_upload.existing_resource','/jsonapi/user/user/{entity}/{file_field_name}','/jsonapi/user/user/%/%',28,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/jsonapi/user/user/{entity}/{file_field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:55:\"jsonapi.file_upload:handleFileUploadForExistingResource\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:3:\"bin\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:6:\"entity\";i:1;s:15:\"file_field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/(?P<file_field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"file_field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:2:{i:0;s:6:\"entity\";i:1;s:15:\"file_field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:22:\"/jsonapi/user/user/%/%\";s:8:\"numParts\";i:5;}}',5),('jsonapi.user--user.file_upload.new_resource','/jsonapi/user/user/{file_field_name}','/jsonapi/user/user/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/jsonapi/user/user/{file_field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:50:\"jsonapi.file_upload:handleFileUploadForNewResource\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:3:\"bin\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"file_field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/jsonapi/user/user/(?P<file_field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"file_field_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"file_field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/user/user/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.user--user.individual','/jsonapi/user/user/{entity}','/jsonapi/user/user/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/user/user/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/user/user/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/user/user/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.user--user.individual.delete','/jsonapi/user/user/{entity}','/jsonapi/user/user/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/user/user/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/user/user/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/user/user/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.user--user.individual.patch','/jsonapi/user/user/{entity}','/jsonapi/user/user/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/user/user/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/user/user/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/user/user/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.user--user.roles.related','/jsonapi/user/user/{entity}/roles','/jsonapi/user/user/%/roles',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/user/user/{entity}/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:5:\"roles\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:10:\"roles.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/roles$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/roles\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:26:\"/jsonapi/user/user/%/roles\";s:8:\"numParts\";i:5;}}',5),('jsonapi.user--user.roles.relationship.delete','/jsonapi/user/user/{entity}/relationships/roles','/jsonapi/user/user/%/relationships/roles',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/user/user/{entity}/relationships/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:5:\"roles\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:10:\"roles.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/relationships/roles$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/relationships/roles\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:40:\"/jsonapi/user/user/%/relationships/roles\";s:8:\"numParts\";i:6;}}',6),('jsonapi.user--user.roles.relationship.get','/jsonapi/user/user/{entity}/relationships/roles','/jsonapi/user/user/%/relationships/roles',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/user/user/{entity}/relationships/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:5:\"roles\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:10:\"roles.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/relationships/roles$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/relationships/roles\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:40:\"/jsonapi/user/user/%/relationships/roles\";s:8:\"numParts\";i:6;}}',6),('jsonapi.user--user.roles.relationship.patch','/jsonapi/user/user/{entity}/relationships/roles','/jsonapi/user/user/%/relationships/roles',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/user/user/{entity}/relationships/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:5:\"roles\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:10:\"roles.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/relationships/roles$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/relationships/roles\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:40:\"/jsonapi/user/user/%/relationships/roles\";s:8:\"numParts\";i:6;}}',6),('jsonapi.user--user.roles.relationship.post','/jsonapi/user/user/{entity}/relationships/roles','/jsonapi/user/user/%/relationships/roles',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/user/user/{entity}/relationships/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:5:\"roles\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:10:\"roles.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/relationships/roles$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/relationships/roles\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:40:\"/jsonapi/user/user/%/relationships/roles\";s:8:\"numParts\";i:6;}}',6),('jsonapi.user--user.user_picture.related','/jsonapi/user/user/{entity}/user_picture','/jsonapi/user/user/%/user_picture',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/user/user/{entity}/user_picture\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:12:\"user_picture\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:17:\"user_picture.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/user_picture$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/user_picture\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:33:\"/jsonapi/user/user/%/user_picture\";s:8:\"numParts\";i:5;}}',5),('jsonapi.user--user.user_picture.relationship.delete','/jsonapi/user/user/{entity}/relationships/user_picture','/jsonapi/user/user/%/relationships/user_picture',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/user/user/{entity}/relationships/user_picture\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"user_picture\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"user_picture.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/relationships/user_picture$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/user_picture\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/user/user/%/relationships/user_picture\";s:8:\"numParts\";i:6;}}',6),('jsonapi.user--user.user_picture.relationship.get','/jsonapi/user/user/{entity}/relationships/user_picture','/jsonapi/user/user/%/relationships/user_picture',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/user/user/{entity}/relationships/user_picture\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"user_picture\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"user_picture.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/relationships/user_picture$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/user_picture\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/user/user/%/relationships/user_picture\";s:8:\"numParts\";i:6;}}',6),('jsonapi.user--user.user_picture.relationship.patch','/jsonapi/user/user/{entity}/relationships/user_picture','/jsonapi/user/user/%/relationships/user_picture',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/user/user/{entity}/relationships/user_picture\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"user_picture\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"user_picture.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/relationships/user_picture$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/user_picture\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/user/user/%/relationships/user_picture\";s:8:\"numParts\";i:6;}}',6),('jsonapi.user--user.user_picture.relationship.post','/jsonapi/user/user/{entity}/relationships/user_picture','/jsonapi/user/user/%/relationships/user_picture',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/jsonapi/user/user/{entity}/relationships/user_picture\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:12:\"user_picture\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:10:\"user--user\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:17:\"user_picture.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/jsonapi/user/user/(?P<entity>[^/]++)/relationships/user_picture$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/relationships/user_picture\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/user/user\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/jsonapi/user/user/%/relationships/user_picture\";s:8:\"numParts\";i:6;}}',6),('jsonapi.user_role--user_role.collection','/jsonapi/user_role/user_role','/jsonapi/user_role/user_role',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/jsonapi/user_role/user_role\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:20:\"user_role--user_role\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/jsonapi/user_role/user_role$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/user_role/user_role\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/jsonapi/user_role/user_role\";s:8:\"numParts\";i:3;}}',3),('jsonapi.user_role--user_role.individual','/jsonapi/user_role/user_role/{entity}','/jsonapi/user_role/user_role/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/user_role/user_role/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:20:\"user_role--user_role\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/user_role/user_role/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/user_role/user_role\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:30:\"/jsonapi/user_role/user_role/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.view--view.collection','/jsonapi/view/view','/jsonapi/view/view',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/jsonapi/view/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:10:\"view--view\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/jsonapi/view/view$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/view/view\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/jsonapi/view/view\";s:8:\"numParts\";i:3;}}',3),('jsonapi.view--view.individual','/jsonapi/view/view/{entity}','/jsonapi/view/view/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/view/view/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:10:\"view--view\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/view/view/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/jsonapi/view/view\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:20:\"/jsonapi/view/view/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.webform--webform.collection','/jsonapi/webform/webform','/jsonapi/webform/webform',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/jsonapi/webform/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:16:\"webform--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/jsonapi/webform/webform$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/webform/webform\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/jsonapi/webform/webform\";s:8:\"numParts\";i:3;}}',3),('jsonapi.webform--webform.individual','/jsonapi/webform/webform/{entity}','/jsonapi/webform/webform/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/jsonapi/webform/webform/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:16:\"webform--webform\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/jsonapi/webform/webform/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/jsonapi/webform/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:26:\"/jsonapi/webform/webform/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.webform_access_group--webform_access_group.collection','/jsonapi/webform_access_group/webform_access_group','/jsonapi/webform_access_group/webform_access_group',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/jsonapi/webform_access_group/webform_access_group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:42:\"webform_access_group--webform_access_group\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/jsonapi/webform_access_group/webform_access_group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:50:\"/jsonapi/webform_access_group/webform_access_group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:50:\"/jsonapi/webform_access_group/webform_access_group\";s:8:\"numParts\";i:3;}}',3),('jsonapi.webform_access_group--webform_access_group.individual','/jsonapi/webform_access_group/webform_access_group/{entity}','/jsonapi/webform_access_group/webform_access_group/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/jsonapi/webform_access_group/webform_access_group/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:42:\"webform_access_group--webform_access_group\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:27:\"entity:webform_access_group\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/jsonapi/webform_access_group/webform_access_group/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:50:\"/jsonapi/webform_access_group/webform_access_group\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:52:\"/jsonapi/webform_access_group/webform_access_group/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.webform_access_type--webform_access_type.collection','/jsonapi/webform_access_type/webform_access_type','/jsonapi/webform_access_type/webform_access_type',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/webform_access_type/webform_access_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:40:\"webform_access_type--webform_access_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/jsonapi/webform_access_type/webform_access_type$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/webform_access_type/webform_access_type\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:48:\"/jsonapi/webform_access_type/webform_access_type\";s:8:\"numParts\";i:3;}}',3),('jsonapi.webform_access_type--webform_access_type.individual','/jsonapi/webform_access_type/webform_access_type/{entity}','/jsonapi/webform_access_type/webform_access_type/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/jsonapi/webform_access_type/webform_access_type/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:40:\"webform_access_type--webform_access_type\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:26:\"entity:webform_access_type\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/jsonapi/webform_access_type/webform_access_type/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/webform_access_type/webform_access_type\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:50:\"/jsonapi/webform_access_type/webform_access_type/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.webform_options--webform_options.collection','/jsonapi/webform_options/webform_options','/jsonapi/webform_options/webform_options',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/webform_options/webform_options\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:32:\"webform_options--webform_options\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/jsonapi/webform_options/webform_options$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/jsonapi/webform_options/webform_options\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:40:\"/jsonapi/webform_options/webform_options\";s:8:\"numParts\";i:3;}}',3),('jsonapi.webform_options--webform_options.individual','/jsonapi/webform_options/webform_options/{entity}','/jsonapi/webform_options/webform_options/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/jsonapi/webform_options/webform_options/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:32:\"webform_options--webform_options\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/jsonapi/webform_options/webform_options/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/jsonapi/webform_options/webform_options\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:42:\"/jsonapi/webform_options/webform_options/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.webform_submission--contact.collection','/jsonapi/webform_submission/contact','/jsonapi/webform_submission/contact',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/webform_submission/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getCollection\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/jsonapi/webform_submission/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:35:\"/jsonapi/webform_submission/contact\";s:8:\"numParts\";i:3;}}',3),('jsonapi.webform_submission--contact.collection.post','/jsonapi/webform_submission/contact','/jsonapi/webform_submission/contact',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/webform_submission/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:createIndividual\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:21:\"_entity_create_access\";s:26:\"webform_submission:contact\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:26:\"access_check.entity_create\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/jsonapi/webform_submission/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:35:\"/jsonapi/webform_submission/contact\";s:8:\"numParts\";i:3;}}',3),('jsonapi.webform_submission--contact.individual','/jsonapi/webform_submission/contact/{entity}','/jsonapi/webform_submission/contact/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/jsonapi/webform_submission/contact/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:37:\"jsonapi.entity_resource:getIndividual\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:37:\"/jsonapi/webform_submission/contact/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.webform_submission--contact.individual.delete','/jsonapi/webform_submission/contact/{entity}','/jsonapi/webform_submission/contact/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/jsonapi/webform_submission/contact/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:40:\"jsonapi.entity_resource:deleteIndividual\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.delete\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:37:\"/jsonapi/webform_submission/contact/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.webform_submission--contact.individual.patch','/jsonapi/webform_submission/contact/{entity}','/jsonapi/webform_submission/contact/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/jsonapi/webform_submission/contact/{entity}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:39:\"jsonapi.entity_resource:patchIndividual\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:14:\"_entity_access\";s:13:\"entity.update\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:37:\"/jsonapi/webform_submission/contact/%\";s:8:\"numParts\";i:4;}}',4),('jsonapi.webform_submission--contact.uid.related','/jsonapi/webform_submission/contact/{entity}/uid','/jsonapi/webform_submission/contact/%/uid',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/webform_submission/contact/{entity}/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:3:\"uid\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/jsonapi/webform_submission/contact/%/uid\";s:8:\"numParts\";i:5;}}',5),('jsonapi.webform_submission--contact.uid.relationship.delete','/jsonapi/webform_submission/contact/{entity}/relationships/uid','/jsonapi/webform_submission/contact/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/webform_submission/contact/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/webform_submission/contact/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.webform_submission--contact.uid.relationship.get','/jsonapi/webform_submission/contact/{entity}/relationships/uid','/jsonapi/webform_submission/contact/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/webform_submission/contact/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/webform_submission/contact/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.webform_submission--contact.uid.relationship.patch','/jsonapi/webform_submission/contact/{entity}/relationships/uid','/jsonapi/webform_submission/contact/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/webform_submission/contact/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/webform_submission/contact/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.webform_submission--contact.uid.relationship.post','/jsonapi/webform_submission/contact/{entity}/relationships/uid','/jsonapi/webform_submission/contact/%/relationships/uid',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/jsonapi/webform_submission/contact/{entity}/relationships/uid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:3:\"uid\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:8:\"uid.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/relationships/uid$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/relationships/uid\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:55:\"/jsonapi/webform_submission/contact/%/relationships/uid\";s:8:\"numParts\";i:6;}}',6),('jsonapi.webform_submission--contact.webform_id.related','/jsonapi/webform_submission/contact/{entity}/webform_id','/jsonapi/webform_submission/contact/%/webform_id',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/jsonapi/webform_submission/contact/{entity}/webform_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:34:\"jsonapi.entity_resource:getRelated\";s:7:\"related\";s:10:\"webform_id\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:34:\"_jsonapi_relationship_route_access\";s:15:\"webform_id.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/webform_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/webform_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:48:\"/jsonapi/webform_submission/contact/%/webform_id\";s:8:\"numParts\";i:5;}}',5),('jsonapi.webform_submission--contact.webform_id.relationship.delete','/jsonapi/webform_submission/contact/{entity}/relationships/webform_id','/jsonapi/webform_submission/contact/%/relationships/webform_id',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/webform_submission/contact/{entity}/relationships/webform_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:10:\"webform_id\";s:11:\"_controller\";s:50:\"jsonapi.entity_resource:removeFromRelationshipData\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:15:\"webform_id.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:6:\"DELETE\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/relationships/webform_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/relationships/webform_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/webform_submission/contact/%/relationships/webform_id\";s:8:\"numParts\";i:6;}}',6),('jsonapi.webform_submission--contact.webform_id.relationship.get','/jsonapi/webform_submission/contact/{entity}/relationships/webform_id','/jsonapi/webform_submission/contact/%/relationships/webform_id',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/webform_submission/contact/{entity}/relationships/webform_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:10:\"webform_id\";s:11:\"_controller\";s:39:\"jsonapi.entity_resource:getRelationship\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:15:\"webform_id.view\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/relationships/webform_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/relationships/webform_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/webform_submission/contact/%/relationships/webform_id\";s:8:\"numParts\";i:6;}}',6),('jsonapi.webform_submission--contact.webform_id.relationship.patch','/jsonapi/webform_submission/contact/{entity}/relationships/webform_id','/jsonapi/webform_submission/contact/%/relationships/webform_id',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/webform_submission/contact/{entity}/relationships/webform_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:10:\"webform_id\";s:11:\"_controller\";s:47:\"jsonapi.entity_resource:replaceRelationshipData\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:15:\"webform_id.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:5:\"PATCH\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/relationships/webform_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/relationships/webform_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/webform_submission/contact/%/relationships/webform_id\";s:8:\"numParts\";i:6;}}',6),('jsonapi.webform_submission--contact.webform_id.relationship.post','/jsonapi/webform_submission/contact/{entity}/relationships/webform_id','/jsonapi/webform_submission/contact/%/relationships/webform_id',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/jsonapi/webform_submission/contact/{entity}/relationships/webform_id\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:16:\"_on_relationship\";b:1;s:7:\"related\";s:10:\"webform_id\";s:11:\"_controller\";s:45:\"jsonapi.entity_resource:addToRelationshipData\";s:13:\"resource_type\";s:27:\"webform_submission--contact\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:4:{s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:34:\"_jsonapi_relationship_route_access\";s:15:\"webform_id.edit\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:6:\"entity\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:34:\"paramconverter.jsonapi.entity_uuid\";}s:13:\"resource_type\";a:2:{s:4:\"type\";s:21:\"jsonapi_resource_type\";s:9:\"converter\";s:36:\"paramconverter.jsonapi.resource_type\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:2:{i:0;s:46:\"access_check.jsonapi.relationship_route_access\";i:1;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"entity\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/jsonapi/webform_submission/contact/(?P<entity>[^/]++)/relationships/webform_id$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/relationships/webform_id\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/webform_submission/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"entity\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:62:\"/jsonapi/webform_submission/contact/%/relationships/webform_id\";s:8:\"numParts\";i:6;}}',6),('jsonapi_extras.settings','/admin/config/services/jsonapi/extras','/admin/config/services/jsonapi/extras',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/services/jsonapi/extras\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:53:\"\\Drupal\\jsonapi_extras\\Form\\JsonapiExtrasSettingsForm\";s:6:\"_title\";s:15:\"JSON:API Extras\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/services/jsonapi/extras$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/services/jsonapi/extras\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/services/jsonapi/extras\";s:8:\"numParts\";i:5;}}',5),('jsonapi_menu_items.menu','/jsonapi/menu_items/{menu}','/jsonapi/menu_items/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/jsonapi/menu_items/{menu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:17:\"_jsonapi_resource\";s:52:\"Drupal\\jsonapi_menu_items\\Resource\\MenuItemsResource\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/jsonapi/menu_items/(?P<menu>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/jsonapi/menu_items\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:21:\"/jsonapi/menu_items/%\";s:8:\"numParts\";i:3;}}',3),('jsonapi_views.block_content.default','/jsonapi/views/block_content/default','/jsonapi/views/block_content/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/jsonapi/views/block_content/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:20:\"block_content--basic\";}s:4:\"view\";s:13:\"block_content\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/jsonapi/views/block_content/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/jsonapi/views/block_content/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:36:\"/jsonapi/views/block_content/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.block_content.page_1','/jsonapi/views/block_content/page_1','/jsonapi/views/block_content/page_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/views/block_content/page_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:20:\"block_content--basic\";}s:4:\"view\";s:13:\"block_content\";s:7:\"display\";s:6:\"page_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/jsonapi/views/block_content/page_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/views/block_content/page_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/jsonapi/views/block_content/page_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.comment.default','/jsonapi/views/comment/default','/jsonapi/views/comment/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/views/comment/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:16:\"comment--comment\";}s:4:\"view\";s:7:\"comment\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/jsonapi/views/comment/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/jsonapi/views/comment/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/jsonapi/views/comment/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.comment.page_published','/jsonapi/views/comment/page_published','/jsonapi/views/comment/page_published',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/views/comment/page_published\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:16:\"comment--comment\";}s:4:\"view\";s:7:\"comment\";s:7:\"display\";s:14:\"page_published\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/views/comment/page_published$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/jsonapi/views/comment/page_published\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/jsonapi/views/comment/page_published\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.comment.page_unapproved','/jsonapi/views/comment/page_unapproved','/jsonapi/views/comment/page_unapproved',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/jsonapi/views/comment/page_unapproved\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:16:\"comment--comment\";}s:4:\"view\";s:7:\"comment\";s:7:\"display\";s:15:\"page_unapproved\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/jsonapi/views/comment/page_unapproved$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/jsonapi/views/comment/page_unapproved\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:38:\"/jsonapi/views/comment/page_unapproved\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.comments_recent.block_1','/jsonapi/views/comments_recent/block_1','/jsonapi/views/comments_recent/block_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/jsonapi/views/comments_recent/block_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:16:\"comment--comment\";}s:4:\"view\";s:15:\"comments_recent\";s:7:\"display\";s:7:\"block_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/jsonapi/views/comments_recent/block_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/jsonapi/views/comments_recent/block_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:38:\"/jsonapi/views/comments_recent/block_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.comments_recent.default','/jsonapi/views/comments_recent/default','/jsonapi/views/comments_recent/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/jsonapi/views/comments_recent/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:16:\"comment--comment\";}s:4:\"view\";s:15:\"comments_recent\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/jsonapi/views/comments_recent/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/jsonapi/views/comments_recent/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:38:\"/jsonapi/views/comments_recent/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.content.default','/jsonapi/views/content/default','/jsonapi/views/content/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/views/content/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:7:\"content\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/jsonapi/views/content/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/jsonapi/views/content/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/jsonapi/views/content/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.content.page_1','/jsonapi/views/content/page_1','/jsonapi/views/content/page_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/jsonapi/views/content/page_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:7:\"content\";s:7:\"display\";s:6:\"page_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/jsonapi/views/content/page_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/jsonapi/views/content/page_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/jsonapi/views/content/page_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.content_recent.block_1','/jsonapi/views/content_recent/block_1','/jsonapi/views/content_recent/block_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/views/content_recent/block_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:14:\"content_recent\";s:7:\"display\";s:7:\"block_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/views/content_recent/block_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/jsonapi/views/content_recent/block_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/jsonapi/views/content_recent/block_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.content_recent.default','/jsonapi/views/content_recent/default','/jsonapi/views/content_recent/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/jsonapi/views/content_recent/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:14:\"content_recent\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/jsonapi/views/content_recent/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/jsonapi/views/content_recent/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/jsonapi/views/content_recent/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.files.default','/jsonapi/views/files/default','/jsonapi/views/files/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/jsonapi/views/files/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"file--file\";}s:4:\"view\";s:5:\"files\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/jsonapi/views/files/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/jsonapi/views/files/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/jsonapi/views/files/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.files.page_1','/jsonapi/views/files/page_1','/jsonapi/views/files/page_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/views/files/page_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"file--file\";}s:4:\"view\";s:5:\"files\";s:7:\"display\";s:6:\"page_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/jsonapi/views/files/page_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/views/files/page_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:27:\"/jsonapi/views/files/page_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.files.page_2','/jsonapi/views/files/page_2','/jsonapi/views/files/page_2',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/jsonapi/views/files/page_2\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"file--file\";}s:4:\"view\";s:5:\"files\";s:7:\"display\";s:6:\"page_2\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/jsonapi/views/files/page_2$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/jsonapi/views/files/page_2\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:27:\"/jsonapi/views/files/page_2\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.frontpage.default','/jsonapi/views/frontpage/default','/jsonapi/views/frontpage/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/views/frontpage/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:9:\"frontpage\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/views/frontpage/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/views/frontpage/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/jsonapi/views/frontpage/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.frontpage.feed_1','/jsonapi/views/frontpage/feed_1','/jsonapi/views/frontpage/feed_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/views/frontpage/feed_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:9:\"frontpage\";s:7:\"display\";s:6:\"feed_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/jsonapi/views/frontpage/feed_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/views/frontpage/feed_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/jsonapi/views/frontpage/feed_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.frontpage.page_1','/jsonapi/views/frontpage/page_1','/jsonapi/views/frontpage/page_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/views/frontpage/page_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:9:\"frontpage\";s:7:\"display\";s:6:\"page_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/jsonapi/views/frontpage/page_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/views/frontpage/page_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/jsonapi/views/frontpage/page_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.redirect.default','/jsonapi/views/redirect/default','/jsonapi/views/redirect/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/jsonapi/views/redirect/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:18:\"redirect--redirect\";}s:4:\"view\";s:8:\"redirect\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/jsonapi/views/redirect/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/jsonapi/views/redirect/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/jsonapi/views/redirect/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.redirect.page_1','/jsonapi/views/redirect/page_1','/jsonapi/views/redirect/page_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/jsonapi/views/redirect/page_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:18:\"redirect--redirect\";}s:4:\"view\";s:8:\"redirect\";s:7:\"display\";s:6:\"page_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/jsonapi/views/redirect/page_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/jsonapi/views/redirect/page_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/jsonapi/views/redirect/page_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.taxonomy_term.default','/jsonapi/views/taxonomy_term/default','/jsonapi/views/taxonomy_term/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/jsonapi/views/taxonomy_term/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:13:\"taxonomy_term\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/jsonapi/views/taxonomy_term/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/jsonapi/views/taxonomy_term/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:36:\"/jsonapi/views/taxonomy_term/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.taxonomy_term.feed_1','/jsonapi/views/taxonomy_term/feed_1','/jsonapi/views/taxonomy_term/feed_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/views/taxonomy_term/feed_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:13:\"taxonomy_term\";s:7:\"display\";s:6:\"feed_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/jsonapi/views/taxonomy_term/feed_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/views/taxonomy_term/feed_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/jsonapi/views/taxonomy_term/feed_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.taxonomy_term.page_1','/jsonapi/views/taxonomy_term/page_1','/jsonapi/views/taxonomy_term/page_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/views/taxonomy_term/page_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:3:{i:0;s:13:\"node--article\";i:1;s:10:\"node--page\";i:2;s:13:\"node--webform\";}s:4:\"view\";s:13:\"taxonomy_term\";s:7:\"display\";s:6:\"page_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/jsonapi/views/taxonomy_term/page_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/views/taxonomy_term/page_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/jsonapi/views/taxonomy_term/page_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.user_admin_people.default','/jsonapi/views/user_admin_people/default','/jsonapi/views/user_admin_people/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/jsonapi/views/user_admin_people/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"user--user\";}s:4:\"view\";s:17:\"user_admin_people\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/jsonapi/views/user_admin_people/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/jsonapi/views/user_admin_people/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:40:\"/jsonapi/views/user_admin_people/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.user_admin_people.page_1','/jsonapi/views/user_admin_people/page_1','/jsonapi/views/user_admin_people/page_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/jsonapi/views/user_admin_people/page_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"user--user\";}s:4:\"view\";s:17:\"user_admin_people\";s:7:\"display\";s:6:\"page_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/jsonapi/views/user_admin_people/page_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/jsonapi/views/user_admin_people/page_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/jsonapi/views/user_admin_people/page_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.webform_submissions.default','/jsonapi/views/webform_submissions/default','/jsonapi/views/webform_submissions/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/jsonapi/views/webform_submissions/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:27:\"webform_submission--contact\";}s:4:\"view\";s:19:\"webform_submissions\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/jsonapi/views/webform_submissions/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/jsonapi/views/webform_submissions/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:42:\"/jsonapi/views/webform_submissions/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.webform_submissions.embed_administer','/jsonapi/views/webform_submissions/embed_administer','/jsonapi/views/webform_submissions/embed_administer',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/jsonapi/views/webform_submissions/embed_administer\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:27:\"webform_submission--contact\";}s:4:\"view\";s:19:\"webform_submissions\";s:7:\"display\";s:16:\"embed_administer\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/jsonapi/views/webform_submissions/embed_administer$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/jsonapi/views/webform_submissions/embed_administer\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:51:\"/jsonapi/views/webform_submissions/embed_administer\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.webform_submissions.embed_default','/jsonapi/views/webform_submissions/embed_default','/jsonapi/views/webform_submissions/embed_default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/jsonapi/views/webform_submissions/embed_default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:27:\"webform_submission--contact\";}s:4:\"view\";s:19:\"webform_submissions\";s:7:\"display\";s:13:\"embed_default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/jsonapi/views/webform_submissions/embed_default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/jsonapi/views/webform_submissions/embed_default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:48:\"/jsonapi/views/webform_submissions/embed_default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.webform_submissions.embed_manage','/jsonapi/views/webform_submissions/embed_manage','/jsonapi/views/webform_submissions/embed_manage',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/views/webform_submissions/embed_manage\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:27:\"webform_submission--contact\";}s:4:\"view\";s:19:\"webform_submissions\";s:7:\"display\";s:12:\"embed_manage\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/views/webform_submissions/embed_manage$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/jsonapi/views/webform_submissions/embed_manage\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:47:\"/jsonapi/views/webform_submissions/embed_manage\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.webform_submissions.embed_review','/jsonapi/views/webform_submissions/embed_review','/jsonapi/views/webform_submissions/embed_review',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/jsonapi/views/webform_submissions/embed_review\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:27:\"webform_submission--contact\";}s:4:\"view\";s:19:\"webform_submissions\";s:7:\"display\";s:12:\"embed_review\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/jsonapi/views/webform_submissions/embed_review$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/jsonapi/views/webform_submissions/embed_review\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:47:\"/jsonapi/views/webform_submissions/embed_review\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.who_s_new.block_1','/jsonapi/views/who_s_new/block_1','/jsonapi/views/who_s_new/block_1',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/views/who_s_new/block_1\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"user--user\";}s:4:\"view\";s:9:\"who_s_new\";s:7:\"display\";s:7:\"block_1\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/views/who_s_new/block_1$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/views/who_s_new/block_1\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/jsonapi/views/who_s_new/block_1\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.who_s_new.default','/jsonapi/views/who_s_new/default','/jsonapi/views/who_s_new/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/jsonapi/views/who_s_new/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"user--user\";}s:4:\"view\";s:9:\"who_s_new\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/jsonapi/views/who_s_new/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/jsonapi/views/who_s_new/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/jsonapi/views/who_s_new/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.who_s_online.default','/jsonapi/views/who_s_online/default','/jsonapi/views/who_s_online/default',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/jsonapi/views/who_s_online/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"user--user\";}s:4:\"view\";s:12:\"who_s_online\";s:7:\"display\";s:7:\"default\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/jsonapi/views/who_s_online/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/jsonapi/views/who_s_online/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/jsonapi/views/who_s_online/default\";s:8:\"numParts\";i:4;}}',4),('jsonapi_views.who_s_online.who_s_online_block','/jsonapi/views/who_s_online/who_s_online_block','/jsonapi/views/who_s_online/who_s_online_block',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/jsonapi/views/who_s_online/who_s_online_block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:17:\"_jsonapi_resource\";s:43:\"Drupal\\jsonapi_views\\Resource\\ViewsResource\";s:23:\"_jsonapi_resource_types\";a:1:{i:0;s:10:\"user--user\";}s:4:\"view\";s:12:\"who_s_online\";s:7:\"display\";s:18:\"who_s_online_block\";s:11:\"_is_jsonapi\";b:1;}s:12:\"requirements\";a:3:{s:7:\"_access\";s:4:\"TRUE\";s:20:\"_content_type_format\";s:8:\"api_json\";s:7:\"_format\";s:8:\"api_json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/jsonapi/views/who_s_online/who_s_online_block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/jsonapi/views/who_s_online/who_s_online_block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:46:\"/jsonapi/views/who_s_online/who_s_online_block\";s:8:\"numParts\";i:4;}}',4),('language.add','/admin/config/regional/language/add','/admin/config/regional/language/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/config/regional/language/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"configurable_language.add\";s:6:\"_title\";s:12:\"Add language\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:21:\"configurable_language\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/config/regional/language/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/regional/language/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:35:\"/admin/config/regional/language/add\";s:8:\"numParts\";i:5;}}',5),('language.content_settings_page','/admin/config/regional/content-language','/admin/config/regional/content-language',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/regional/content-language\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:59:\"\\Drupal\\language\\Form\\ContentLanguageSettingsForm::getTitle\";s:5:\"_form\";s:49:\"\\Drupal\\language\\Form\\ContentLanguageSettingsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer languages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/config/regional/content\\-language$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/regional/content-language\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/config/regional/content-language\";s:8:\"numParts\";i:4;}}',4),('language.negotiation','/admin/config/regional/language/detection','/admin/config/regional/language/detection',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/config/regional/language/detection\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:46:\"\\Drupal\\language\\Form\\NegotiationConfigureForm\";s:6:\"_title\";s:23:\"Detection and selection\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer languages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/config/regional/language/detection$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/config/regional/language/detection\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/config/regional/language/detection\";s:8:\"numParts\";i:5;}}',5),('language.negotiation_browser','/admin/config/regional/language/detection/browser','/admin/config/regional/language/detection/browser',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/config/regional/language/detection/browser\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\language\\Form\\NegotiationBrowserForm\";s:6:\"_title\";s:40:\"Browser language detection configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer languages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/admin/config/regional/language/detection/browser$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:49:\"/admin/config/regional/language/detection/browser\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:49:\"/admin/config/regional/language/detection/browser\";s:8:\"numParts\";i:6;}}',6),('language.negotiation_browser_delete','/admin/config/regional/language/detection/browser/delete/{browser_langcode}','/admin/config/regional/language/detection/browser/delete/%',254,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/config/regional/language/detection/browser/delete/{browser_langcode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:50:\"\\Drupal\\language\\Form\\NegotiationBrowserDeleteForm\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer languages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"browser_langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/config/regional/language/detection/browser/delete/(?P<browser_langcode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"browser_langcode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:56:\"/admin/config/regional/language/detection/browser/delete\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"browser_langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:254;s:14:\"patternOutline\";s:58:\"/admin/config/regional/language/detection/browser/delete/%\";s:8:\"numParts\";i:8;}}',8),('language.negotiation_selected','/admin/config/regional/language/detection/selected','/admin/config/regional/language/detection/selected',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/config/regional/language/detection/selected\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\language\\Form\\NegotiationSelectedForm\";s:6:\"_title\";s:31:\"Selected language configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer languages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/config/regional/language/detection/selected$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:50:\"/admin/config/regional/language/detection/selected\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:50:\"/admin/config/regional/language/detection/selected\";s:8:\"numParts\";i:6;}}',6),('language.negotiation_session','/admin/config/regional/language/detection/session','/admin/config/regional/language/detection/session',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/config/regional/language/detection/session\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\language\\Form\\NegotiationSessionForm\";s:6:\"_title\";s:40:\"Session language detection configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer languages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/admin/config/regional/language/detection/session$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:49:\"/admin/config/regional/language/detection/session\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:49:\"/admin/config/regional/language/detection/session\";s:8:\"numParts\";i:6;}}',6),('language.negotiation_url','/admin/config/regional/language/detection/url','/admin/config/regional/language/detection/url',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/regional/language/detection/url\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\language\\Form\\NegotiationUrlForm\";s:6:\"_title\";s:36:\"URL language detection configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer languages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/config/regional/language/detection/url$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/regional/language/detection/url\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:45:\"/admin/config/regional/language/detection/url\";s:8:\"numParts\";i:6;}}',6),('linkit.autocomplete','/linkit/autocomplete/{linkit_profile_id}','/linkit/autocomplete/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/linkit/autocomplete/{linkit_profile_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\linkit\\Controller\\AutocompleteController::autocomplete\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:6:\"_theme\";s:14:\"ajax_base_page\";s:10:\"parameters\";a:1:{s:17:\"linkit_profile_id\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"linkit_profile_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/linkit/autocomplete/(?P<linkit_profile_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"linkit_profile_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/linkit/autocomplete\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"linkit_profile_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:22:\"/linkit/autocomplete/%\";s:8:\"numParts\";i:3;}}',3),('linkit.matcher.add','/admin/config/content/linkit/manage/{linkit_profile}/matchers/add','/admin/config/content/linkit/manage/%/matchers/add',251,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/config/content/linkit/manage/{linkit_profile}/matchers/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:35:\"\\Drupal\\linkit\\Form\\Matcher\\AddForm\";s:6:\"_title\";s:11:\"Add matcher\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/matchers/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/matchers/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:50:\"/admin/config/content/linkit/manage/%/matchers/add\";s:8:\"numParts\";i:8;}}',8),('linkit.matcher.delete','/admin/config/content/linkit/manage/{linkit_profile}/matchers/{plugin_instance_id}/delete','/admin/config/content/linkit/manage/%/matchers/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/config/content/linkit/manage/{linkit_profile}/matchers/{plugin_instance_id}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:38:\"\\Drupal\\linkit\\Form\\Matcher\\DeleteForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:18:\"plugin_instance_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/matchers/(?P<plugin_instance_id>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"plugin_instance_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/matchers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:18:\"plugin_instance_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:55:\"/admin/config/content/linkit/manage/%/matchers/%/delete\";s:8:\"numParts\";i:9;}}',9),('linkit.matcher.edit','/admin/config/content/linkit/manage/{linkit_profile}/matchers/{plugin_instance_id}','/admin/config/content/linkit/manage/%/matchers/%',250,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/config/content/linkit/manage/{linkit_profile}/matchers/{plugin_instance_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\linkit\\Form\\Matcher\\EditForm\";s:15:\"_title_callback\";s:55:\"Drupal\\linkit\\Controller\\LinkitController::matcherTitle\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:18:\"plugin_instance_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/matchers/(?P<plugin_instance_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"plugin_instance_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/matchers\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:18:\"plugin_instance_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:48:\"/admin/config/content/linkit/manage/%/matchers/%\";s:8:\"numParts\";i:8;}}',8),('linkit.matchers','/admin/config/content/linkit/manage/{linkit_profile}/matchers','/admin/config/content/linkit/manage/%/matchers',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/content/linkit/manage/{linkit_profile}/matchers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\linkit\\Form\\Matcher\\OverviewForm\";s:6:\"_title\";s:15:\"Manage matchers\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/matchers$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/matchers\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/content/linkit/manage/%/matchers\";s:8:\"numParts\";i:7;}}',7),('locale.check_translation','/admin/reports/translations/check','/admin/reports/translations/check',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/reports/translations/check\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:60:\"\\Drupal\\locale\\Controller\\LocaleController::checkTranslation\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"translate interface\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/reports/translations/check$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/reports/translations/check\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/reports/translations/check\";s:8:\"numParts\";i:4;}}',4),('locale.settings','/admin/config/regional/translate/settings','/admin/config/regional/translate/settings',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/config/regional/translate/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\locale\\Form\\LocaleSettingsForm\";s:6:\"_title\";s:30:\"Interface translation settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"translate interface\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/config/regional/translate/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/config/regional/translate/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/config/regional/translate/settings\";s:8:\"numParts\";i:5;}}',5),('locale.translate_export','/admin/config/regional/translate/export','/admin/config/regional/translate/export',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/regional/translate/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:30:\"\\Drupal\\locale\\Form\\ExportForm\";s:6:\"_title\";s:28:\"Interface translation export\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"translate interface\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/config/regional/translate/export$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/regional/translate/export\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/config/regional/translate/export\";s:8:\"numParts\";i:5;}}',5),('locale.translate_import','/admin/config/regional/translate/import','/admin/config/regional/translate/import',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/regional/translate/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:30:\"\\Drupal\\locale\\Form\\ImportForm\";s:6:\"_title\";s:28:\"Interface translation import\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"translate interface\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/config/regional/translate/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/regional/translate/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/config/regional/translate/import\";s:8:\"numParts\";i:5;}}',5),('locale.translate_page','/admin/config/regional/translate','/admin/config/regional/translate',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/regional/translate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:57:\"\\Drupal\\locale\\Controller\\LocaleController::translatePage\";s:6:\"_title\";s:26:\"User interface translation\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"translate interface\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/regional/translate$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/regional/translate\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/regional/translate\";s:8:\"numParts\";i:4;}}',4),('locale.translate_status','/admin/reports/translations','/admin/reports/translations',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/reports/translations\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:41:\"\\Drupal\\locale\\Form\\TranslationStatusForm\";s:6:\"_title\";s:29:\"Available translation updates\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"translate interface\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/reports/translations$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/reports/translations\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/reports/translations\";s:8:\"numParts\";i:3;}}',3),('menu_item_extras.clear_all_extra_data','/admin/modules/uninstall/extra_data/menu_item_extras','/admin/modules/uninstall/extra_data/menu_item_extras',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/modules/uninstall/extra_data/menu_item_extras\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\menu_item_extras\\Controller\\MenuController::removeExtraData\";s:6:\"_title\";s:27:\"Remove menu item extra data\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:15:\"administer menu\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/modules/uninstall/extra_data/menu_item_extras$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/modules/uninstall/extra_data/menu_item_extras\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:52:\"/admin/modules/uninstall/extra_data/menu_item_extras\";s:8:\"numParts\";i:5;}}',5),('menu_ui.link_edit','/admin/structure/menu/link/{menu_link_plugin}/edit','/admin/structure/menu/link/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/menu/link/{menu_link_plugin}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\menu_ui\\Form\\MenuLinkEditForm\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"menu_link_plugin\";a:2:{s:4:\"type\";s:16:\"menu_link_plugin\";s:9:\"converter\";s:54:\"drupal.proxy_original_service.paramconverter.menu_link\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"menu_link_plugin\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/link\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/link/%/edit\";s:8:\"numParts\";i:6;}}',6),('menu_ui.link_reset','/admin/structure/menu/link/{menu_link_plugin}/reset','/admin/structure/menu/link/%/reset',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/link/{menu_link_plugin}/reset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm\";s:6:\"_title\";s:15:\"Reset menu link\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:15:\"administer menu\";s:14:\"_custom_access\";s:56:\"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm::linkIsResettable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"menu_link_plugin\";a:2:{s:4:\"type\";s:16:\"menu_link_plugin\";s:9:\"converter\";s:54:\"drupal.proxy_original_service.paramconverter.menu_link\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/reset$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reset\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"menu_link_plugin\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/link\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/menu/link/%/reset\";s:8:\"numParts\";i:6;}}',6),('menu_ui.parent_options_js','/admin/structure/menu/parents','/admin/structure/menu/parents',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/menu/parents\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:59:\"\\Drupal\\menu_ui\\Controller\\MenuController::getParentOptions\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/menu/parents$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/menu/parents\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/menu/parents\";s:8:\"numParts\";i:4;}}',4),('metatag.reports_plugins','/admin/reports/metatag-plugins','/admin/reports/metatag-plugins',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/reports/metatag-plugins\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\metatag\\Controller\\MetatagController::reportPlugins\";s:6:\"_title\";s:15:\"Metatag plugins\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/metatag\\-plugins$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/reports/metatag-plugins\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/reports/metatag-plugins\";s:8:\"numParts\";i:3;}}',3),('metatag.settings','/admin/config/search/metatag/settings','/admin/config/search/metatag/settings',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/search/metatag/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\metatag\\Form\\MetatagSettingsForm\";s:6:\"_title\";s:28:\"Configure the Metatag module\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/search/metatag/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/search/metatag/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/search/metatag/settings\";s:8:\"numParts\";i:5;}}',5),('node.add','/node/add/{node_type}','/node/add/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/node/add/{node_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"node.default\";s:15:\"_title_callback\";s:52:\"\\Drupal\\node\\Controller\\NodeController::addPageTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:16:\"node:{node_type}\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:3:{s:4:\"type\";s:16:\"entity:node_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/node/add/(?P<node_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/node/add\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:11:\"/node/add/%\";s:8:\"numParts\";i:3;}}',3),('node.add_page','/node/add','/node/add',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:9:\"/node/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:11:\"Add content\";s:11:\"_controller\";s:47:\"\\Drupal\\node\\Controller\\NodeController::addPage\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:4:\"node\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:16:\"{^/node/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/node/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:9:\"/node/add\";s:8:\"numParts\";i:2;}}',2),('node.configure_rebuild_confirm','/admin/reports/status/rebuild','/admin/reports/status/rebuild',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/status/rebuild\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\RebuildPermissionsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer nodes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/status/rebuild$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/status/rebuild\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/reports/status/rebuild\";s:8:\"numParts\";i:4;}}',4),('node.multiple_delete_confirm','/admin/content/node/delete','/admin/content/node/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/content/node/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\node\\Form\\DeleteMultiple\";s:14:\"entity_type_id\";s:4:\"node\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:4:\"node\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/node/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/node/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/content/node/delete\";s:8:\"numParts\";i:4;}}',4),('node.revision_delete_confirm','/node/{node}/revisions/{node_revision}/delete','/node/%/revisions/%/delete',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/revisions/{node_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\NodeRevisionDeleteForm\";s:6:\"_title\";s:23:\"Delete earlier revision\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.delete revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/node/%/revisions/%/delete\";s:8:\"numParts\";i:5;}}',5),('node.revision_revert_confirm','/node/{node}/revisions/{node_revision}/revert','/node/%/revisions/%/revert',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/revisions/{node_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\NodeRevisionRevertForm\";s:6:\"_title\";s:26:\"Revert to earlier revision\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.revert revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/node/%/revisions/%/revert\";s:8:\"numParts\";i:5;}}',5),('node.revision_revert_translation_confirm','/node/{node}/revisions/{node_revision}/revert/{langcode}','/node/%/revisions/%/revert/%',42,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/node/{node}/revisions/{node_revision}/revert/{langcode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\node\\Form\\NodeRevisionRevertTranslationForm\";s:6:\"_title\";s:43:\"Revert to earlier revision of a translation\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.revert revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert/(?P<langcode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:42;s:14:\"patternOutline\";s:28:\"/node/%/revisions/%/revert/%\";s:8:\"numParts\";i:6;}}',6),('node.type_add','/admin/structure/types/add','/admin/structure/types/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"node_type.add\";s:6:\"_title\";s:16:\"Add content type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/types/add\";s:8:\"numParts\";i:4;}}',4),('pathauto.admin.delete','/admin/config/search/path/delete_bulk','/admin/config/search/path/delete_bulk',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/search/path/delete_bulk\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:41:\"\\Drupal\\pathauto\\Form\\PathautoAdminDelete\";s:6:\"_title\";s:14:\"Delete aliases\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer pathauto+bulk delete aliases\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/search/path/delete_bulk$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/search/path/delete_bulk\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/search/path/delete_bulk\";s:8:\"numParts\";i:5;}}',5),('pathauto.bulk.update.form','/admin/config/search/path/update_bulk','/admin/config/search/path/update_bulk',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/search/path/update_bulk\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\pathauto\\Form\\PathautoBulkUpdateForm\";s:6:\"_title\";s:13:\"Bulk generate\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer pathauto+bulk update aliases\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/search/path/update_bulk$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/search/path/update_bulk\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/search/path/update_bulk\";s:8:\"numParts\";i:5;}}',5),('pathauto.settings.form','/admin/config/search/path/settings','/admin/config/search/path/settings',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/search/path/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\pathauto\\Form\\PathautoSettingsForm\";s:6:\"_title\";s:8:\"Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"administer pathauto\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/search/path/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/config/search/path/settings\";s:8:\"numParts\";i:5;}}',5),('redirect.add','/admin/config/search/redirect/add','/admin/config/search/redirect/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/search/redirect/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"redirect.default\";s:6:\"_title\";s:16:\"Add URL redirect\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:8:\"redirect\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/search/redirect/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/redirect/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:33:\"/admin/config/search/redirect/add\";s:8:\"numParts\";i:5;}}',5),('redirect.list','/admin/config/search/redirect','/admin/config/search/redirect',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/search/redirect\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"redirect\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"administer redirects\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/search/redirect$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/search/redirect\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/search/redirect\";s:8:\"numParts\";i:4;}}',4),('redirect.settings','/admin/config/search/redirect/settings','/admin/config/search/redirect/settings',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/config/search/redirect/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\redirect\\Form\\RedirectSettingsForm\";s:6:\"_title\";s:8:\"Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer redirect settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/search/redirect/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/config/search/redirect/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:38:\"/admin/config/search/redirect/settings\";s:8:\"numParts\";i:5;}}',5),('rest.entity.webform.GET','/webform/{webform}','/webform/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/webform/{webform}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:34:\"Drupal\\rest\\RequestHandler::handle\";s:21:\"_rest_resource_config\";s:14:\"entity.webform\";}s:12:\"requirements\";a:4:{s:7:\"_access\";s:4:\"TRUE\";s:14:\"_entity_access\";s:12:\"webform.view\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:21:\"_rest_resource_config\";a:2:{s:4:\"type\";s:27:\"entity:rest_resource_config\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:3:{i:0;s:20:\"access_check.default\";i:1;s:19:\"access_check.entity\";i:2;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/webform/(?P<webform>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/webform/%\";s:8:\"numParts\";i:2;}}',2),('rest.entity.webform_options.GET','/entity/webform_options/{webform_options}','/entity/webform_options/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/entity/webform_options/{webform_options}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:34:\"Drupal\\rest\\RequestHandler::handle\";s:21:\"_rest_resource_config\";s:22:\"entity.webform_options\";}s:12:\"requirements\";a:4:{s:7:\"_access\";s:4:\"TRUE\";s:14:\"_entity_access\";s:20:\"webform_options.view\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:21:\"_rest_resource_config\";a:2:{s:4:\"type\";s:27:\"entity:rest_resource_config\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:14:\"_access_checks\";a:3:{i:0;s:20:\"access_check.default\";i:1;s:19:\"access_check.entity\";i:2;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/entity/webform_options/(?P<webform_options>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/entity/webform_options\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:25:\"/entity/webform_options/%\";s:8:\"numParts\";i:3;}}',3),('rest.webform_rest_elements.GET','/webform_rest/{webform_id}/elements','/webform_rest/%/elements',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/webform_rest/{webform_id}/elements\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:34:\"Drupal\\rest\\RequestHandler::handle\";s:21:\"_rest_resource_config\";s:21:\"webform_rest_elements\";}s:12:\"requirements\";a:4:{s:7:\"_access\";s:4:\"TRUE\";s:11:\"_permission\";s:33:\"restful get webform_rest_elements\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:10:\"parameters\";a:1:{s:21:\"_rest_resource_config\";a:2:{s:4:\"type\";s:27:\"entity:rest_resource_config\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:3:{i:0;s:20:\"access_check.default\";i:1;s:23:\"access_check.permission\";i:2;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"webform_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/webform_rest/(?P<webform_id>[^/]++)/elements$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/elements\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"webform_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/webform_rest\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"webform_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:24:\"/webform_rest/%/elements\";s:8:\"numParts\";i:3;}}',3),('rest.webform_rest_submit.POST','/webform_rest/submit','/webform_rest/submit',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/webform_rest/submit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:34:\"Drupal\\rest\\RequestHandler::handle\";s:21:\"_rest_resource_config\";s:19:\"webform_rest_submit\";}s:12:\"requirements\";a:5:{s:7:\"_access\";s:4:\"TRUE\";s:11:\"_permission\";s:32:\"restful post webform_rest_submit\";s:26:\"_csrf_request_header_token\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";s:20:\"_content_type_format\";s:4:\"json\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:5:\"_auth\";a:1:{i:0;s:6:\"cookie\";}s:10:\"parameters\";a:1:{s:21:\"_rest_resource_config\";a:2:{s:4:\"type\";s:27:\"entity:rest_resource_config\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:3:{i:0;s:20:\"access_check.default\";i:1;s:23:\"access_check.permission\";i:2;s:24:\"access_check.header.csrf\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/webform_rest/submit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/webform_rest/submit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:20:\"/webform_rest/submit\";s:8:\"numParts\";i:2;}}',2),('restui.disable','/admin/config/services/rest/resource/{resource_id}/disable','/admin/config/services/rest/resource/%/disable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/config/services/rest/resource/{resource_id}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\restui\\Controller\\RestUIController::disable\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:25:\"administer rest resources\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"resource_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/services/rest/resource/(?P<resource_id>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"resource_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/services/rest/resource\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"resource_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/services/rest/resource/%/disable\";s:8:\"numParts\";i:7;}}',7),('restui.edit','/admin/config/services/rest/resource/{resource_id}/edit','/admin/config/services/rest/resource/%/edit',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/config/services/rest/resource/{resource_id}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:30:\"\\Drupal\\restui\\Form\\RestUIForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer rest resources\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"resource_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/config/services/rest/resource/(?P<resource_id>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"resource_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/services/rest/resource\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"resource_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:43:\"/admin/config/services/rest/resource/%/edit\";s:8:\"numParts\";i:7;}}',7),('restui.list','/admin/config/services/rest','/admin/config/services/rest',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/config/services/rest\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:57:\"\\Drupal\\restui\\Controller\\RestUIController::listResources\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer rest resources\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/config/services/rest$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/config/services/rest\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:27:\"/admin/config/services/rest\";s:8:\"numParts\";i:4;}}',4),('shortcut.link_add','/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link','/admin/config/user-interface/shortcut/manage/%/add-link',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\shortcut\\Controller\\ShortcutController::addForm\";s:6:\"_title\";s:8:\"Add link\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:23:\"shortcut:{shortcut_set}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/add-link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:55:\"/admin/config/user-interface/shortcut/manage/%/add-link\";s:8:\"numParts\";i:7;}}',7),('shortcut.link_add_inline','/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline','/admin/config/user-interface/shortcut/manage/%/add-link-inline',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\shortcut\\Controller\\ShortcutSetController::addShortcutLinkInline\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link\\-inline$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/add-link-inline\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:62:\"/admin/config/user-interface/shortcut/manage/%/add-link-inline\";s:8:\"numParts\";i:7;}}',7),('shortcut.set_add','/admin/config/user-interface/shortcut/add-set','/admin/config/user-interface/shortcut/add-set',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/user-interface/shortcut/add-set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut_set.add\";s:6:\"_title\";s:16:\"Add shortcut set\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:12:\"shortcut_set\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/user\\-interface/shortcut/add\\-set$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/user-interface/shortcut/add-set\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:45:\"/admin/config/user-interface/shortcut/add-set\";s:8:\"numParts\";i:5;}}',5),('shortcut.set_switch','/user/{user}/shortcuts','/user/%/shortcuts',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/user/{user}/shortcuts\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\shortcut\\Form\\SwitchShortcutSet\";s:6:\"_title\";s:9:\"Shortcuts\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:52:\"\\Drupal\\shortcut\\Form\\SwitchShortcutSet::checkAccess\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"user\";s:3:\"\\d+\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/user/(?P<user>[^/]++)/shortcuts$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/shortcuts\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/user/%/shortcuts\";s:8:\"numParts\";i:3;}}',3),('simple_sitemap.add','/admin/config/search/simplesitemap/variants/add','/admin/config/search/simplesitemap/variants/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/search/simplesitemap/variants/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"simple_sitemap.add\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/search/simplesitemap/variants/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/search/simplesitemap/variants/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:47:\"/admin/config/search/simplesitemap/variants/add\";s:8:\"numParts\";i:6;}}',6),('simple_sitemap.custom','/admin/config/search/simplesitemap/custom','/admin/config/search/simplesitemap/custom',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/config/search/simplesitemap/custom\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\simple_sitemap\\Form\\CustomLinksForm\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/config/search/simplesitemap/custom$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/config/search/simplesitemap/custom\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/config/search/simplesitemap/custom\";s:8:\"numParts\";i:5;}}',5),('simple_sitemap.entities','/admin/config/search/simplesitemap/entities','/admin/config/search/simplesitemap/entities',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/config/search/simplesitemap/entities\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\simple_sitemap\\Form\\EntitiesForm\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/config/search/simplesitemap/entities$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/entities\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:43:\"/admin/config/search/simplesitemap/entities\";s:8:\"numParts\";i:5;}}',5),('simple_sitemap.entity_bundles','/admin/config/search/simplesitemap/entities/{entity_type_id}','/admin/config/search/simplesitemap/entities/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/search/simplesitemap/entities/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\simple_sitemap\\Form\\EntityBundlesForm\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/search/simplesitemap/entities/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/entities\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:45:\"/admin/config/search/simplesitemap/entities/%\";s:8:\"numParts\";i:6;}}',6),('simple_sitemap.settings','/admin/config/search/simplesitemap/settings','/admin/config/search/simplesitemap/settings',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/config/search/simplesitemap/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\simple_sitemap\\Form\\SettingsForm\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/config/search/simplesitemap/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/config/search/simplesitemap/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:43:\"/admin/config/search/simplesitemap/settings\";s:8:\"numParts\";i:5;}}',5),('simple_sitemap.sitemap_default','/sitemap.xml','/sitemap.xml',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/sitemap.xml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:69:\"\\Drupal\\simple_sitemap\\Controller\\SimpleSitemapController::getSitemap\";s:25:\"_disable_route_normalizer\";s:4:\"TRUE\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/sitemap\\.xml$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/sitemap.xml\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:12:\"/sitemap.xml\";s:8:\"numParts\";i:1;}}',1),('simple_sitemap.sitemap_variant','/sitemaps/{variant}/sitemap.xml','/sitemaps/%/sitemap.xml',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/sitemaps/{variant}/sitemap.xml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:69:\"\\Drupal\\simple_sitemap\\Controller\\SimpleSitemapController::getSitemap\";s:25:\"_disable_route_normalizer\";s:4:\"TRUE\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/sitemaps/(?P<variant>[^/]++)/sitemap\\.xml$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/sitemap.xml\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/sitemaps\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:23:\"/sitemaps/%/sitemap.xml\";s:8:\"numParts\";i:3;}}',3),('simple_sitemap.sitemap_xsl','/sitemap_generator/{sitemap_generator}/sitemap.xsl','/sitemap_generator/%/sitemap.xsl',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/sitemap_generator/{sitemap_generator}/sitemap.xsl\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:72:\"\\Drupal\\simple_sitemap\\Controller\\SimpleSitemapController::getSitemapXsl\";s:25:\"_disable_route_normalizer\";s:4:\"TRUE\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"sitemap_generator\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/sitemap_generator/(?P<sitemap_generator>[^/]++)/sitemap\\.xsl$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/sitemap.xsl\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"sitemap_generator\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/sitemap_generator\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"sitemap_generator\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:32:\"/sitemap_generator/%/sitemap.xsl\";s:8:\"numParts\";i:3;}}',3),('simple_sitemap_type.add','/admin/config/search/simplesitemap/types/add','/admin/config/search/simplesitemap/types/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/config/search/simplesitemap/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"simple_sitemap_type.add\";s:6:\"_title\";s:18:\"Simple XML Sitemap\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer sitemap settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/config/search/simplesitemap/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/search/simplesitemap/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:44:\"/admin/config/search/simplesitemap/types/add\";s:8:\"numParts\";i:6;}}',6),('system.401','/system/401','/system/401',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/401\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on401\";s:6:\"_title\";s:12:\"Unauthorized\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/401$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/401\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/401\";s:8:\"numParts\";i:2;}}',2),('system.403','/system/403','/system/403',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/403\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on403\";s:6:\"_title\";s:13:\"Access denied\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/403$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/403\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/403\";s:8:\"numParts\";i:2;}}',2),('system.404','/system/404','/system/404',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/404\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on404\";s:6:\"_title\";s:14:\"Page not found\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/404$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/404\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/404\";s:8:\"numParts\";i:2;}}',2),('system.4xx','/system/4xx','/system/4xx',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/4xx\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on4xx\";s:6:\"_title\";s:12:\"Client error\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/4xx$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/4xx\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/4xx\";s:8:\"numParts\";i:2;}}',2),('system.admin','/admin','/admin',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/admin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:14:\"Administration\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/admin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/admin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/admin\";s:8:\"numParts\";i:1;}}',1),('system.admin_compact_page','/admin/compact/{mode}','/admin/compact',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/compact/{mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\system\\Controller\\SystemController::compactPage\";s:4:\"mode\";s:3:\"off\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"access administration pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/compact(?:/(?P<mode>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/compact\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/compact\";s:8:\"numParts\";i:3;}}',3),('system.admin_config','/admin/config','/admin/config',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\SystemController::overview\";s:7:\"link_id\";s:19:\"system.admin_config\";s:6:\"_title\";s:13:\"Configuration\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:27:\"_access_admin_overview_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:32:\"access_check.admin_overview_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/config\";s:8:\"numParts\";i:2;}}',2),('system.admin_config_content','/admin/config/content','/admin/config/content',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/config/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:17:\"Content authoring\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/config/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/config/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/config/content\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_development','/admin/config/development','/admin/config/development',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/development\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:11:\"Development\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/development$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/development\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/config/development\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_media','/admin/config/media','/admin/config/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/config/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:5:\"Media\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/config/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/config/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/config/media\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_regional','/admin/config/regional','/admin/config/regional',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/regional\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:19:\"Region and language\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/regional$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/regional\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/regional\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_search','/admin/config/search','/admin/config/search',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/search\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:19:\"Search and metadata\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/search$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/search\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/search\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_services','/admin/config/services','/admin/config/services',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/services\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:12:\"Web services\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/services$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/services\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/services\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_system','/admin/config/system','/admin/config/system',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/system\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:6:\"System\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/system$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/system\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/system\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_ui','/admin/config/user-interface','/admin/config/user-interface',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/config/user-interface\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:14:\"User interface\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/user\\-interface$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/user-interface\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/config/user-interface\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_workflow','/admin/config/workflow','/admin/config/workflow',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/workflow\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:8:\"Workflow\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/workflow$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/workflow\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/workflow\";s:8:\"numParts\";i:3;}}',3),('system.admin_content','/admin/content','/admin/content',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:23:\"access content overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/content\";s:8:\"numParts\";i:2;}}',2),('system.admin_index','/admin/index','/admin/index',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/admin/index\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\system\\Controller\\AdminController::index\";s:6:\"_title\";s:14:\"Administration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"access administration pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/admin/index$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/admin/index\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/admin/index\";s:8:\"numParts\";i:2;}}',2),('system.admin_reports','/admin/reports','/admin/reports',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/reports\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:7:\"Reports\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/reports$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/reports\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/reports\";s:8:\"numParts\";i:2;}}',2);
INSERT INTO `router` VALUES ('system.admin_structure','/admin/structure','/admin/structure',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:16:\"/admin/structure\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:9:\"Structure\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:23:\"{^/admin/structure$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/admin/structure\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:16:\"/admin/structure\";s:8:\"numParts\";i:2;}}',2),('system.batch_page.html','/batch','/batch',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/batch\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\BatchController::batchPage\";s:15:\"_title_callback\";s:57:\"\\Drupal\\system\\Controller\\BatchController::batchPageTitle\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:12:\"_no_big_pipe\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/batch$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/batch\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/batch\";s:8:\"numParts\";i:1;}}',1),('system.batch_page.json','/batch','/batch',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/batch\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\BatchController::batchPage\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/batch$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/batch\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/batch\";s:8:\"numParts\";i:1;}}',1),('system.cron','/cron/{key}','/cron/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/cron/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:34:\"\\Drupal\\system\\CronController::run\";}s:12:\"requirements\";a:1:{s:19:\"_access_system_cron\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:17:\"access_check.cron\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/cron/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/cron\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/cron/%\";s:8:\"numParts\";i:2;}}',2),('system.cron_settings','/admin/config/system/cron','/admin/config/system/cron',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/system/cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:28:\"\\Drupal\\system\\Form\\CronForm\";s:6:\"_title\";s:4:\"Cron\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/system/cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/system/cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/config/system/cron\";s:8:\"numParts\";i:4;}}',4),('system.csrftoken','/session/token','/session/token',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/session/token\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:56:\"\\Drupal\\system\\Controller\\CsrfTokenController::csrfToken\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/session/token$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/session/token\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/session/token\";s:8:\"numParts\";i:2;}}',2),('system.css_asset','/sites/default/files/css/{file_name}','/sites/default/files/css/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/sites/default/files/css/{file_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"Drupal\\system\\Controller\\CssAssetController::deliver\";s:25:\"_disable_route_normalizer\";b:1;}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"file_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/sites/default/files/css/(?P<file_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"file_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/sites/default/files/css\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"file_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:26:\"/sites/default/files/css/%\";s:8:\"numParts\";i:5;}}',5),('system.date_format_add','/admin/config/regional/date-time/formats/add','/admin/config/regional/date-time/formats/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/config/regional/date-time/formats/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"date_format.add\";s:6:\"_title\";s:15:\"Add date format\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/config/regional/date\\-time/formats/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/regional/date-time/formats/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:44:\"/admin/config/regional/date-time/formats/add\";s:8:\"numParts\";i:6;}}',6),('system.db_update','/update.php/{op}','/update.php',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:16:\"/update.php/{op}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:2:\"op\";s:4:\"info\";}s:12:\"requirements\";a:1:{s:21:\"_access_system_update\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"default_url_options\";a:1:{s:15:\"path_processing\";b:0;}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:22:\"access_check.db_update\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"op\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/update\\.php(?:/(?P<op>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"op\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/update.php\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"op\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:11:\"/update.php\";s:8:\"numParts\";i:2;}}',2),('system.development_settings','/admin/config/development/settings','/admin/config/development/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/development/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\system\\Form\\DevelopmentSettingsForm\";s:6:\"_title\";s:20:\"Development settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/development/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/development/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/config/development/settings\";s:8:\"numParts\";i:4;}}',4),('system.entity_autocomplete','/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}','/entity_reference_autocomplete/%/%/%',8,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:74:\"\\Drupal\\system\\Controller\\EntityAutocompleteController::handleAutocomplete\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:11:\"target_type\";i:1;s:17:\"selection_handler\";i:2;s:22:\"selection_settings_key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/entity_reference_autocomplete/(?P<target_type>[^/]++)/(?P<selection_handler>[^/]++)/(?P<selection_settings_key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"selection_settings_key\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"selection_handler\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/entity_reference_autocomplete\";}}s:9:\"path_vars\";a:3:{i:0;s:11:\"target_type\";i:1;s:17:\"selection_handler\";i:2;s:22:\"selection_settings_key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:8;s:14:\"patternOutline\";s:36:\"/entity_reference_autocomplete/%/%/%\";s:8:\"numParts\";i:4;}}',4),('system.files','/system/files/{scheme}','/system/files',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/system/files/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";s:6:\"scheme\";s:7:\"private\";s:25:\"_disable_route_normalizer\";b:1;}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/system/files(?:/(?P<scheme>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/system/files\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/system/files\";s:8:\"numParts\";i:3;}}',3),('system.file_system_settings','/admin/config/media/file-system','/admin/config/media/file-system',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/media/file-system\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\system\\Form\\FileSystemForm\";s:6:\"_title\";s:11:\"File system\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/media/file\\-system$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/media/file-system\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/media/file-system\";s:8:\"numParts\";i:4;}}',4),('system.image_toolkit_settings','/admin/config/media/image-toolkit','/admin/config/media/image-toolkit',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/image-toolkit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\system\\Form\\ImageToolkitForm\";s:6:\"_title\";s:13:\"Image toolkit\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/media/image\\-toolkit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/image-toolkit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/image-toolkit\";s:8:\"numParts\";i:4;}}',4),('system.js_asset','/sites/default/files/js/{file_name}','/sites/default/files/js/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/sites/default/files/js/{file_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"Drupal\\system\\Controller\\JsAssetController::deliver\";s:25:\"_disable_route_normalizer\";b:1;}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"file_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/sites/default/files/js/(?P<file_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"file_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/sites/default/files/js\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"file_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:25:\"/sites/default/files/js/%\";s:8:\"numParts\";i:5;}}',5),('system.linkset_settings','/admin/config/services/linkset','/admin/config/services/linkset',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/config/services/linkset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:21:\"Menu Linkset Settings\";s:5:\"_form\";s:42:\"Drupal\\system\\Form\\MenuLinksetSettingsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/admin/config/services/linkset$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/services/linkset\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/config/services/linkset\";s:8:\"numParts\";i:4;}}',4),('system.logging_settings','/admin/config/development/logging','/admin/config/development/logging',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/development/logging\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\system\\Form\\LoggingForm\";s:6:\"_title\";s:18:\"Logging and errors\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/development/logging$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/development/logging\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/development/logging\";s:8:\"numParts\";i:4;}}',4),('system.modules_list','/admin/modules','/admin/modules',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/modules\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Extend\";s:14:\"_title_context\";s:15:\"With components\";s:5:\"_form\";s:35:\"\\Drupal\\system\\Form\\ModulesListForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_no_big_pipe\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/modules$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/modules\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/modules\";s:8:\"numParts\";i:2;}}',2),('system.modules_list_confirm','/admin/modules/list/confirm','/admin/modules/list/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/modules/list/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\system\\Form\\ModulesListConfirmForm\";s:6:\"_title\";s:39:\"Some required modules must be installed\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/modules/list/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/modules/list/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:27:\"/admin/modules/list/confirm\";s:8:\"numParts\";i:4;}}',4),('system.modules_list_non_stable_confirm','/admin/modules/list/confirm-non-stable','/admin/modules/list/confirm-non-stable',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/modules/list/confirm-non-stable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\system\\Form\\ModulesListNonStableConfirmForm\";s:6:\"_title\";s:18:\"Non-stable modules\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/modules/list/confirm\\-non\\-stable$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/modules/list/confirm-non-stable\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:38:\"/admin/modules/list/confirm-non-stable\";s:8:\"numParts\";i:4;}}',4),('system.modules_uninstall','/admin/modules/uninstall','/admin/modules/uninstall',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/modules/uninstall\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\system\\Form\\ModulesUninstallForm\";s:6:\"_title\";s:9:\"Uninstall\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/modules/uninstall$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/modules/uninstall\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/modules/uninstall\";s:8:\"numParts\";i:3;}}',3),('system.modules_uninstall_confirm','/admin/modules/uninstall/confirm','/admin/modules/uninstall/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/modules/uninstall/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\system\\Form\\ModulesUninstallConfirmForm\";s:6:\"_title\";s:17:\"Confirm uninstall\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/modules/uninstall/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/modules/uninstall/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/modules/uninstall/confirm\";s:8:\"numParts\";i:4;}}',4),('system.performance_settings','/admin/config/development/performance','/admin/config/development/performance',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/development/performance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\PerformanceController::build\";s:6:\"_title\";s:11:\"Performance\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/development/performance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/development/performance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/development/performance\";s:8:\"numParts\";i:4;}}',4),('system.php','/admin/reports/status/php','/admin/reports/status/php',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/reports/status/php\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\system\\Controller\\SystemInfoController::php\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/reports/status/php$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/reports/status/php\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/reports/status/php\";s:8:\"numParts\";i:4;}}',4),('system.prepare_modules_entity_uninstall','/admin/modules/uninstall/entity/{entity_type_id}','/admin/modules/uninstall/entity/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/modules/uninstall/entity/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:53:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm\";s:15:\"_title_callback\";s:64:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::formTitle\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:18:\"administer modules\";s:14:\"_custom_access\";s:66:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::checkAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/modules/uninstall/entity/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/modules/uninstall/entity\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/modules/uninstall/entity/%\";s:8:\"numParts\";i:5;}}',5),('system.private_file_download','/system/files/{filepath}','/system/files/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/system/files/{filepath}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";}s:12:\"requirements\";a:2:{s:8:\"filepath\";s:2:\".+\";s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"filepath\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/system/files/(?P<filepath>.+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:2:\".+\";i:3;s:8:\"filepath\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/system/files\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"filepath\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:15:\"/system/files/%\";s:8:\"numParts\";i:3;}}',3),('system.regional_settings','/admin/config/regional/settings','/admin/config/regional/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/regional/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\system\\Form\\RegionalForm\";s:6:\"_title\";s:17:\"Regional settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/config/regional/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/regional/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/regional/settings\";s:8:\"numParts\";i:4;}}',4),('system.rss_feeds_settings','/admin/config/services/rss-publishing','/admin/config/services/rss-publishing',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/services/rss-publishing\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\system\\Form\\RssFeedsForm\";s:6:\"_title\";s:14:\"RSS publishing\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/services/rss\\-publishing$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/services/rss-publishing\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/services/rss-publishing\";s:8:\"numParts\";i:4;}}',4),('system.run_cron','/admin/reports/status/run-cron','/admin/reports/status/run-cron',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/reports/status/run-cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:42:\"\\Drupal\\system\\CronController::runManually\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/status/run\\-cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/reports/status/run-cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/reports/status/run-cron\";s:8:\"numParts\";i:4;}}',4),('system.site_information_settings','/admin/config/system/site-information','/admin/config/system/site-information',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/system/site-information\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\system\\Form\\SiteInformationForm\";s:6:\"_title\";s:19:\"Basic site settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/system/site\\-information$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/system/site-information\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/system/site-information\";s:8:\"numParts\";i:4;}}',4),('system.site_maintenance_mode','/admin/config/development/maintenance','/admin/config/development/maintenance',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/development/maintenance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\system\\Form\\SiteMaintenanceModeForm\";s:6:\"_title\";s:16:\"Maintenance mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:57:\"administer site configuration+administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/development/maintenance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/development/maintenance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/development/maintenance\";s:8:\"numParts\";i:4;}}',4),('system.status','/admin/reports/status','/admin/reports/status',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/status\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\SystemInfoController::status\";s:6:\"_title\";s:13:\"Status report\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/status$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/status\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/status\";s:8:\"numParts\";i:3;}}',3),('system.temporary','/system/temporary','/system/temporary',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/system/temporary\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";s:6:\"scheme\";s:9:\"temporary\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/system/temporary$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/system/temporary\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:17:\"/system/temporary\";s:8:\"numParts\";i:2;}}',2),('system.themes_page','/admin/appearance','/admin/appearance',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/appearance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:10:\"Appearance\";s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\SystemController::themesPage\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/appearance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/appearance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:17:\"/admin/appearance\";s:8:\"numParts\";i:2;}}',2),('system.theme_install','/admin/appearance/install','/admin/appearance/install',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/appearance/install\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:50:\"\\Drupal\\system\\Controller\\ThemeController::install\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/appearance/install$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/appearance/install\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/appearance/install\";s:8:\"numParts\";i:3;}}',3),('system.theme_settings','/admin/appearance/settings','/admin/appearance/settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/appearance/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\system\\Form\\ThemeSettingsForm\";s:6:\"_title\";s:19:\"Appearance settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/appearance/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/appearance/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/appearance/settings\";s:8:\"numParts\";i:3;}}',3),('system.theme_settings_theme','/admin/appearance/settings/{theme}','/admin/appearance/settings/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/appearance/settings/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\system\\Form\\ThemeSettingsForm\";s:15:\"_title_callback\";s:21:\"theme_handler:getName\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/appearance/settings/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/appearance/settings\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:28:\"/admin/appearance/settings/%\";s:8:\"numParts\";i:4;}}',4),('system.theme_set_default','/admin/appearance/default','/admin/appearance/default',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/appearance/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:20:\"Set as default theme\";s:11:\"_controller\";s:58:\"\\Drupal\\system\\Controller\\ThemeController::setDefaultTheme\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/appearance/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/appearance/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/appearance/default\";s:8:\"numParts\";i:3;}}',3),('system.theme_uninstall','/admin/appearance/uninstall','/admin/appearance/uninstall',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/appearance/uninstall\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\ThemeController::uninstall\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/appearance/uninstall$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/appearance/uninstall\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/appearance/uninstall\";s:8:\"numParts\";i:3;}}',3),('system.timezone','/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}','/system/timezone',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:57:\"\\Drupal\\system\\Controller\\TimezoneController::getTimezone\";s:12:\"abbreviation\";s:0:\"\";s:6:\"offset\";i:-1;s:23:\"is_daylight_saving_time\";N;}s:12:\"requirements\";a:4:{s:7:\"_access\";s:4:\"TRUE\";s:12:\"abbreviation\";s:14:\"0|([A-Z]{3,5})\";s:6:\"offset\";s:6:\"\\-?\\d+\";s:23:\"is_daylight_saving_time\";s:7:\"\\-1|0|1\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"abbreviation\";i:1;s:6:\"offset\";i:2;s:23:\"is_daylight_saving_time\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/system/timezone(?:/(?P<abbreviation>0|(?:[A-Z]{3,5}))(?:/(?P<offset>\\-?\\d+)(?:/(?P<is_daylight_saving_time>\\-1|0|1))?)?)?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:7:\"\\-1|0|1\";i:3;s:23:\"is_daylight_saving_time\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"\\-?\\d+\";i:3;s:6:\"offset\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:16:\"0|(?:[A-Z]{3,5})\";i:3;s:12:\"abbreviation\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/system/timezone\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"abbreviation\";i:1;s:6:\"offset\";i:2;s:23:\"is_daylight_saving_time\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:16:\"/system/timezone\";s:8:\"numParts\";i:5;}}',5),('token.tree','/token/tree','/token/tree',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/token/tree\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:56:\"\\Drupal\\token\\Controller\\TokenTreeController::outputTree\";}s:12:\"requirements\";a:1:{s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/token/tree$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/token/tree\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/token/tree\";s:8:\"numParts\";i:2;}}',2),('toolbar.subtrees','/toolbar/subtrees/{hash}','/toolbar/subtrees/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/toolbar/subtrees/{hash}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\toolbar\\Controller\\ToolbarController::subtreesAjax\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\toolbar\\Controller\\ToolbarController::checkSubTreeAccess\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/toolbar/subtrees/(?P<hash>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/toolbar/subtrees\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:19:\"/toolbar/subtrees/%\";s:8:\"numParts\";i:3;}}',3),('update.confirmation_page','/admin/update/ready','/admin/update/ready',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/update/ready\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\update\\Form\\UpdateReady\";s:6:\"_title\";s:15:\"Ready to update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/update/ready$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/update/ready\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/update/ready\";s:8:\"numParts\";i:3;}}',3),('update.manual_status','/admin/reports/updates/check','/admin/reports/updates/check',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/updates/check\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:19:\"Manual update check\";s:11:\"_controller\";s:64:\"\\Drupal\\update\\Controller\\UpdateController::updateStatusManually\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/reports/updates/check$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/updates/check\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/reports/updates/check\";s:8:\"numParts\";i:4;}}',4),('update.module_update','/admin/modules/update','/admin/modules/update',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/modules/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/modules/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/modules/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/modules/update\";s:8:\"numParts\";i:3;}}',3),('update.report_update','/admin/reports/updates/update','/admin/reports/updates/update',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/updates/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/updates/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/updates/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/reports/updates/update\";s:8:\"numParts\";i:4;}}',4),('update.settings','/admin/reports/updates/settings','/admin/reports/updates/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/reports/updates/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:33:\"\\Drupal\\update\\UpdateSettingsForm\";s:6:\"_title\";s:23:\"Update Manager settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/updates/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/reports/updates/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/reports/updates/settings\";s:8:\"numParts\";i:4;}}',4),('update.status','/admin/reports/updates','/admin/reports/updates',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/reports/updates\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\update\\Controller\\UpdateController::updateStatus\";s:6:\"_title\";s:17:\"Available updates\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/reports/updates$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/reports/updates\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/reports/updates\";s:8:\"numParts\";i:3;}}',3),('update.theme_update','/admin/appearance/update','/admin/appearance/update',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/appearance/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/appearance/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/appearance/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/appearance/update\";s:8:\"numParts\";i:3;}}',3),('user.admin_create','/admin/people/create','/admin/people/create',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/people/create\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"user.register\";s:6:\"_title\";s:8:\"Add user\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"user\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/people/create$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/people/create\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/people/create\";s:8:\"numParts\";i:3;}}',3),('user.admin_index','/admin/config/people','/admin/config/people',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:6:\"People\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/people\";s:8:\"numParts\";i:3;}}',3),('user.admin_permissions','/admin/people/permissions','/admin/people/permissions',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/people/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\user\\Form\\UserPermissionsForm\";s:6:\"_title\";s:11:\"Permissions\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/people/permissions$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/people/permissions\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/people/permissions\";s:8:\"numParts\";i:3;}}',3),('user.admin_permissions.module','/admin/people/permissions/module/{modules}','/admin/people/permissions/module/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/people/permissions/module/{modules}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm\";s:6:\"_title\";s:18:\"Module Permissions\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:22:\"administer permissions\";s:7:\"modules\";s:16:\"[a-z][a-z0-9_,]*\";s:14:\"_custom_access\";s:59:\"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"modules\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/people/permissions/module/(?P<modules>[a-z][a-z0-9_,]*)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:16:\"[a-z][a-z0-9_,]*\";i:3;s:7:\"modules\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/people/permissions/module\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"modules\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:34:\"/admin/people/permissions/module/%\";s:8:\"numParts\";i:5;}}',5),('user.cancel_confirm','/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}','/user/%/cancel/confirm',11,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:28:\"Confirm account cancellation\";s:11:\"_controller\";s:53:\"\\Drupal\\user\\Controller\\UserController::confirmCancel\";s:9:\"timestamp\";i:0;s:11:\"hashed_pass\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"user.delete\";s:4:\"user\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"user\";i:1;s:9:\"timestamp\";i:2;s:11:\"hashed_pass\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:97:\"{^/user/(?P<user>\\d+)/cancel/confirm(?:/(?P<timestamp>[^/]++)(?:/(?P<hashed_pass>[^/]++))?)?$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"hashed_pass\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/cancel/confirm\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"user\";i:1;s:9:\"timestamp\";i:2;s:11:\"hashed_pass\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:22:\"/user/%/cancel/confirm\";s:8:\"numParts\";i:6;}}',6),('user.edit','/user/edit','/user/edit',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/user/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\user\\Controller\\UserController::userEditPage\";s:6:\"_title\";s:12:\"Edit account\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/user/edit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/user/edit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/user/edit\";s:8:\"numParts\";i:2;}}',2),('user.login','/user/login','/user/login',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/user/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\user\\Form\\UserLoginForm\";s:6:\"_title\";s:6:\"Log in\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/user/login$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/login\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/user/login\";s:8:\"numParts\";i:2;}}',2),('user.login.http','/user/login','/user/login',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/user/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:59:\"\\Drupal\\user\\Controller\\UserAuthenticationController::login\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";s:7:\"_format\";s:8:\"json|xml\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/user/login$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/login\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/user/login\";s:8:\"numParts\";i:2;}}',2),('user.login_status.http','/user/login_status','/user/login_status',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/user/login_status\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\user\\Controller\\UserAuthenticationController::loginStatus\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:8:\"json|xml\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/user/login_status$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/user/login_status\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:18:\"/user/login_status\";s:8:\"numParts\";i:2;}}',2),('user.logout','/user/logout','/user/logout',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/logout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:46:\"\\Drupal\\user\\Controller\\UserController::logout\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:24:\"_csrf_confirm_form_route\";s:19:\"user.logout.confirm\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/user/logout$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/user/logout\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/user/logout\";s:8:\"numParts\";i:2;}}',2),('user.logout.confirm','/user/logout/confirm','/user/logout/confirm',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/user/logout/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:35:\"\\Drupal\\user\\Form\\UserLogoutConfirm\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/user/logout/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/user/logout/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/user/logout/confirm\";s:8:\"numParts\";i:3;}}',3),('user.logout.http','/user/logout','/user/logout',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/logout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:60:\"\\Drupal\\user\\Controller\\UserAuthenticationController::logout\";}s:12:\"requirements\";a:3:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:7:\"_format\";s:8:\"json|xml\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/user/logout$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/user/logout\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/user/logout\";s:8:\"numParts\";i:2;}}',2),('user.multiple_cancel_confirm','/admin/people/cancel','/admin/people/cancel',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/people/cancel\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\user\\Form\\UserMultipleCancelConfirm\";s:6:\"_title\";s:11:\"Cancel user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer users\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/people/cancel$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/people/cancel\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/people/cancel\";s:8:\"numParts\";i:3;}}',3),('user.page','/user','/user',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:5:\"/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\user\\Controller\\UserController::userPage\";s:6:\"_title\";s:10:\"My account\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:12:\"{^/user$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:5:\"/user\";s:8:\"numParts\";i:1;}}',1),('user.pass','/user/password','/user/password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\user\\Form\\UserPasswordForm\";s:6:\"_title\";s:19:\"Reset your password\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/password\";s:8:\"numParts\";i:2;}}',2),('user.pass.http','/user/password','/user/password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\user\\Controller\\UserAuthenticationController::resetPassword\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:8:\"json|xml\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/password\";s:8:\"numParts\";i:2;}}',2),('user.register','/user/register','/user/register',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/register\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"user.register\";s:6:\"_title\";s:18:\"Create new account\";}s:12:\"requirements\";a:1:{s:21:\"_access_user_register\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.user.register\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/register$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/register\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/register\";s:8:\"numParts\";i:2;}}',2),('user.reset','/user/reset/{uid}/{timestamp}/{hash}','/user/reset/%/%/%',24,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/user/reset/{uid}/{timestamp}/{hash}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\user\\Controller\\UserController::resetPass\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:24;s:14:\"patternOutline\";s:17:\"/user/reset/%/%/%\";s:8:\"numParts\";i:5;}}',5),('user.reset.form','/user/reset/{uid}','/user/reset/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/user/reset/{uid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\user\\Controller\\UserController::getResetPassForm\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"uid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/user/reset/(?P<uid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"uid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:13:\"/user/reset/%\";s:8:\"numParts\";i:3;}}',3),('user.reset.login','/user/reset/{uid}/{timestamp}/{hash}/login','/user/reset/%/%/%/login',49,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/user/reset/{uid}/{timestamp}/{hash}/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\user\\Controller\\UserController::resetPassLogin\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)/login$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/login\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:49;s:14:\"patternOutline\";s:23:\"/user/reset/%/%/%/login\";s:8:\"numParts\";i:6;}}',6),('user.role.settings','/admin/people/role-settings','/admin/people/role-settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/people/role-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\user\\Form\\RoleSettingsForm\";s:6:\"_title\";s:13:\"Role settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/people/role\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/people/role-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/people/role-settings\";s:8:\"numParts\";i:3;}}',3),('user.role_add','/admin/people/roles/add','/admin/people/roles/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/admin/people/roles/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"user_role.default\";s:6:\"_title\";s:8:\"Add role\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:30:\"{^/admin/people/roles/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/admin/people/roles/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:23:\"/admin/people/roles/add\";s:8:\"numParts\";i:4;}}',4),('user.well-known.change_password','/.well-known/change-password','/.well-known/change-password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/.well-known/change-password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\user\\Controller\\UserController::userEditPage\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/\\.well\\-known/change\\-password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/.well-known/change-password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:28:\"/.well-known/change-password\";s:8:\"numParts\";i:2;}}',2),('view.block_content.page_1','/admin/content/block','/admin/content/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"block_content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"access block library\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/block\";s:8:\"numParts\";i:3;}}',3),('view.comment.page_published','/admin/content/comment','/admin/content/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/content/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:14:\"page_published\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/content/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/content/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/content/comment\";s:8:\"numParts\";i:3;}}',3),('view.comment.page_unapproved','/admin/content/comment/approval','/admin/content/comment/approval',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/content/comment/approval\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:15:\"page_unapproved\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/content/comment/approval$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/content/comment/approval\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/content/comment/approval\";s:8:\"numParts\";i:4;}}',4),('view.content.page_1','/admin/content','/admin/content',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:23:\"access content overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/content\";s:8:\"numParts\";i:2;}}',2),('view.files.page_1','/admin/content/files','/admin/content/files',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/files\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"files\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access files overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/files$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/files\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/files\";s:8:\"numParts\";i:3;}}',3),('view.files.page_2','/admin/content/files/usage/{arg_0}','/admin/content/files/usage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/content/files/usage/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"files\";s:10:\"display_id\";s:6:\"page_2\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access files overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/content/files/usage/(?P<arg_0>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/files/usage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/content/files/usage/%\";s:8:\"numParts\";i:5;}}',5),('view.frontpage.feed_1','/rss.xml','/rss.xml',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/rss.xml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:9:\"frontpage\";s:10:\"display_id\";s:6:\"feed_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"feed\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Feed\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:16:\"{^/rss\\.xml$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/rss.xml\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/rss.xml\";s:8:\"numParts\";i:1;}}',1),('view.frontpage.page_1','/node','/node',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:5:\"/node\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:9:\"frontpage\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:12:\"{^/node$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:5:\"/node\";s:8:\"numParts\";i:1;}}',1),('view.redirect.page_1','/admin/config/search/redirect','/admin/config/search/redirect',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/search/redirect\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"redirect\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"administer redirects\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/search/redirect$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/search/redirect\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/search/redirect\";s:8:\"numParts\";i:4;}}',4),('view.taxonomy_term.feed_1','/taxonomy/term/{arg_0}/feed','/taxonomy/term/%/feed',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/taxonomy/term/{arg_0}/feed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"feed_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"feed\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Feed\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/taxonomy/term/(?P<arg_0>[^/]++)/feed$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/feed\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:21:\"/taxonomy/term/%/feed\";s:8:\"numParts\";i:4;}}',4),('view.taxonomy_term.page_1','/taxonomy/term/{arg_0}','/taxonomy/term/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/taxonomy/term/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/taxonomy/term/(?P<arg_0>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/taxonomy/term/%\";s:8:\"numParts\";i:3;}}',3),('view.user_admin_people.page_1','/admin/people','/admin/people',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:17:\"user_admin_people\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:16:\"administer users\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/people\";s:8:\"numParts\";i:2;}}',2),('view.watchdog.page','/admin/reports/dblog','/admin/reports/dblog',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/reports/dblog\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"watchdog\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/reports/dblog$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/reports/dblog\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/reports/dblog\";s:8:\"numParts\";i:3;}}',3),('views.ajax','/views/ajax','/views/ajax',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/views/ajax\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:53:\"\\Drupal\\views\\Controller\\ViewAjaxController::ajaxView\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/views/ajax$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/views/ajax\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/views/ajax\";s:8:\"numParts\";i:2;}}',2),('views_ui.add','/admin/structure/views/add','/admin/structure/views/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/views/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:8:\"view.add\";s:6:\"_title\";s:8:\"Add view\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/views/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/views/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/views/add\";s:8:\"numParts\";i:4;}}',4),('views_ui.autocomplete','/admin/views/ajax/autocomplete/tag','/admin/views/ajax/autocomplete/tag',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/views/ajax/autocomplete/tag\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::autocompleteTag\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/views/ajax/autocomplete/tag$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/views/ajax/autocomplete/tag\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/views/ajax/autocomplete/tag\";s:8:\"numParts\";i:5;}}',5),('views_ui.form_add_handler','/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}','/admin/structure/views/%/add-handler/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:46:\"\\Drupal\\views_ui\\Form\\Ajax\\AddHandler::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/views/(?P<js>nojs|ajax)/add\\-handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/add-handler\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:42:\"/admin/structure/views/%/add-handler/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_analyze','/admin/structure/views/{js}/analyze/{view}/{display_id}','/admin/structure/views/%/analyze/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/views/{js}/analyze/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:43:\"\\Drupal\\views_ui\\Form\\Ajax\\Analyze::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/views/(?P<js>nojs|ajax)/analyze/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/analyze\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:36:\"/admin/structure/views/%/analyze/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_display','/admin/structure/views/{js}/display/{view}/{display_id}/{type}','/admin/structure/views/%/display/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/views/{js}/display/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:43:\"\\Drupal\\views_ui\\Form\\Ajax\\Display::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/views/(?P<js>nojs|ajax)/display/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:38:\"/admin/structure/views/%/display/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_edit_details','/admin/structure/views/{js}/edit-details/{view}/{display_id}','/admin/structure/views/%/edit-details/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/views/{js}/edit-details/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\views_ui\\Form\\Ajax\\EditDetails::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/views/(?P<js>nojs|ajax)/edit\\-details/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/edit-details\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:41:\"/admin/structure/views/%/edit-details/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_handler','/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:49:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandler::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:127:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/handler\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:40:\"/admin/structure/views/%/handler/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_handler_extra','/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler-extra/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:54:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerExtra::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-extra/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/handler-extra\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:46:\"/admin/structure/views/%/handler-extra/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_handler_group','/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler-group/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerGroup::getForm\";s:10:\"form_state\";N;}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-group/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/handler-group\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:46:\"/admin/structure/views/%/handler-group/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_rearrange','/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}','/admin/structure/views/%/rearrange/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:45:\"\\Drupal\\views_ui\\Form\\Ajax\\Rearrange::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/rearrange\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:40:\"/admin/structure/views/%/rearrange/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_rearrange_filter','/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}','/admin/structure/views/%/rearrange-filter/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Form\\Ajax\\RearrangeFilter::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange\\-filter/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/rearrange-filter\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:45:\"/admin/structure/views/%/rearrange-filter/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_reorder_displays','/admin/structure/views/{js}/reorder-displays/{view}/{display_id}','/admin/structure/views/%/reorder-displays/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/reorder-displays/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Form\\Ajax\\ReorderDisplays::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/views/(?P<js>nojs|ajax)/reorder\\-displays/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/reorder-displays\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:45:\"/admin/structure/views/%/reorder-displays/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.reports_fields','/admin/reports/fields/views-fields','/admin/reports/fields/views-fields',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/reports/fields/views-fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportFields\";s:6:\"_title\";s:13:\"Used in views\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/reports/fields/views\\-fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/reports/fields/views-fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/reports/fields/views-fields\";s:8:\"numParts\";i:4;}}',4),('views_ui.reports_plugins','/admin/reports/views-plugins','/admin/reports/views-plugins',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/views-plugins\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportPlugins\";s:6:\"_title\";s:13:\"Views plugins\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/views\\-plugins$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/views-plugins\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/reports/views-plugins\";s:8:\"numParts\";i:3;}}',3),('views_ui.settings_advanced','/admin/structure/views/settings/advanced','/admin/structure/views/settings/advanced',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/views/settings/advanced\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\views_ui\\Form\\AdvancedSettingsForm\";s:6:\"_title\";s:23:\"Advanced Views settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/views/settings/advanced$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/views/settings/advanced\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/views/settings/advanced\";s:8:\"numParts\";i:5;}}',5),('views_ui.settings_basic','/admin/structure/views/settings','/admin/structure/views/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/views/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\views_ui\\Form\\BasicSettingsForm\";s:6:\"_title\";s:14:\"Views settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/views/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/views/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/views/settings\";s:8:\"numParts\";i:4;}}',4),('webform.addons','/admin/structure/webform/addons','/admin/structure/webform/addons',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/addons\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:57:\"\\Drupal\\webform\\Controller\\WebformAddonsController::index\";s:6:\"_title\";s:17:\"Webforms: Add-ons\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/addons$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/addons\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/addons\";s:8:\"numParts\";i:4;}}',4),('webform.config','/admin/structure/webform/config','/admin/structure/webform/config',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:60:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigFormsForm\";s:6:\"_title\";s:29:\"Webforms: Forms configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/config\";s:8:\"numParts\";i:4;}}',4),('webform.config.advanced','/admin/structure/webform/config/advanced','/admin/structure/webform/config/advanced',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/advanced\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigAdvancedForm\";s:6:\"_title\";s:32:\"Webforms: Advanced configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/advanced$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/advanced\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/advanced\";s:8:\"numParts\";i:5;}}',5),('webform.config.elements','/admin/structure/webform/config/elements','/admin/structure/webform/config/elements',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/elements\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigElementsForm\";s:6:\"_title\";s:32:\"Webforms: Elements configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/elements$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/elements\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/elements\";s:8:\"numParts\";i:5;}}',5),('webform.config.exporters','/admin/structure/webform/config/exporters','/admin/structure/webform/config/exporters',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/config/exporters\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:64:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigExportersForm\";s:6:\"_title\";s:33:\"Webforms: Exporters configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/structure/webform/config/exporters$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/exporters\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/config/exporters\";s:8:\"numParts\";i:5;}}',5),('webform.config.handlers','/admin/structure/webform/config/handlers','/admin/structure/webform/config/handlers',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigHandlersForm\";s:6:\"_title\";s:32:\"Webforms: Handlers configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/handlers$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/handlers\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/handlers\";s:8:\"numParts\";i:5;}}',5),('webform.config.libraries','/admin/structure/webform/config/libraries','/admin/structure/webform/config/libraries',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/config/libraries\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:64:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigLibrariesForm\";s:6:\"_title\";s:33:\"Webforms: Libraries configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/structure/webform/config/libraries$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/libraries\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/config/libraries\";s:8:\"numParts\";i:5;}}',5),('webform.config.repair','/admin/structure/webform/config/repair','/admin/structure/webform/config/repair',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/structure/webform/config/repair\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:61:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigRepairForm\";s:6:\"_title\";s:38:\"Webforms: Repair webform configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/structure/webform/config/repair$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/structure/webform/config/repair\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:38:\"/admin/structure/webform/config/repair\";s:8:\"numParts\";i:5;}}',5),('webform.config.submissions','/admin/structure/webform/config/submissions','/admin/structure/webform/config/submissions',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/structure/webform/config/submissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:66:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigSubmissionsForm\";s:6:\"_title\";s:35:\"Webforms: Submissions configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/structure/webform/config/submissions$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/config/submissions\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/config/submissions\";s:8:\"numParts\";i:5;}}',5),('webform.config.variants','/admin/structure/webform/config/variants','/admin/structure/webform/config/variants',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigVariantsForm\";s:6:\"_title\";s:32:\"Webforms: Variants configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/variants$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/variants\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/variants\";s:8:\"numParts\";i:5;}}',5),('webform.element.autocomplete','/webform/{webform}/autocomplete/{key}','/webform/%/autocomplete/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/webform/{webform}/autocomplete/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformElementController::autocomplete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform.submission_create\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/webform/(?P<webform>[^/]++)/autocomplete/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/autocomplete\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:25:\"/webform/%/autocomplete/%\";s:8:\"numParts\";i:4;}}',4),('webform.element.message.close','/webform/message/close/{storage}/{id}','/webform/message/close/%/%',28,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/webform/message/close/{storage}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\webform\\Controller\\WebformElementController::close\";s:8:\"_storage\";s:4:\"user\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"storage\";i:1;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/webform/message/close/(?P<storage>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"storage\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/webform/message/close\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"storage\";i:1;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:26:\"/webform/message/close/%/%\";s:8:\"numParts\";i:5;}}',5),('webform.help','/admin/structure/webform/help','/admin/structure/webform/help',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/webform/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\webform\\Controller\\WebformHelpController::index\";s:6:\"_title\";s:14:\"Webforms: Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access webform help\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/webform/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/webform/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/webform/help\";s:8:\"numParts\";i:4;}}',4),('webform.help.video','/admin/help/webform/video/{id}','/admin/help/webform/video/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/help/webform/video/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:41:\"\\Drupal\\webform\\Form\\WebformHelpVideoForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/help/webform/video/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/help/webform/video\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:27:\"/admin/help/webform/video/%\";s:8:\"numParts\";i:5;}}',5),('webform.reports_plugins.elements','/admin/reports/webform-plugins/elements','/admin/reports/webform-plugins/elements',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/elements\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginElementController::index\";s:6:\"_title\";s:25:\"Webform plugins: Elements\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/elements$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/elements\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/elements\";s:8:\"numParts\";i:4;}}',4),('webform.reports_plugins.elements.test','/admin/reports/webform-plugins/elements/{type}/test','/admin/reports/webform-plugins/elements/%/test',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/reports/webform-plugins/elements/{type}/test\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\webform_ui\\Form\\WebformUiElementTestForm\";s:6:\"_title\";s:12:\"Test element\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/reports/webform\\-plugins/elements/(?P<type>[^/]++)/test$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/test\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/elements\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/reports/webform-plugins/elements/%/test\";s:8:\"numParts\";i:6;}}',6),('webform.reports_plugins.exporters','/admin/reports/webform-plugins/exporters','/admin/reports/webform-plugins/exporters',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/reports/webform-plugins/exporters\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformPluginExporterController::index\";s:6:\"_title\";s:26:\"Webform plugins: Exporters\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/reports/webform\\-plugins/exporters$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/reports/webform-plugins/exporters\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:40:\"/admin/reports/webform-plugins/exporters\";s:8:\"numParts\";i:4;}}',4),('webform.reports_plugins.handlers','/admin/reports/webform-plugins/handlers','/admin/reports/webform-plugins/handlers',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginHandlerController::index\";s:6:\"_title\";s:25:\"Webform plugins: Handlers\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/handlers$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/handlers\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/handlers\";s:8:\"numParts\";i:4;}}',4),('webform.reports_plugins.variants','/admin/reports/webform-plugins/variants','/admin/reports/webform-plugins/variants',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginVariantController::index\";s:6:\"_title\";s:25:\"Webform plugins: Variants\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/variants$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/variants\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/variants\";s:8:\"numParts\";i:4;}}',4),('webform_rest.settings','/admin/webform_rest/settings','/admin/webform_rest/settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/webform_rest/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:41:\"\\Drupal\\webform_rest\\Form\\WebformRestForm\";s:6:\"_title\";s:21:\"Webform Rest Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"access webform rest settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/webform_rest/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/webform_rest/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/webform_rest/settings\";s:8:\"numParts\";i:3;}}',3),('webform_schema.export','/admin/structure/webform/manage/{webform}/schema/export','/admin/structure/webform/manage/%/schema/export',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/schema/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:64:\"\\Drupal\\webform_schema\\Controller\\WebformSchemaController::index\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:21:\"access webform schema\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/schema/export$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/schema/export\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/schema/export\";s:8:\"numParts\";i:7;}}',7),('webform_submission.multiple_delete_confirm','/admin/structure/webform/results/delete','/admin/structure/webform/results/delete',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/webform/results/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\webform\\Form\\WebformSubmissionDeleteMultipleForm\";s:14:\"entity_type_id\";s:18:\"webform_submission\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:18:\"webform_submission\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/structure/webform/results/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/results/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/webform/results/delete\";s:8:\"numParts\";i:5;}}',5);
/*!40000 ALTER TABLE `router` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `semaphore`
--

DROP TABLE IF EXISTS `semaphore`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `semaphore` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique name.',
  `value` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A value for the semaphore.',
  `expire` double NOT NULL COMMENT 'A Unix timestamp with microseconds indicating when the semaphore should expire.',
  PRIMARY KEY (`name`),
  KEY `value` (`value`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Table for holding semaphores, locks, flags, etc. that…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `semaphore`
--

LOCK TABLES `semaphore` WRITE;
/*!40000 ALTER TABLE `semaphore` DISABLE KEYS */;
/*!40000 ALTER TABLE `semaphore` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sequences`
--

DROP TABLE IF EXISTS `sequences`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `sequences` (
  `value` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The value of the sequence.',
  PRIMARY KEY (`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores IDs.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sequences`
--

LOCK TABLES `sequences` WRITE;
/*!40000 ALTER TABLE `sequences` DISABLE KEYS */;
/*!40000 ALTER TABLE `sequences` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sessions`
--

DROP TABLE IF EXISTS `sessions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `sessions` (
  `uid` int unsigned NOT NULL COMMENT 'The "users".uid corresponding to a session, or 0 for anonymous user.',
  `sid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A session ID (hashed). The value is generated by Drupal''s session handlers.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The IP address that last used this session ID (sid).',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when this session last requested a page. Old records are purged by PHP automatically.',
  `session` longblob COMMENT 'The serialized contents of the user''s session, an array of name/value pairs that persists across page requests by this session ID. Drupal loads the user''s session from here   at the start of each request and saves it at the end.',
  PRIMARY KEY (`sid`),
  KEY `timestamp` (`timestamp`),
  KEY `uid` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Drupal''s session handlers read and write into the sessions…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sessions`
--

LOCK TABLES `sessions` WRITE;
/*!40000 ALTER TABLE `sessions` DISABLE KEYS */;
/*!40000 ALTER TABLE `sessions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut`
--

DROP TABLE IF EXISTS `shortcut`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `shortcut_field__uuid__value` (`uuid`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for shortcut entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut`
--

LOCK TABLES `shortcut` WRITE;
/*!40000 ALTER TABLE `shortcut` DISABLE KEYS */;
INSERT INTO `shortcut` VALUES (1,'default','9f9facf6-0ca2-4505-bc2e-1687f4a7481e','en'),(2,'default','848e6c73-4d4a-4f74-a1bb-66b54a579984','en');
/*!40000 ALTER TABLE `shortcut` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut_field_data`
--

DROP TABLE IF EXISTS `shortcut_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut_field_data` (
  `id` int unsigned NOT NULL,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `shortcut__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`),
  KEY `shortcut_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for shortcut entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut_field_data`
--

LOCK TABLES `shortcut_field_data` WRITE;
/*!40000 ALTER TABLE `shortcut_field_data` DISABLE KEYS */;
INSERT INTO `shortcut_field_data` VALUES (1,'default','en','Add content',-20,'internal:/node/add',NULL,_binary 'a:0:{}',1),(2,'default','en','All content',-19,'internal:/admin/content',NULL,_binary 'a:0:{}',1);
/*!40000 ALTER TABLE `shortcut_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut_set_users`
--

DROP TABLE IF EXISTS `shortcut_set_users`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut_set_users` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid for this set.',
  `set_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "shortcut_set".set_name that will be displayed for this user.',
  PRIMARY KEY (`uid`),
  KEY `set_name` (`set_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maps users to shortcut sets.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut_set_users`
--

LOCK TABLES `shortcut_set_users` WRITE;
/*!40000 ALTER TABLE `shortcut_set_users` DISABLE KEYS */;
/*!40000 ALTER TABLE `shortcut_set_users` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `simple_sitemap`
--

DROP TABLE IF EXISTS `simple_sitemap`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `simple_sitemap` (
  `id` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sitemap chunk unique identifier.',
  `type` varchar(32) NOT NULL DEFAULT '' COMMENT 'Type of sitemap this chunk belongs to.',
  `delta` int unsigned NOT NULL COMMENT 'Delta of the chunk within the type scope.',
  `sitemap_string` longtext NOT NULL COMMENT 'XML sitemap chunk string.',
  `sitemap_created` int unsigned NOT NULL DEFAULT '0' COMMENT 'Timestamp of sitemap chunk generation.',
  `status` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Flag indicating the publishing status of the chunk.',
  `link_count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The number of links in the sitemap.',
  PRIMARY KEY (`id`),
  KEY `type_status_delta` (`type`,`status`,`delta`)
) ENGINE=InnoDB AUTO_INCREMENT=18 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Holds XML sitemaps as strings for quick retrieval.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `simple_sitemap`
--

LOCK TABLES `simple_sitemap` WRITE;
/*!40000 ALTER TABLE `simple_sitemap` DISABLE KEYS */;
INSERT INTO `simple_sitemap` VALUES (17,'default',1,'<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<?xml-stylesheet type=\"text/xsl\" href=\"/sitemap_generator/default/sitemap.xsl\"?>\n<!--Generated by the Simple XML Sitemap Drupal module: https://drupal.org/project/simple_sitemap.-->\n<urlset xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\" xmlns:image=\"http://www.google.com/schemas/sitemap-image/1.1\">\n <url>\n  <loc>http://jsonapi.local/</loc>\n  <lastmod>2025-04-02T22:36:32+02:00</lastmod>\n  <changefreq>daily</changefreq>\n  <priority>1.0</priority>\n </url>\n</urlset>\n',1743931974,1,1);
/*!40000 ALTER TABLE `simple_sitemap` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `simple_sitemap_entity_overrides`
--

DROP TABLE IF EXISTS `simple_sitemap_entity_overrides`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `simple_sitemap_entity_overrides` (
  `id` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Override unique identifier.',
  `type` varchar(50) NOT NULL COMMENT 'Type of sitemap this override belongs to.',
  `entity_type` varchar(32) NOT NULL COMMENT 'Entity type of the overriding entity.',
  `entity_id` varchar(32) NOT NULL COMMENT 'ID of the overriding entity.',
  `inclusion_settings` blob COMMENT 'Setting for the overriding entity.',
  PRIMARY KEY (`id`),
  KEY `entity_key` (`type`,`entity_type`,`entity_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Holds sitemap settings overridden by entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `simple_sitemap_entity_overrides`
--

LOCK TABLES `simple_sitemap_entity_overrides` WRITE;
/*!40000 ALTER TABLE `simple_sitemap_entity_overrides` DISABLE KEYS */;
/*!40000 ALTER TABLE `simple_sitemap_entity_overrides` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_index`
--

DROP TABLE IF EXISTS `taxonomy_index`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_index` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid this record tracks.',
  `tid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The term ID.',
  `status` int NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether the node is published (visible to non-administrators).',
  `sticky` tinyint DEFAULT '0' COMMENT 'Boolean indicating whether the node is sticky.',
  `created` int NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was created.',
  PRIMARY KEY (`nid`,`tid`),
  KEY `term_node` (`tid`,`status`,`sticky`,`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maintains denormalized information about node/term…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_index`
--

LOCK TABLES `taxonomy_index` WRITE;
/*!40000 ALTER TABLE `taxonomy_index` DISABLE KEYS */;
INSERT INTO `taxonomy_index` VALUES (1,1,1,0,1742136181),(2,1,1,0,1742136412),(2,2,1,0,1742136412),(3,3,1,0,1742153852);
/*!40000 ALTER TABLE `taxonomy_index` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term__parent`
--

DROP TABLE IF EXISTS `taxonomy_term__parent`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`),
  KEY `bundle_delta_target_id` (`bundle`,`delta`,`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for taxonomy_term field parent.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term__parent`
--

LOCK TABLES `taxonomy_term__parent` WRITE;
/*!40000 ALTER TABLE `taxonomy_term__parent` DISABLE KEYS */;
INSERT INTO `taxonomy_term__parent` VALUES ('tags',0,1,1,'en',0,0),('tags',0,2,2,'en',0,0),('tags',0,3,3,'en',0,0);
/*!40000 ALTER TABLE `taxonomy_term__parent` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_data`
--

DROP TABLE IF EXISTS `taxonomy_term_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_data` (
  `tid` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`tid`),
  UNIQUE KEY `taxonomy_term_field__uuid__value` (`uuid`),
  UNIQUE KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__vid__target_id` (`vid`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_data`
--

LOCK TABLES `taxonomy_term_data` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_data` DISABLE KEYS */;
INSERT INTO `taxonomy_term_data` VALUES (1,1,'tags','93b951da-d894-4d0f-a4a0-a7845e9e91d3','en'),(2,2,'tags','f203b178-3672-4312-b974-4fb5ea8b35cb','en'),(3,3,'tags','d7ce0282-1edf-45e4-a4ab-d775b6fca04c','en');
/*!40000 ALTER TABLE `taxonomy_term_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_field_data`
--

DROP TABLE IF EXISTS `taxonomy_term_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_field_data` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) NOT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `weight` int NOT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  `rh_action` varchar(255) DEFAULT NULL,
  `rh_redirect` varchar(255) DEFAULT NULL,
  `rh_redirect_response` int DEFAULT NULL,
  `rh_redirect_fallback_action` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`tid`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__name` (`name`(191)),
  KEY `taxonomy_term__status_vid` (`status`,`vid`,`tid`),
  KEY `taxonomy_term__tree` (`vid`,`weight`,`name`(191)),
  KEY `taxonomy_term__vid_name` (`vid`,`name`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_field_data`
--

LOCK TABLES `taxonomy_term_field_data` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_field_data` DISABLE KEYS */;
INSERT INTO `taxonomy_term_field_data` VALUES (1,1,'tags','en',1,'JSON:API',NULL,NULL,0,1742153626,1,1,'bundle_default',NULL,301,'bundle_default'),(2,2,'tags','en',1,'Drupal',NULL,NULL,0,1742136512,1,1,NULL,NULL,NULL,NULL),(3,3,'tags','en',1,'Javacript',NULL,NULL,0,1742154261,1,1,NULL,NULL,NULL,NULL);
/*!40000 ALTER TABLE `taxonomy_term_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_field_revision`
--

DROP TABLE IF EXISTS `taxonomy_term_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_field_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) DEFAULT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term_field__description__format` (`description__format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_field_revision`
--

LOCK TABLES `taxonomy_term_field_revision` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_field_revision` DISABLE KEYS */;
INSERT INTO `taxonomy_term_field_revision` VALUES (1,1,'en',1,'JSON:API',NULL,NULL,1742153626,1,1),(2,2,'en',1,'Drupal',NULL,NULL,1742136512,1,1),(3,3,'en',1,'Javacript',NULL,NULL,1742154261,1,1);
/*!40000 ALTER TABLE `taxonomy_term_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_revision`
--

DROP TABLE IF EXISTS `taxonomy_term_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `taxonomy_term__tid` (`tid`),
  KEY `taxonomy_term_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_revision`
--

LOCK TABLES `taxonomy_term_revision` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_revision` DISABLE KEYS */;
INSERT INTO `taxonomy_term_revision` VALUES (1,1,'en',NULL,1742136377,NULL,1),(2,2,'en',NULL,1742136512,NULL,1),(3,3,'en',NULL,1742154261,NULL,1);
/*!40000 ALTER TABLE `taxonomy_term_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_revision__parent`
--

DROP TABLE IF EXISTS `taxonomy_term_revision__parent`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_revision__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for taxonomy_term field parent.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_revision__parent`
--

LOCK TABLES `taxonomy_term_revision__parent` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_revision__parent` DISABLE KEYS */;
INSERT INTO `taxonomy_term_revision__parent` VALUES ('tags',0,1,1,'en',0,0),('tags',0,2,2,'en',0,0),('tags',0,3,3,'en',0,0);
/*!40000 ALTER TABLE `taxonomy_term_revision__parent` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `user__roles`
--

DROP TABLE IF EXISTS `user__roles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `user__roles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `roles_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `roles_target_id` (`roles_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for user field roles.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `user__roles`
--

LOCK TABLES `user__roles` WRITE;
/*!40000 ALTER TABLE `user__roles` DISABLE KEYS */;
INSERT INTO `user__roles` VALUES ('user',0,1,1,'en',0,'administrator');
/*!40000 ALTER TABLE `user__roles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `user__user_picture`
--

DROP TABLE IF EXISTS `user__user_picture`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `user__user_picture` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `user_picture_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `user_picture_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `user_picture_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `user_picture_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `user_picture_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `user_picture_target_id` (`user_picture_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for user field user_picture.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `user__user_picture`
--

LOCK TABLES `user__user_picture` WRITE;
/*!40000 ALTER TABLE `user__user_picture` DISABLE KEYS */;
/*!40000 ALTER TABLE `user__user_picture` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users`
--

DROP TABLE IF EXISTS `users`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users` (
  `uid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`uid`),
  UNIQUE KEY `user_field__uuid__value` (`uuid`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for user entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users`
--

LOCK TABLES `users` WRITE;
/*!40000 ALTER TABLE `users` DISABLE KEYS */;
INSERT INTO `users` VALUES (0,'f2a9814d-d6f8-4f27-89f7-b668408b76ee','en'),(1,'fea7f633-7fce-4d7b-ae76-3fd76124ad69','en');
/*!40000 ALTER TABLE `users` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users_data`
--

DROP TABLE IF EXISTS `users_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users_data` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid this record affects.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module declaring the variable.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The identifier of the data.',
  `value` longblob COMMENT 'The value.',
  `serialized` tinyint unsigned DEFAULT '0' COMMENT 'Whether value is serialized.',
  PRIMARY KEY (`uid`,`module`,`name`),
  KEY `module` (`module`),
  KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores module data as key/value pairs per user.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users_data`
--

LOCK TABLES `users_data` WRITE;
/*!40000 ALTER TABLE `users_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `users_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users_field_data`
--

DROP TABLE IF EXISTS `users_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users_field_data` (
  `uid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `preferred_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `preferred_admin_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `name` varchar(60) NOT NULL,
  `pass` varchar(255) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `timezone` varchar(32) DEFAULT NULL,
  `status` tinyint DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `access` int NOT NULL,
  `login` int DEFAULT NULL,
  `init` varchar(254) DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`uid`,`langcode`),
  UNIQUE KEY `user__name` (`name`,`langcode`),
  KEY `user__id__default_langcode__langcode` (`uid`,`default_langcode`,`langcode`),
  KEY `user_field__mail` (`mail`(191)),
  KEY `user_field__created` (`created`),
  KEY `user_field__access` (`access`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for user entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users_field_data`
--

LOCK TABLES `users_field_data` WRITE;
/*!40000 ALTER TABLE `users_field_data` DISABLE KEYS */;
INSERT INTO `users_field_data` VALUES (0,'en','en',NULL,'',NULL,NULL,NULL,0,1742072755,1742072755,0,0,NULL,1),(1,'en','en',NULL,'admin','$2y$10$tnNBt1HCIffHlIkcQPQkdu92HLUu/KpiDpDNg2Mc8xTP4hMWrVXgi','admin@example.com','Europe/Belgrade',1,1742072755,1742073849,1743937126,1742073849,'admin@example.com',1);
/*!40000 ALTER TABLE `users_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `watchdog`
--

DROP TABLE IF EXISTS `watchdog`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `watchdog` (
  `wid` bigint NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique watchdog event ID.',
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid of the user who triggered the event.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Type of log message, for example "user" or "page not found."',
  `message` longtext NOT NULL COMMENT 'Text of log message to be passed into the t() function.',
  `variables` longblob NOT NULL COMMENT 'Serialized array of variables that match the message string and that is passed into the t() function.',
  `severity` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'The severity level of the event. ranges from 0 (Emergency) to 7 (Debug)',
  `link` text COMMENT 'Link to view the result of the event.',
  `location` text NOT NULL COMMENT 'URL of the origin of the event.',
  `referer` text COMMENT 'URL of referring page.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Hostname of the user who triggered the event.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'Unix timestamp of when event occurred.',
  PRIMARY KEY (`wid`),
  KEY `type` (`type`),
  KEY `uid` (`uid`),
  KEY `severity` (`severity`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Table that contains logs of all system events.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `watchdog`
--

LOCK TABLES `watchdog` WRITE;
/*!40000 ALTER TABLE `watchdog` DISABLE KEYS */;
/*!40000 ALTER TABLE `watchdog` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform`
--

DROP TABLE IF EXISTS `webform`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform` (
  `webform_id` varchar(32) NOT NULL COMMENT 'The webform id.',
  `next_serial` int unsigned NOT NULL DEFAULT '1' COMMENT 'The serial number to give to the next submission to this webform.',
  PRIMARY KEY (`webform_id`,`next_serial`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores all webform data.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform`
--

LOCK TABLES `webform` WRITE;
/*!40000 ALTER TABLE `webform` DISABLE KEYS */;
INSERT INTO `webform` VALUES ('contact',4);
/*!40000 ALTER TABLE `webform` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform_access_group_admin`
--

DROP TABLE IF EXISTS `webform_access_group_admin`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform_access_group_admin` (
  `group_id` varchar(32) NOT NULL COMMENT 'The webform access group id.',
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The admin user id.',
  PRIMARY KEY (`group_id`,`uid`),
  KEY `indexing` (`group_id`,`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores admin associated with a webform access group.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform_access_group_admin`
--

LOCK TABLES `webform_access_group_admin` WRITE;
/*!40000 ALTER TABLE `webform_access_group_admin` DISABLE KEYS */;
/*!40000 ALTER TABLE `webform_access_group_admin` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform_access_group_entity`
--

DROP TABLE IF EXISTS `webform_access_group_entity`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform_access_group_entity` (
  `group_id` varchar(32) NOT NULL COMMENT 'The webform access group id.',
  `entity_type` varchar(32) NOT NULL COMMENT 'The source entity type.',
  `entity_id` varchar(32) NOT NULL COMMENT 'The source entity id.',
  `field_name` varchar(32) NOT NULL COMMENT 'The webform field name.',
  `webform_id` varchar(32) NOT NULL COMMENT 'The webform id.',
  PRIMARY KEY (`group_id`,`webform_id`,`entity_type`,`entity_id`,`field_name`),
  KEY `source_entity` (`entity_type`,`entity_id`,`field_name`,`webform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores users associated with a webform access group.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform_access_group_entity`
--

LOCK TABLES `webform_access_group_entity` WRITE;
/*!40000 ALTER TABLE `webform_access_group_entity` DISABLE KEYS */;
/*!40000 ALTER TABLE `webform_access_group_entity` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform_access_group_user`
--

DROP TABLE IF EXISTS `webform_access_group_user`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform_access_group_user` (
  `group_id` varchar(32) NOT NULL COMMENT 'The webform access group id.',
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The user id.',
  PRIMARY KEY (`group_id`,`uid`),
  KEY `indexing` (`group_id`,`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores users associated with a webform access group.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform_access_group_user`
--

LOCK TABLES `webform_access_group_user` WRITE;
/*!40000 ALTER TABLE `webform_access_group_user` DISABLE KEYS */;
/*!40000 ALTER TABLE `webform_access_group_user` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform_submission`
--

DROP TABLE IF EXISTS `webform_submission`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform_submission` (
  `sid` int NOT NULL AUTO_INCREMENT,
  `webform_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `serial` int DEFAULT NULL,
  `token` varchar(255) DEFAULT NULL,
  `uri` varchar(2000) DEFAULT NULL,
  `created` int DEFAULT NULL,
  `completed` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `in_draft` tinyint DEFAULT NULL,
  `current_page` varchar(128) DEFAULT NULL,
  `remote_addr` varchar(128) DEFAULT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `entity_id` varchar(255) DEFAULT NULL,
  `locked` tinyint DEFAULT NULL,
  `sticky` tinyint DEFAULT NULL,
  `notes` longtext,
  PRIMARY KEY (`sid`),
  UNIQUE KEY `webform_submission_field__uuid__value` (`uuid`),
  KEY `webform_submission_field__webform_id__target_id` (`webform_id`),
  KEY `webform_submission_field__uid__target_id` (`uid`),
  KEY `webform_submission_field__token` (`token`(191))
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for webform_submission entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform_submission`
--

LOCK TABLES `webform_submission` WRITE;
/*!40000 ALTER TABLE `webform_submission` DISABLE KEYS */;
INSERT INTO `webform_submission` VALUES (1,'contact','3126f3dc-0c02-4232-888b-9f05e709201c','en',1,'zGyO9K63eDbKhsq_NxuxdL43T9VO1CZaoPig-QKyVEA',NULL,1743405995,1743405995,1743405995,0,NULL,'127.0.0.1',0,NULL,NULL,0,0,NULL),(2,'contact','5020124a-6135-4966-8b6f-69ac0af10ace','en',2,'0R9pUCd6zd0pfDkW6lMxhtd8qW2hMIBCFlAsUm6QCfI','http://localhost:3000/',1743406360,1743406360,1743406360,0,NULL,'127.0.0.1',0,NULL,NULL,0,0,NULL),(3,'contact','fec0a426-5f80-413f-8b4d-6cb89bcc761b','en',3,'R7EVjd6dD3KXIB823qej88vk8yKjVoHp5wd7ZU0kjEI','http://localhost:3000/',1743406526,1743406526,1743406526,0,NULL,'127.0.0.1',0,NULL,NULL,0,0,NULL);
/*!40000 ALTER TABLE `webform_submission` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `webform_submission_data`
--

DROP TABLE IF EXISTS `webform_submission_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `webform_submission_data` (
  `webform_id` varchar(32) NOT NULL COMMENT 'The webform id.',
  `sid` int unsigned NOT NULL COMMENT 'The unique identifier for this submission.',
  `name` varchar(128) NOT NULL COMMENT 'The name of the element.',
  `property` varchar(128) NOT NULL DEFAULT '' COMMENT 'The property of the element''s value.',
  `delta` int unsigned NOT NULL DEFAULT '0' COMMENT 'The delta of the element''s value.',
  `value` mediumtext NOT NULL COMMENT 'The element''s value.',
  PRIMARY KEY (`sid`,`name`,`property`,`delta`),
  KEY `webform_id` (`webform_id`),
  KEY `sid_webform_id` (`sid`,`webform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores all submitted data for webform submissions.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `webform_submission_data`
--

LOCK TABLES `webform_submission_data` WRITE;
/*!40000 ALTER TABLE `webform_submission_data` DISABLE KEYS */;
INSERT INTO `webform_submission_data` VALUES ('contact',1,'email','',0,'levmyshkin89@gmail.com'),('contact',1,'message','',0,'asdf'),('contact',1,'name','',0,'Ivan Abramenko'),('contact',1,'subject','',0,'Test'),('contact',2,'email','',0,'dsaf@sadf.com'),('contact',2,'message','',0,'asdf'),('contact',2,'name','',0,'asdf'),('contact',2,'subject','',0,'asdf'),('contact',3,'email','',0,'asdf@asdf.com'),('contact',3,'message','',0,'asdf\n'),('contact',3,'name','',0,'asdf'),('contact',3,'subject','',0,'asdfa');
/*!40000 ALTER TABLE `webform_submission_data` ENABLE KEYS */;
UNLOCK TABLES;
